@@ -13,6 +13,7 @@ OC.L10N.register(
     "Enable" : "Habilitar",
     "High contrast theme" : "Tema de alto contraste",
     "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un tema de alto contraste para facilitar su navegación. Se reducirá la calidad visual pero se aumentará la claridad.",
-    "Dark theme (beta)" : "Tema oscuro (beta)"
+    "Dark theme (beta)" : "Tema oscuro (beta)",
+    "Provides multiple accessibilities options to ease your use of nextcloud" : "Proporciona múltiples opciones de accesibilidad para facilitar su uso de nextcloud"
 },
 "nplurals=2; plural=(n != 1);");
