@@ -1,22 +1,7 @@
 OC.L10N.register(
     "comments",
     {
-    "Edit comment" : "עריכת תגובה",
-    "Delete comment" : "מחיקת תגובה",
-    "New comment …" : "תגובה חדשה",
-    "Post" : "פרסום",
-    "Cancel" : "ביטול",
-    "[Deleted user]" : "[משתמשים מוסרים]",
     "Comments" : "תגובות",
-    "No comments yet, start the conversation!" : "אין תגובות עדיין, בואו נתחיל לקשקש!",
-    "More comments …" : "תגובות נוספות…",
-    "Save" : "שמירה",
-    "Allowed characters {count} of {max}" : "תווים מותרים {count} מתוך {max}",
-    "Error occurred while retrieving comment with ID {id}" : "אירעה שגיאה בעת קבלת התגובה עם המזהה {id}",
-    "Error occurred while updating comment with id {id}" : "שגיאה אירעה כאשר עודכנה תגובה עם מספר זיהוי {id}",
-    "Error occurred while posting comment" : "אירעה שגיאה בזמן פרסום תגובה",
-    "_%n unread comment_::_%n unread comments_" : ["תגובה אחת שלא נקראה","%n תגובות שלא נקראו","%n תגובות שלא נקראו","%n תגובות שלא נקראו"],
-    "Comment" : "תגובה",
     "You commented" : "הערות שלך",
     "%1$s commented" : "התקבלו תגובות %1$s",
     "{author} commented" : "התקבלה תגובה מאת {author}",
@@ -28,7 +13,20 @@ OC.L10N.register(
     "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "אוזכרת ב־„{file}”, בתגובה של משתמש שנמחק בינתיים.",
     "{user} mentioned you in a comment on “{file}”" : "אוזכרת על ידי „{user}” בתגובה על „{file}”",
     "Files app plugin to add comments to files" : "תוסף ליישומון הקבצים כדי להוסיף הערות על קבצים",
-    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "אוזכרת ב־„%s”, בתגובה על ידי משתמש שנמחק בינתיים.",
-    "%1$s mentioned you in a comment on “%2$s”" : "אוזכרת על ידי %1$s בתגובה על „%2$s”"
+    "Edit comment" : "עריכת תגובה",
+    "Delete comment" : "מחיקת תגובה",
+    "New comment …" : "תגובה חדשה",
+    "Post" : "פרסום",
+    "Cancel" : "ביטול",
+    "[Deleted user]" : "[משתמשים מוסרים]",
+    "No comments yet, start the conversation!" : "אין תגובות עדיין, בואו נתחיל לקשקש!",
+    "More comments …" : "תגובות נוספות…",
+    "Save" : "שמירה",
+    "Allowed characters {count} of {max}" : "תווים מותרים {count} מתוך {max}",
+    "Error occurred while retrieving comment with ID {id}" : "אירעה שגיאה בעת קבלת התגובה עם המזהה {id}",
+    "Error occurred while updating comment with id {id}" : "שגיאה אירעה כאשר עודכנה תגובה עם מספר זיהוי {id}",
+    "Error occurred while posting comment" : "אירעה שגיאה בזמן פרסום תגובה",
+    "_%n unread comment_::_%n unread comments_" : ["תגובה אחת שלא נקראה","%n תגובות שלא נקראו","%n תגובות שלא נקראו","%n תגובות שלא נקראו"],
+    "Comment" : "תגובה"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
