@@ -44,11 +44,17 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "Промяна на календарно <strong>събитие</strong>",
     "A calendar <strong>todo</strong> was modified" : "Промяна на календарна <strong>задача</strong>",
     "Contact birthdays" : "Рождени дни на контакти",
+    "%s (%s ago)" : "%s (преди %s)",
+    "Hello %s," : "Здравейте %s,",
+    "Link:" : "Връзка:",
     "Accept" : "Приемане",
     "Contacts" : "Контакти",
+    "WebDAV" : "WebDAV",
     "Technical details" : "Технически детайли",
     "Remote Address: %s" : "Отдалечен адрес: %s",
     "Request ID: %s" : "ID на заявката: %s",
+    "Tentative" : "Несигурно",
+    "Save" : "Запазване",
     "Send invitations to attendees" : "Изпращане на покани до участниците",
     "Automatically generate a birthday calendar" : "Автоматично генериране на календар с рождени дни.",
     "Birthday calendars will be generated by a background job." : "Календарите с рождени дни се генерират от background job.",
