@@ -16,7 +16,7 @@ OC.L10N.register(
     "You shared calendar {calendar} with {user}" : "S uživatelem {user} jste začali sdílet kalendář {calendar}",
     "{actor} shared calendar {calendar} with {user}" : "{actor} začal(a) sdílet kalendář {calendar} s uživatelem {user}",
     "{actor} unshared calendar {calendar} from you" : "{actor} s vámi přestal(a) sdílet kalendář {calendar}",
-    "You unshared calendar {calendar} from {user}" : "S uživatelem {user} jste přestal(a) sdílet kalendář {calendar}",
+    "You unshared calendar {calendar} from {user}" : "S uživatelem {user} jste přestali sdílet kalendář {calendar}",
     "{actor} unshared calendar {calendar} from {user}" : "{actor} přestal(a) sdílet kalendář {calendar} s uživatelem {user}",
     "{actor} unshared calendar {calendar} from themselves" : "{actor} přestal sdílet kalendář {calendar} sám se sebou",
     "You shared calendar {calendar} with group {group}" : "Se skupinou {group} jste začali sdílet kalendář {calendar}",
@@ -24,26 +24,26 @@ OC.L10N.register(
     "You unshared calendar {calendar} from group {group}" : "Zrušili jste sdílení kalendáře {calendar} skupině {group}",
     "{actor} unshared calendar {calendar} from group {group}" : "{actor} přestal(a) sdílet kalendář {calendar} se skupinou {group}",
     "{actor} created event {event} in calendar {calendar}" : "{actor} vytvořil(a) událost {event} v kalendáři {calendar}",
-    "You created event {event} in calendar {calendar}" : "V kalendáři {calendar} jste vytvořil(a) událost {event}",
+    "You created event {event} in calendar {calendar}" : "V kalendáři {calendar} jste vytvořili událost {event}",
     "{actor} deleted event {event} from calendar {calendar}" : "{actor} z kalendáře {calendar} smazal(a) událost {event}",
-    "You deleted event {event} from calendar {calendar}" : "Smazal(a) jste událost {event} z kalendáře {calendar}",
+    "You deleted event {event} from calendar {calendar}" : "Smazali jste událost {event} z kalendáře {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} aktualizoval(a) událost {event} v kalendáři {calendar}",
-    "You updated event {event} in calendar {calendar}" : "Aktualizoval(a) jste událost {event} v kalendáři {calendar}",
+    "You updated event {event} in calendar {calendar}" : "Aktualizovali jste událost {event} v kalendáři {calendar}",
     "Busy" : "Zaneprázdněn(a)",
     "{actor} created todo {todo} in list {calendar}" : "{actor} vytvořil(a) v seznamu {calendar} vytvořila úkol {todo}",
-    "You created todo {todo} in list {calendar}" : "V seznamu {calendar} jste vytvořil(a) úkol {todo}",
+    "You created todo {todo} in list {calendar}" : "V seznamu {calendar} jste vytvořili úkol {todo}",
     "{actor} deleted todo {todo} from list {calendar}" : "{actor} smazal(a) úkol {todo} ze seznamu {calendar}",
-    "You deleted todo {todo} from list {calendar}" : "Ze seznamu {calendar} jste smazal(a) úkol {todo}",
+    "You deleted todo {todo} from list {calendar}" : "Ze seznamu {calendar} jste smazali úkol {todo}",
     "{actor} updated todo {todo} in list {calendar}" : "{actor} aktualizoval(a) úkol {todo} v seznamu {calendar}",
-    "You updated todo {todo} in list {calendar}" : "Aktualizoval(a) jste úkol {todo} v seznamu {calendar}",
+    "You updated todo {todo} in list {calendar}" : "Aktualizovali jste úkol {todo} v seznamu {calendar}",
     "{actor} solved todo {todo} in list {calendar}" : "{actor} vyřešil(a) úkol {todo} v seznamu {calendar}",
-    "You solved todo {todo} in list {calendar}" : "Vyřešil(a) jste úkol {todo} v seznamu {calendar}",
+    "You solved todo {todo} in list {calendar}" : "Vyřešili jste úkol {todo} v seznamu {calendar}",
     "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otevřel(a) úkol {todo} v seznamu {calendar}",
-    "You reopened todo {todo} in list {calendar}" : "Znovu jste otevřel(a) úkol {todo} v seznamu {calendar}",
+    "You reopened todo {todo} in list {calendar}" : "Znovu jste otevřeli úkol {todo} v seznamu {calendar}",
     "A <strong>calendar</strong> was modified" : "<strong>Kalendář</strong> byl změněn",
     "A calendar <strong>event</strong> was modified" : "<strong>Událost</strong> v kalendáři byla změněna",
     "A calendar <strong>todo</strong> was modified" : "<strong>Úkol</strong> v kalendáři byl změněn",
-    "Death of %s" : "Den úmrtí %s",
+    "Death of %s" : "Datum úmrtí %s",
     "Contact birthdays" : "Narozeniny kontaktů",
     "Calendar:" : "Kalendář:",
     "Date:" : "Datum:",
@@ -63,7 +63,7 @@ OC.L10N.register(
     "Where: %s" : "Kde: %s",
     "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
     "Invitation canceled" : "Pozvánka zrušena",
-    "Hello %s," : "Dobrý den %s,",
+    "Hello %s," : "Zdravím %s,",
     "The meeting »%1$s« with %2$s was canceled." : "Setkání „%1$s“ sc%2$s bylo zrušeno.",
     "Invitation updated" : "Pozvánka aktualizována",
     "The meeting »%1$s« with %2$s was updated." : "Setkání „%1$s“ s %2$s bylo zrušeno.",
@@ -83,7 +83,7 @@ OC.L10N.register(
     "Technical details" : "Technické podrobnosti",
     "Remote Address: %s" : "Vzdálená adresa: %s",
     "Request ID: %s" : "Identif. požadavku: %s",
-    "There was an error updating your attendance status." : "Vyskytla se chyba při aktualizaci Vašeho stavu.",
+    "There was an error updating your attendance status." : "Vyskytla se chyba při aktualizaci vašeho stavu účasti.",
     "Please contact the organizer directly." : "Kontaktujte organizátora přímo.",
     "Are you accepting the invitation?" : "Přijímáte pozvání?",
     "Tentative" : "Nezávazně",
@@ -94,10 +94,12 @@ OC.L10N.register(
     "Send invitations to attendees" : "Poslat pozvánky na adresy účastníků",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ověřte, že jste správně nastavili {emailopen}e-mailový server{linkclose}.",
     "Automatically generate a birthday calendar" : "Automaticky vytvořit kalendář s narozeninami",
-    "Birthday calendars will be generated by a background job." : "Narozeninový kalendář bude vytvořen na pozadí.",
+    "Birthday calendars will be generated by a background job." : "Kalendáře s narozeninami budou vytvářeny úlohou na pozadí.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "A tedy nebudou zpřístupněny ihned po povolení, ale objeví se až se zpožděním.",
     "Send notifications for events" : "Posílat upozornění na události",
-    "Notifications will be send through background jobs, so these need to happen often enough." : "Oznámení budou odeslána prostřednictvím úloh na pozadí, takže je třeba, aby se děly dostatečně často.",
-    "Please make sure to properly set up the email settings above." : "Ujistěte se, že jste správně nastavili výše uvedená nastavení e-mailu."
+    "Notifications are sent via background jobs, so these must occur often enough." : "Upozornění jsou odesílána prostřednictvím úloh na pozadí – proto je třeba, aby tyto probíhaly dostatečně často.",
+    "Enable notifications for events via push" : "Oznamovat události prostřednictvím push",
+    "Please make sure to properly set up the email settings above." : "Ujistěte se, že jste správně nastavili výše uvedená nastavení e-mailu.",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Oznámení budou odeslána prostřednictvím úloh na pozadí, takže je třeba, aby se děly dostatečně často."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
