@@ -43,27 +43,27 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "A calendar <strong>event</strong> was modified",
     "A calendar <strong>todo</strong> was modified" : "A calendar <strong>todo</strong> was modified",
     "Contact birthdays" : "Contact birthdays",
+    "Where:" : "Where:",
+    "Description:" : "Description:",
     "Invitation canceled" : "Invitation canceled",
     "Hello %s," : "Hello %s,",
     "Invitation updated" : "Invitation updated",
     "When:" : "When:",
-    "Where:" : "Where:",
-    "Description:" : "Description:",
     "Link:" : "Link:",
+    "Accept" : "Accept",
+    "Decline" : "Decline",
     "Contacts" : "Contacts",
     "WebDAV" : "WebDAV",
+    "WebDAV endpoint" : "WebDAV endpoint",
     "Technical details" : "Technical details",
     "Remote Address: %s" : "Remote Address: %s",
     "Request ID: %s" : "Request ID: %s",
+    "Tentative" : "Tentative",
+    "Save" : "Save",
     "Send invitations to attendees" : "Send invitations to attendees",
-    "Please make sure to properly set up the email settings above." : "Please make sure to properly set up the email settings above.",
     "Automatically generate a birthday calendar" : "Automatically generate a birthday calendar",
     "Birthday calendars will be generated by a background job." : "Birthday calendars will be generated by a background job.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Hence they will not be available immediately after enabling but will show up after some time.",
-    "%s via %s" : "%s via %s",
-    "The meeting »%s« with %s was canceled." : "The meeting »%s« with %s was canceled.",
-    "The meeting »%s« with %s was updated." : "The meeting »%s« with %s was updated.",
-    "%s invited you to »%s«" : "%s invited you to »%s«",
-    "CalDAV server" : "CalDAV server"
+    "Please make sure to properly set up the email settings above." : "Please make sure to properly set up the email settings above."
 },
 "nplurals=2; plural=(n != 1);");
