@@ -43,28 +43,27 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> de un calendario fue modificado",
     "A calendar <strong>todo</strong> was modified" : "Un <strong>pendiente</strong> de un calendario fue modificado",
     "Contact birthdays" : "Cumpleaños del contacto",
-    "%s via %s" : "%s vía %s",
-    "Invitation canceled" : "Invitación cancelada",
-    "Hello %s," : "Hola %s,",
-    "The meeting »%s« with %s was canceled." : "La cita »%s« con %s fue cancelada.",
-    "Invitation updated" : "Invitación actualizada",
-    "The meeting »%s« with %s was updated." : "La reunión »%s« con %s ha sido actualizada.",
-    "%s invited you to »%s«" : "%s te ha invitado a »%s«",
-    "When:" : "Cuándo:",
     "Where:" : "Dónde:",
     "Description:" : "Descripción:",
+    "Invitation canceled" : "Invitación cancelada",
+    "Hello %s," : "Hola %s,",
+    "Invitation updated" : "Invitación actualizada",
+    "When:" : "Cuándo:",
     "Link:" : "Enlace:",
+    "Accept" : "Aceptar",
+    "Decline" : "Rechazar",
     "Contacts" : "Contactos",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "Endpoint WebDAV",
     "Technical details" : "Detalles técnicos",
     "Remote Address: %s" : "Dirección remota: %s",
     "Request ID: %s" : "ID de solicitud: %s",
-    "CalDAV server" : "Servidor CalDAV",
+    "Tentative" : "Tentativo",
+    "Save" : "Guardar",
     "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
-    "Please make sure to properly set up the email settings above." : "Por favor asegurarte de establecer correctamente las configuraciones de correo anteriores. ",
     "Automatically generate a birthday calendar" : "Generar automaticamente un calendario para cumpleaños",
     "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños serán generados por un trabajo de segundo plano",
-    "Hence they will not be available immediately after enabling but will show up after some time." : "Por lo tanto no estarán disponbiles inmediatamente después de habilitarlos pero se mostrarán después de un tiempo."
+    "Hence they will not be available immediately after enabling but will show up after some time." : "Por lo tanto no estarán disponbiles inmediatamente después de habilitarlos pero se mostrarán después de un tiempo.",
+    "Please make sure to properly set up the email settings above." : "Por favor asegurarte de establecer correctamente las configuraciones de correo anteriores. "
 },
 "nplurals=2; plural=(n != 1);");
