@@ -23,10 +23,11 @@ OC.L10N.register(
     "{actor} unshared calendar {calendar} from group {group}" : "{actor}-rk  {group} taldearekin {calendar} egutegia partekatzeari utzi dio.",
     "{actor} created event {event} in calendar {calendar}" : "{actor} erabiltzaileak {event} gertaera {calendar} egutegian sortu du.",
     "You created event {event} in calendar {calendar}" : "{calendar} egutegia {event} gertaera sortu duzu",
-    "{actor} deleted event {event} from calendar {calendar}" : "{actor} erbiltzaileak {event} gertaera {calendar} egutegitik ezabatu du",
+    "{actor} deleted event {event} from calendar {calendar}" : "{actor} erabiltzaileak {event} gertaera {calendar} egutegitik ezabatu du",
     "You deleted event {event} from calendar {calendar}" : "{event} gertaera {calendar} egutegitik ezabatu duzu",
     "{actor} updated event {event} in calendar {calendar}" : "{actor}-rek {event} gertaera {calendar} eguneratu du egutegian",
     "You updated event {event} in calendar {calendar}" : "{event} gertaera {calendar} egutegian eguneratu duzu ",
+    "Busy" : "Lanpetua",
     "{actor} created todo {todo} in list {calendar}" : "{actor}-rek {calendar} zerrendan {todo} ekintza sortu du.",
     "You created todo {todo} in list {calendar}" : "{calendar} zerrendan {todo} ekintza sortu duzu.",
     "{actor} deleted todo {todo} from list {calendar}" : "{actor}-rek {calendar} zerrendan {todo} zeregina borratu du.",
@@ -41,24 +42,32 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "Egutegiaren <strong>gertaera</strong> bat aldatu da",
     "A calendar <strong>todo</strong> was modified" : "Egutegiaren zeregin bat aldatu da",
     "Contact birthdays" : "Urtebetetze kontaktua",
+    "Calendar:" : "Egutegia:",
+    "Date:" : "Data:",
+    "Where:" : "Non:",
+    "Description:" : "Deskribapena:",
+    "Untitled event" : "Izenik gabeko gertaera",
+    "Calendar: %s" : "Egutegia: %s",
+    "Date: %s" : "Data: %s",
+    "Description: %s" : "Deskripzioa: %s",
+    "Where: %s" : "Non: %s",
     "Invitation canceled" : "Gonbidapena ezeztatua",
     "Hello %s," : "Kaixo 1%s,",
     "Invitation updated" : "Gonbidapena eguneratu da",
     "When:" : "Noiz:",
-    "Where:" : "Non:",
-    "Description:" : "Deskribapena:",
     "Link:" : "Esteka:",
     "Accept" : "Onartu",
+    "Decline" : "Uko egin",
     "More options …" : "Aukera gehiago …",
     "Contacts" : "Kontaktuak",
     "WebDAV" : "WebDAV",
     "Technical details" : "Xehetasun teknikoak",
     "Remote Address: %s" : "Urruneko helbidea: 1%s",
     "Request ID: %s" : "Eskatutako ID: 1%s",
+    "Tentative" : "Behin behinekoa",
     "Save" : "Gorde",
+    "Calendar server" : "Egutegi-zerbitzaria",
     "Send invitations to attendees" : "Gonbidatutakoei gonbidapenak bidali",
-    "The meeting »%s« with %s was canceled." : "1%s-rekin duzun » 1%s « bilera ezeztatu da",
-    "%s invited you to »%s«" : "1%s-k »1%s«-ra gonbidatu zaitu",
     "Please make sure to properly set up the email settings above." : "Mesedez, eposta ezarpenak ondo zehaztuta daudela ziurta ezazu"
 },
 "nplurals=2; plural=(n != 1);");
