@@ -43,7 +43,24 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "Un <strong>agenda</strong> a été modifié",
     "A calendar <strong>event</strong> was modified" : "Un <strong>événement</strong> de l'agenda a été modifié",
     "A calendar <strong>todo</strong> was modified" : "Une <strong>liste de tâches</strong> de l'agenda a été modifiée",
+    "Death of %s" : "Mort de %s",
     "Contact birthdays" : "Anniversaires des contacts",
+    "Calendar:" : "Agenda:",
+    "Date:" : "Date:",
+    "Where:" : "Où :",
+    "Description:" : "Description :",
+    "Untitled event" : "Événement sans titre",
+    "_%n year_::_%n years_" : ["%n an","%n ans"],
+    "_%n month_::_%n months_" : ["%n mois","%n mois"],
+    "_%n day_::_%n days_" : ["%n jour","%n jours"],
+    "_%n hour_::_%n hours_" : ["%n heure","%n heures"],
+    "_%n minute_::_%n minutes_" : ["%n minute","%n minutes"],
+    "%s (in %s)" : "%s(parmi %s)",
+    "%s (%s ago)" : "%s (il y a %s)",
+    "Calendar: %s" : "Agenda: %s",
+    "Date: %s" : "Date: %s",
+    "Description: %s" : "Description: %s",
+    "Where: %s" : "Où : %s",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Invitation canceled" : "Invitation annulée",
     "Hello %s," : "Bonjour %s,",
@@ -52,8 +69,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "La réunion «%1$s» avec %2$s a été mise à jour.",
     "%1$s invited you to »%2$s«" : "%1$s vous a invité à «%2$s»",
     "When:" : "Quand :",
-    "Where:" : "Où :",
-    "Description:" : "Description :",
     "Link:" : "Lien :",
     "Accept" : "Accepter",
     "Decline" : "Refuser",
@@ -72,7 +87,7 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Merci de contacter l'organisateur directement.",
     "Are you accepting the invitation?" : "Acceptez-vous l'invitation ?",
     "Tentative" : "Provisoire",
-    "Save" : "Sauvegarder",
+    "Save" : "Enregistrer",
     "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès.",
     "Calendar server" : "Serveur de calendrier",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer aussi {calendarappstoreopen}l'application Calendrier{linkclose}, ou {calendardocopen}connecter à votre PC & téléphone pour synchroniser ↗{linkclose}.",
@@ -81,11 +96,10 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Générer automatiquement un agenda d'anniversaire",
     "Birthday calendars will be generated by a background job." : "Les agendas d'anniversaire seront générés par une tâche de fond.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Par conséquent, ils ne seront pas disponibles immédiatement après l'activation mais apparaîtront après un certain temps.",
-    "%s via %s" : "%s via %s",
-    "The meeting »%s« with %s was canceled." : "La réunion «%s» avec %s a été annulée.",
-    "The meeting »%s« with %s was updated." : "La réunion «%s» avec %s a été mise à jour.",
-    "%s invited you to »%s«" : "%s vous a invité à «%s»",
-    "CalDAV server" : "Serveur CalDAV",
-    "Please make sure to properly set up the email settings above." : "Merci de vérifier d'avoir correctement configuré les paramètres de courriel ci-dessus"
+    "Send notifications for events" : "Envoyer une notification pour les évènements",
+    "Notifications are sent via background jobs, so these must occur often enough." : "Les notifications sont envoyées par des tâches de fond qui doivent, par conséquent, être exécutées régulièrement.",
+    "Enable notifications for events via push" : "Activer les notifications push pour les évènements",
+    "Please make sure to properly set up the email settings above." : "Merci de vérifier d'avoir correctement configuré les paramètres de courriel ci-dessus",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Les notifications seront envoyées par des tâches de fond qui doivent, par conséquent, être exécutées régulièrement."
 },
 "nplurals=2; plural=(n > 1);");
