@@ -29,6 +29,7 @@ OC.L10N.register(
     "You deleted event {event} from calendar {calendar}" : "Törölted ezt az eseményt: {event} ebből a naptárból: {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} frissítette ezt az eseményt: {event} ebben a naptárban: {calendar}",
     "You updated event {event} in calendar {calendar}" : "Frissítetted ezt az eseményt: {event} ebben a naptárban: {calendar}",
+    "Busy" : "Foglalt",
     "{actor} created todo {todo} in list {calendar}" : "{actor} létrehozta ezt a teendőt: {todo} ebben a listában: {calendar}",
     "You created todo {todo} in list {calendar}" : "Létrehoztad ezt a teendőt: {todo} ebben a listában: {calendar}",
     "{actor} deleted todo {todo} from list {calendar}" : "{actor} törölte ezt a teendőt: {todo} ebből a listából: {calendar}",
@@ -43,6 +44,8 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "Egy naptár <strong>esemény</strong> megváltozott",
     "A calendar <strong>todo</strong> was modified" : "Egy naptár <strong>teendő</strong> megváltozott",
     "Contact birthdays" : "Születésnapok",
+    "Where:" : "Hol:",
+    "Description:" : "Leírás:",
     "%1$s via %2$s" : "%1$s - %2$s",
     "Invitation canceled" : "Meghívás visszavonva",
     "Hello %s," : "Üdv %s,",
@@ -51,8 +54,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "A »%1$s« találkozó vele:%2$s módosult.",
     "%1$s invited you to »%2$s«" : "%1$s meghívott ide: »%2$s«",
     "When:" : "Mikor:",
-    "Where:" : "Hol:",
-    "Description:" : "Leírás:",
     "Link:" : "Link:",
     "Accept" : "Elfogad",
     "Decline" : "Elutasít",
@@ -75,10 +76,6 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Születésnapokat tartalmazó naptár automatikus létrehozása",
     "Birthday calendars will be generated by a background job." : "A születésnapokat tartalmazó naptárakat egy háttérben futó folyamat fogja létrehozni.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Nem lesznek elérhetőek azonnal az engedélyezés után, de egy rövid idő múlva már láthatóak lesznek.",
-    "%s via %s" : "%s - %s",
-    "The meeting »%s« with %s was canceled." : "A »%s« találkozó vele: %s lemondásra került.",
-    "The meeting »%s« with %s was updated." : "A »%s«  találkozó  vele: %s módosult.",
-    "%s invited you to »%s«" : "%s meghívott ide: »%s«",
     "Please make sure to properly set up the email settings above." : "Győződj meg róla, hogy a fenti e-mail beállítások helyesek."
 },
 "nplurals=2; plural=(n != 1);");
