@@ -44,6 +44,9 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "<strong>Atburði</strong> dagatals var breytt",
     "A calendar <strong>todo</strong> was modified" : "<strong>Verkefnalista</strong> dagatals var breytt",
     "Contact birthdays" : "Afmælisdagar tengiliðar",
+    "Where:" : "Hvar:",
+    "Description:" : "Lýsing:",
+    "Untitled event" : "Ónefndur atburður",
     "%1$s via %2$s" : "%1$s með %2$s",
     "Invitation canceled" : "Hætt við boð",
     "Hello %s," : "Halló %s,",
@@ -52,8 +55,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "Fundurinn »%1$s« með %2$s var uppfærður.",
     "%1$s invited you to »%2$s«" : "%1$s bauð þér að taka þátt í »%2$s«",
     "When:" : "Hvenær:",
-    "Where:" : "Hvar:",
-    "Description:" : "Lýsing:",
     "Link:" : "Tengill:",
     "Accept" : "Samþykkja",
     "Decline" : "Hafna",
@@ -81,10 +82,6 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Útbúa fæðingardagatal sjálfvirkt",
     "Birthday calendars will be generated by a background job." : "Fæðingardagatöl verða útbúin í bakvinnsluferli.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Þar með verða þau ekki tilbúin strax eftir að þetta er virkjað, heldur birtast þau eftir nokkurn tíma.",
-    "%s via %s" : "%s með %s",
-    "The meeting »%s« with %s was canceled." : "Hætt var við fundinn »%s« með %s.",
-    "The meeting »%s« with %s was updated." : "Fundurinn »%s« með %s var uppfærður.",
-    "%s invited you to »%s«" : "%s bauð þér að taka þátt í »%s«",
     "Please make sure to properly set up the email settings above." : "Gakktu úr skugga um að tölvupóststillingarnar hér fyrir ofan séu réttar."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
