@@ -43,7 +43,24 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> è stato modificato",
     "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario è stato modificato",
     "A calendar <strong>todo</strong> was modified" : "Una <strong>cosa da fare</strong> del calendario è stata modificata",
+    "Death of %s" : "Morte di %s",
     "Contact birthdays" : "Date di nascita dei contatti",
+    "Calendar:" : "Calendario:",
+    "Date:" : "Data:",
+    "Where:" : "Dove:",
+    "Description:" : "Descrizione:",
+    "Untitled event" : "Evento senza titolo",
+    "_%n year_::_%n years_" : ["%n anno","%n anni"],
+    "_%n month_::_%n months_" : ["%n mese","%n mesi"],
+    "_%n day_::_%n days_" : ["%n giorno","%n giorni"],
+    "_%n hour_::_%n hours_" : ["%n ora","%n ore"],
+    "_%n minute_::_%n minutes_" : ["%n minuto","%n minuti"],
+    "%s (in %s)" : "%s (in %s)",
+    "%s (%s ago)" : "%s (%s fa)",
+    "Calendar: %s" : "Calendario: %s",
+    "Date: %s" : "Data: %s",
+    "Description: %s" : "Descrizione: %s",
+    "Where: %s" : "Dove: %s",
     "%1$s via %2$s" : "%1$s tramite %2$s",
     "Invitation canceled" : "Invito annullato",
     "Hello %s," : "Ciao %s,",
@@ -52,14 +69,15 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "L'incontro «%1$s» con %2$s è stato aggiornato.",
     "%1$s invited you to »%2$s«" : "%1$s ti ha invitato a «%2$s»",
     "When:" : "Quando:",
-    "Where:" : "Dove:",
-    "Description:" : "Descrizione:",
     "Link:" : "Collegamento:",
     "Accept" : "Accetta",
     "Decline" : "Rifiuta",
     "More options …" : "Altre opzioni...",
     "More options at %s" : "Altre opzioni alle %s",
     "Contacts" : "Contatti",
+    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Il tuo %s deve essere configurato all'uso di HTTPS per poter usare CalDAV e CardDAV con iOS/macOS.",
+    "Configures a CalDAV account" : "Configura un account CalDAV",
+    "Configures a CardDAV account" : "Configura un account CardDAV",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "Terminatore WebDAV",
     "Technical details" : "Dettagli tecnici",
@@ -72,15 +90,16 @@ OC.L10N.register(
     "Save" : "Salva",
     "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente.",
     "Calendar server" : "Server di calendari",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installa anche {calendarappstoreopen}l'applicazione Calendario{linkclose}, o {calendardocopen}connetti il tuo desktop e mobile per la sicronizzazione ↗{linkclose}.",
     "Send invitations to attendees" : "Invia gli inviti ai partecipanti",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assicurati di configurare correttamente {emailopen}il server di posta{linkclose}.",
     "Automatically generate a birthday calendar" : "Genera automaticamente un calendario dei compleanni",
     "Birthday calendars will be generated by a background job." : "Il calendario dei compleanni sarà generato con un'operazione in background.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Per cui non saranno disponibili immediatamente dopo l'abilitazione, ma saranno mostrati dopo qualche istante.",
-    "%s via %s" : "%s tramite %s",
-    "The meeting »%s« with %s was canceled." : "L'incontro «%s» con %s è stato annullato.",
-    "The meeting »%s« with %s was updated." : "L'incontro «%s» con %s è stato aggiornato.",
-    "%s invited you to »%s«" : "%s ti ha invitato a «%s»",
-    "CalDAV server" : "Server CalDAV",
-    "Please make sure to properly set up the email settings above." : "Assicurati di configurare correttamente le impostazioni di posta sopra."
+    "Send notifications for events" : "Invia notifiche per eventi",
+    "Notifications are sent via background jobs, so these must occur often enough." : "Le notifiche saranno inviate tramite operazioni in background, per cui tali operazioni devono essere eseguite abbastanza spesso.",
+    "Enable notifications for events via push" : "Abilita notifiche per eventi tramite push",
+    "Please make sure to properly set up the email settings above." : "Assicurati di configurare correttamente le impostazioni di posta sopra.",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Le notifiche saranno inviate tramite operazioni in background, per cui devono verificarsi abbastanza spesso."
 },
 "nplurals=2; plural=(n != 1);");
