@@ -43,27 +43,26 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "კალენდრის <strong>მოვლენა</strong> შეიცვალა",
     "A calendar <strong>todo</strong> was modified" : "კალენდრის <strong>შესასრულებელი დავალება</strong> შეიცვალა",
     "Contact birthdays" : "კონტაქტების დაბადების დღეები",
+    "Where:" : "სად:",
+    "Description:" : "აღწერა:",
     "Invitation canceled" : "მოწვევა გაუქმდა",
     "Hello %s," : "გამარჯობა %s,",
     "Invitation updated" : "მოწვევა განახლდა",
     "When:" : "როდის:",
-    "Where:" : "სად:",
-    "Description:" : "აღწერა:",
     "Link:" : "ბმული:",
+    "Accept" : "მიღება",
+    "Decline" : "ურაყოფა",
     "Contacts" : "კონტაქტები",
     "WebDAV" : "WebDAV",
     "Technical details" : "ტექნიკური დეტალები",
     "Remote Address: %s" : "დისტანციური მისამართი: %s",
     "Request ID: %s" : "მოთხოვნის ID: %s",
+    "Tentative" : "საცდელი",
+    "Save" : "შენახვა",
     "Send invitations to attendees" : "გაუგზავნეთ მოწვევა დამსწრეებს",
-    "Please make sure to properly set up the email settings above." : "გთხოვთ დაამოწმოთ, რომ სწორად აყენებთ ზემოთ მოცემულ ელ-ფოსტის პარამეტრებს.",
     "Automatically generate a birthday calendar" : "დაბადების დღეების კალენდრების ავტომატური გენერირება",
     "Birthday calendars will be generated by a background job." : "ბადადების დღეების კალენდრები გენერირებულ იქნება ფონურ რეჟიმში.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "ისინი არ იქნებიან ხელმიწავდომნი უცბად, მაგრამ გამოჩნდებიან გარკვეული პერიოდის შემდეგ.",
-    "%s via %s" : "%s %s-ით",
-    "The meeting »%s« with %s was canceled." : "შეხვედრა »%s« %s-სთან გაუქმდა.",
-    "The meeting »%s« with %s was updated." : "შეხვედრა »%s« %s-სთან განახლდა.",
-    "%s invited you to »%s«" : "%s-მ დაგპატიჟათ რომ »%s«",
-    "CalDAV server" : "CalDAV სერვერი"
+    "Please make sure to properly set up the email settings above." : "გთხოვთ დაამოწმოთ, რომ სწორად აყენებთ ზემოთ მოცემულ ელ-ფოსტის პარამეტრებს."
 },
 "nplurals=2; plural=(n!=1);");
