@@ -23,12 +23,13 @@ OC.L10N.register(
     "{actor} shared calendar {calendar} with group {group}" : "{actor} pradėjo bendrinti kalendorių {calendar} su grupe {group}",
     "You unshared calendar {calendar} from group {group}" : "Jūs nustojote bendrinti kalendorių {calendar} su grupe {group}",
     "{actor} unshared calendar {calendar} from group {group}" : "{actor} nustojo bendrinti kalendorių {calendar} su grupe {group}",
-    "{actor} created event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} sukūrė įvykį {event}",
+    "{actor} created event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} sukūrė įvykį {event}",
     "You created event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} sukūrėte įvykį {event}",
-    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ištrynė įvykį {event} iš kalendoriaus {calendar}",
+    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ištrynė įvykį {event} iš kalendoriaus {calendar}",
     "You deleted event {event} from calendar {calendar}" : "Jūs ištrynėte įvykį {event} iš kalendoriaus {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} atnaujino įvykį {event}",
     "You updated event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} atnaujinote įvykį {event}",
+    "Busy" : "Užimtas laikas",
     "{actor} created todo {todo} in list {calendar}" : "{actor} sąraše {calendar} sukūrė užduotį {todo}",
     "You created todo {todo} in list {calendar}" : "Jūs sąraše {calendar} sukūrėte užduotį {todo}",
     "{actor} deleted todo {todo} from list {calendar}" : "{actor} iš sąrašo {calendar} ištrynė užduotį {todo}",
@@ -39,20 +40,22 @@ OC.L10N.register(
     "You solved todo {todo} in list {calendar}" : "Jūs sąraše {calendar} išsprendėte užduotį {todo}",
     "{actor} reopened todo {todo} in list {calendar}" : "{actor} sąraše {calendar} vėl pradėjo užduotį {todo}",
     "You reopened todo {todo} in list {calendar}" : "Jūs sąraše {calendar} vėl pradėjote užduotį {todo}",
-    "A <strong>calendar</strong> was modified" : "<strong>Kalendorius</strong> buvo pakeistas",
-    "A calendar <strong>event</strong> was modified" : "Kalendoriaus <strong>įvykis</strong> buvo pakeistas",
-    "A calendar <strong>todo</strong> was modified" : "Kalendoriaus <strong>užduotis</strong> buvo pakeista",
+    "A <strong>calendar</strong> was modified" : "<strong>Kalendorius</strong> buvo modifikuotas",
+    "A calendar <strong>event</strong> was modified" : "Kalendoriaus <strong>įvykis</strong> buvo modifikuotas",
+    "A calendar <strong>todo</strong> was modified" : "Kalendoriaus <strong>užduotis</strong> buvo modifikuota",
     "Contact birthdays" : "Adresatų gimtadieniai",
     "Calendar:" : "Kalendorius:",
     "Date:" : "Data:",
     "Where:" : "Kur:",
     "Description:" : "Aprašas:",
+    "Untitled event" : "Įvykis be pavadinimo",
+    "%s (%s ago)" : "%s (prieš %s)",
     "Calendar: %s" : "Kalendorius: %s",
     "Date: %s" : "Data: %s",
     "Description: %s" : "Aprašas: %s",
     "Where: %s" : "Kur: %s",
     "%1$s via %2$s" : "%1$s per %2$s",
-    "Invitation canceled" : "Kvietimas atšauktas",
+    "Invitation canceled" : "Pakvietimo atsisakyta",
     "Hello %s," : "Sveiki, %s,",
     "The meeting »%1$s« with %2$s was canceled." : "Susikimas „%1$s“ su  %2$s atšauktas.",
     "Invitation updated" : "Pakvietimas atnaujintas",
@@ -61,8 +64,9 @@ OC.L10N.register(
     "Link:" : "Nuoroda:",
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
-    "More options …" : "Daugiau parinkčių …",
+    "More options …" : "Daugiau parinkčių…",
     "Contacts" : "Adresatai",
+    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Norint naudoti CalDAV ir CardDAV su iOS/macOS, jūsų %s turi būti sukonfigūruota taip, kad naudotų HTTPS.",
     "Configures a CalDAV account" : "Konfigūruoja CalDAV paskyrą",
     "Configures a CardDAV account" : "Konfigūruoja CardDAV paskyrą",
     "WebDAV" : "WebDAV",
@@ -70,7 +74,17 @@ OC.L10N.register(
     "Remote Address: %s" : "Nuotolinis adresas: %s",
     "Request ID: %s" : "Užklausos ID: %s",
     "Are you accepting the invitation?" : "Ar priimate pakvietimą?",
+    "Tentative" : "Preliminarus",
     "Save" : "Įrašyti",
-    "Calendar server" : "Kalendoriaus serveris"
+    "Calendar server" : "Kalendoriaus serveris",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Taip pat įsidiekite {calendarappstoreopen}Kalendoriaus programėlę{linkclose} arba sinchronizavimui {calendardocopen}prijunkite savo darbalaukį ir mobilųjį ↗{linkclose}.",
+    "Send invitations to attendees" : "Siųsti pakvietimus kviestiniams",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Įsitikinkite, kad tinkamai nusistatėte {emailopen}el. pašto serverį{linkclose}.",
+    "Automatically generate a birthday calendar" : "Automatiškai sukurti gimtadienių kalendorių",
+    "Birthday calendars will be generated by a background job." : "Gimtadienių kalendoriai bus sukurti foninės užduoties.",
+    "Hence they will not be available immediately after enabling but will show up after some time." : "Tai reiškia, kad jie nebus matomi iš karto įjungus, o pasirodys tik po kurio laiko.",
+    "Send notifications for events" : "Siųsti įvykių pranešimus",
+    "Please make sure to properly set up the email settings above." : "Įsitikinkite, kad aukščiau tinkamai nusistatėte el. pašto nustatymus.",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Pranešimai bus siunčiami per fonines užduotis, taigi jos turi būti įvykdomos gana dažnai."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
