@@ -29,6 +29,7 @@ OC.L10N.register(
     "You deleted event {event} from calendar {calendar}" : "Du slettet hendelsen {event} fra kalenderen {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} oppdaterte hendelsen {event} i kalenderen {calendar}",
     "You updated event {event} in calendar {calendar}" : "Du oppdaterte hendelsen {event} i kalenderen {calendar}",
+    "Busy" : "Opptatt",
     "{actor} created todo {todo} in list {calendar}" : "{actor} opprettet en oppgaven {todo} i listen {calendar}",
     "You created todo {todo} in list {calendar}" : "Du opprettet en oppgave {todo} i listen {calendar}",
     "{actor} deleted todo {todo} from list {calendar}" : "{actor} slettet gjøremålet {todo} fra listen {calendar}",
@@ -45,16 +46,21 @@ OC.L10N.register(
     "Contact birthdays" : "Kontakters fødelsdag",
     "Where:" : "Hvor:",
     "Description:" : "Beskrivelse:",
+    "%1$s via %2$s" : "%1$s via %2$s",
     "Invitation canceled" : "Invitasjon tilbakekalt",
     "Hello %s," : "Hei %s,",
     "Invitation updated" : "Invitasjon oppdatert",
     "When:" : "Når:",
     "Link:" : "Lenke:",
+    "Accept" : "Aksepter",
+    "Decline" : "Avslå",
     "Contacts" : "Kontakter",
     "WebDAV" : "WebDAV",
     "Technical details" : "Tekniske detaljer",
     "Remote Address: %s" : "Ekstern adresse: %s",
     "Request ID: %s" : "Forespørsel ID: %s",
+    "Tentative" : "Foreløpig",
+    "Save" : "Lagre",
     "Calendar server" : "Kalenderserver",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer også {calendarappstoreopen} Kalender-appen {linkclose}, eller {calendardocopen} knytt datamaskinen og mobilen din for synkronisering ↗{linkclose}.",
     "Send invitations to attendees" : "Send invitasjoner til oppmøtte",
