@@ -43,7 +43,24 @@ OC.L10N.register(
     "A <strong>calendar</strong> was modified" : "<strong>Kalendarz</strong> został zmodyfikowany",
     "A calendar <strong>event</strong> was modified" : "<strong>Zdarzenie</strong> kalendarza zostało zmodyfikowane",
     "A calendar <strong>todo</strong> was modified" : "Kalendarz <strong>zadań</strong> został zmieniony",
+    "Death of %s" : "Śmierć %s",
     "Contact birthdays" : "Urodziny kontaktu",
+    "Calendar:" : "Kalendarz:",
+    "Date:" : "Data:",
+    "Where:" : "Gdzie:",
+    "Description:" : "Opis:",
+    "Untitled event" : "Wydarzenie bez tytułu",
+    "_%n year_::_%n years_" : ["%n rok","%n lata","%n lat","%n lat"],
+    "_%n month_::_%n months_" : ["%n miesiąc","%n miesiące","%n miesięcy","%n miesięcy"],
+    "_%n day_::_%n days_" : ["%n dzień","%n dni","%n dni","%n dni"],
+    "_%n hour_::_%n hours_" : ["%n godzina","%n godziny","%n godzin","%n godziny"],
+    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuty","%n minut","%n minuty"],
+    "%s (in %s)" : "%s (w %s)",
+    "%s (%s ago)" : "%s (%s temu)",
+    "Calendar: %s" : "Kalendarz: %s",
+    "Date: %s" : "Data: %s",
+    "Description: %s" : "Opis: %s",
+    "Where: %s" : "Gdzie: %s",
     "%1$s via %2$s" : "%1$s przez %2$s",
     "Invitation canceled" : "Zaproszenie anulowane",
     "Hello %s," : "Witaj %s,",
@@ -52,8 +69,6 @@ OC.L10N.register(
     "The meeting »%1$s« with %2$s was updated." : "Spotkanie »%1$s« z %2$s zostało zaktualizowane.",
     "%1$s invited you to »%2$s«" : "%1$s zaprosił cię do »%2$s«",
     "When:" : "Kiedy:",
-    "Where:" : "Gdzie: ",
-    "Description:" : "Opis:",
     "Link:" : "Link: ",
     "Accept" : "Akceptuj",
     "Decline" : "Odrzuć",
@@ -81,10 +96,10 @@ OC.L10N.register(
     "Automatically generate a birthday calendar" : "Automatycznie generuj kalendarz urodzin",
     "Birthday calendars will be generated by a background job." : "Kalendarz urodzin będzie generowany przez uruchomione zadanie w tle.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Dlatego nie będą dostępne natychmiast po włączeniu, ale pojawią się po pewnym czasie.",
-    "%s via %s" : "%s przez %s",
-    "The meeting »%s« with %s was canceled." : "Spotkanie »%s« z %s zostało anulowane.",
-    "The meeting »%s« with %s was updated." : "Spotkanie »%s« z %s zostało zaktualizowane.",
-    "%s invited you to »%s«" : "%s zaprosił Cię do »%s«",
-    "Please make sure to properly set up the email settings above." : "Upewnij się, że poprawnie skonfigurowałeś ustawienia e-mail."
+    "Send notifications for events" : "Wysyłaj powiadomienia o wydarzeniach",
+    "Notifications are sent via background jobs, so these must occur often enough." : "Powiadomienia są wysyłane za pośrednictwem zadań w tle, więc muszą one występować wystarczająco często.",
+    "Enable notifications for events via push" : "Włącz powiadomienia o zdarzeniach poprzez push",
+    "Please make sure to properly set up the email settings above." : "Upewnij się, że poprawnie skonfigurowałeś ustawienia e-mail.",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Powiadomienia będą wysyłane za pośrednictwem zadań w tle, więc mogą pojawiać się one dosyć często."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
