@@ -97,8 +97,8 @@ OC.L10N.register(
     "Birthday calendars will be generated by a background job." : "Календари дней рождения будут создаваться фоновым процессом.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "И поэтому они станут доступны не моментально, а через некоторое время.",
     "Send notifications for events" : "Отправлять уведомления о событиях",
-    "Notifications will be send through background jobs, so these need to happen often enough." : "Уведомления будут отправляться через фоновые задания, поэтому они должны выполняться достаточно часто.",
     "Enable notifications for events via push" : "Включить уведомления о событиях с помощью push",
-    "Please make sure to properly set up the email settings above." : "Проверьте правильность заданных выше параметров электронной почты."
+    "Please make sure to properly set up the email settings above." : "Проверьте правильность заданных выше параметров электронной почты.",
+    "Notifications will be send through background jobs, so these need to happen often enough." : "Уведомления будут отправляться через фоновые задания, поэтому они должны выполняться достаточно часто."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
