@@ -41,9 +41,24 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "Një <strong>event</strong> në kalendar u modifikua",
     "A calendar <strong>todo</strong> was modified" : "Një kalendar <strong>todo<strong> u modifikua",
     "Contact birthdays" : "Ditëlindjet e kontakteve",
+    "Where:" : "Ku:",
+    "Description:" : "Përshkrimi:",
+    "Invitation canceled" : "Ftesa u anullua",
+    "Hello %s," : "Përshëndetje %s,",
+    "Invitation updated" : "Ftesa u përditësua",
+    "When:" : "Kur:",
+    "Link:" : "Link:",
+    "Accept" : "Prano",
+    "Decline" : "Refuzo",
+    "More options …" : "Më shumë opsione ...",
     "Contacts" : "Kontaktet",
+    "WebDAV" : "WebDAV",
     "Technical details" : "Detaje teknike",
     "Remote Address: %s" : "Adresa remote: %s",
-    "Request ID: %s" : "ID e kërkesës: %s"
+    "Request ID: %s" : "ID e kërkesës: %s",
+    "Tentative" : "Tentativë",
+    "Save" : "Ruaj",
+    "Your attendance was updated successfully." : "Pjesëmarrja juaj u përditësua me sukses.",
+    "Send invitations to attendees" : "Dërgo ftesa tek pjesëmarrësit"
 },
 "nplurals=2; plural=(n != 1);");
