@@ -5,18 +5,18 @@ OC.L10N.register(
     "Remote share" : "Vzdálené sdílení",
     "Remote share password" : "Heslo ke vzdálenému sdílení",
     "Cancel" : "Storno",
-    "Add remote share" : "Přidat propojené sdílení",
+    "Add remote share" : "Přidat vzdálené sdílení",
     "Copy" : "Kopie",
     "Copied!" : "Zkopírováno!",
     "Not supported!" : "Nepodporováno!",
-    "Press ⌘-C to copy." : "Zkopírujete stisknutím ⌘-C.",
-    "Press Ctrl-C to copy." : "Zmáčknout Ctrl-C pro kopírování.",
-    "Invalid Federated Cloud ID" : "Neplatné sdružené cloud ID",
+    "Press ⌘-C to copy." : "Zkopírujete stisknutím ⌘C.",
+    "Press Ctrl-C to copy." : "Zkopírujete stisknutím Ctrl+C.",
+    "Invalid Federated Cloud ID" : "Neplatný identifikátor federovaného cloudu",
     "Server to server sharing is not enabled on this server" : "Sdílení ze serveru na server není na tomto serveru povoleno",
-    "Couldn't establish a federated share." : "Nepodařilo se ustavit spojené sdílení.",
-    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodařilo se ustavit propojené sdílení, heslo může být nesprávné.",
+    "Couldn't establish a federated share." : "Nepodařilo se ustavit federované sdílení.",
+    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodařilo se ustavit federované sdílení – možná je nesprávné heslo.",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požadavek na spojené sdílení byl odeslán, obdržíte pozvánku. Zkontrolujte vaše upozornění.",
-    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodařilo se ustavit federované sdílení, vypadá to, že server, se kterým má být federováno je příliš starý (Nextcloud <= 9).",
+    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodařilo se ustavit federované sdílení – vypadá to, že server, se kterým má být federováno, je příliš starý (Nextcloud verze 9 a starší).",
     "It is not allowed to send federated group shares from this server." : "Z tohoto serveru není povoleno posílat federovaná skupinová sdílení.",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "Sdílení %1$s se nezdařilo, protože tato položka už je sdílena s %2$s",
     "Not allowed to create a federated share with the same user" : "Není povoleno vytvořit propojené sdílení s tím samým uživatelem",
@@ -24,10 +24,10 @@ OC.L10N.register(
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sdílení %1$s se nezdařilo, %2$s se nepodařilo nalézt, server pravděpodobně právě není dostupný nebo používá self-signed certifikát.",
     "Could not find share" : "Nedaří se nalézt sdílení",
     "Federated sharing" : "Federované sdílení",
-    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Obdržel(a) jste %3$s jako vzdálené sdílení od %1$s (jménem %2$s)",
-    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdržel(a) jste {share} jako vzdálené sdílení od {user} (jménem {behalf})",
-    "You received \"%3$s\" as a remote share from %1$s" : "Obdržel(a) jste %3$s jako vzdálené sdílení od %1$s",
-    "You received {share} as a remote share from {user}" : "Obdržel(a) jste {share} jako vzdálené sdílení od {user}",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Obdrželi jste „%3$s“ jako vzdálené sdílení od %4$s (%1$s) (na pokyn %5$s (%2$s))",
+    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdrželi jste {share} jako vzdálené sdílení od {user} (jménem {behalf})",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Obdrželi jste „%3$s“ jako vzdálené sdílení od %4$s (%1$s)",
+    "You received {share} as a remote share from {user}" : "Obdrželi jste {share} jako vzdálené sdílení od {user}",
     "Accept" : "Přijmout",
     "Decline" : "Zamítnout",
     "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Sdílej se mnou pomocí mého #Nextcloud sdruženého cloud ID, více na %s",
@@ -42,16 +42,16 @@ OC.L10N.register(
     "Allow users on this server to receive shares from other servers" : "Povolit uživatelům na tomto serveru přijímat sdílení z jiných serverů",
     "Allow users on this server to send shares to groups on other servers" : "Povolit uživatelům na tomto serveru zasílat sdílení skupinám na ostatních serverech",
     "Allow users on this server to receive group shares from other servers" : "Povolit uživatelům na tomto serveru přijímat skupinová sdílení z jiných serverů",
-    "Search global and public address book for users" : "Hledat uživatele v globálním a veřejném adresáři",
-    "Allow users to publish their data to a global and public address book" : "Povolit uživatelům publikování jejich dat do globálního a sdíleného adresáře",
+    "Search global and public address book for users" : "Hledat uživatele v globálním a veřejném adresáři kontaktů",
+    "Allow users to publish their data to a global and public address book" : "Povolit uživatelům publikování jejich dat do globálního a sdíleného adresáře kontaktů",
     "Federated Cloud" : "Sdružený cloud",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Můžete sdílet s kýmkoliv, kdo používá Nextcloud nebo jiný server či služby, kompatibilní se standardem Open Cloud Mesh (OCM)! Stačí do dialogu pro sdílení zadat jejich jejich identif. sdruženého cloudu. Má podobu person@cloud.example.com",
     "Your Federated Cloud ID:" : "Vaše sdružené cloud ID:",
-    "Share it so your friends can share files with you:" : "Nasdílejte to, aby mohli vaši přátelé sdílet soubory s vámi:",
+    "Share it so your friends can share files with you:" : "Podělte se o to, aby mohli vaši přátelé s vámi mohli sdílet soubory:",
     "Add to your website" : "Přidat na svou webovou stránku",
     "Share with me via Nextcloud" : "Sdíleno se mnou přes Nextcloud",
     "HTML Code:" : "HTML kód:",
-    "Sharing %s failed, because this item is already shared with %s" : "Sdílení položky %s se nezdařilo, protože položka už je s uživatelem %s sdílena",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sdílení %s selhalo, %s se nepodařilo nalézt, server pravděpodobně právě není dostupný nebo používá self-signed certifikát."
+    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Obdrželi jste %3$s jako vzdálené sdílení od %1$s (jménem %2$s)",
+    "You received \"%3$s\" as a remote share from %1$s" : "Obdrželi jste %3$s jako vzdálené sdílení od %1$s"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
