@@ -2,6 +2,9 @@
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
+ * @author Joas Schilling <coding@schilljs.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
  * @license AGPL-3.0
@@ -16,28 +19,42 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
 
 namespace OCA\Federation;
 
 use OC\BackgroundJob\TimedJob;
-use OCA\Federation\AppInfo\Application;
+use OCP\ILogger;
 
 class SyncJob extends TimedJob {
 
-	public function __construct() {
+	/** @var SyncFederationAddressBooks */
+	protected $syncService;
+
+	/** @var ILogger */
+	protected $logger;
+
+	/**
+	 * @param SyncFederationAddressBooks $syncService
+	 * @param ILogger $logger
+	 */
+	public function __construct(SyncFederationAddressBooks $syncService, ILogger $logger) {
 		// Run once a day
 		$this->setInterval(24 * 60 * 60);
+		$this->syncService = $syncService;
+		$this->logger = $logger;
 	}
 
 	protected function run($argument) {
-		$app = new Application();
-		$ss = $app->getSyncService();
-		$ss->syncThemAll(function($url, $ex) {
+		$this->syncService->syncThemAll(function($url, $ex) {
 			if ($ex instanceof \Exception) {
-				\OC::$server->getLogger()->error("Error while syncing $url : " . $ex->getMessage(), ['app' => 'fed-sync']);
+				$this->logger->logException($ex, [
+					'message' => "Error while syncing $url.",
+					'level' => ILogger::INFO,
+					'app' => 'fed-sync',
+				]);
 			}
 		});
 	}
