@@ -28,6 +28,7 @@ OC.L10N.register(
     "Rename" : "إعادة التسمية",
     "Copy" : "نسخ",
     "Open" : "افتح",
+    "Delete folder" : "حذف المجلد",
     "Disconnect storage" : "قطع اتصال التخزين",
     "Unshare" : "إلغاء المشاركة",
     "Could not load info for file \"{file}\"" : "لم يستطع تحميل معلومات الملف \"{file}\"",
@@ -88,11 +89,16 @@ OC.L10N.register(
     "An error occurred while trying to update the tags" : "حدث خطأ اثناء محاولة تحديث tags",
     "Added to favorites" : "تمت إضافته إلى المفضلة",
     "Removed from favorites" : "تمت إزالته مِن المفضلة",
+    "\"remote user\"" : "\"مستخدم عن بعد\"",
     "A new file or folder has been <strong>created</strong>" : "تم <strong>  إنشاء</strong> ملف جديد أو مجلد ",
+    "A file or folder has been <strong>deleted</strong>" : "تم <strong>حذف </strong> ملف أو مجلد",
+    "A file or folder has been <strong>restored</strong>" : "تم <strong> استعادة </strong> ملف أو مجلد",
     "Unlimited" : "غير محدود",
     "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
+    "Accept" : "قبول",
     "File Management" : "إدارة الملفات",
     "%s used" : "%s مُستخدَم",
+    "%1$s of %2$s used" : "تم استخدام %1$s من %2$s",
     "Settings" : "الإعدادات",
     "Show hidden files" : "عرض الملفات المخفية",
     "WebDAV" : "WebDAV",
@@ -109,10 +115,10 @@ OC.L10N.register(
     "Deleted files" : "الملفات المحذوفة",
     "Shares" : "التي قمتَ بمشاركتها",
     "Shared with others" : "شاركته مع الاخرين",
+    "Shared with you" : "شورك معك",
     "Shared by link" : "شاركته باستخدام رابط مشاركة",
     "Text file" : "ملف نصي",
     "New text file.txt" : "ملف نصي جديد fille.txt",
-    "Target folder" : "المجلد الهدف",
     "File handling" : "التعامل مع الملف",
     "Maximum upload size" : "الحد الأقصى لحجم الملفات التي يمكن رفعها",
     "max. possible: " : "الحد الأقصى المسموح به",
