@@ -18,9 +18,13 @@ OC.L10N.register(
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun pudo xubise {filename}, paez que ye un directoriu o tien 0 bytes",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu llibre, tas xubiendo {size1} pero namái falta {size2}",
     "Not enough free space" : "Nun hai espaciu llibre abondo",
+    "Uploading …" : "Xubiendo...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "Actions" : "Aiciones",
     "Rename" : "Renomar",
+    "Copy" : "Copiar",
+    "Delete file" : "Desasniciar ficheru",
+    "Delete folder" : "Desaniciar",
     "Disconnect storage" : "Desconeutar almacenamientu",
     "Unshare" : "Dexar de compartir",
     "Could not load info for file \"{file}\"" : "Nun pudo cargase la información del ficheru «{file}»",
@@ -41,6 +45,7 @@ OC.L10N.register(
     "Could not create file \"{file}\" because it already exists" : "Nun pudo crease'l ficheru \"{file}\" porque yá esiste",
     "Could not create folder \"{dir}\" because it already exists" : "Nun pudo crease la carpeta \"{dir}\" porque yá esiste",
     "Error deleting file \"{fileName}\"." : "Fallu borrando'l ficheru \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Nun hai resultaos de gueta n'otres carpetes pa {tag}{filter}{endtag}",
     "Name" : "Nome",
     "Size" : "Tamañu",
     "Modified" : "Modificáu",
@@ -52,6 +57,7 @@ OC.L10N.register(
     "New" : "Nuevu",
     "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
     "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
+    "\"{name}\" is not an allowed filetype" : "«{name}» nun ye una triba de ficheru permitida",
     "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'almacenamientu de {owner} ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
     "Your storage is full, files can not be updated or synced anymore!" : "L'almacenamientu ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'almacenamientu de {owner} ta casi completu ({usedSpacePercent}%)",
@@ -64,8 +70,12 @@ OC.L10N.register(
     "Favorited" : "Favoritos",
     "Favorite" : "Favoritu",
     "New folder" : "Nueva carpeta",
+    "Upload file" : "Xubir ficheru",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Add to favorites",
     "An error occurred while trying to update the tags" : "Hebo un fallu mientres s'intentaba actualizar les etiquetes",
     "Added to favorites" : "Amestóse a favoritos",
+    "\"remote user\"" : "«usuariu remotu»",
     "{user} created {file}" : "{user} creó {file}",
     "{file} was created in a public folder" : "{file} creóse nuna carpeta pública",
     "You changed {file}" : "Camudesti {file}",
@@ -78,8 +88,14 @@ OC.L10N.register(
     "{user} renamed {oldfile} to {newfile}" : "{user} renomó {oldfile} a {newfile}",
     "You moved {oldfile} to {newfile}" : "Moviesti {oldfile} a {newfile}",
     "A new file or folder has been <strong>created</strong>" : "<strong>Creóse</strong> un ficheru o carpeta nuevos",
+    "A file or folder has been <strong>deleted</strong>" : "<strong>Desanicióse</strong> un ficheru o carpeta",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Llendar les notificaciones tocantes a creación y cambeos a tos <strong>ficheros favoritos</strong <em>(namás Stream)</em>",
+    "A file or folder has been <strong>restored</strong>" : "<strong>Restauróse</strong> un ficheru o carpeta",
+    "Unlimited" : "Non llendáu",
     "Upload (max. %s)" : "Xuba (máx. %s)",
+    "Accept" : "Aceutar",
+    "Change" : "Camudar",
+    "%1$s of %2$s used" : "%1$s de %2$s usao",
     "Settings" : "Axustes",
     "Show hidden files" : "Amosar ficheros ocultos",
     "WebDAV" : "WebDAV",
@@ -93,14 +109,18 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Los ficheros y carpetes que marque como favoritos apaecerán equí",
     "Tags" : "Etiquetes",
     "Deleted files" : "Ficheros desaniciaos",
+    "Shares" : "Comparticiones",
+    "Shared with others" : "Compartío con otros",
+    "Shared with you" : "Shared with you",
+    "Shared by link" : "Compartíos per enllaz",
     "Text file" : "Ficheru de testu",
     "New text file.txt" : "Nuevu testu ficheru.txt",
-    "Target folder" : "Carpeta oxetivu",
     "File handling" : "Alministración de ficheros",
     "Maximum upload size" : "Tamañu máximu de xubida",
     "max. possible: " : "máx. posible:",
     "Save" : "Guardar",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM pue retrasase 5 minutos pa que los cambeos s'apliquen.",
-    "Missing permissions to edit from here." : "Falten permisos pa editar dende equí."
+    "Missing permissions to edit from here." : "Falten permisos pa editar dende equí.",
+    "Cancel upload" : "Encaboxar xuba"
 },
 "nplurals=2; plural=(n != 1);");
