@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Копирай",
     "Choose target folder" : "Избор на папка",
     "Open" : "Отвори",
+    "Delete file" : "Изтриване на файл",
+    "Delete folder" : "Изтриване на папка",
     "Disconnect storage" : "Извади хранилището",
     "Unshare" : "Прекратяване на споделяне",
     "Could not load info for file \"{file}\"" : "Информацията за файла \"{file}\" не може да бъде заредена",
@@ -45,6 +47,7 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Директорията не е налична. Проверете журнала или се свържете с администратора",
     "Could not move \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде преместен, дестинацията съществува",
     "Could not move \"{file}\"" : "Файлът \"{file}\" не може да бъде преместен",
+    "copy" : "Копиране",
     "Could not copy \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде копиран, дестинацията съществува",
     "Could not copy \"{file}\"" : "Файлът \"{file}\" не може да бъде копиран",
     "{newName} already exists" : "{newName} вече съществува",
@@ -65,6 +68,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
     "_Uploading %n file_::_Uploading %n files_" : ["Качване на %n файл","Качване на %n файла"],
     "New" : "Създай",
+    "Select file range" : "Избери от файловете",
     "{used} of {quota} used" : "{used} от {quota} използвани",
     "{used} used" : "{used} използвани",
     "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
@@ -77,6 +81,7 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)" : "Вашето хранилище е почти запълнено ({usedSpacePercent}%).",
     "_matches '{filter}'_::_match '{filter}'_" : ["пасва на '{filter}'","пасват на '{filter}'\n "],
     "View in folder" : "Преглед в папката",
+    "Copied!" : "Копирано!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Копирай директната връзка (ще работи само за потребители с достъп до файла/папката)",
     "Path" : "Път",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байта"],
@@ -84,6 +89,7 @@ OC.L10N.register(
     "Favorite" : "Любими",
     "New folder" : "Нова папка",
     "Upload file" : "Качи файл",
+    "Not favorited" : "Премахни от любими",
     "Remove from favorites" : "Премахни от любимите",
     "Add to favorites" : "Добави към любимите",
     "An error occurred while trying to update the tags" : "Възникна грешка при опита за промяна на етикети",
@@ -120,7 +126,16 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "<strong>Възстановяване</strong>на файл или папка",
     "Unlimited" : "Неограничено",
     "Upload (max. %s)" : "Качи (макс. %s)",
+    "Accept" : "Приемане",
+    "Reject" : "Откажи",
+    "Ownership transfer done" : "Промяната на собственик е успешна",
     "File Management" : "Управление на файлове",
+    "Change" : "Промени",
+    "New owner" : "Нов собственик",
+    "Search users" : "Търсене за потребители",
+    "Transfer" : "Прехвърли",
+    "Invalid path selected" : "Предоставен е невалиден път до файл.",
+    "Error while loading the file data" : "Грешка при зареждането на файловете.",
     "%s used" : "%s използвани",
     "%s%% of %s used" : "%s%% от %s използвани",
     "%1$s of %2$s used" : "%1$s от %2$s използвани",
