@@ -136,7 +136,9 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "S'ha <strong>restaurat</strong> un fitxer o una carpeta",
     "Unlimited" : "Il·limitat",
     "Upload (max. %s)" : "Càrrega (màx. %s)",
+    "Accept" : "Accepta",
     "File Management" : "Gestió de fitxers",
+    "Change" : "Canvia",
     "Error while loading the file data" : "S'ha produït un error mentre es carregava la informació de l'arxiu",
     "Unable to change the favourite state of the file" : "No s'ha pogut canviar l'estat de favorit de l'arxiu",
     "%s used" : "%s utilitzat",
