@@ -110,9 +110,9 @@ OC.L10N.register(
     "Moved by {user}" : "Verschoben durch {user}",
     "\"remote user\"" : "„Externer Benutzer“",
     "You created {file}" : "Du hast {file} erstellt",
-    "You created an encrypted file in {file}" : "Du hast die verschlüsselte Datei in {file} erstellt",
+    "You created an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} erstellt",
     "{user} created {file}" : "{user} hat {file} erstellt",
-    "{user} created an encrypted file in {file}" : "{user} hat die verschlüsselte Datei in {file} erstellt",
+    "{user} created an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} erstellt",
     "{file} was created in a public folder" : "{file} wurde in einem öffentlichen Ordner erstellt",
     "You changed {file}" : "Du hast {file} geändert",
     "You changed an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} geändert",
@@ -121,7 +121,7 @@ OC.L10N.register(
     "You deleted {file}" : "Du hast {file} gelöscht",
     "You deleted an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} gelöscht",
     "{user} deleted {file}" : "{user} hat {file} gelöscht",
-    "{user} deleted an encrypted file in {file}" : "{user} hat die verschlüsselte Datei in {file} gelöscht",
+    "{user} deleted an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} gelöscht",
     "You restored {file}" : "Du hast {file} wiederhergestellt",
     "{user} restored {file}" : "{user} hat {file} wiederhergestellt",
     "You renamed {oldfile} to {newfile}" : "Du hast {oldfile} in {newfile} umbenannt",
@@ -136,7 +136,27 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Eine Datei oder ein Ordner wurde <strong>wiederhergestellt</strong>",
     "Unlimited" : "Unbegrenzt",
     "Upload (max. %s)" : "Hochladen (max. %s)",
+    "Accept" : "Akzeptieren",
+    "Reject" : "Ablehnen",
+    "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Soll {path} angenommen werden?\n\nInfo: Der Übertragungsprozess nach der Annahme kann bis zu einer Stunde dauern.",
+    "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
+    "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
+    "The ownership transfer of {path} from {user} failed." : "Die Übertragung von {path} ist fehlgeschlagen.",
+    "Ownership transfer done" : "Besitzübertragung abgeschlossen",
+    "Your ownership transfer of {path} to {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
+    "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
     "File Management" : "Dateiverwaltung",
+    "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
+    "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
+    "Change" : "Ändern",
+    "New owner" : "Neuer Besitzer",
+    "Search users" : "Suche Nutzer",
+    "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
+    "Transfer" : "Übertragen",
+    "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
+    "Invalid path selected" : "Ungültiger Dateipfad ausgewählt",
+    "Ownership transfer request sent" : "Anforderung für die Übertragung des Besitzes versandt",
     "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
     "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei kann nicht geändert werden",
     "%s used" : "%s verwendet",
@@ -162,6 +182,7 @@ OC.L10N.register(
     "Shared with you" : "Mit Dir geteilt",
     "Shared by link" : "Über einen Link geteilt",
     "Deleted shares" : "Gelöschte Freigaben",
+    "Pending shares" : "Ausstehende Freigaben",
     "Text file" : "Textdatei",
     "New text file.txt" : "Neue Textdatei file.txt",
     "File handling" : "Dateibehandlung",
