@@ -27,6 +27,8 @@ OC.L10N.register(
     "Actions" : "Actions",
     "Rename" : "Rename",
     "Copy" : "Copy",
+    "Delete file" : "Delete file",
+    "Delete folder" : "Delete folder",
     "Disconnect storage" : "Disconnect storage",
     "Unshare" : "Unshare",
     "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
@@ -125,8 +127,11 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
     "Unlimited" : "Unlimited",
     "Upload (max. %s)" : "Upload (max. %s)",
-    "%s of %s used" : "%s of %s used",
+    "Accept" : "Accept",
+    "File Management" : "File Management",
+    "Change" : "Change",
     "%s used" : "%s used",
+    "%1$s of %2$s used" : "%1$s of %2$s used",
     "Settings" : "Settings",
     "Show hidden files" : "Show hidden files",
     "WebDAV" : "WebDAV",
@@ -141,18 +146,19 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
     "Tags" : "Tags",
     "Deleted files" : "Deleted files",
+    "Shares" : "Shares",
     "Shared with others" : "Shared with others",
     "Shared with you" : "Shared with you",
     "Shared by link" : "Shared by link",
     "Text file" : "Text file",
     "New text file.txt" : "New text file.txt",
-    "Target folder" : "Target folder",
     "File handling" : "File handling",
     "Maximum upload size" : "Maximum upload size",
     "max. possible: " : "max. possible: ",
     "Save" : "Save",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "With PHP-FPM it might take 5 minutes for changes to be applied.",
     "Missing permissions to edit from here." : "Missing permissions to edit from here.",
-    "Cancel upload" : "Cancel upload"
+    "Cancel upload" : "Cancel upload",
+    "%s of %s used" : "%s of %s used"
 },
 "nplurals=2; plural=(n != 1);");
