@@ -136,7 +136,10 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Dosiero aŭ dosierujo <strong>restaŭrita</strong>",
     "Unlimited" : "Senlima",
     "Upload (max. %s)" : "Alŝuti (maks. %s)",
+    "Accept" : "Akcepti",
+    "Reject" : "Rifuzi",
     "File Management" : "Dosieradministrado",
+    "Change" : "Ŝanĝi",
     "Error while loading the file data" : "Eraro dum ŝargo de la dosierdatumoj",
     "Unable to change the favourite state of the file" : "Ne eblas ŝanĝi la staton pri pliŝatataĵo de la dosiero",
     "%s used" : "%s uzataj",
