@@ -14,16 +14,16 @@ OC.L10N.register(
     "Home" : "Inicio",
     "Close" : "Cerrar",
     "Could not create folder \"{dir}\"" : "No se pudo crear la carpeta \"{dir}\"",
-    "This will stop your current uploads." : "Esto detendrá las actuales subidas.",
+    "This will stop your current uploads." : "Esto detendrá las subidas en curso.",
     "Upload cancelled." : "Subida cancelada.",
-    "Processing files …" : "Procesando archivos...",
-    "…" : "...",
+    "Processing files …" : "Procesando archivos …",
+    "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
     "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
     "Not enough free space" : "No hay espacio libre suficiente",
     "An unknown error has occurred" : "Ha ocurrido un error desconocido",
-    "Uploading …" : "Subiendo...",
+    "Uploading …" : "Subiendo …",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Subir este archivo no es compatible",
     "Target folder does not exist any more" : "La carpeta destino ya no existe",
@@ -94,13 +94,13 @@ OC.L10N.register(
     "New folder" : "Nueva carpeta",
     "Upload file" : "Subir archivo",
     "Not favorited" : "Quitado como favorito",
-    "Remove from favorites" : "Eliminar de favoritos",
+    "Remove from favorites" : "Quitar de favoritos",
     "Add to favorites" : "Añadir a favoritos",
     "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
     "Added to favorites" : "Agregado a favoritos",
-    "Removed from favorites" : "Borrado de favoritos",
+    "Removed from favorites" : "Quitado de favoritos",
     "You added {file} to your favorites" : "Has agregado {file} a tus favoritos",
-    "You removed {file} from your favorites" : "Has borrado {file} de tus favoritos",
+    "You removed {file} from your favorites" : "Has quitado {file} de tus favoritos",
     "File changes" : "Cambios del archivo",
     "Created by {user}" : "Creado por {user}",
     "Changed by {user}" : "Modificado por {user}",
@@ -124,7 +124,7 @@ OC.L10N.register(
     "{user} deleted an encrypted file in {file}" : "{user} ha borrado un archivo cifrado en {file}",
     "You restored {file}" : "Has restaurado {file}",
     "{user} restored {file}" : "{user} restauró {file}",
-    "You renamed {oldfile} to {newfile}" : "Has renombrado {oldfile} como {newfile}",
+    "You renamed {oldfile} to {newfile}" : "Has renombrado {oldfile} a {newfile}",
     "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile} a {newfile}",
     "You moved {oldfile} to {newfile}" : "Has movido {oldfile} a {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
@@ -138,12 +138,12 @@ OC.L10N.register(
     "Upload (max. %s)" : "Subida (máx. %s)",
     "Accept" : "Aceptar",
     "Reject" : "Rechazar",
-    "Incoming ownership transfer from {user}" : "Ha llegado un cambio de la propiedad de {user}",
-    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Deseas acceptar {path}?\n\nNota: El proceso de transferencia tras aceptar puede llevar una hora.",
+    "Incoming ownership transfer from {user}" : "Ha llegado una transferencia de propiedad de {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Deseas aceptar {path}?\n\nNota: El proceso de transferencia tras aceptar podría tardar hasta 1 hora.",
     "Ownership transfer failed" : "Fallo al transferir la propiedad",
     "Your ownership transfer of {path} to {user} failed." : "Ha fallado tu transferencia de propiedad de {path} a {user}.",
     "The ownership transfer of {path} from {user} failed." : "Ha fallado la transferencia de propiedad de {path} desde {user}.",
-    "Ownership transfer done" : "Realizada la transferencia de propiedad",
+    "Ownership transfer done" : "Transferencia de propiedad realizada",
     "Your ownership transfer of {path} to {user} has completed." : "Se ha completado su transferencia de propiedad de {path} a {user}.",
     "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
     "File Management" : "Gestión de archivos",
@@ -155,13 +155,13 @@ OC.L10N.register(
     "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
     "Transfer" : "Transferir",
     "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
-    "Invalid path selected" : "Ruta de archivo seleccionada inválida.",
+    "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
     "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
-    "Error while loading the file data" : "Error al cargar el archivo de datos",
+    "Error while loading the file data" : "Error al cargar los datos del archivo",
     "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
     "%s used" : "usado %s",
     "%s%% of %s used" : "%s%% de %s usado",
-    "%1$s of %2$s used" : "%1$s de %2$s utilizados",
+    "%1$s of %2$s used" : "%1$s de %2$s usados",
     "Settings" : "Ajustes",
     "Show hidden files" : "Mostrar archivos ocultos",
     "WebDAV" : "WebDAV",
@@ -182,10 +182,11 @@ OC.L10N.register(
     "Shared with you" : "Compartido conmigo",
     "Shared by link" : "Compartido por enlace",
     "Deleted shares" : "Recursos compartidos eliminados",
+    "Pending shares" : "Recursos compartidos pendientes",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo archivo.txt",
     "File handling" : "Manejo de archivos",
-    "Maximum upload size" : "Tamaño de subida máximo ",
+    "Maximum upload size" : "Tamaño máximo de subida",
     "max. possible: " : "máx. posible: ",
     "Save" : "Guardar",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tardar hasta 5 minutos en realizarse los cambios.",
