@@ -30,6 +30,8 @@ OC.L10N.register(
     "Copy" : "Copiar",
     "Choose target folder" : "Elegir carpeta destino",
     "Open" : "Abrir",
+    "Delete file" : "Borrar archivo",
+    "Delete folder" : "Borrar carpeta",
     "Disconnect storage" : "Desconectar almacenamiento",
     "Unshare" : "Dejar de compartir",
     "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
@@ -114,11 +116,15 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de sus strong>favoritos</strong>",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado </strong> o <strong>renombrado</strong>",
     "A new file or folder has been <strong>created</strong>" : "Un nuevo archivo ha sido <strong>creado</strong>",
+    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite las notificación de la creación y cambios a sus <strong>archivos favoritos</strong> <em>(sólo flujo)</em>",
     "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Cargar (max. %s)",
+    "Accept" : "Aceptar",
     "File Management" : "Administración de Archivos",
+    "Change" : "Cambiar",
     "%s used" : "%s usado",
+    "%1$s of %2$s used" : "%1$s de %2$s usados",
     "Settings" : "Configuraciones ",
     "Show hidden files" : "Mostrar archivos ocultos",
     "WebDAV" : "WebDAV",
@@ -133,6 +139,7 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marque como favortios se mostrarán aquí. ",
     "Tags" : "Etiquetas",
     "Deleted files" : "Archivos borrados",
+    "Shares" : "Shares",
     "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido con usted",
     "Shared by link" : "Compartido por link",
