@@ -26,6 +26,9 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Se presentó un error al ensamblar los bloques, código de estatus {status}",
     "Actions" : "Acciones",
     "Rename" : "Renombrar",
+    "Copy" : "Copiar",
+    "Delete file" : "Borrar archivo",
+    "Delete folder" : "Borrar carpeta",
     "Disconnect storage" : "Desconectar almacenamiento",
     "Unshare" : "Dejar de compartir",
     "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
@@ -115,14 +118,10 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
     "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Cargar (max. %s)",
-    "File handling" : "Manejo de archivos",
-    "Maximum upload size" : "Tamaño máximo de carga",
-    "max. possible: " : "max. posible:",
-    "Save" : "Guardar",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tomar 5 minutos para que los cambios apliquen. ",
-    "Missing permissions to edit from here." : "Faltan privilegios para editar desde aquí. ",
-    "%s of %s used" : "%s de %s usado",
+    "Accept" : "Aceptar",
+    "Change" : "Cambiar",
     "%s used" : "%s usado",
+    "%1$s of %2$s used" : "%1$s de %2$s usados",
     "Settings" : "Configuraciones ",
     "Show hidden files" : "Mostrar archivos ocultos",
     "WebDAV" : "WebDAV",
@@ -137,12 +136,19 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
     "Tags" : "Etiquetas",
     "Deleted files" : "Archivos borrados",
+    "Shares" : "Elementos compartidos",
     "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido con usted",
     "Shared by link" : "Compartido por liga",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
-    "Target folder" : "Carpeta destino",
-    "Cancel upload" : "Cancelar carga"
+    "File handling" : "Manejo de archivos",
+    "Maximum upload size" : "Tamaño máximo de carga",
+    "max. possible: " : "max. posible:",
+    "Save" : "Guardar",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tomar 5 minutos para que los cambios apliquen. ",
+    "Missing permissions to edit from here." : "Faltan privilegios para editar desde aquí. ",
+    "Cancel upload" : "Cancelar carga",
+    "%s of %s used" : "%s de %s usado"
 },
 "nplurals=2; plural=(n != 1);");
