@@ -21,7 +21,7 @@ OC.L10N.register(
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} kargatu karpeta bat delako edo 0 byte dituelako",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ez dago leku nahikorik, {size1} kargatzen ari zara baina {size2} daude libre soilik",
     "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" helburuko karpeta ez da existitzen jadanik",
-    "Not enough free space" : "Ez dago leku libre nahikoa",
+    "Not enough free space" : "Ez dago leku libre nahikorik",
     "An unknown error has occurred" : "Errore ezezagun bat gertatu da",
     "Uploading …" : "Kargatzen...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Kopiatu",
     "Choose target folder" : "Aukeratu helburuko karpeta",
     "Open" : "Ireki",
+    "Delete file" : "Ezabatu fitxategia",
+    "Delete folder" : "Ezabatu karpeta",
     "Disconnect storage" : "Deskonektatu biltegia",
     "Unshare" : "Ez partekatu",
     "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
@@ -51,7 +53,7 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "{origin} {destination} barruan kopiatu da",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} eta beste {nbfiles} fitxategi {destination} barruan kopiatu dira",
     "{newName} already exists" : "{newName} existitzen da dagoeneko",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Ezin izan da \"{fileName}\" berrizendatu, ez da existitzen jadanik",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Ezin izan da \"{fileName}\" berrizendatu, ez da existitzen jada",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" izena dagoeneko erabiltzen da \"{dir}\" karpetan. Aukeratu beste izen bat.",
     "Could not rename \"{fileName}\"" : "Ezin izan da \"{fileName}\" berrizendatu ",
     "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
@@ -62,11 +64,11 @@ OC.L10N.register(
     "Name" : "Izena",
     "Size" : "Tamaina",
     "Modified" : "Aldatuta",
-    "_%n folder_::_%n folders_" : ["karpeta %n","%n karpeta"],
-    "_%n file_::_%n files_" : ["fitxategi %n","%n fitxategi"],
+    "_%n folder_::_%n folders_" : ["Karpeta %n","%n karpeta"],
+    "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
     "{dirs} and {files}" : "{dirs} eta {files}",
     "_including %n hidden_::_including %n hidden_" : ["ezkutuko %n barne","ezkutuko %n barne"],
-    "You don’t have permission to upload or create files here" : "Ez duzu fitxategiak hona igotzeko edo hemen sortzeko baimenik",
+    "You don’t have permission to upload or create files here" : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko",
     "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n kargatzen","%n fitxategi kargatzen"],
     "New" : "Berria",
     "Select file range" : "Hautatu fitxategi-barrutia",
@@ -76,19 +78,19 @@ OC.L10N.register(
     "File name cannot be empty." : "Fitxategi-izena ezin da hutsa izan.",
     "\"/\" is not allowed inside a file name." : "\"/\" ez da onartzen fitxategi-izenen barnean.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi-mota ez da onartzen",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner}(e)n biltegia beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu jada!",
+    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} erabiltzailearen biltegia beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu jada!",
     "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegia beteta dago, ezin duzu fitxategirik igo edo sinkronizatu jada!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner}(e)n biltegia ia beteta dago ({usedSpacePercent}%)",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} erabiltzailearen biltegia ia beteta dago ({usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegia ia beteta dago (%{usedSpacePercent})",
-    "_matches '{filter}'_::_match '{filter}'_" : ["bat dator '{filter}'(e)kin","bat datoz '{filter}'(e)kin"],
+    "_matches '{filter}'_::_match '{filter}'_" : ["bat dator '{filter}' iragazkiarekin","bat datoz '{filter}' iragazkiarekin"],
     "View in folder" : "Ikusi karpetan",
     "Copied!" : "Kopiatua!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
     "Path" : "Bidea",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
-    "Favorited" : "Gogoko egina",
+    "Favorited" : "Gogoko gisa markatua",
     "Favorite" : "Gogokoa",
-    "You can only favorite a single file or folder at a time" : "Fitxategi edo karpeta bakarra egin dezakezu gogoko aldiko",
+    "You can only favorite a single file or folder at a time" : "Fitxategi edo karpeta bakarra markatu dezakezu gogoko gisa aldiko",
     "New folder" : "Karpeta berria",
     "Upload file" : "Kargatu fitxategia",
     "Not favorited" : "Ez da gogokoa",
@@ -100,32 +102,32 @@ OC.L10N.register(
     "You added {file} to your favorites" : "{file} gehitu duzu gogokoetara",
     "You removed {file} from your favorites" : "{file} kendu duzu gogokoetatik",
     "File changes" : "Fitxategi aldaketak",
-    "Created by {user}" : "{user}(e)k sortua",
-    "Changed by {user}" : "{user}(e)k aldatua",
-    "Deleted by {user}" : "{user}(e)k ezabatua",
-    "Restored by {user}" : "{user}(e)k leheneratua",
-    "Renamed by {user}" : "{user}(e)k berrizendatua",
-    "Moved by {user}" : "{user}(e)k lekuz aldatua",
+    "Created by {user}" : "{user} erabiltzaileak sortua",
+    "Changed by {user}" : "{user} erabiltzaileak aldatua",
+    "Deleted by {user}" : "{user} erabiltzaileak ezabatua",
+    "Restored by {user}" : "{user} erabiltzaileak leheneratua",
+    "Renamed by {user}" : "{user} erabiltzaileak berrizendatua",
+    "Moved by {user}" : "{user} erabiltzaileak lekuz aldatua",
     "\"remote user\"" : "\"urruneko erabiltzailea\"",
     "You created {file}" : "{file} sortu duzu",
-    "You created an encrypted file in {file}" : "{file}(e)n enkriptatutako fitxategi bat sortu duzu",
-    "{user} created {file}" : "{user}(e)k {file} sortu du",
-    "{user} created an encrypted file in {file}" : "{user}(e)k enkriptatutako fitxategi bat sortu du {file}(e)n",
-    "{file} was created in a public folder" : "{file} karpeta publiko batean sortu da",
+    "You created an encrypted file in {file}" : "{file} karpetan enkriptatutako fitxategi bat sortu duzu",
+    "{user} created {file}" : "{user} erabiltzaileak {file} sortu du",
+    "{user} created an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat sortu du {file} karpetan",
+    "{file} was created in a public folder" : "{file} sortu da karpeta publiko batean",
     "You changed {file}" : "{file} aldatu duzu",
-    "You changed an encrypted file in {file}" : "{file}(e)n enkriptatutako fitxategi bat aldatu duzu",
-    "{user} changed {file}" : "{user}(e)k {file} aldatu du",
-    "{user} changed an encrypted file in {file}" : "{user}(e)k enkriptatutako fitxategi bat aldatu du {file}(e)n",
+    "You changed an encrypted file in {file}" : "{file} karpetan enkriptatutako fitxategi bat aldatu duzu",
+    "{user} changed {file}" : "{user} erabiltzaileak {file} aldatu du",
+    "{user} changed an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat aldatu du {file} karpetan",
     "You deleted {file}" : "{file} ezabatu duzu",
-    "You deleted an encrypted file in {file}" : "Enkriptatutako fitxategi bat ezabatu duzu {file}(e)n",
-    "{user} deleted {file}" : "{user}(e)k {file} ezabatu du",
-    "{user} deleted an encrypted file in {file}" : "{user}(e)k enkriptatutako fitxategi bat ezabatu du {file}(e)n",
+    "You deleted an encrypted file in {file}" : "Enkriptatutako fitxategi bat ezabatu duzu {file} karpetan",
+    "{user} deleted {file}" : "{user} erabiltzaileak {file} ezabatu du",
+    "{user} deleted an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat ezabatu du {file} karpetan",
     "You restored {file}" : "{file} leheneratu duzu",
-    "{user} restored {file}" : "{user}(e)k {file} leheneratu du",
+    "{user} restored {file}" : "{user} erabiltzaileak {file} leheneratu du",
     "You renamed {oldfile} to {newfile}" : "{oldfile} {newfile} bezala berrizendatu duzu",
-    "{user} renamed {oldfile} to {newfile}" : "{user}(e)k {oldfile} {newfile} bezala berrizendatu du",
+    "{user} renamed {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} {newfile} bezala berrizendatu du",
     "You moved {oldfile} to {newfile}" : "{oldfile} lekuz aldatu duzu {newfile}(e)ra",
-    "{user} moved {oldfile} to {newfile}" : "{user}(e)k {oldfile} lekuz aldatu du {newfile}(e)ra",
+    "{user} moved {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} lekuz aldatu du {newfile}(e)ra",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Fitxategi bat gehitu edo kendu da zure <strong>gogokoetatik</strong>",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu</strong> edo <strong>berrizendatu</strong> da",
     "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu</strong> da",
@@ -133,11 +135,17 @@ OC.L10N.register(
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Mugatu <strong>gogoko fitxategien</strong> sorrera eta aldaketen jakinarazpenak <em>(Jarioa soilik)</em>",
     "A file or folder has been <strong>restored</strong>" : "Fitxategia edo karpeta bat <strong>leheneratu</strong> da",
     "Unlimited" : "Mugarik gabe",
-    "Upload (max. %s)" : "Kargatu (max. %s)",
+    "Upload (max. %s)" : "Kargatu (%s gehienez)",
+    "Accept" : "Onartu",
     "File Management" : "Fitxategi-kudeaketa",
+    "Change" : "Aldatu",
+    "Invalid path selected" : "Bide baliogabea hautatuta",
+    "Ownership transfer request sent" : "Jabetza transferentzia eskaera bidalita",
+    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
+    "Unable to change the favourite state of the file" : "Ezinezkoa fitxategiaren gogoko egoera aldatzea",
     "%s used" : "%s erabilita",
     "%s%% of %s used" : "%s%% / %s erabilita",
-    "%1$s of %2$s used" : "%1$s / %2$s(e)tik erabilita",
+    "%1$s of %2$s used" : "%1$s / %2$s erabilita",
     "Settings" : "Ezarpenak",
     "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
     "WebDAV" : "WebDAV",
@@ -162,12 +170,12 @@ OC.L10N.register(
     "New text file.txt" : "Testu-fitxategi berria.txt",
     "File handling" : "Fitxategien kudeaketa",
     "Maximum upload size" : "Karga daitekeen gehienezko tamaina",
-    "max. possible: " : "max, posiblea:",
+    "max. possible: " : "gehienez:",
     "Save" : "Gorde",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPMrekin 5 minutu pasa daitezke aldaketak aplikatu arte.",
-    "Missing permissions to edit from here." : "Hemen editatzeko baimenik ez duzu.",
+    "Missing permissions to edit from here." : "Hemendik editatzeko baimenik ez duzu.",
     "Cancel upload" : "Karga bertan behera utzita",
-    "%s of %s used" : "%s / %s(e)tik erabilita",
-    "%1$s%% of %2$s used" : "%1$s%% / %2$s(e)tik erabilita"
+    "%s of %s used" : "%s / %s erabilita",
+    "%1$s%% of %2$s used" : "%1$s%% / %2$serabilita"
 },
 "nplurals=2; plural=(n != 1);");
