@@ -136,7 +136,9 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Tiedosto tai kansio on <strong>palautettu</strong>",
     "Unlimited" : "Rajoittamaton",
     "Upload (max. %s)" : "Lähetys (enintään %s)",
+    "Accept" : "Hyväksy",
     "File Management" : "Tiedostohallinta",
+    "Change" : "Muuta",
     "%s used" : "%s käytetty",
     "%s%% of %s used" : "%s%% / %s käytetty",
     "%1$s of %2$s used" : "%1$s/%2$s käytetty",
