@@ -138,12 +138,17 @@ OC.L10N.register(
     "Upload (max. %s)" : "Envoi (max. %s)",
     "Accept" : "Accepter",
     "Reject" : "Refuser",
+    "Ownership transfer failed" : "Le transfert de propriétaire a échoué",
     "Ownership transfer done" : "Transfert de propriétaire terminé",
     "File Management" : "Gestion de fichier",
+    "Transfer ownership of a file or folder" : "Transférer la propriété d'un fichier ou d'un dossier",
+    "Choose file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
     "Change" : "Modifier",
     "New owner" : "Nouveau propriétaire",
     "Search users" : "Rechercher des utilisateurs",
+    "Choose a file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
     "Transfer" : "Transférer",
+    "Transfer {path} to {userid}" : "Transférer {path} à {userid}",
     "Invalid path selected" : "Chemin sélectionné non valide",
     "Ownership transfer request sent" : "Requête de transfert de propriété envoyée",
     "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
@@ -171,6 +176,7 @@ OC.L10N.register(
     "Shared with you" : "Partagés avec vous",
     "Shared by link" : "Partagés par lien",
     "Deleted shares" : "Partages supprimés",
+    "Pending shares" : "Partages en attente",
     "Text file" : "Fichier texte",
     "New text file.txt" : "Nouveau fichier texte.txt",
     "File handling" : "Gestion de fichiers",
