@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "העתקה",
     "Choose target folder" : "נא לבחור תיקיית יעד",
     "Open" : "פתיחה",
+    "Delete file" : "מחיקת קבצים",
+    "Delete folder" : "מחיקת תיקייה",
     "Disconnect storage" : "ניתוק אחסון",
     "Unshare" : "הסר שיתוף",
     "Could not load info for file \"{file}\"" : "לא ניתן לטעון מידע על הקובץ „{file}”",
@@ -134,7 +136,9 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "קובץ או תיקייה <strong>שוחזרו</strong>",
     "Unlimited" : "ללא הגבלה",
     "Upload (max. %s)" : "העלאה (מקסימום %s)",
+    "Accept" : "קבלה",
     "File Management" : "ניהול קבצים",
+    "Change" : "שינוי",
     "%s used" : "%s בשימוש",
     "%1$s of %2$s used" : "%1$s מתוך %2$s בשימוש",
     "Settings" : "הגדרות",
