@@ -136,7 +136,10 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Datoteka ili mapa je <strong>vraćena</strong>",
     "Unlimited" : "Neograničeno",
     "Upload (max. %s)" : "Otprema (maks. %s)",
+    "Accept" : "Prihvati",
+    "Reject" : "Odbij",
     "File Management" : "Upravljanje datotekama",
+    "Change" : "Promijeni",
     "%s used" : "Iskorišteno %s",
     "%s%% of %s used" : "Iskorišteno %s%% od %s",
     "%1$s of %2$s used" : "Iskorišteno %1$s od %2$s",
