@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Másolás",
     "Choose target folder" : "Válasszon célmappát",
     "Open" : "Megnyitás",
+    "Delete file" : "Fájl törlése",
+    "Delete folder" : "Mappa törlés",
     "Disconnect storage" : "Tároló leválasztása",
     "Unshare" : "Megosztás visszavonása",
     "Could not load info for file \"{file}\"" : "Nem sikerült betölteni a(z) „{file}” fájl információit",
@@ -134,7 +136,9 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Egy új fájl vagy mappa <strong>visszaállítva</strong>",
     "Unlimited" : "Korlátlan",
     "Upload (max. %s)" : "Feltöltés (max.: %s)",
+    "Accept" : "Elfogad",
     "File Management" : "Fájlkezelés",
+    "Change" : "Módosít",
     "%s used" : "%s használt",
     "%1$s of %2$s used" : "%1$s a %2$s-ból használva",
     "Settings" : "Beállítások",
