@@ -21,6 +21,8 @@ OC.L10N.register(
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "Actions" : "Actiones",
     "Rename" : "Renominar",
+    "Copy" : "Copiar",
+    "Delete folder" : "Deler dossier",
     "Disconnect storage" : "Immagazinage disconnectite ",
     "Unshare" : "Leva sin compartir",
     "Could not load info for file \"{file}\"" : "Impossibile cargar informationes pro file \"{file}\"",
@@ -61,11 +63,15 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)" : "Tu immagazinage es quasi plen ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["corresponde '{filter}'","corresponde '{filter}'"],
     "View in folder" : "Vider in dossier",
+    "Copied!" : "Copiate!",
     "Path" : "Sentiero",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Favorite",
     "Favorite" : "Favorite",
     "New folder" : "Nove dossier",
+    "Upload file" : "Upload file",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Add to favorites",
     "An error occurred while trying to update the tags" : "Un error occurreva durante le actualisation del etiquettas",
     "Added to favorites" : "Addite al favoritos",
     "Removed from favorites" : "Removite del favoritos",
@@ -78,6 +84,7 @@ OC.L10N.register(
     "Restored by {user}" : "Restaurate per {user}",
     "Renamed by {user}" : "Renominate per {user}",
     "Moved by {user}" : "Displaciate per {user}",
+    "\"remote user\"" : "\"usator remote\"",
     "You created {file}" : "Tu creava {file}",
     "{user} created {file}" : "{user} creava {file}",
     "{file} was created in a public folder" : "{file} esseva create in un dossier public",
@@ -94,8 +101,13 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un file esseva addite a o removite de tu <strong>favoritos</strong>",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un nove file o dossier ha essite <strong>delite</strong> o <strong>renominate</strong>",
     "A new file or folder has been <strong>created</strong>" : "Un nove file o dossier ha essite <strong>create</strong>",
+    "A file or folder has been <strong>deleted</strong>" : "Un file o dossier ha essite <strong>delite</strong>",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar notificationes concernente le creation e le modification de tu <strong>files favorite</strong> <em>(Solmente fluxo)</em>",
+    "A file or folder has been <strong>restored</strong>" : "Un file o un dossier ha essite <strong>restabilite</strong>",
+    "Unlimited" : "Ilimitate",
     "Upload (max. %s)" : "Incarga (maxime %s)",
+    "Accept" : "Acceptar",
+    "%1$s of %2$s used" : "%1$s de %2$s usate",
     "Settings" : "Configurationes",
     "Show hidden files" : "Monstrar files occultate",
     "WebDAV" : "WebDAV",
@@ -108,17 +120,18 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Files e dossiers que tu marca como favorito essera monstrate ci",
     "Tags" : "Etiquettas",
     "Deleted files" : "Files delite",
+    "Shares" : "Compartimentos",
     "Shared with others" : "Compartite con alteres",
     "Shared with you" : "Compartite con te",
     "Shared by link" : "Compartite per ligamine",
     "Text file" : "File de texto",
     "New text file.txt" : "Nove texto file.txt",
-    "Target folder" : "Dossier de destination",
     "File handling" : "Gestion de file",
     "Maximum upload size" : "Maxime dimension de incarga",
     "max. possible: " : "maxime possibile:",
     "Save" : "Salveguardar",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM possibilemente il requirera 5 minutas pro modificationes esser applicate.",
-    "Missing permissions to edit from here." : "Il manca permissiones pro modificar desde ci."
+    "Missing permissions to edit from here." : "Il manca permissiones pro modificar desde ci.",
+    "Cancel upload" : "Cancellar incarga"
 },
 "nplurals=2; plural=(n != 1);");
