@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Afrita",
     "Choose target folder" : "Veldu úttaksmöppu",
     "Open" : "Opna",
+    "Delete file" : "Eyða skrá",
+    "Delete folder" : "Eyða möppu",
     "Disconnect storage" : "Aftengja geymslu",
     "Unshare" : "Hætta deilingu",
     "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
@@ -134,7 +136,10 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Skjal eða mappa hefur verið <strong>endurheimt</strong>",
     "Unlimited" : "Ótakmarkað",
     "Upload (max. %s)" : "Senda inn (hám. %s)",
+    "Accept" : "Samþykkja",
+    "Reject" : "Hafna",
     "File Management" : "Skráastjórnun",
+    "Change" : "Breyta",
     "%s used" : "%s notað",
     "%s%% of %s used" : "%s%% af %s notað",
     "%1$s of %2$s used" : "%1$s af %2$s notað",
