@@ -139,8 +139,13 @@ OC.L10N.register(
     "Accept" : "Accetta",
     "Reject" : "Rifiuta",
     "Incoming ownership transfer from {user}" : "Trasferimento di proprietà in ingressso da {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vuoi accettare {path}?\n\nNota: il processo di trasferimento dopo l'accettazione potrebbe richiedere fino a un'ora.",
     "Ownership transfer failed" : "Trasferimento di proprietà non riuscito",
+    "Your ownership transfer of {path} to {user} failed." : "Il tuo trasferimento di proprietà di {path} a {user} non è riuscito.",
+    "The ownership transfer of {path} from {user} failed." : "Il trasferimento di proprietà di {path} da {user} non è riuscito.",
     "Ownership transfer done" : "Trasferimento di proprietà completato",
+    "Your ownership transfer of {path} to {user} has completed." : "Il tuo trasferimento di proprietà di {path} a {user} è completato.",
+    "The ownership transfer of {path} from {user} has completed." : "Il trasferimento di proprietà di {path} da {user} è completato.",
     "File Management" : "Gestione dei file",
     "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
     "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
@@ -177,6 +182,7 @@ OC.L10N.register(
     "Shared with you" : "Condivisi con te",
     "Shared by link" : "Condivisi tramite collegamento",
     "Deleted shares" : "Condivisioni eliminate",
+    "Pending shares" : "Condivisioni in corso",
     "Text file" : "File di testo",
     "New text file.txt" : "Nuovo file di testo.txt",
     "File handling" : "Gestione file",
