@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "コピー",
     "Choose target folder" : "ターゲットフォルダーを選択",
     "Open" : "開く",
+    "Delete file" : "ファイルを削除",
+    "Delete folder" : "フォルダを削除",
     "Disconnect storage" : "ストレージを切断する",
     "Unshare" : "共有解除",
     "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
@@ -134,7 +136,9 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "ファイルまたはフォルダーが<strong>復元</strong>されたとき",
     "Unlimited" : "無制限",
     "Upload (max. %s)" : "アップロード ( 最大 %s )",
+    "Accept" : "承諾",
     "File Management" : "ファイル管理",
+    "Change" : "変更",
     "%s used" : "%s 使用中",
     "%s%% of %s used" : "%s中%s%%が使われています。",
     "%1$s of %2$s used" : "%2$s 中%1$s が使われています。",
@@ -160,15 +164,14 @@ OC.L10N.register(
     "Deleted shares" : "削除された共有",
     "Text file" : "テキストファイル",
     "New text file.txt" : "新規のテキストファイル作成",
-    "Target folder" : "対象フォルダー",
     "File handling" : "ファイル操作",
     "Maximum upload size" : "最大アップロードサイズ",
     "max. possible: " : "最大容量: ",
     "Save" : "保存",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM の場合は値を変更後、反映されるのに5分程度かかります。",
     "Missing permissions to edit from here." : "ここから編集するための権限がありません。",
-    "%s of %s used" : "%s / %s 使用中",
     "Cancel upload" : "アップロードをキャンセル",
+    "%s of %s used" : "%s / %s 使用中",
     "%1$s%% of %2$s used" : "%2$s 中%1$s %%が使われています。"
 },
 "nplurals=1; plural=0;");
