@@ -27,6 +27,8 @@ OC.L10N.register(
     "Actions" : "მოქმედებები",
     "Rename" : "გადარქმევა",
     "Copy" : "კოპირება",
+    "Delete file" : "გაუქმდეს ფაილი",
+    "Delete folder" : "დირექტორიის გაუქმება",
     "Disconnect storage" : "საცავის გათიშვა",
     "Unshare" : "გაზიარების შეწყვეტა",
     "Could not load info for file \"{file}\"" : "ფაილზე \"{file}\" ინფორმაცია ვერ ჩაიტვირთა",
@@ -125,7 +127,10 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "ფაილი ან დირექტორია <strong>აღდგენილ იქნა</strong>",
     "Unlimited" : "ულიმიტო",
     "Upload (max. %s)" : "ატვირთვა (მაქს. %s)",
+    "Accept" : "მიღება",
+    "Change" : "შეცვლა",
     "%s used" : "%s მოხმარებულია",
+    "%1$s of %2$s used" : "გამოყენებულია %1$s სულ %2$s-იდან ",
     "Settings" : "პარამეტრები",
     "Show hidden files" : "დამალული ფაილების ჩვენება",
     "WebDAV" : "WebDAV",
@@ -140,19 +145,19 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "აქ გამოჩნდებიან ფაილები და დირექტორიები, რომლებსაც მონიშნავთ რჩეულებად",
     "Tags" : "ტეგები",
     "Deleted files" : "გაუქმებული ფაილები",
+    "Shares" : "გაზიარებები",
     "Shared with others" : "გაზიარდა სხვებთან",
     "Shared with you" : "გაზიარდა თქვენთან",
     "Shared by link" : "გაზიარდა ბმულით",
     "Text file" : "ტექსტური ფაილი",
     "New text file.txt" : "ახალი ტექსტი file.txt",
-    "Target folder" : "დანიშნულების დირექტორია",
     "File handling" : "ფაილის დამუშავება",
     "Maximum upload size" : "მაქსიმუმ ატვირთის ზომა",
     "max. possible: " : "მაქს. შესაძლებელი:",
     "Save" : "შენახვა",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-ით ცვლილებების შენახვამ შეიძლება გასტანოს 5 წუთი.",
     "Missing permissions to edit from here." : "არასაკმარისი უფლებები აქედან შეცვლისათვის.",
-    "%s of %s used" : "%s სულ %s-დან მოხმარებულია",
-    "Cancel upload" : "ატვირთვის შეჩერება"
+    "Cancel upload" : "ატვირთვის შეჩერება",
+    "%s of %s used" : "%s სულ %s-დან მოხმარებულია"
 },
 "nplurals=2; plural=(n!=1);");
