@@ -26,6 +26,8 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "조각을 모으는 중 오류 발생, 상태 코드 {status}",
     "Actions" : "작업",
     "Rename" : "이름 바꾸기",
+    "Copy" : "복사",
+    "Delete file" : "파일 삭제",
     "Delete folder" : "폴더 삭제",
     "Disconnect storage" : "저장소 연결 해제",
     "Unshare" : "공유 해제",
@@ -39,6 +41,7 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
     "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
     "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
+    "copy" : "복사",
     "Could not copy \"{file}\", target exists" : "\"{file}\"을(를) 복사할 수 없음, 대상이 존재함",
     "Could not copy \"{file}\"" : "\"{file}\"을(를) 복사할 수 없음",
     "Copied {origin} inside {destination}" : "{origin}을(를) {destination}(으)로 복사함",
@@ -119,11 +122,15 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "파일이나 폴더가 <strong>복원됨</strong>",
     "Unlimited" : "무제한",
     "Upload (max. %s)" : "업로드(최대 %s)",
+    "Accept" : "수락",
+    "Change" : "변경",
     "%s used" : "%s 사용함",
+    "%1$s of %2$s used" : "%2$s 중 %1$s 사용됨",
     "Settings" : "설정",
     "Show hidden files" : "숨김 파일 보이기",
     "WebDAV" : "WebDAV",
     "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">내 파일에 WebDAV로 접근</a>하려면 이 주소를 사용하십시오",
+    "Toggle grid view" : "모눈 보기 전환",
     "No files in here" : "여기에 파일 없음",
     "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
     "No entries found in this folder" : "이 폴더에 항목 없음",
@@ -134,9 +141,11 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "즐겨찾기에 추가한 파일과 폴더가 여기에 나타납니다",
     "Tags" : "태그",
     "Deleted files" : "삭제된 파일",
+    "Shares" : "공유",
     "Shared with others" : "다른 사람과 공유됨",
     "Shared with you" : "나와 공유됨",
     "Shared by link" : "링크로 공유됨",
+    "Deleted shares" : "삭제된 공유",
     "Text file" : "텍스트 파일",
     "New text file.txt" : "새 텍스트 파일.txt",
     "File handling" : "파일 처리",
