@@ -21,6 +21,7 @@ OC.L10N.register(
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} vun {totalSize} ({bitrate})",
     "Actions" : "Aktiounen",
     "Rename" : "Ëmbenennen",
+    "Delete folder" : "Dossier läschen",
     "Disconnect storage" : "Net connectéierten Späicher",
     "Unshare" : "Net méi deelen",
     "Could not load info for file \"{file}\"" : "Et konnten keng Informatiounen zu {file} gelueden ginn",
@@ -61,11 +62,15 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)" : "Däin Späicher ass baal voll ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["entsprecht","entspriechen"],
     "View in folder" : "Kuk am Dossier ",
+    "Copied!" : "Kopéiert!",
     "Path" : "Pad",
     "_%n byte_::_%n bytes_" : ["¦%n Byte","¦%n Byte"],
     "Favorited" : "Favoriséiert",
     "Favorite" : "Favorit",
     "New folder" : "Neien Dossier",
+    "Upload file" : "Upload file",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Add to favorites",
     "An error occurred while trying to update the tags" : "Beim Updaten vun den Tags ass e Fehler entstaanen",
     "Added to favorites" : "Zu den Favoriten dobaigesat",
     "Removed from favorites" : "Vun den Favoriten eweggeholl",
@@ -78,6 +83,7 @@ OC.L10N.register(
     "Restored by {user}" : "Erem hier gestallt vum {user}",
     "Renamed by {user}" : "Embenannt vum {user}",
     "Moved by {user}" : "Beweegt vum {user}",
+    "\"remote user\"" : "\"Remote-Benotzer\"",
     "You created {file}" : "Du hues {file} erstallt",
     "{user} created {file}" : "Den {user} huet {file} erstallt",
     "{file} was created in a public folder" : "{file} ass an engem ëffentlechen Dossier erstallt ginn",
@@ -113,12 +119,12 @@ OC.L10N.register(
     "Shared by link" : "Mat engem Link gedeelt",
     "Text file" : "Text Fichier",
     "New text file.txt" : "Neien Text file.txt",
-    "Target folder" : "Ziel Dossier",
     "File handling" : "Fichier handling",
     "Maximum upload size" : "Maximum Upload Gréisst ",
     "max. possible: " : "max. méiglech:",
     "Save" : "Späicheren",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Mat PHP-FPM kann et 5 Minutten dauern bis d'Ännerungen iwwerholl goufen",
-    "Missing permissions to edit from here." : "Net genuch Recher fir hei eppes ze veränneren"
+    "Missing permissions to edit from here." : "Net genuch Recher fir hei eppes ze veränneren",
+    "Cancel upload" : "Eroplueden ofbriechen"
 },
 "nplurals=2; plural=(n != 1);");
