@@ -67,7 +67,7 @@ OC.L10N.register(
     "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankas"],
     "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failas"],
     "{dirs} and {files}" : "{dirs} ir {files}",
-    "_including %n hidden_::_including %n hidden_" : ["įskaitant %n paslėptą","įskaitant %n paslėptus","įskaitant %n paslėptų","įskaitant %n paslėptų"],
+    "_including %n hidden_::_including %n hidden_" : ["įskaitant %n paslėptą","įskaitant %n paslėptus","įskaitant %n paslėptų","įskaitant %n paslėptą"],
     "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
     "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų","Įkeliamas %n failas"],
     "New" : "Naujas",
@@ -82,7 +82,7 @@ OC.L10N.register(
     "Your storage is full, files can not be updated or synced anymore!" : "Jūsų saugykla pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} saugykla yra beveik pilna ({usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)" : "Jūsų saugykla yra beveik pilna ({usedSpacePercent}%)",
-    "_matches '{filter}'_::_match '{filter}'_" : ["atitinka '{filter}'","atitinka '{filter}'","atitinka '{filter}'","atitinka '{filter}'"],
+    "_matches '{filter}'_::_match '{filter}'_" : ["atitinka \"{filter}\"","atitinka \"{filter}\"","atitinka \"{filter}\"","atitinka \"{filter}\""],
     "View in folder" : "Rodyti aplanke",
     "Copied!" : "Nukopijuota!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopijuoti tiesioginę nuorodą (veiks tik naudotojams, turintiems prieigą prie failo/aplanko)",
@@ -132,7 +132,7 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Failas ar aplankas <strong>pakeistas</strong> ar <strong>pervadintas</strong>",
     "A new file or folder has been <strong>created</strong>" : "<strong>Sukurtas</strong> naujas failas ar aplankas",
     "A file or folder has been <strong>deleted</strong>" : "Failas ar aplankas <strong>ištrintas</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Riboti pranešimus apie jūsų <strong>mėgstamų failų</strong>sukūrimą ar pakeitimus <em>(Tik srautas)</em>",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Riboti pranešimus apie jūsų <strong>mėgstamų failų</strong> sukūrimą ar pakeitimus <em>(Tik srautas)</em>",
     "A file or folder has been <strong>restored</strong>" : "Failas ar aplankas <strong>atkurtas</strong>",
     "Unlimited" : "Neribotai",
     "Upload (max. %s)" : "Įkelti (maks. %s)",
@@ -140,6 +140,7 @@ OC.L10N.register(
     "Reject" : "Atmesti",
     "Ownership transfer failed" : "Nuosavybės perdavimas nepavyko",
     "File Management" : "Failų tvarkymas",
+    "Change" : "Keisti",
     "New owner" : "Naujasis savininkas",
     "Search users" : "Ieškoti naudotojų",
     "Invalid path selected" : "Pasirinktas neteisingas kelias",
