@@ -16,7 +16,7 @@ OC.L10N.register(
     "Could not create folder \"{dir}\"" : "Nevarēja izveidot mapi \"{dir}\"",
     "This will stop your current uploads." : "Tādējādi tiks pārtraukta jūsu pašreizējā augšupielāde.",
     "Upload cancelled." : "Augšupielāde ir atcelta.",
-    "Processing files …" : "Notiek failu apstrāde …",
+    "Processing files …" : "Notiek datņu apstrāde …",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturoša datne.",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
@@ -29,6 +29,8 @@ OC.L10N.register(
     "Rename" : "Pārsaukt",
     "Copy" : "Kopēt",
     "Open" : "Atvērt",
+    "Delete file" : "Dzēst datni",
+    "Delete folder" : "Dzēst mapi",
     "Disconnect storage" : "Atvienot glabātuvi",
     "Unshare" : "Pārtraukt koplietošanu",
     "Could not load info for file \"{file}\"" : "Nevar ielādēt informāciju par datni \"{file}\"",
@@ -50,6 +52,7 @@ OC.L10N.register(
     "Could not create file \"{file}\" because it already exists" : "Nevarēja izveidot datni \"{file}\", jo tā jau eksistē",
     "Could not create folder \"{dir}\" because it already exists" : "Nevarēja izveidot mapi \"{dir}\", jo tā jau eksistē",
     "Error deleting file \"{fileName}\"." : "Kļūda dzēšot datni \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Nav nekas atrasts citā mapēs {tag}{filter}{endtag}",
     "Name" : "Nosaukums",
     "Size" : "Izmērs",
     "Modified" : "Mainīts",
@@ -77,7 +80,7 @@ OC.L10N.register(
     "Upload file" : "Augšupielādēt datni",
     "Remove from favorites" : "Noņemt no favorītiem",
     "Add to favorites" : "Pievienot izlasei",
-    "An error occurred while trying to update the tags" : "Notika kļūda atjaunojot atzīmi",
+    "An error occurred while trying to update the tags" : "Notika kļūda mēģinot atjaunot birkas",
     "Added to favorites" : "Pievienot favorītiem",
     "Removed from favorites" : "Noņemt no favorītiem",
     "You added {file} to your favorites" : "Pievienoji {file} saviem favorītiem",
@@ -89,7 +92,8 @@ OC.L10N.register(
     "Restored by {user}" : "Atjaunoja {user}",
     "Renamed by {user}" : "Pārdēvēja {user}",
     "Moved by {user}" : "Pārvietoja {user}",
-    "You created {file}" : "Izveidoji {file}",
+    "\"remote user\"" : "\"attālināts lietotājs\"",
+    "You created {file}" : "Jūs izveidojāt {file}",
     "{user} created {file}" : "{user} izveidoja {file}",
     "{file} was created in a public folder" : "{file} tika izveidots publiskajā mapē",
     "You changed {file}" : "Jūs izmainījāt {file}",
@@ -105,9 +109,15 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Datne ir pievienota vai noņemta no jūsu <strong>favorītiem</strong>",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datne vai mape tika <strong>mainīta</strong> vai <strong>pārsaukta</strong>",
     "A new file or folder has been <strong>created</strong>" : "<strong>Izveidota</strong> jauna datne vai mape",
+    "A file or folder has been <strong>deleted</strong>" : "<strong>Dzēsta</strong> datne vai mape",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitēt ziņojumus par jūsu <strong>iecienīto datņu</strong> izveidošanu un izmaiņām <em>(tikai datu straumei)</em>",
+    "A file or folder has been <strong>restored</strong>" : "<strong>Atjaunota</strong> datne vai mape",
+    "Unlimited" : "Neierobežota",
     "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
+    "Accept" : "Akceptēt",
+    "Change" : "Mainīt",
     "%s used" : "%s izmantoti",
+    "%1$s of %2$s used" : "%1$s no %2$s lietoti",
     "Settings" : "Iestatījumi",
     "Show hidden files" : "Rādīt slēptās datnes",
     "WebDAV" : "WebDAV",
@@ -118,15 +128,15 @@ OC.L10N.register(
     "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
     "Files and folders you mark as favorite will show up here" : "Datnes un mapes, ko atzīmēsiet kā favorītus, tiks rādīti šeit",
-    "Tags" : "Atzīmes",
+    "Tags" : "Birkas",
     "Deleted files" : "Dzēstās datnes",
     "Shares" : "Koplietots",
     "Shared with others" : "Koplietots ar citiem",
     "Shared with you" : "Koplietots ar tevi",
     "Shared by link" : "Koplietots ar saiti",
+    "Deleted shares" : "Dzēstās koplietotnes",
     "Text file" : "Teksta datne",
     "New text file.txt" : "Jauna teksta datne.txt",
-    "Target folder" : "Mērķa mape",
     "File handling" : "Datņu pārvaldība",
     "Maximum upload size" : "Maksimālais datņu augšupielādes apjoms",
     "max. possible: " : "maksimālais iespējamais:",
