@@ -136,7 +136,27 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Датотека или папка е <strong>вратена</strong>",
     "Unlimited" : "Неограничено",
     "Upload (max. %s)" : "Префрлање (макс. %s)",
+    "Accept" : "Прифати",
+    "Reject" : "Одбиј",
+    "Incoming ownership transfer from {user}" : "Барање за трансфер на сопственост од {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Дали прифаќате {path}?\n\nЗабелешка: Процесот на трансфер одкога ќе прифатите може да трае и повеќе од 1 час.",
+    "Ownership transfer failed" : "Неуспешен трансфер на сопственост",
+    "Your ownership transfer of {path} to {user} failed." : "Неуспешен трансфер на сопственост на {path} до {user}.",
+    "The ownership transfer of {path} from {user} failed." : "Неуспешен трансфер на сопственост на {path} од {user}.",
+    "Ownership transfer done" : "Направено е трансфер на сопственост",
+    "Your ownership transfer of {path} to {user} has completed." : "Вашиот транфер на сопственост на {path} до {user} е комплетиран.",
+    "The ownership transfer of {path} from {user} has completed." : "Трансферот на сопственост на {path} од {user} е комплетиран.",
     "File Management" : "Датотеки",
+    "Transfer ownership of a file or folder" : "Трансфер на сопственост на датотека или папка",
+    "Choose file or folder to transfer" : "Избери датотека или папка за трансфер",
+    "Change" : "Измени",
+    "New owner" : "Нов сопственик",
+    "Search users" : "Пребарувај корисници",
+    "Choose a file or folder to transfer" : "Избери датотека или папка за трансфер",
+    "Transfer" : "Трансфер",
+    "Transfer {path} to {userid}" : "Трансфер {path} до {userid}",
+    "Invalid path selected" : "Избрана невалидна патека",
+    "Ownership transfer request sent" : "Испратено барање за трансфер на сопственост",
     "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
     "Unable to change the favourite state of the file" : "Неможе да се промени статусот на омимени на датотеката",
     "%s used" : "Искористено %s",
