@@ -26,6 +26,8 @@ OC.L10N.register(
     "Actions" : "Үйл ажиллагаа",
     "Rename" : "Нэр өөрчлөх",
     "Copy" : "Хуулах",
+    "Delete file" : "Файл устгах",
+    "Delete folder" : "Хавтсыг устгах",
     "Disconnect storage" : "Хадгалах төхөөрөмж салгах",
     "Unshare" : "Түгээлтийг зогсоох",
     "Files" : "Файлууд",
@@ -70,6 +72,8 @@ OC.L10N.register(
     "Favorite" : "Дуртай",
     "New folder" : "Шинэ хавтас",
     "Upload file" : "Файл байршуулах",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Add to favorites",
     "An error occurred while trying to update the tags" : "Tag шинэчлэхэд алдаа гарлаа",
     "Added to favorites" : "Дуртай файлаар сонгов",
     "You added {file} to your favorites" : "{file} дуртай файлаар сонгов",
@@ -95,6 +99,10 @@ OC.L10N.register(
     "{user} renamed {oldfile} to {newfile}" : "{user} хэрэглэгч {oldfile} файлын нэрийг {newfile} болгож өөрчлөв",
     "You moved {oldfile} to {newfile}" : "Та {oldfile} файлыг {newfile} болгож зөөв",
     "{user} moved {oldfile} to {newfile}" : "{user} хэрэглэгч {oldfile} файлыг {newfile} болгож зөөв",
+    "A file or folder has been <strong>deleted</strong>" : "Файл эсвэл хавтас амжилттай <strong>устгагдлаа</strong>",
+    "A file or folder has been <strong>restored</strong>" : "Файл эсвэл хавтас амжилттай <strong>сэргээгдлээ</strong>",
+    "Accept" : "Хүлээн зөвшөөрөх",
+    "%1$s of %2$s used" : "%1$s-с %2$s хэрэглэсэн",
     "Settings" : "Тохиргоо",
     "Show hidden files" : "Нууцлагдсан файлыг харах",
     "No files in here" : "энэд файл байхгүй байна",
@@ -104,11 +112,12 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Таны байршуулах гэж оролдсон файлууд нь энэ сервер дээр файл байршуулах дээд хэмжээнээс хэтэрч.",
     "Tags" : "Тэгүүд",
     "Deleted files" : "Устгасан файлууд",
+    "Shares" : "Түгээлтүүд",
     "Shared with others" : "Бусдад түгээсэн",
+    "Shared with you" : "тантай хуваалцсан",
     "Shared by link" : "Холбоосоор түгээсэн",
     "Text file" : "текст файл",
     "New text file.txt" : "шинэ текст file.txt",
-    "Target folder" : "Заагч хавтас",
     "File handling" : "файлтай харьцах",
     "Maximum upload size" : "хамгийн их байршуулах хэмжээ",
     "max. possible: " : "боломжтой хамгийн их хэмжээ",
