@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "Kopier",
     "Choose target folder" : "Velg målmappe",
     "Open" : "Åpne",
+    "Delete file" : "Slett fil",
+    "Delete folder" : "Slett mappe",
     "Disconnect storage" : "Koble fra lager",
     "Unshare" : "Opphev deling",
     "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
@@ -132,7 +134,9 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "En fil eller mappe ble <strong>gjenopprettet</strong>",
     "Unlimited" : "Ubegrenset",
     "Upload (max. %s)" : "Opplasting (maks %s)",
+    "Accept" : "Aksepter",
     "File Management" : "Filbehandling",
+    "Change" : "Endre",
     "%s used" : "%s brukt",
     "%1$s of %2$s used" : "%1$s av %2$s brukt",
     "Settings" : "Innstillinger",
