@@ -136,7 +136,12 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
     "Unlimited" : "Ongelimiteerd",
     "Upload (max. %s)" : "Upload (max. %s)",
+    "Accept" : "Accepteren",
+    "Reject" : "Afwijzen",
     "File Management" : "Bestandsbeheer",
+    "Change" : "Pas aan",
+    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
+    "Unable to change the favourite state of the file" : "Niet mogelijk om voorkeurtoestand van het bestand te wijzigen",
     "%s used" : "%s gebruikt",
     "%s%% of %s used" : "%s%% van %s gebruikt",
     "%1$s of %2$s used" : "%1$s van %2$s gebruikt",
