@@ -26,6 +26,9 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Erro ao agregar partições, código de estado: {estado}",
     "Actions" : "Ações",
     "Rename" : "Renomear",
+    "Copy" : "Copiar",
+    "Delete file" : "Eliminar ficheiro",
+    "Delete folder" : "Eliminar pasta",
     "Disconnect storage" : "Desligue o armazenamento",
     "Unshare" : "Cancelar partilha",
     "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
@@ -38,6 +41,7 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
     "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", destino já existe",
     "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
+    "copy" : "copiar",
     "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", o destino já existe",
     "Could not copy \"{file}\"" : "Impossível copiar \"{file}\"",
     "Copied {origin} inside {destination}" : "Copiado {origin} para {destination}",
@@ -118,8 +122,9 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Um ficheiro ou pasta foram <strong>restaurados</strong>",
     "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Envio (máx. %s)",
-    "%s of %s used" : "%s de %s utilizado",
+    "Accept" : "Aceitar",
     "%s used" : "%s utilizado",
+    "%1$s of %2$s used" : "Usado %1$s de %2$s",
     "Settings" : "Configurações",
     "Show hidden files" : "Mostrar ficheiros ocultos",
     "WebDAV" : "WebDAV",
@@ -134,18 +139,19 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
     "Tags" : "Etiquetas",
     "Deleted files" : "Ficheiros eliminados",
+    "Shares" : "Partilhas",
     "Shared with others" : "Partilhado com terceiros",
     "Shared with you" : "Partilhado consigo ",
     "Shared by link" : "Partilhado por hiperligação",
     "Text file" : "Ficheiro de Texto",
     "New text file.txt" : "Novo texto ficheiro.txt",
-    "Target folder" : "Pasta de destino",
     "File handling" : "Utilização do ficheiro",
     "Maximum upload size" : "Tamanho máximo de envio",
     "max. possible: " : "Máx. possível: ",
     "Save" : "Guardar",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com o PHP-FPM poderá demorar 5 minutos até que as alterações sejam aplicadas.",
     "Missing permissions to edit from here." : "Faltam permissões para editar a partir daqui.",
-    "Cancel upload" : "Cancelar envio"
+    "Cancel upload" : "Cancelar envio",
+    "%s of %s used" : "%s de %s utilizado"
 },
 "nplurals=2; plural=(n != 1);");
