@@ -136,7 +136,10 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Файл или каталог <strong>восстановлен</strong>",
     "Unlimited" : "Неограничено",
     "Upload (max. %s)" : "Отправка (максимум %s)",
+    "Accept" : "Принять",
     "File Management" : "Управление файлами",
+    "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
+    "Change" : "Изменить",
     "%s used" : "%s использовано",
     "%s%% of %s used" : "использовано %s%% из %s",
     "%1$s of %2$s used" : "использовано %1$s из %2$s ",
