@@ -137,7 +137,28 @@ OC.L10N.register(
     "Unlimited" : "Neobmedzené",
     "Upload (max. %s)" : "Nahrať (max. %s)",
     "Accept" : "Prijať",
+    "Reject" : "Odmietnuť",
+    "Incoming ownership transfer from {user}" : "Prichádzajúci prevod vlastníctva od {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete prijať {path}?\n\nPozn.: Proces pre prijatie môže trvať až hodinu.",
+    "Ownership transfer failed" : "Prevod vlastníctva zlyhal",
+    "Your ownership transfer of {path} to {user} failed." : "Prevod vlastníctva {path} od vás na {user} zlyhal.",
+    "The ownership transfer of {path} from {user} failed." : "Prevod vlastníctva {path} od {user} zlyhal.",
+    "Ownership transfer done" : "Prevod vlastníctva dokončený",
+    "Your ownership transfer of {path} to {user} has completed." : "Prevod vami vlastnenej položky {path} na {user} bol dokončený.",
+    "The ownership transfer of {path} from {user} has completed." : "Prevod vlastníctva položky {path} od {user} bol dokončený.",
     "File Management" : "Správa súborov",
+    "Transfer ownership of a file or folder" : "Prevod vlastníctva súboru alebo priečinka",
+    "Choose file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
+    "Change" : "Zmeniť",
+    "New owner" : "Nový vlastník",
+    "Search users" : "Hľadať používateľov",
+    "Choose a file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
+    "Transfer" : "Prevod",
+    "Transfer {path} to {userid}" : "Previesť {path} na {userid}",
+    "Invalid path selected" : "Bola vybraná neplatná cesta",
+    "Ownership transfer request sent" : "Žiadosť o prevod vlastníctva bola odoslaná",
+    "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
+    "Unable to change the favourite state of the file" : "Nie je možné zmeniť stav „obľúbené“ daného súboru",
     "%s used" : "%s použitých",
     "%s%% of %s used" : "Využité %s%% z %s",
     "%1$s of %2$s used" : "Využité: %1$s z %2$s",
