@@ -136,7 +136,9 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Datoteka ali mapa je bila <strong>obnovljena</strong>",
     "Unlimited" : "Neomejeno",
     "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
+    "Accept" : "Sprejmi",
     "File Management" : "Upravljanje datotek",
+    "Change" : "Spremeni",
     "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
     "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
     "%s used" : "Uporabljeno %s",
