@@ -21,6 +21,9 @@ OC.L10N.register(
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} nga {totalSize} ({bitrate})",
     "Actions" : "Veprime",
     "Rename" : "Riemërtojeni",
+    "Copy" : "Kopjo",
+    "Delete file" : "Fshi skedarin",
+    "Delete folder" : "Fshini dosjen",
     "Disconnect storage" : "Shkëpute depozitën",
     "Unshare" : "Hiqe ndarjen",
     "Could not load info for file \"{file}\"" : "Nuk mund të ngarkohet informacioni për skedarin \"{file}\"",
@@ -33,6 +36,7 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Kjo drejtori nuk kapet, ju lutemi, kontrolloni regjistrat ose lidhuni me përgjegjësin",
     "Could not move \"{file}\", target exists" : "S’u lëviz dot \"{file}\", objektivi ekziston",
     "Could not move \"{file}\"" : "S’u lëviz dot \"{file}\"",
+    "copy" : "kopjo",
     "{newName} already exists" : "{newName} ekziston tashmë",
     "Could not rename \"{fileName}\", it does not exist any more" : "S’u riemërtua dot \"{fileName}\", s’ekziston më",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Emri \"{targetName}\" është tashmë i përdorur te dosja \"{dir}\". Ju lutemi, zgjidhni një emër tjetër.",
@@ -69,6 +73,8 @@ OC.L10N.register(
     "Favorite" : "E parapëlqyer",
     "New folder" : "Dosje e re",
     "Upload file" : "Ngarko skedar",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Shtoje tek të parapëlqyerat",
     "An error occurred while trying to update the tags" : "Ndodhi një gabim teksa provohej të përditësoheshin etiketat",
     "Added to favorites" : "U shtua te të parapëlqyerat",
     "Removed from favorites" : "U hoq nga të parapëlqyerat",
@@ -103,7 +109,10 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Një skedar ose dosje është <strong> rikthyer </strong>",
     "Unlimited" : "E palimituar",
     "Upload (max. %s)" : "Ngarkim (max. %s)",
+    "Accept" : "Prano",
+    "Change" : "Ndrysho",
     "%s used" : "%s të përdorura",
+    "%1$s of %2$s used" : "%1$s e %2$s përdorur",
     "Settings" : "Rregullime",
     "Show hidden files" : "Shfaq kartela të fshehura",
     "WebDAV" : "WebDAV",
