@@ -137,7 +137,24 @@ OC.L10N.register(
     "Unlimited" : "Неограничено",
     "Upload (max. %s)" : "Отпремање (макс. %s)",
     "Accept" : "Прихвати",
+    "Reject" : "Одбаци",
+    "Incoming ownership transfer from {user}" : "Надолазећи пренос власништва од корисника {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Да ли желите да прихватите {path}?\n\nПажња: После прихватања, процес трансфера може потрајати и до 1h.",
+    "Ownership transfer failed" : "Пренос власништва није успео",
+    "Your ownership transfer of {path} to {user} failed." : "Ваш пренос власништва {path} на корисника {user} није успео.",
+    "The ownership transfer of {path} from {user} failed." : "Пренос власништва {path} на корисника {user} није успео.",
+    "Ownership transfer done" : "Пренос власништва завршен",
+    "Your ownership transfer of {path} to {user} has completed." : "Ваш пренос власништва {path} на корисника {user} завршен.",
+    "The ownership transfer of {path} from {user} has completed." : "Пренос власништва {path} на корисника {user} завршен.",
     "File Management" : "Управљање фајловима",
+    "Transfer ownership of a file or folder" : "Пренеси власништво фајла или фасцикле",
+    "Choose file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
+    "Change" : "Измени",
+    "New owner" : "Нови власник",
+    "Search users" : "Претражи кориснике",
+    "Choose a file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
+    "Transfer" : "Пренеси",
+    "Transfer {path} to {userid}" : "Пренеси {path} на корисника {userid}",
     "Invalid path selected" : "Одабрана неисправна путања",
     "Ownership transfer request sent" : "Послат захтев за пренос власништва",
     "Error while loading the file data" : "Грешка при учитавању података фајла",
