@@ -68,7 +68,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n fil","%n filer"],
     "{dirs} and {files}" : "{dirs} och {files}",
     "_including %n hidden_::_including %n hidden_" : ["inkluderar %n gömd","inkluderar %n gömda"],
-    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
+    "You don’t have permission to upload or create files here" : "Du har inte tillåtelse att ladda upp eller skapa filer här",
     "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
     "New" : "Ny",
     "Select file range" : "Välj filintervall",
@@ -85,7 +85,7 @@ OC.L10N.register(
     "_matches '{filter}'_::_match '{filter}'_" : ["matchar '{filter}'","matcha '{filter}'"],
     "View in folder" : "Utforska i mapp",
     "Copied!" : "Kopierad!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för de användare som har tillgång till denna fil eller mapp)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för användare som har tillgång till denna fil eller mapp)",
     "Path" : "sökväg",
     "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
     "Favorited" : "Favoriserad",
@@ -93,7 +93,7 @@ OC.L10N.register(
     "You can only favorite a single file or folder at a time" : "Du kan bara favoritmarkera en fil eller mapp åt gången",
     "New folder" : "Ny mapp",
     "Upload file" : "Ladda upp fil",
-    "Not favorited" : "Ej favoriserade",
+    "Not favorited" : "Inte favoriserade",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till i favoriter",
     "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
@@ -137,7 +137,24 @@ OC.L10N.register(
     "Unlimited" : "Obegränsad",
     "Upload (max. %s)" : "Ladda upp (högst %s)",
     "Accept" : "Acceptera",
+    "Reject" : "Avvisa",
+    "Incoming ownership transfer from {user}" : "Inkommande ägaröverföring från {user}",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vill du acceptera {path}?\n\nNotera: Överföringen kan efter att du accepterat ta upp till 1 timme.",
+    "Ownership transfer failed" : "Ägarskapsöverföring misslyckades",
+    "Your ownership transfer of {path} to {user} failed." : "Din ägaröverföring av {path} till {user} misslyckades.",
+    "The ownership transfer of {path} from {user} failed." : "Din ägaröverföring av {path} från {user} misslyckades.",
+    "Ownership transfer done" : "Ägarskapsöverföring klar",
+    "Your ownership transfer of {path} to {user} has completed." : "Din ägaröverföring av {path} till {user} är klar.",
+    "The ownership transfer of {path} from {user} has completed." : "Ägaröverföringen av {path} från {user} är klar.",
     "File Management" : "Filhantering",
+    "Transfer ownership of a file or folder" : "Överför ägarskap till en fil eller mapp",
+    "Choose file or folder to transfer" : "Välj fil eller mapp att överföra",
+    "Change" : "Ändra",
+    "New owner" : "Ny ägare",
+    "Search users" : "Sök användare",
+    "Choose a file or folder to transfer" : "Välj en fil eller mapp att överföra",
+    "Transfer" : "Överför",
+    "Transfer {path} to {userid}" : "Överför {path} till {userid}",
     "Invalid path selected" : "Ogiltig sökväg vald",
     "Ownership transfer request sent" : "Förfrågan om ägaröverföring skickad",
     "Error while loading the file data" : "Fel vid inläsning av filens data",
@@ -165,6 +182,7 @@ OC.L10N.register(
     "Shared with you" : "Delad med dig",
     "Shared by link" : "Delad via länk",
     "Deleted shares" : "Raderade delningar",
+    "Pending shares" : "Väntande delningar",
     "Text file" : "Textfil",
     "New text file.txt" : "Ny textfil.txt",
     "File handling" : "Filhantering",
