@@ -16,27 +16,27 @@ OC.L10N.register(
     "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
     "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
     "Upload cancelled." : "Yükleme iptal edildi.",
-    "Processing files …" : "Dosyalar işleniyor…",
+    "Processing files …" : "Dosyalar işleniyor …",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnız {size2} boş alan var",
     "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
     "Not enough free space" : "Yeterli boş alan yok",
     "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
-    "Uploading …" : "Yükleniyor…",
+    "Uploading …" : "Yükleniyor …",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
     "Target folder does not exist any more" : "Hedef klasör artık yok",
     "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
     "Actions" : "İşlemler",
-    "Rename" : "Yeniden Adlandır",
+    "Rename" : "Yeniden adlandır",
     "Copy" : "Kopyala",
     "Choose target folder" : "Hedef klasörü seçin",
     "Open" : "Aç",
     "Delete file" : "Dosyayı sil",
     "Delete folder" : "Klasörü sil",
     "Disconnect storage" : "Depolama bağlantısını kes",
-    "Unshare" : "Paylaşımı Kaldır",
+    "Unshare" : "Paylaşımı kaldır",
     "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
     "Files" : "Dosyalar",
     "Details" : "Ayrıntılar",
@@ -68,7 +68,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
     "{dirs} and {files}" : "{dirs} ve {files}",
     "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
-    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme veya ekleme izniniz yok",
+    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
     "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
     "New" : "Yeni",
     "Select file range" : "Dosya aralığını seçin",
@@ -136,7 +136,27 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Bir dosya ya da klasör <strong>geri yüklendi</strong>",
     "Unlimited" : "Sınırsız",
     "Upload (max. %s)" : "Yükle (en büyük: %s)",
+    "Accept" : "Kabul Et",
+    "Reject" : "Reddet",
+    "Incoming ownership transfer from {user}" : "{user} kullanıcısından gelen sahiplik aktarımı ",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} yolunu onaylamak istiyor musunuz?\n\nNot: Onay verdikten sonra aktarım işleminin tamamlanması 1 saat kadar sürebilir.",
+    "Ownership transfer failed" : "Sahiplik aktarılamadı",
+    "Your ownership transfer of {path} to {user} failed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarılamadı.",
+    "The ownership transfer of {path} from {user} failed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarılamadı.",
+    "Ownership transfer done" : "Sahiplik aktarıldı",
+    "Your ownership transfer of {path} to {user} has completed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarıldı.",
+    "The ownership transfer of {path} from {user} has completed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarıldı.",
     "File Management" : "Dosya Yönetimi",
+    "Transfer ownership of a file or folder" : "Bir dosya ya da klasörün sahipliğini aktar",
+    "Choose file or folder to transfer" : "Sahipliği aktarılacak dosya ya da klasörü seçin",
+    "Change" : "Değiştir",
+    "New owner" : "Yeni sahip",
+    "Search users" : "Kullanıcı arama",
+    "Choose a file or folder to transfer" : "Sahipliği aktarılacak bir dosya ya da klasör seçin",
+    "Transfer" : "Sahipliği Aktar",
+    "Transfer {path} to {userid}" : "{path} yolunun sahipliğini {userid} kullanıcısına aktar",
+    "Invalid path selected" : "Seçilen yol geçersiz",
+    "Ownership transfer request sent" : "Sahiplik aktarımı isteği gönderildi",
     "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
     "Unable to change the favourite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
     "%s used" : "%s kullanılıyor",
@@ -162,6 +182,7 @@ OC.L10N.register(
     "Shared with you" : "Sizinle paylaşılan",
     "Shared by link" : "Bağlantı ile paylaşılmış",
     "Deleted shares" : "Silinmiş paylaşımlar",
+    "Pending shares" : "Bekleyen paylaşımlar",
     "Text file" : "Metin dosyası",
     "New text file.txt" : "Yeni metin dosyası.txt",
     "File handling" : "Dosya işlemleri",
