@@ -33,6 +33,7 @@ OC.L10N.register(
     "Copy" : "Скопіювати",
     "Choose target folder" : "Виберіть цільовий каталог",
     "Open" : "Відкрити",
+    "Delete folder" : "Видалити теку",
     "Disconnect storage" : "Від’єднати сховище",
     "Unshare" : "Закрити доступ",
     "Could not load info for file \"{file}\"" : "Не вдалося завантажити інформацію для файлу \"{file}\"",
@@ -134,6 +135,7 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Файл або теку було <strong> відновлено </strong>",
     "Unlimited" : "Необмежено",
     "Upload (max. %s)" : "Вивантаження (макс. %s)",
+    "Accept" : "Прийняти",
     "File Management" : "Управління файлами",
     "%s used" : "%s використано",
     "%1$s of %2$s used" : "використано %1$s з %2$s",
