@@ -19,9 +19,12 @@ OC.L10N.register(
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Không đủ dung lượng trống, bạn đang tải {size1} nhưng chỉ còn {size2} trống",
     "Target folder \"{dir}\" does not exist any more" : "Thư mục đích \"{dir}\" không còn tồn tại",
     "Not enough free space" : "Không đủ dung lượng trống",
+    "Uploading …" : "Đang tải lên …",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} trong tổng số {totalSize} ({bitrate})",
     "Actions" : "Actions",
     "Rename" : "Sửa tên",
+    "Copy" : "Sao chép",
+    "Delete folder" : "Xóa thư mục",
     "Disconnect storage" : "Bộ lưu trữ đã ngắt kết nối",
     "Unshare" : "Bỏ chia sẻ",
     "Could not load info for file \"{file}\"" : "Không thể tải thông tin cho tệp \"{file}\"",
@@ -74,6 +77,8 @@ OC.L10N.register(
     "Favorite" : "Ưu thích",
     "New folder" : "Tạo thư mục",
     "Upload file" : "Tải lên tập tin",
+    "Remove from favorites" : "Xóa khỏi ưa thích",
+    "Add to favorites" : "Thêm vào ưa thích",
     "An error occurred while trying to update the tags" : "Đã xảy ra lỗi khi cố gắng cập nhật tags",
     "Added to favorites" : "Đã thêm vào mục yêu thích",
     "Removed from favorites" : "Đã xóa khỏi mục ưa thích",
@@ -101,7 +106,12 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Bạn đã chuyển {oldfile} tới {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} đã chuyển {oldfile} tới {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Một tệp đã được thêm hoặc bị xóa khỏi <strong>mục yêu thích của bạn</strong>",
+    "A file or folder has been <strong>deleted</strong>" : "Tệp hoặc thư mục đã bị <strong>xóa</strong>",
+    "A file or folder has been <strong>restored</strong>" : "Tệp hoặc thư mục đã được <strong>khôi phục</strong>",
+    "Unlimited" : "Không giới hạn",
     "Upload (max. %s)" : "Tải lên (tối đa. %s)",
+    "Change" : "Chỉnh sửa",
+    "%1$s of %2$s used" : "%1$s trên %2$s đã sử dụng",
     "Settings" : "Cài đặt",
     "Show hidden files" : "Hiển thị cac file bị ẩn",
     "WebDAV" : "WebDAV",
@@ -114,16 +124,17 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Các tệp và thư mục mà bạn đánh dấu là yêu thích sẽ hiển thị ở đây",
     "Tags" : "Nhãn",
     "Deleted files" : "Thùng rác",
+    "Shares" : "Chia sẻ",
     "Shared with others" : "Chia sẻ với người khác",
     "Shared with you" : "Đã chia sẻ với bạn",
     "Shared by link" : "Được chia sẻ bởi liên kết",
     "Text file" : "Tập tin văn bản",
-    "Target folder" : "Thư mục đích",
     "File handling" : "Xử lý tập tin",
     "Maximum upload size" : "Kích thước tối đa ",
     "max. possible: " : "tối đa cho phép:",
     "Save" : "Lưu",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Với PHP-FPM, có thể mất 5 phút để áp dụng các thay đổi.",
-    "Missing permissions to edit from here." : "Thiếu quyền để chỉnh sửa từ đây."
+    "Missing permissions to edit from here." : "Thiếu quyền để chỉnh sửa từ đây.",
+    "Cancel upload" : "Hủy tải lên"
 },
 "nplurals=1; plural=0;");
