@@ -1,14 +1,14 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "存储暂时不可用",
+    "Storage is temporarily not available" : "存储空间暂时不可用",
     "Storage invalid" : "存储空间无效",
     "Unknown error" : "未知错误",
     "All files" : "全部文件",
     "Recent" : "最近",
     "Favorites" : "收藏",
     "File could not be found" : "文件未找到",
-    "Move or copy" : "移动或者复制",
+    "Move or copy" : "移动或复制",
     "Download" : "下载",
     "Delete" : "删除",
     "Home" : "首页",
@@ -16,14 +16,14 @@ OC.L10N.register(
     "Could not create folder \"{dir}\"" : "无法创建文件夹 \"{dir}\"",
     "This will stop your current uploads." : "这会终止您当前的上传。",
     "Upload cancelled." : "上传已取消。",
-    "Processing files …" : "文件处理中…",
+    "Processing files …" : "正在处理文件…",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "无法上传文件 {filename}，因为它是一个目录或者是大小为 0 的空文件",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空间不足，您上传的文件大小为 {size1} ，但可用空间仅剩 {size2}",
     "Target folder \"{dir}\" does not exist any more" : "目标目录 \"{dir}\" 不存在",
     "Not enough free space" : "可用空间不足",
     "An unknown error has occurred" : "发生了未知错误。",
-    "Uploading …" : "上传中…",
+    "Uploading …" : "正在上传...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "不支持上传此项目",
     "Target folder does not exist any more" : "目标文件夹不存在",
@@ -35,7 +35,7 @@ OC.L10N.register(
     "Open" : "打开",
     "Delete file" : "删除文件",
     "Delete folder" : "删除文件夹",
-    "Disconnect storage" : "断开存储的连接",
+    "Disconnect storage" : "断开与存储空间的连接",
     "Unshare" : "取消共享",
     "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
     "Files" : "文件",
@@ -43,7 +43,7 @@ OC.L10N.register(
     "Select" : "选择",
     "Pending" : "等待",
     "Unable to determine date" : "无法确定日期",
-    "This operation is forbidden" : "操作被禁止",
+    "This operation is forbidden" : "该操作被禁止",
     "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
     "Could not move \"{file}\", target exists" : "无法移动 \"{file}\"，目标已存在",
     "Could not move \"{file}\"" : "无法移动 \"{file}\"",
@@ -69,7 +69,7 @@ OC.L10N.register(
     "{dirs} and {files}" : "{dirs} 和 {files}",
     "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
     "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
-    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
+    "_Uploading %n file_::_Uploading %n files_" : ["正在上传 %n 个文件"],
     "New" : "新建",
     "Select file range" : "选择文件范围",
     "{used} of {quota} used" : "已使用 {used} / {quota}",
@@ -182,6 +182,7 @@ OC.L10N.register(
     "Shared with you" : "与您共享",
     "Shared by link" : "通过链接共享",
     "Deleted shares" : "已删除的共享",
+    "Pending shares" : "待定共享",
     "Text file" : "文本文件",
     "New text file.txt" : "新建文本文件.txt",
     "File handling" : "文件处理",
