@@ -33,6 +33,8 @@ OC.L10N.register(
     "Copy" : "複製",
     "Choose target folder" : "選擇目標資料夾",
     "Open" : "開啟",
+    "Delete file" : "刪除檔案",
+    "Delete folder" : "刪除資料夾",
     "Disconnect storage" : "切斷儲存空間連接",
     "Unshare" : "取消分享",
     "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
@@ -134,8 +136,31 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
     "Unlimited" : "無限制",
     "Upload (max. %s)" : "上傳（至多 %s）",
+    "Accept" : "接受",
+    "Reject" : "拒絕",
+    "Incoming ownership transfer from {user}" : "來自 {user} 的所有權轉移",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您想要接收 \"{path}\" 嗎？\n\n註：所有權轉移的流程最多需要一小時",
+    "Ownership transfer failed" : "所有權轉移失敗",
+    "Your ownership transfer of {path} to {user} failed." : "您將 \"{path}\" 的所有權轉移給 {user} 失敗",
+    "The ownership transfer of {path} from {user} failed." : "來自 {user} 的 \"{path}\" 所有權轉移失敗",
+    "Ownership transfer done" : "所有權轉移完成",
+    "Your ownership transfer of {path} to {user} has completed." : "您將 \"{path}\" 的所有權轉移給 {user} 已經完成",
+    "The ownership transfer of {path} from {user} has completed." : "來自 {user} 的 \"{path}\" 所有權轉移已經完成",
     "File Management" : "檔案管理",
+    "Transfer ownership of a file or folder" : "轉移檔案或是資料夾的所有權",
+    "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
+    "Change" : "更改",
+    "New owner" : "新的擁有者",
+    "Search users" : "搜尋使用者",
+    "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
+    "Transfer" : "轉移",
+    "Transfer {path} to {userid}" : "轉移 \"{path}\" 給 {userid}",
+    "Invalid path selected" : "所選的路徑無效",
+    "Ownership transfer request sent" : "已送出所有權轉移的請求",
+    "Error while loading the file data" : "載入檔案資料失敗",
+    "Unable to change the favourite state of the file" : "無法更改檔案的最愛狀態",
     "%s used" : "%s已使用",
+    "%s%% of %s used" : "%s 在 %s 中使用了 %%",
     "%1$s of %2$s used" : "在  %2$s中使用了%1$s ",
     "Settings" : "設定",
     "Show hidden files" : "顯示隱藏檔",
@@ -159,15 +184,14 @@ OC.L10N.register(
     "Deleted shares" : "已刪除的分享",
     "Text file" : "文字檔",
     "New text file.txt" : "新文字檔.txt",
-    "Target folder" : "目標資料夾",
     "File handling" : "檔案處理",
     "Maximum upload size" : "上傳限制",
     "max. possible: " : "最大允許：",
     "Save" : "儲存",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "如果使用 PHP-FPM ，此設定值需要5分鐘左右才會生效。",
     "Missing permissions to edit from here." : "您沒有在此編輯的權限",
-    "%s of %s used" : "在 %s 中使用了%s ",
     "Cancel upload" : "取消上傳",
+    "%s of %s used" : "在 %s 中使用了%s ",
     "%1$s%% of %2$s used" : "在%2$s使用了%1$s%%"
 },
 "nplurals=1; plural=0;");
