@@ -13,6 +13,7 @@ OC.L10N.register(
     "(group)" : "(grupu)",
     "Enable encryption" : "Habilitar cifráu",
     "Never" : "Enxamás",
+    "Read only" : "Namái llectura",
     "Delete" : "Desaniciar",
     "Delete storage?" : "¿Desaniciar almacenamientu?",
     "Saved" : "Guardáu",
@@ -58,6 +59,7 @@ OC.L10N.register(
     "Root" : "Raíz",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Compartir",
+    "Show hidden files" : "Amosar ficheros anubríos",
     "SMB / CIFS using OC login" : "SMB / CIFS usando accesu OC",
     "Username as share" : "Nome d'usuariu como Compartición",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -65,16 +67,13 @@ OC.L10N.register(
     "Name" : "Nome",
     "Storage type" : "Triba d'almacenamientu",
     "Scope" : "Ámbitu",
+    "Open documentation" : "Abrir documentación",
     "Folder name" : "Nome de la carpeta",
     "External storage" : "Almacenamientu esternu",
     "Authentication" : "Autenticación",
     "Configuration" : "Configuración",
     "Available for" : "Disponible pa",
     "Add storage" : "Amestar almacenamientu",
-    "Advanced settings" : "Axustes avanzaos",
-    "OpenStack" : "OpenStack",
-    "No external storage configured" : "Nun se configuraron almacenamientos esternos",
-    "You can add external storages in the personal settings" : "Pues amestar almacenamientos enternos nos axustes personales",
-    "Allow users to mount the following external storage" : "Permitir a los usuarios montar el siguiente almacenamientu esternu"
+    "Advanced settings" : "Axustes avanzaos"
 },
 "nplurals=2; plural=(n != 1);");
