@@ -98,6 +98,7 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP med hemmelig nøglelogin",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Del",
+    "Show hidden files" : "Vis skjulte filer",
     "SMB / CIFS using OC login" : "SMB / CIFS med OC-login",
     "Username as share" : "Brugernavn som deling",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -108,6 +109,7 @@ OC.L10N.register(
     "Name" : "Navn",
     "Storage type" : "Lagertype",
     "Scope" : "Anvendelsesområde",
+    "Open documentation" : "Åbn dokumentation",
     "Folder name" : "Mappenavn",
     "External storage" : "Eksternt lager",
     "Authentication" : "Godkendelse",
