@@ -19,6 +19,7 @@ OC.L10N.register(
     "Check for changes" : "Verificar si hay cambios",
     "Never" : "Nunca",
     "Once every direct access" : "Una vez cada acceso directo",
+    "Read only" : "Sólo lectura",
     "Delete" : "Borrar",
     "Admin defined" : "Administrador definido",
     "Delete storage?" : "¿Borrar almacenamiento?",
@@ -33,7 +34,6 @@ OC.L10N.register(
     "External mount error" : "Error de montaje externo",
     "external-storage" : "almacenamiento externo",
     "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "No fue posible obtener el listado de los puntos de motaje de unidades de red Windows. Respuesta vacía del servidor",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algunos de los puntos de montaje externos configurados no se encuentran conectados. Por favor has click en los renglon(es) en rojo para más información",
     "Please enter the credentials for the {mount} mount" : "Por favor ingresa las credenciales para el montaje {mount}",
     "Username" : "Usuario",
     "Password" : "Contraseña",
@@ -96,6 +96,7 @@ OC.L10N.register(
     "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Compartir",
+    "Show hidden files" : "Mostrar archivos ocultos",
     "SMB / CIFS using OC login" : "SMB / CIFS usando inicio de sesión OC",
     "Username as share" : "Usuario como elemento compartido",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -103,9 +104,11 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segudos)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para cURL en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Por favor solicita a tu administador su instalación. ",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para FTP en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Por favor solicita a tu administador su instalación. ",
+    "No external storage configured or you don't have the permission to configure them" : "No se ha configurado almacenamiento externo o no tienes permiso para configurarlo",
     "Name" : "Nombre",
     "Storage type" : "Tipo de almacenamiento",
     "Scope" : "Alcance",
+    "Open documentation" : "Abrir documentación",
     "Folder name" : "Nombre de la carpeta",
     "External storage" : "Almacenamiento externo",
     "Authentication" : "Autenticación",
@@ -113,10 +116,6 @@ OC.L10N.register(
     "Available for" : "Disponible para",
     "Add storage" : "Agregar almacenamiento",
     "Advanced settings" : "Configuraciones avanzadas",
-    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo",
-    "Are you sure you want to delete this external storage" : "¿Estás seguro de que quieres borrar este almacenamiento externo?",
-    "OpenStack" : "OpenStack",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" no se encuentra instalado. El montaje de %s no es posible. Por favor solicita a tu administrador su instalación.  ",
-    "Allow users to mount the following external storage" : "Permitir a los usuarios montar el siguiente almacenamiento externo"
+    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo"
 },
 "nplurals=2; plural=(n != 1);");
