@@ -19,6 +19,7 @@ OC.L10N.register(
     "Check for changes" : "Verificar si hay cambios",
     "Never" : "Nunca",
     "Once every direct access" : "Una vez cada acceso directo",
+    "Read only" : "Solo lectura",
     "Delete" : "Borrar",
     "Admin defined" : "Administrador definido",
     "Saved" : "Guardado",
@@ -92,6 +93,7 @@ OC.L10N.register(
     "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Compartir",
+    "Show hidden files" : "Mostrar archivos ocultos",
     "SMB / CIFS using OC login" : "SMB / CIFS usando inicio de sesión OC",
     "Username as share" : "Nombre de usuario como elemento compartido",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -99,9 +101,11 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segudos)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para cURL en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Favor de solicitar a su administador su instalación. ",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para FTP en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Favor de solicitar a su administador su instalación. ",
+    "External storage support" : "Soporte de almacenamiento externo",
     "Name" : "Nombre",
     "Storage type" : "Tipo de almacenamiento",
     "Scope" : "Alcance",
+    "Open documentation" : "Abrir documentación",
     "Folder name" : "Nombre de la carpeta",
     "External storage" : "Almacenamiento externo",
     "Authentication" : "Autenticación",
@@ -109,8 +113,6 @@ OC.L10N.register(
     "Available for" : "Disponible para",
     "Add storage" : "Agregar almacenamiento",
     "Advanced settings" : "Configuraciones avanzadas",
-    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algunos de los puntos de montaje externos configurados no se encuentran conectados. Favor de hacer click en los renglon(es) en rojo para más información",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" no se encuentra instalado. El montaje de %s no es posible. Favor de solicitar a su administrador su instalación.  "
+    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo"
 },
 "nplurals=2; plural=(n != 1);");
