@@ -19,6 +19,7 @@ OC.L10N.register(
     "Check for changes" : "Verificar si hay cambios",
     "Never" : "Nunca",
     "Once every direct access" : "Una vez cada acceso directo",
+    "Read only" : "Sólo lectura",
     "Delete" : "Borrar",
     "Admin defined" : "Administrador definido",
     "Delete storage?" : "¿Borrar almacenamiento?",
@@ -95,6 +96,7 @@ OC.L10N.register(
     "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Compartir",
+    "Show hidden files" : "Mostrar archivos ocultos",
     "SMB / CIFS using OC login" : "SMB / CIFS usando inicio de sesión OC",
     "Username as share" : "Usuario como elemento compartido",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -105,6 +107,7 @@ OC.L10N.register(
     "Name" : "Nombre",
     "Storage type" : "Tipo de almacenamiento",
     "Scope" : "Alcance",
+    "Open documentation" : "Abrir la documentación",
     "Folder name" : "Nombre de la carpeta",
     "External storage" : "Almacenamiento externo",
     "Authentication" : "Autenticación",
@@ -112,8 +115,6 @@ OC.L10N.register(
     "Available for" : "Disponible para",
     "Add storage" : "Agregar almacenamiento",
     "Advanced settings" : "Configuraciones avanzadas",
-    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algunos de los puntos de montaje externos configurados no se encuentran conectados. Por favor has click en los renglon(es) en rojo para más información",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" no se encuentra instalado. El montaje de %s no es posible. Por favor solicita a tu administrador su instalación.  "
+    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo"
 },
 "nplurals=2; plural=(n != 1);");
