@@ -17,9 +17,11 @@ OC.L10N.register(
     "Check for changes" : "Otsi uuendusi",
     "Never" : "Mitte kunagi",
     "Once every direct access" : "Kord iga otsese pöördumise korral",
+    "Read only" : "kirjutuskaitstud",
     "Delete" : "Kustuta",
     "Admin defined" : "Admini poolt määratud",
     "Saved" : "Salvestatud",
+    "Saving..." : "Salvestamine...",
     "Save" : "Salvesta",
     "Empty response from the server" : "Tühi vastus serverilt",
     "Couldn't get the list of external mount points: {type}" : "Välise ühenduspunkti hankimine ebaõnnestus: {type}",
@@ -65,11 +67,13 @@ OC.L10N.register(
     "Secure ftps://" : "Turvaline ftps://",
     "Local" : "Kohalik",
     "Location" : "Asukoht",
+    "Nextcloud" : "Nextcloud",
     "SFTP" : "SFTP",
     "Root" : "Juur",
     "SFTP with secret key login" : "SFTP koos salajase võtmega logimisega",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Jaga",
+    "Show hidden files" : "Näita peidetud faile",
     "SMB / CIFS using OC login" : "SMB / CIFS kasutades OC logimist",
     "Username as share" : "Kasutajanimi kui jagamine",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -77,6 +81,7 @@ OC.L10N.register(
     "Name" : "Nimi",
     "Storage type" : "Andmehoidla tüüp",
     "Scope" : "Skoop",
+    "Open documentation" : "Ava dokumentatsioon",
     "Folder name" : "Kausta nimi",
     "External storage" : "Väline andmehoidla",
     "Authentication" : "Autentimine",
