@@ -13,6 +13,7 @@ OC.L10N.register(
     "Enable sharing" : "Gaitu partekatzea",
     "Check for changes" : "Begiratu aldaketarik dagoen",
     "Never" : "inoiz ez",
+    "Read only" : "Irakurtzeko soilik",
     "Delete" : "Ezabatu",
     "Admin defined" : "Administratzaileak definitua",
     "Delete storage?" : "Ezabatu biltegiratzea?",
@@ -29,7 +30,7 @@ OC.L10N.register(
     "Access key" : "Sarbide-gakoa",
     "Secret key" : "Gako sekretua",
     "Builtin" : "Integratua",
-    "None" : "Ezer",
+    "None" : "Bat ere ez",
     "OAuth1" : "OAuth1",
     "App key" : "Aplikazio gakoa",
     "App secret" : "App sekretua",
@@ -49,7 +50,7 @@ OC.L10N.register(
     "Private key" : "Gako pribatua",
     "Amazon S3" : "Amazon S3",
     "Hostname" : "Ostalari izena",
-    "Port" : "Portua",
+    "Port" : "Ataka",
     "Region" : "Eskualdea",
     "Enable SSL" : "Gaitu SSL",
     "Enable Path Style" : "Gaitu Bide Estiloa",
@@ -60,13 +61,15 @@ OC.L10N.register(
     "FTP" : "FTP",
     "Host" : "Ostalaria",
     "Secure ftps://" : "ftps:// segurua",
-    "Local" : "Bertakoa",
+    "Local" : "Lokala",
     "Location" : "Kokapena",
     "Nextcloud" : "Nextcloud",
     "SFTP" : "SFTP",
     "Root" : "Erroa",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Partekatu",
+    "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
+    "Timeout" : "Denbora-muga",
     "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz",
     "Username as share" : "Erabiltzaile izena elkarbanaketa bezala",
     "OpenStack Object Storage" : "OpenStack Objektu Biltegiratzea",
@@ -74,6 +77,7 @@ OC.L10N.register(
     "Name" : "Izena",
     "Storage type" : "Biltegiratze mota",
     "Scope" : "Esparrua",
+    "Open documentation" : "Ireki dokumentazioa",
     "Folder name" : "Karpetaren izena",
     "External storage" : "Kanpoko biltegiratzea",
     "Authentication" : "Autentifikazioa",
