@@ -103,6 +103,7 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP titkos kulcs belépéssel",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Megosztás",
+    "Show hidden files" : "Rejtett fájlok megjelenítése",
     "SMB / CIFS using OC login" : "SMB / CIFS OC belépéssel",
     "Username as share" : "Felhasználónév és megosztás",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -115,6 +116,7 @@ OC.L10N.register(
     "Name" : "Név",
     "Storage type" : "Tároló típusa",
     "Scope" : "Hatáskör",
+    "Open documentation" : "Dokumentáció megnyitása",
     "Folder name" : "Mappa neve",
     "External storage" : "Külső tárolók",
     "Authentication" : "Hitelesítés",
@@ -123,8 +125,6 @@ OC.L10N.register(
     "Click to recheck the configuration" : "Kattints ide a konfiguráció újraellenőrzéséhez",
     "Add storage" : "Tároló becsatolása",
     "Advanced settings" : "Haladó beállítások",
-    "Allow users to mount external storage" : "Külső tárolók csatolásának  engedélyezése a felhasználók részére",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Néhány beállított külső csatolási pont nincs kapcsolatban. További információkért kattints a piros sor(ok)ra.",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "%s nincs telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse."
+    "Allow users to mount external storage" : "Külső tárolók csatolásának  engedélyezése a felhasználók részére"
 },
 "nplurals=2; plural=(n != 1);");
