@@ -103,6 +103,8 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP innskráning með leynilykli",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Deila",
+    "Show hidden files" : "Sýna faldar skrár",
+    "Timeout" : "Tímamörk",
     "SMB / CIFS using OC login" : "SMB / CIFS með OC-innskráningu",
     "Username as share" : "Notandanafn sem sameign",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -117,6 +119,7 @@ OC.L10N.register(
     "Name" : "Nafn",
     "Storage type" : "Tegund gagnageymslu",
     "Scope" : "Umfang",
+    "Open documentation" : "Opna hjálparskjöl",
     "Folder name" : "Nafn möppu",
     "External storage" : "Ytri gagnageymsla",
     "Authentication" : "Auðkenning",
