@@ -18,6 +18,7 @@ OC.L10N.register(
     "Enable sharing" : "Koplietošanas iespējošana",
     "Check for changes" : "Pārbaudīt, vai nav izmaiņu",
     "Never" : "Nekad",
+    "Read only" : "Tikai lasāms",
     "Delete" : "Dzēst",
     "Admin defined" : "Administrators definētās",
     "Saved" : "Saglabāts",
@@ -64,12 +65,14 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP pieteikšanās ar slepeno atslēgu",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Koplietot",
+    "Show hidden files" : "Rādīt slēptās datnes",
     "SMB / CIFS using OC login" : "SMB / CIFS lietojot OC lietotāju",
     "OpenStack Object Storage" : "OpenStack Object krātuve",
     "Service name" : "Servisa nosaukums",
     "Name" : "Nosaukums",
     "Storage type" : "Krātuves tips",
     "Scope" : "Darbības joma",
+    "Open documentation" : "Atvērt dokumentāciju",
     "Folder name" : "Mapes nosaukums",
     "External storage" : "Ārējā krātuve",
     "Authentication" : "Autentifikācija",
