@@ -102,6 +102,8 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP med hemmelig nøkkel for pålogging",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Delt ressurs",
+    "Show hidden files" : "Vis skjulte filer",
+    "Timeout" : "Tidsavbrudd",
     "SMB / CIFS using OC login" : "SMB / CIFS med OC-pålogging",
     "Username as share" : "Brukernavn som delt ressurs",
     "OpenStack Object Storage" : "OpenStack objektlager",
@@ -114,6 +116,7 @@ OC.L10N.register(
     "Name" : "Navn",
     "Storage type" : "Lagringstype",
     "Scope" : "Omfang",
+    "Open documentation" : "Åpne dokumentasjon",
     "Folder name" : "Mappenavn",
     "External storage" : "Ekstern lagring",
     "Authentication" : "Autentisering",
