@@ -16,9 +16,11 @@ OC.L10N.register(
     "Check for changes" : "Verifică dacă au intervenit modificări",
     "Never" : "Niciodată",
     "Once every direct access" : "O dată la fiecare acces direct",
+    "Read only" : "Doar citire",
     "Delete" : "Șterge",
     "Admin defined" : "Administrator definit",
     "Saved" : "Salvat",
+    "Saving..." : "Se salvează...",
     "Save" : "Salvează",
     "Empty response from the server" : "Răspuns nul de la server",
     "There was an error with message: " : "A apărut o eroare cu mesajul:",
@@ -59,24 +61,25 @@ OC.L10N.register(
     "Secure ftps://" : "ftps:// sigur",
     "Local" : "Local",
     "Location" : "Locație",
+    "Nextcloud" : "Nextcloud",
     "SFTP" : "SFTP",
     "Root" : "Root",
     "SFTP with secret key login" : "SFTP cu cheie secretă de autentificare",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Partajează",
+    "Show hidden files" : "Arată fișierele ascunse",
     "SMB / CIFS using OC login" : "SMB / CIFS folosind autentificare OC",
     "Service name" : "Nume serviciu",
     "Name" : "Nume",
     "Storage type" : "Tip stocare",
     "Scope" : "Scop",
+    "Open documentation" : "Deschide documentația",
     "Folder name" : "Denumire director",
     "External storage" : "Stocare externă",
     "Authentication" : "Autentificare",
     "Configuration" : "Configurație",
     "Available for" : "Disponibil pentru",
     "Add storage" : "Adauga stocare",
-    "Advanced settings" : "Setări avansate",
-    "OpenStack" : "OpenStack",
-    "Allow users to mount the following external storage" : "Permite utilizatorilor să monteze următoarea unitate de stocare"
+    "Advanced settings" : "Setări avansate"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
