@@ -97,14 +97,18 @@ OC.L10N.register(
     "SFTP with secret key login" : "Prijava prek protokola SFTP z geslom",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Souporaba",
+    "Show hidden files" : "Pokaži skrite datoteke",
+    "Timeout" : "Časovni zamik",
     "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
     "Username as share" : "Uporabniško ime za souporabo",
     "OpenStack Object Storage" : "Shramba predmeta OpenStack",
     "Service name" : "Ime storitve",
     "Request timeout (seconds)" : "Zahtevan časovni zamik (sekunde)",
+    "External storage support" : "Podpora zunanjim hrambam",
     "Name" : "Ime",
     "Storage type" : "Vrsta shrambe",
     "Scope" : "Obseg",
+    "Open documentation" : "Odpri dokumentacijo",
     "Folder name" : "Ime mape",
     "External storage" : "Zunanja shramba",
     "Authentication" : "Overitev",
