@@ -20,6 +20,7 @@ OC.L10N.register(
     "Delete" : "ลบ",
     "Admin defined" : "ถูกกำหนดโดยผู้ดูแลระบบ",
     "Saved" : "บันทึกแล้ว",
+    "Saving..." : "กำลังบันทึกข้อมูล...",
     "Save" : "บันทึก",
     "Empty response from the server" : "ไม่มีการตอบสนองจากเซิร์ฟเวอร์",
     "Couldn't get the list of external mount points: {type}" : "ไม่สามารถรับรายชื่อของจุดเชื่อมต่อภายนอก: {type}",
@@ -82,6 +83,7 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP กับคีย์ลับสำหรับเข้าสู่ระบบ",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "แชร์",
+    "Show hidden files" : "แสดงไฟล์ที่ซ่อนอยู่",
     "SMB / CIFS using OC login" : "SMB/CIFS กำลังใช้ OC เข้าสู่ระบบ",
     "Username as share" : "ชื่อผู้ใช้ที่แชร์",
     "OpenStack Object Storage" : "OpenStack Object Storage",
@@ -90,6 +92,7 @@ OC.L10N.register(
     "Name" : "ชื่อ",
     "Storage type" : "ชนิดการจัดเก็บข้อมูล",
     "Scope" : "ขอบเขต",
+    "Open documentation" : "เปิดเอกสาร",
     "Folder name" : "ชื่อโฟลเดอร์",
     "External storage" : "จัดเก็บข้อมูลภายนอก",
     "Authentication" : "รับรองความถูกต้อง",
