@@ -19,6 +19,7 @@ OC.L10N.register(
     "Check for changes" : "檢查變動",
     "Never" : "絕不",
     "Once every direct access" : "在每次進行存取動作時",
+    "Read only" : "唯讀",
     "Delete" : "刪除",
     "Admin defined" : "管理者定義",
     "Delete storage?" : "刪除空間",
@@ -91,6 +92,7 @@ OC.L10N.register(
     "SFTP with secret key login" : "以密碼金鑰登入SFTP",
     "SMB / CIFS" : "伺服器訊息區塊-SMB/網路文件共享系統 (CIFS)",
     "Share" : "分享",
+    "Show hidden files" : "顯示隱藏的檔案",
     "SMB / CIFS using OC login" : "SMB / CIFS 使用 OC 登入",
     "Username as share" : "以使用者名稱分享",
     "OpenStack Object Storage" : "OpenStack 物件儲存",
@@ -99,6 +101,7 @@ OC.L10N.register(
     "Name" : "名稱",
     "Storage type" : "儲存類型",
     "Scope" : "範圍",
+    "Open documentation" : "開啟說明文件",
     "Folder name" : "資料夾名稱",
     "External storage" : "外部儲存",
     "Authentication" : "驗證",
@@ -106,7 +109,6 @@ OC.L10N.register(
     "Available for" : "可用的",
     "Add storage" : "增加儲存區",
     "Advanced settings" : "進階設定",
-    "Allow users to mount external storage" : "允許使用者能自行掛載外部儲存",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "有些外部掛載位置設定無法連線，請點(多個)紅色橫幅了解詳情。"
+    "Allow users to mount external storage" : "允許使用者能自行掛載外部儲存"
 },
 "nplurals=1; plural=0;");
