@@ -1,16 +1,19 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido con usted",
-    "Shared by link" : "Compartido por link",
     "Nothing shared with you yet" : "Nada ha sido compartido aún con usted",
     "Files and folders others share with you will show up here" : "Los archivos y carpetas que sean compartidos con usted se mostrarán aquí",
+    "Shared with others" : "Compartido con otros",
     "Nothing shared yet" : "Nada compartido aún",
     "Files and folders you share will show up here" : "Los archivos y carpetas que comparta se mostrarán aquí",
+    "Shared by link" : "Compartido por link",
     "No shared links" : "No hay links compartidos",
     "Files and folders you share by link will show up here" : "Los archivos y carpetas que comparta por links se mostrarán aquí",
+    "Shares" : "Shares",
+    "Move or copy" : "Mover o Copiar",
     "Download" : "Descargar",
+    "Delete" : "Eliminar",
     "You can upload into this folder" : "Usted puede cargar archivos dentro de esta carpeta",
     "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
     "Invalid server URL" : "URL del servidor inválido",
@@ -85,8 +88,32 @@ OC.L10N.register(
     "Direct link" : "Link directa",
     "Add to your Nextcloud" : "Agregar a su Nextcloud",
     "Share API is disabled" : "El API para compartir está deshabilitado",
+    "File sharing" : "Compartir archivos",
+    "Accept" : "Aceptar",
     "Sharing" : "Compartiendo",
+    "Allow editing" : "Permitir edición",
+    "Allow resharing" : "Permitir volver a compartir",
+    "Set expiration date" : "Establecer fecha de caducidad",
+    "Note to recipient" : "Nota al destinatario",
+    "Unshare" : "No compartir",
+    "group" : "grupo",
+    "remote" : "remoto",
+    "Link copied" : "Link copiado",
+    "Copy to clipboard" : "Copiar al portapapeles",
+    "Password protection" : "Protección con contraseña",
+    "Enter a password" : "Ingrese una contraseña",
+    "Cancel" : "Cancelar",
+    "Read only" : "Solo lectura",
+    "Allow upload and editing" : "Permitir cargar y editar",
+    "File drop (upload only)" : "Soltar archivo (solo para carga)",
+    "Hide download" : "Ocultar descarga",
+    "Password protect" : "Proteger con contraseña",
+    "Share link" : "Compartir enlace",
+    "Resharing is not allowed" : "No está permitido volver a compartir",
+    "Shared" : "Compartido",
     "Share" : "Compartir",
+    "Shared with you and the group {group} by {owner}" : "Compartido con usted y el grupo {group} por {owner}",
+    "Shared with you by {owner}" : "Compartido con usted por {owner}",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
     "Name" : "Nombre",
     "Share time" : "Tiempo de compartir",
@@ -97,8 +124,11 @@ OC.L10N.register(
     "the link expired" : "el link expiró",
     "sharing is disabled" : "compartir está deshabilitado",
     "For more info, please ask the person who sent this link." : "Para mayores informes, contacte a la persona que le envió este link.",
+    "Share note" : "Compartir nota",
+    "Toggle grid view" : "Vista de cuadrícula",
     "Download %s" : "Descargar %s",
     "Upload files to %s" : "Cargar archivos a %s",
+    "Note" : "Nota",
     "Select or drop files" : "Seleccione o suelte los archivos",
     "Uploading files…" : "Cargando archivos...",
     "Uploaded files:" : "Archivos cargados:",
