@@ -18,6 +18,7 @@ OC.L10N.register(
     "Shares will show up here" : "A megosztások itt jelennek meg",
     "Restore share" : "Megosztás visszaállítása",
     "Something happened. Unable to restore the share." : "Hiba történt. Nem lehet visszaállítani a megosztást.",
+    "This will stop your current uploads." : "Ez meg fogja állítani a jelenlegi feltöltéseket.",
     "Move or copy" : "Áthelyezés vagy másolás",
     "Download" : "Letöltés",
     "Delete" : "Törlés",
@@ -106,8 +107,42 @@ OC.L10N.register(
     "Add to your Nextcloud" : "Add hozzá a Nextcloudodhoz",
     "Share API is disabled" : "Megosztás API letiltva",
     "File sharing" : "Fájlmegosztás",
+    "Accept" : "Elfogad",
     "Sharing" : "Megosztás",
+    "Allow editing" : "Szerkesztés engedélyezése",
+    "Allow resharing" : "A megosztás továbbadásának engedélyezése",
+    "Expiration date enforced" : "Lejárati idő kötelező",
+    "Set expiration date" : "Lejárati idő beállítása",
+    "Note to recipient" : "Jegyzet a címzettnek",
+    "Unshare" : "Megosztás visszavonása",
+    "group" : "csoport",
+    "conversation" : "beszélgetés",
+    "remote" : "távoli",
+    "remote group" : "távoli csoport",
+    "guest" : "vendég",
+    "Link copied" : "Hivatkozás másolva",
+    "Copy to clipboard" : "Másolás vágólapra",
+    "Only works for users with access to this folder" : "Csak azoknál a felhasználóknál működik, akiknek hozzáférése van ehhez a mappához",
+    "Password protection" : "Jelszavas védelem",
+    "Enter a password" : "Adja meg a jelszót",
+    "Cancel" : "Mégse",
+    "Read only" : "Csak olvasható",
+    "Allow upload and editing" : "Feltöltés és szerkesztés engedélyezése",
+    "File drop (upload only)" : "Fájl ejtés (csak feltöltés)",
+    "Hide download" : "Letöltés elrejtése",
+    "Password protect" : "Jelszóvédelem",
+    "Add another link" : "További hivatkozás hozzáadása",
+    "Share link" : "Hivatkozás megosztása",
+    "Resharing is not allowed" : "Az újra megosztás nem engedélyezett",
+    "Search globally" : "Keresés globálisan",
+    "Shared" : "Megosztva",
     "Share" : "Megosztás",
+    "Shared with" : "Megosztva vele:",
+    "Shared with you and the group {group} by {owner}" : "{owner} megosztotta Önnel és ezzel a csoporttal: {group}",
+    "Shared with you and {circle} by {owner}" : "{owner} megosztotta Önnel és ezzel a csoporttal: {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} megosztotta Önnel és ezzel a beszélgetéssel: {conversation}",
+    "Shared with you in a conversation by {owner}" : "{owner} megosztotta Önnel egy beszélgetésben",
+    "Shared with you by {owner}" : "Megosztotta Önnel: {owner}",
     "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
     "Name" : "Név",
     "Share time" : "A megosztás időpontja",
