@@ -17,6 +17,11 @@ OC.L10N.register(
     "Shares will show up here" : "Čia bus rodomi viešiniai",
     "Restore share" : "Atkurti viešinį",
     "Something happened. Unable to restore the share." : "Kažkas nutiko. Nepavyko atkurti viešinio.",
+    "Accept share" : "Priimti viešinį",
+    "Something happened. Unable to accept the share." : "Kažkas nutiko. Nepavyko priimti viešinio.",
+    "Reject share" : "Atmesti viešinį",
+    "Something happened. Unable to reject the share." : "Kažkas nutiko. Nepavyko atmesti viešinį.",
+    "This will stop your current uploads." : "Tai sustabdys dabartinius įkėlimus.",
     "Move or copy" : "Perkelti ar kopijuoti",
     "Download" : "Atsisiųsti",
     "Delete" : "Ištrinti",
@@ -36,7 +41,7 @@ OC.L10N.register(
     "Removed share for group {group}" : "Nebesidalinama su grupe: {group}",
     "{actor} shared with group {group}" : "{actor} pradėjo bendrinti su grupe {group}",
     "{actor} removed share for group {group}" : "{actor} nustojo dalintis su {group} grupe",
-    "You shared {file} with group {group}" : "Jūs pradėjote bendrinti {file} su grupe {group}",
+    "You shared {file} with group {group}" : "Jūs pradėjote bendrinti {file} su grupe {group}",
     "You removed group {group} from {file}" : "Pašalinote grupę {group} iš {file}",
     "{actor} shared {file} with group {group}" : "{actor} pradėjo bendrinti {file} su grupe {group}",
     "{actor} removed group {group} from {file}" : "{actor} pašalino grupę {group} iš {file}",
@@ -86,8 +91,8 @@ OC.L10N.register(
     "Could not create share" : "Nepavyko sukurti viešinio",
     "invalid permissions" : "neteisingi leidimai",
     "Please specify a valid user" : "Nurodykite naudotoją",
-    "Group sharing is disabled by the administrator" : "Bendrinimas su grupėmis yra išjungtas",
-    "Please specify a valid group" : "Nurodykite grupę",
+    "Group sharing is disabled by the administrator" : "Administratorius išjungė bendrinimą su grupėmis",
+    "Please specify a valid group" : "Nurodykite teisingą grupę",
     "Public upload disabled by the administrator" : "Įkėlimas viešam naudojimui yra išjungtas",
     "Public upload is only possible for publicly shared folders" : "Duomenų įkėlimas viešam naudojimui galimas tik į viešai dalinamus aplankus",
     "Invalid date, date format must be YYYY-MM-DD" : "Netinkamas datos formavimas. Privaloma: YYYY-MM-DD",
@@ -108,26 +113,61 @@ OC.L10N.register(
     "Accept" : "Priimti",
     "Reject" : "Atmesti",
     "Sharing" : "Bendrinimas",
-    "Invited by {initiator}" : "Pakvietė {initiator}",
-    "Open folder" : "Atverti aplanką",
-    "Delete share" : "Ištrinti viešinį",
+    "Accept user and group shares by default" : "Pagal numatymą, priimti naudotojo ir grupių viešinius",
+    "Allow editing" : "Leisti redaguoti",
+    "Allow resharing" : "Leisti bendrinti iš naujo",
+    "Expiration date enforced" : "Aktyvuotas galiojimo laikas",
+    "Set expiration date" : "Nustatyti galiojimo pabaigos datą",
+    "Note to recipient" : "Pastaba gavėjui",
+    "Unshare" : "Nebesidalinti",
+    "group" : "grupė",
+    "conversation" : "pokalbis",
+    "remote" : "nuotolinis",
+    "remote group" : "nuotolinė grupė",
+    "guest" : "svečias",
+    "Added by {initiator}" : "Pridėjo {initiator}",
+    "Via folder" : "Per aplanką",
     "Internal link" : "Vidinė nuoroda",
     "Link copied" : "Nuoroda nukopijuota",
+    "Cannot copy, please copy the link manually" : "Nepavyksta nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
     "Copy to clipboard" : "Kopijuoti į iškarpinę",
     "Only works for users with access to this folder" : "Veikia tik naudotojams, turintiems prieigą prie šio aplanko",
     "Only works for users with access to this file" : "Veikia tik naudotojams, turintiems prieigą prie šio failo",
+    "Please enter the following required information before creating the share" : "Prieš sukurdami viešinį, įveskite šią reikiamą informaciją",
+    "Password protection" : "Password protection",
+    "Enter a password" : "Enter a password",
     "Cancel" : "Atsisakyti",
+    "Read only" : "Tik skaitymui",
+    "Allow upload and editing" : "Leisti įkelti ir redaguoti",
+    "File drop (upload only)" : "Failų įmetimas (tik įkėlimas)",
+    "Hide download" : "Slėpti atsisiuntimą",
+    "Password protect" : "Apsaugoti slaptažodžiu",
     "Add another link" : "Pridėti kitą nuorodą",
     "Create a new share link" : "Sukurti naują bendrinimo nuorodą",
+    "Share link" : "Bendrinimo nuoroda",
+    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
+    "Resharing is not allowed" : "Bendrinimas iš naujo yra neleidžiamas",
+    "Name or email address …" : "Vardas ar el. pašto adresas…",
+    "Name or federated cloud ID …" : "Vardas ar federacinės debesijos ID…",
     "Name, federated cloud ID or email address …" : "Vardas, federacinės debesijos ID arba el. pašto adresas…",
+    "Name …" : "Vardas…",
     "Searching …" : "Ieškoma…",
     "No elements found." : "Nerasta jokių elementų.",
-    "Others with access {count}" : "Kiti asmenys su prieiga {count}",
+    "Search globally" : "Ieškoti visur",
     "Toggle list of others with access to this directory" : "Perjungti sąrašą kitų asmenų, turinčių prieigą prie šio katalogo",
     "Toggle list of others with access to this file" : "Perjungti sąrašą kitų asmenų, turinčių prieigą prie šio failo",
+    "Unable to load the shares list" : "Nepavyko įkelti viešinių sąrašo",
+    "this share just expired." : "šis viešinys ką tik nustojo galioti.",
+    "Error creating the share" : "Klaida kuriant viešinį",
+    "Error updating the share" : "Klaida atnaujinant viešinį",
     "Shared" : "Pasidalinta",
     "Share" : "Dalintis",
     "Shared with" : "Bendrinama su",
+    "Shared with you and the group {group} by {owner}" : "{owner} pasidalino su jumis ir grupe {group}",
+    "Shared with you and {circle} by {owner}" : "{owner} pasidalino su jumis ir {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokabliu {conversation}",
+    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
+    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
     "No entries found in this folder" : "Šiame aplanke įrašų nerasta",
     "Name" : "Pavadinimas",
     "Share time" : "Bendrinimo laikas",
