@@ -1,39 +1,49 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Shared with others" : "V souporabi  z drugimi",
     "Shared with you" : "V souporabi z vami",
-    "Shared by link" : "V souporabi prek povezave",
-    "Deleted shares" : "Izbrisane povezave za souporabo",
-    "Shares" : "Souporaba",
     "Nothing shared with you yet" : "Datotek drugih uporabnikov še ni v souporabi",
     "Files and folders others share with you will show up here" : "Datoteke in mape, katerih souporabo z vami omogočijo drugi, bodo zbrane na tem mestu.",
+    "Shared with others" : "V souporabi  z drugimi",
     "Nothing shared yet" : "Souporabe datotek še niste omogočili",
     "Files and folders you share will show up here" : "Datoteke in mape, ki ste jih označili za souporabo z drugimi, bodo zbrane na tem mestu.",
+    "Shared by link" : "V souporabi prek povezave",
     "No shared links" : "Ni povezav za souporabo",
     "Files and folders you share by link will show up here" : "Datoteke in mape, ki ste jih označili za souporabo prek povezave, bodo zbrane na tem mestu.",
+    "Deleted shares" : "Izbrisana mesta souporabe",
     "No deleted shares" : "Ni izbrisanih povezav za souporabo.",
+    "Shares" : "Souporaba",
     "No shares" : "Brez souporabe",
     "Shares will show up here" : "Predmeti v souporabi bodo prikazani na tem mestu.",
+    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
+    "Move or copy" : "Premakni ali kopiraj",
     "Download" : "Prejmi",
     "Delete" : "Izbriši",
     "You can upload into this folder" : "V to mapo je dovoljeno pošiljati datoteke",
+    "Terms of service" : "Pogoji uporabe storitve",
+    "No compatible server found at {remote}" : "Skladnega strežnika na {remote} ni mogoče najti",
     "Invalid server URL" : "Neveljaven URL strežnika",
     "No expiration date set" : "Datum poteka ni določen",
     "Shared by" : "V souporabi z",
     "File shares" : "Datoteke v souporabi",
     "Downloaded via public link" : "Prejeto prek javne povezave",
     "{file} downloaded via public link" : "Datoteka {file} je prejeta prek javne povezave",
+    "Shared with group {group}" : "V souporabi skupine {group}",
+    "Removed share for group {group}" : "Odstranjeno je mesto souporabe za skupino {group}",
+    "Shared as public link" : "V souporabi prek javne povezave",
     "Removed public link" : "Javno povezava je odstranjena",
     "Public link expired" : "Javna povezava je potekla",
     "You removed public link for {file}" : "Odstranite povezavo do datoteke {file}",
+    "{actor} removed public link for {file}" : "{actor} odstrani javno povezavo do {file}",
     "{user} accepted the remote share" : "Uporabnik {user} potrdi oddaljeno souporabo",
+    "{user} declined the remote share" : "{user} zavrne oddaljeno souporabo",
     "{user} accepted the remote share of {file}" : "Uporabnik {user} potrdi oddaljeno souporabo {file}",
+    "Shared with {user}" : "Shared with {user}",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Datoteko oziroma mapo v souporabi prek elektronske pošte oziroma javne povezave je uporabnik <strong>prejel na svoj krajevni disk</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Datoteka ali mapa je bila dodana v souporabo prek <strong>drugega strežnika</strong>",
     "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je omogočena <strong>souporaba</strong>",
     "Wrong share ID, share doesn't exist" : "Napačen ID mesta uporabe; mesto ne obstaja!",
-    "Could not delete share" : "Tega predmeta v souporabi ni mogoče izbrisati.",
+    "Could not delete share" : "Mesta souporabe ni mogoče izbrisati",
     "Please specify a file or folder path" : "Določiti je treba datoteko ali pot do mape",
     "Wrong path, file/folder doesn't exist" : "Napačna pot; datoteka ali mapa ne obstaja",
     "Could not create share" : "Mesta souporabe ni mogoče ustvariti",
@@ -50,11 +60,42 @@ OC.L10N.register(
     "Could not lock path" : "Poti ni mogoče zakleniti",
     "Wrong or no update parameter given" : "Parameter posodobitve ni podan ali pa je navedena napačna vrednost",
     "Can't change permissions for public share links" : "Za javne povezave souporabe, spreminjanje dovoljenj ni mogoče.",
+    "Download all files" : "Prejmi vse datoteke",
     "Direct link" : "Neposredna povezava",
     "Add to your Nextcloud" : "Dodaj v svoj Nextcloud",
     "Share API is disabled" : "Vmesnik API za souporabo je onemogočen",
-    "Share" : "Souporaba",
+    "Accept" : "Sprejmi",
     "Sharing" : "Souporaba",
+    "Allow editing" : "Dovoli urejanje",
+    "Allow resharing" : "Dovoli nadaljnjo souporabo",
+    "Expiration date enforced" : "Datum preteka je vsiljeno omogočen",
+    "Set expiration date" : "Nastavi datum preteka",
+    "Note to recipient" : "Sporočilo za prejemnika",
+    "Unshare" : "Prekini souporabo",
+    "group" : "skupina",
+    "conversation" : "pogovor",
+    "remote" : "oddaljeno",
+    "remote group" : "oddaljena skupina",
+    "guest" : "gost",
+    "Link copied" : "Povezava je kopirana",
+    "Copy to clipboard" : "Kopiraj v odložišče",
+    "Only works for users with access to this folder" : "Možnost deluje le za uporabnike, ki imajo dostop do te mape",
+    "Password protection" : "Zaščita z geslom",
+    "Enter a password" : "Vpis gesla",
+    "Cancel" : "Prekliči",
+    "Read only" : "Le za branje",
+    "Allow upload and editing" : "Dovoli pošiljanje in urejanje",
+    "File drop (upload only)" : "Povleci datoteke (samo nalaganje)",
+    "Hide download" : "Skrij prejem",
+    "Password protect" : "Zaščiti z geslom",
+    "Add another link" : "Dodaj novo povezavo",
+    "Share link" : "Povezava za souporabo",
+    "Resharing is not allowed" : "Osveževanje ni dovoljena",
+    "Shared" : "V souporabi",
+    "Share" : "Souporaba",
+    "Shared with" : "V skupni rabi z uporabnikom",
+    "Shared with you and the group {group} by {owner}" : "{owner} omogoči souporabo z vami in s skupino {group}.",
+    "Shared with you by {owner}" : "{owner} vam omogoči souporabo",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
     "Name" : "Ime",
     "Share time" : "Čas souporabe",
@@ -65,9 +106,11 @@ OC.L10N.register(
     "the link expired" : "povezava je pretekla,",
     "sharing is disabled" : "souporaba je onemogočena.",
     "For more info, please ask the person who sent this link." : "Za več podrobnosti stopite v stik s pošiljateljem te povezave.",
+    "Toggle grid view" : "Preklopi mrežni pogled",
     "Download %s" : "Prejmi %s",
     "Upload files to %s" : "Pošlji datoteke v %s",
-    "Select or drop files" : "Izberi ali povleci datoteke",
+    "Note" : "Opomba",
+    "Select or drop files" : "Izberte ali povlecite datoteke",
     "Uploading files…" : "Poteka pošiljanje datotek ...",
     "Uploaded files:" : "Poslane datoteke:",
     "could not delete share" : "mesta souporabe ni mogoče ustvariti"
