@@ -13,11 +13,18 @@ OC.L10N.register(
     "Deleted shares" : "已删除的共享",
     "No deleted shares" : "没有删除的共享",
     "Shares you deleted will show up here" : "您删除的共享将在这里显示",
+    "Pending shares" : "待定共享",
+    "No pending shares" : "没有待定共享",
+    "Shares you have received but not confirmed will show up here" : "您收到但未确认的共享将显示在这里",
     "Shares" : "共享",
     "No shares" : "没有共享",
     "Shares will show up here" : "共享将在这里显示",
     "Restore share" : "恢复共享",
     "Something happened. Unable to restore the share." : "发生了问题。无法恢复该共享。",
+    "Accept share" : "接受共享",
+    "Something happened. Unable to accept the share." : "发生了问题。无法接受该共享。",
+    "Reject share" : "拒绝共享",
+    "Something happened. Unable to reject the share." : "发生了问题。无法拒绝该共享。",
     "This will stop your current uploads." : "此操作将终止您当前的上传。",
     "Move or copy" : "移动或复制",
     "Download" : "下载",
@@ -127,7 +134,9 @@ OC.L10N.register(
     "Sharing" : "共享",
     "Accept user and group shares by default" : "默认接受用户和分组共享",
     "Allow editing" : "允许编辑",
-    "Can reshare" : "可以再次共享",
+    "Allow creating" : "允许创建",
+    "Allow deleting" : "允许删除",
+    "Allow resharing" : "允许二次共享",
     "Expiration date enforced" : "强制过期日期",
     "Set expiration date" : "设置过期日期",
     "Enter a date" : "输入日期",
@@ -141,9 +150,8 @@ OC.L10N.register(
     "Shared with the group {user} by {owner}" : "{owner} 共享给分组 {user}",
     "Shared with the conversation {user} by {owner}" : "由{owner}共享给会话{user}",
     "Shared with {user} by {owner}" : "{owner} 共享给 {user}",
-    "Invited by {initiator}" : "由 {initiator} 邀请",
-    "Open folder" : "打开文件夹",
-    "Delete share" : "删除共享",
+    "Added by {initiator}" : "由 {initiator} 添加",
+    "Via folder" : "通过文件夹",
     "Internal link" : "内部链接",
     "Link copied" : "已复制链接",
     "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
@@ -176,7 +184,8 @@ OC.L10N.register(
     "No elements found." : "未发现元素。",
     "Search globally" : "全局搜索",
     "on {server}" : "在 {server} 上",
-    "Others with access {count}" : "其他具有访问权限的人 {count} ",
+    "Others with access" : "其他具有访问权限的人",
+    "No other users with access found" : "找不到其他具有访问权限的用户",
     "Toggle list of others with access to this directory" : "切换有权访问此目录的其他人的列表",
     "Toggle list of others with access to this file" : "切换有权访问此文件的其他人的列表",
     "Unable to fetch inherited shares" : "无法获取继承的共享",
@@ -211,7 +220,7 @@ OC.L10N.register(
     "Upload files to %s" : "上传文件到 %s",
     "Note" : "备注",
     "Select or drop files" : "选择或删除文件",
-    "Uploading files…" : "上传文件... ",
+    "Uploading files…" : "正在上传文件... ",
     "Uploaded files:" : "上传的文件： ",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "通过上传文件，您同意了 %1$s 服务条款 %2$s。",
     "could not delete share" : "无法删除共享"
