@@ -4,7 +4,6 @@ OC.L10N.register(
     "Deleted files" : "فایل های حذف شده",
     "restored" : "بازیابی شد",
     "Restore" : "بازیابی",
-    "Delete" : "حذف",
     "Delete permanently" : "حذف قطعی",
     "This operation is forbidden" : "این عملیات غیرمجاز است",
     "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
@@ -13,9 +12,8 @@ OC.L10N.register(
     "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
     "Select all" : "انتخاب همه",
     "Name" : "نام",
+    "Actions" : "فعالیت ها",
     "Deleted" : "حذف شده",
-    "Couldn't delete %s permanently" : "%s را نمی توان برای همیشه حذف کرد",
-    "Couldn't restore %s" : "%s را نمی توان بازگرداند",
-    "Error" : "خطا"
+    "Delete" : "حذف"
 },
 "nplurals=2; plural=(n > 1);");
