@@ -1,12 +1,11 @@
 OC.L10N.register(
     "files_versions",
     {
-    "Could not revert: %s" : "Αδυναμία επαναφοράς: %s",
     "Versions" : "Εκδόσεις",
+    "This application automatically maintains older versions of files that are changed." : "Η εφαρμογή διατηρεί αυτόματα παλαιότερες εκδόσεις των αρχείων που έχουν αλλάξει.",
     "Failed to revert {file} to revision {timestamp}." : "Αποτυχία επαναφοράς του {file} στην αναθεώρηση {timestamp}.",
     "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
     "Restore" : "Επαναφορά",
-    "No earlier versions available" : "Δεν είναι διαθέριμες νεότερες εκδόσεις",
-    "More versions …" : "Περισσότερες εκδόσεις ..."
+    "No other versions available" : "Δεν υπάρχουν άλλες εκδόσεις διαθέσιμες"
 },
 "nplurals=2; plural=(n != 1);");
