@@ -1,12 +1,10 @@
 OC.L10N.register(
     "files_versions",
     {
-    "Could not revert: %s" : "بازگردانی امکان ناپذیر است: %s",
     "Versions" : "نسخه ها",
     "Failed to revert {file} to revision {timestamp}." : "برگرداندن {file} به نسخه {timestamp} با شکست روبرو شد",
     "_%n byte_::_%n bytes_" : ["%n بایت","%n بایت"],
     "Restore" : "بازیابی",
-    "No earlier versions available" : "هیچ نسخه قدیمی تری در دسترس نیست",
-    "More versions …" : "نسخه های بیشتر ..."
+    "No other versions available" : "نسخه ی دیگری در دسترس نیست"
 },
 "nplurals=2; plural=(n > 1);");
