@@ -5,8 +5,6 @@ OC.L10N.register(
     "Failed to revert {file} to revision {timestamp}." : "Не вдалося повернути {file} до ревізії {timestamp}.",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байтів","%n байта","%n байта"],
     "Restore" : "Відновити",
-    "Could not revert: %s" : "Не вдалося відновити: %s",
-    "No earlier versions available" : "Попередні версії недоступні",
-    "More versions …" : "Більше версій …"
+    "No other versions available" : "Інші версії недоступні"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
