@@ -8,6 +8,10 @@ OC.L10N.register(
     "No server logs" : "서버 로그 없음",
     "One or more entries are hidden by the log level filter" : "로그 단계 필터에 의해서 하나 이상의 항목이 숨겨짐",
     "Everything is working fine" : "모두 올바르게 작동하고 있습니다",
+    "Level" : "단계",
+    "App" : "앱",
+    "Message" : "메시지",
+    "Time" : "시간",
     "Log levels" : "로그 단계",
     "Log content" : "로그 내용",
     "Live update" : "실시간 업데이트",
