@@ -43,6 +43,7 @@ OC.L10N.register(
     "Please select tags to filter by" : "Παρακαλώ επιλέξτε ετικέτες για να φιλτραριστούν με",
     "No files found for the selected tags" : "Δεν βρέθηκαν αρχεία για τις επιλεγμένες ετικέτες",
     "Select tag …" : "Επιλογή ετικέτας ...",
+    "Create a new tag" : "Δημιούργησε νέα ετικέτα",
     "Name" : "Όνομα",
     "Public" : "Δημόσιο",
     "Restricted" : "Περιορισμένο",
@@ -52,7 +53,6 @@ OC.L10N.register(
     "No files in here" : "Δεν υπάρχουν αρχεία",
     "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
     "Size" : "Μέγεθος",
-    "Modified" : "Τροποποιήθηκε",
-    "Create and edit collaborative tags. These tags affect all users." : "Δημιουργήστε και διορθώστε συνεργατικές ετικέτες. Αυτές οι ετικέτες επηρεάζουν όλους τους χρήστες."
+    "Modified" : "Τροποποιήθηκε"
 },
 "nplurals=2; plural=(n != 1);");
