@@ -5,11 +5,6 @@ OC.L10N.register(
     "Update" : "Actualizar",
     "Create" : "Crear",
     "Select tag…" : "Seleccionar etiqueta...",
-    "Tagged files" : "Archivos etiquetados",
-    "Select tags to filter by" : "Seleccione las etiquetas para el filtro",
-    "No tags found" : "No se encontraron etiquetas",
-    "Please select tags to filter by" : "Favor de seleccionar etiquetas para el filtro",
-    "No files found for the selected tags" : "No se encontraron archivos para las etiquetas seleccionadas",
     "Added system tag {systemtag}" : "Etiqueta del sistema {systemtag} agregada",
     "Added system tag %1$s" : "Etiqueta del sistema %1$s agregada",
     "%1$s added system tag %2$s" : "%1$s agregó la etiqueta del sistema %2$s",
@@ -42,6 +37,11 @@ OC.L10N.register(
     "%s (invisible)" : "%s (invisible) ",
     "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
     "Collaborative tags" : "Etiquetas colaborativas",
+    "Tagged files" : "Archivos etiquetados",
+    "Select tags to filter by" : "Seleccione las etiquetas para el filtro",
+    "No tags found" : "No se encontraron etiquetas",
+    "Please select tags to filter by" : "Favor de seleccionar etiquetas para el filtro",
+    "No files found for the selected tags" : "No se encontraron archivos para las etiquetas seleccionadas",
     "Select tag …" : "Seleccionar etiqueta ...",
     "Name" : "Nombre",
     "Public" : "Público",
@@ -52,7 +52,6 @@ OC.L10N.register(
     "No files in here" : "No hay archivos aquí",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
     "Size" : "Tamaño",
-    "Modified" : "Modificado",
-    "Create and edit collaborative tags. These tags affect all users." : "Crear y editar etiquetas colaborativas. Estas etiquetas afectan a todos los usuarios. "
+    "Modified" : "Modificado"
 },
 "nplurals=2; plural=(n != 1);");
