@@ -8,12 +8,15 @@ OC.L10N.register(
     "Name cannot be empty" : "Je třeba zadat název",
     "The given name is too long" : "Zadaný název je příliš dlouhý",
     "The given web address is too long" : "Zadaná webová adresa je příliš dlouhá",
+    "The given web address is not a valid URL" : "Zadaná webová adresa není platná URL",
     "The given legal notice address is too long" : "Daná adresa právního upozornění je příliš dlouhá",
+    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platnou URL adresou",
     "The given privacy policy address is too long" : "Daná adresa zásad ochrany osobních údajů je příliš dlouhá",
+    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o ochraně soukromí není platná URL adresa",
     "The given slogan is too long" : "Zadaný slogan je příliš dlouhý",
     "The given color is invalid" : "Zadaná barva není platná",
     "The file was uploaded" : "Soubor byl nahrán",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahrávaný soubor přesahuje nastavení upload_max_filesize v php.ini",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Nahraný soubor překračuje nastavení MAX_FILE_SIZE, která byla zadána ve HTML formuláři",
     "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
     "No file was uploaded" : "Nebyl nahrán žádný soubor",
@@ -25,8 +28,9 @@ OC.L10N.register(
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používáte svůj vlastní motiv vzhledu. Nastavení aplikace pro změnu motivu vzhledu tím mohou být přepsána.",
     "Theming" : "Motivy",
     "Legal notice" : "Právní upozornění",
-    "Privacy policy" : "Zásady soukromí",
+    "Privacy policy" : "Zásady ochrany soukromí",
     "Adjust the Nextcloud theme" : "Upravit motiv vzhledu Nextcloud",
+    "Open documentation" : "Otevřít dokumentaci",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduché přizpůsobení vzhledu vaší instance a podporovaných klientů. Tato přizpůsobení uvidí všichni uživatelé.",
     "Name" : "Název",
     "Reset to default" : "Obnovit výchozí",
