@@ -11,6 +11,7 @@ OC.L10N.register(
     "The given slogan is too long" : "指定的標語太長",
     "The given color is invalid" : "指定的顏色無效",
     "The file was uploaded" : "檔案已上傳",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
     "No file was uploaded" : "沒有檔案被上傳",
     "Missing a temporary folder" : "找不到暫存資料夾",
     "Could not write file to disk" : "寫入硬碟失敗",
@@ -18,6 +19,7 @@ OC.L10N.register(
     "No file uploaded" : "未上傳檔案",
     "Unsupported image type" : "不支援的圖片類型",
     "Theming" : "佈景主題",
+    "Open documentation" : "開啟說明文件",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "使用佈景主題來客製化網頁界面和客戶端程式的外觀（並非所有客戶端程式都支援佈景主題），外觀將會套用至所有使用者。",
     "Name" : "名稱",
     "Reset to default" : "恢復預設值",
@@ -27,6 +29,7 @@ OC.L10N.register(
     "Upload new logo" : "上傳新的 Logo",
     "Login image" : "登入圖片",
     "Upload new login background" : "上傳新的登入頁背景",
-    "Remove background image" : "移除背景圖片"
+    "Remove background image" : "移除背景圖片",
+    "Advanced options" : "進階選項"
 },
 "nplurals=1; plural=0;");
