@@ -7,20 +7,20 @@ OC.L10N.register(
     "Save backup codes" : "Tallenna varakoodit",
     "Print backup codes" : "Tulosta varakoodit",
     "Backup codes have been generated. {used} of {total} codes have been used." : "Varakoodit on luotu. {used}/{total} koodia on käytetty.",
-    "Regenerate backup codes" : "Uudelleenluo varakoodit",
+    "Regenerate backup codes" : "Luo varakoodit uudelleen",
     "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
-    "If you regenerate backup codes, you automatically invalidate old codes." : "Jos uudelleenluot varakoodit, vanhat varakoodit poistetaan käytöstä.",
+    "If you regenerate backup codes, you automatically invalidate old codes." : "Jos luot varakoodit uudelleen, vanhat koodit poistetaan automaattisesti käytöstä.",
     "Generate backup codes" : "Luo varakoodit",
     "You created two-factor backup codes for your account" : "Loit kaksivaiheisen tunnistautumisen varakoodit tilillesi",
     "Second-factor backup codes" : "Kaksivaiheisen tunnistautumisen varakoodit",
     "Backup code" : "Varakoodi",
     "Use backup code" : "Käytä varakoodia",
     "Two factor backup codes" : "Kaksivaiheiden tunnistautumisen varakoodit",
-    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Varakoodit on luotu. {{used}}/{{total}} koodia on käytetty.",
-    "Nextcloud backup codes" : "Nextcloud-varakoodit",
+    "Submit" : "Lähetä",
     "activated" : "aktivoitu",
     "updated" : "päivitetty",
     "created" : "luotu",
-    "destroyed" : "tuhottu"
+    "destroyed" : "tuhottu",
+    "Nextcloud backup codes" : "Nextcloud-varakoodit"
 },
 "nplurals=2; plural=(n != 1);");
