@@ -8,6 +8,11 @@ OC.L10N.register(
     "No data specified" : "Nav norādīti dati",
     " Could not set configuration %s" : "Nevarēja iestatīt konfigurāciju %s",
     "Action does not exist" : "Darbība neeksistē",
+    "Very weak password" : "Ļoti vāja parole",
+    "Weak password" : "Vāja parole",
+    "So-so password" : "Normāla parole",
+    "Good password" : "Laba parole",
+    "Strong password" : "Lieliska parole",
     "The Base DN appears to be wrong" : "DN bāze šķiet nepareiza",
     "Testing configuration…" : "Konfigurācijas pārbaude...",
     "Configuration incorrect" : "Nepareiza konfigurācija",
@@ -63,6 +68,12 @@ OC.L10N.register(
     "Saving" : "Saglabā",
     "Back" : "Atpakaļ",
     "Continue" : "Turpināt",
+    "An internal error occurred." : "Radās iekšēja kļūda.",
+    "Please try again or contact your administrator." : "Lūdzu, mēģiniet vēlreiz vai sazinieties ar administratoru.",
+    "Current password" : "Pašreizējā parole",
+    "New password" : "Jauna parole",
+    "Wrong password." : "Nepareiza parole.",
+    "Cancel" : "Atcelt",
     "Server" : "Serveris",
     "Users" : "Lietotāji",
     "Login Attributes" : "Pieteikšanās atribūti",
