@@ -9,6 +9,10 @@ OC.L10N.register(
     " Could not set configuration %s" : "Ni mogoče uveljaviti nastavitev %s",
     "Action does not exist" : "Dejanje ne obstaja",
     "Very weak password" : "Zelo šibko geslo",
+    "Weak password" : "Šibko geslo",
+    "So-so password" : "Slabo geslo",
+    "Good password" : "Dobro geslo",
+    "Strong password" : "Odlično geslo",
     "The Base DN appears to be wrong" : "Enoznačno ime (DN) podatkovne zbirke je napačno",
     "Testing configuration…" : "Poteka preizkušanje nastavitev ...",
     "Configuration incorrect" : "Nastavitev ni ustrezna",
@@ -38,11 +42,13 @@ OC.L10N.register(
     "The search filter is invalid, probably due to syntax issues like uneven number of opened and closed brackets. Please revise." : "Filter iskanja ni veljaven. Najverjetneje je to zaradi napake skladnje, kot je neustrezno ali neskladno uporabljen oklepaj. Preverite vpis.",
     "A connection error to LDAP / AD occurred, please check host, port and credentials." : "Prišlo je do napake povezave z LDAP / AD. Preverite podatke o gostitelju, vratih in poverilih.",
     "Please provide a login name to test against" : "Vpisati je treba uporabniško ime za preizkus",
-    "The group box was disabled, because the LDAP / AD server does not support memberOf." : "Skupina je onemogočena, ker na strežniku ni omogočena podpora atributu memberOf.",
+    "The group box was disabled, because the LDAP / AD server does not support memberOf." : "Skupina je onemogočena, ker na strežniku LDAP / AD ni omogočena podpora atributu memberOf.",
+    "Password change rejected. Hint: " : "Spreminjanje gesla je zavrnjeno. Namig: ",
     "Please login with the new password" : "Prijavite se z novim geslom",
-    "Your password will expire tomorrow." : "Vaše geslo bo poteklo naslednji dan",
+    "Your password will expire tomorrow." : "Vaše geslo bo jutri poteklo.",
     "Your password will expire today." : "Geslo vam poteče danes!",
     "_Your password will expire within %n day._::_Your password will expire within %n days._" : ["Geslo bo poteklo čez %n dan.","Geslo bo poteklo čez %n dneva","Geslo bo poteklo čez %n dni.","Geslo bo poteklo čez %n dni."],
+    "LDAP / AD integration" : "Podpora LDAP / AD",
     "_%s group found_::_%s groups found_" : ["%s najdena skupina","%s najdeni skupini","%s najdene skupine","%s najdenih skupin"],
     "_%s user found_::_%s users found_" : ["%s najden uporabnik","%s najdena uporabnika","%s najdeni uporabniki","%s najdenih uporabnikov"],
     "Could not find the desired feature" : "Želene zmožnosti ni mogoče najti",
@@ -64,7 +70,7 @@ OC.L10N.register(
     "Other Attributes:" : "Drugi atributi:",
     "Test Loginname" : "Preizkusi prijavno ime",
     "Verify settings" : "Preveri nastavitve",
-    "%s. Server:" : "%s. strežnik:",
+    "%s. Server:" : "%s. Strežnik:",
     "Copy current configuration into new directory binding" : "Kopiraj trenutne nastavitve v vezi nove mape.",
     "Delete the current configuration" : "Izbriši trenutne nastavitve",
     "Host" : "Gostitelj",
@@ -74,6 +80,7 @@ OC.L10N.register(
     "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "Enolično ime uporabnikovega odjemalca, s katerim naj se opravi vezava, npr. uid=agent,dc=example,dc=com. Za brezimni dostop sta polji prikaznega imena in gesla prazni.",
     "Password" : "Geslo",
     "For anonymous access, leave DN and Password empty." : "Za brezimni dostop naj bosta polji imena in gesla prazni.",
+    "Save Credentials" : "Shrani poverila",
     "One Base DN per line" : "Eno osnovno enolično ime na vrstico",
     "You can specify Base DN for users and groups in the Advanced tab" : "Osnovno enolično ime za uporabnike in skupine lahko določite v zavihku naprednih možnosti.",
     "Detect Base DN" : "Zaznava osnovnega enoznačnega imena (DN)",
@@ -85,8 +92,12 @@ OC.L10N.register(
     "Saving" : "Poteka shranjevanje ...",
     "Back" : "Nazaj",
     "Continue" : "Nadaljuj",
+    "An internal error occurred." : "Prišlo je do notranje napake.",
+    "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
     "Current password" : "Trenutno geslo",
     "New password" : "Novo geslo",
+    "Renew password" : "Posodobi geslo",
+    "Wrong password." : "Napačno geslo",
     "Cancel" : "Prekliči",
     "Server" : "Strežnik",
     "Users" : "Uporabniki",
