@@ -8,6 +8,11 @@ OC.L10N.register(
     "No data specified" : "沒有指定資料",
     " Could not set configuration %s" : "無法設定 %s 為設定值",
     "Action does not exist" : "操作不存在",
+    "Very weak password" : "密碼安全性極弱",
+    "Weak password" : "密碼安全性弱",
+    "So-so password" : "密碼安全性普通",
+    "Good password" : "密碼安全性佳",
+    "Strong password" : "密碼安全性極佳",
     "The Base DN appears to be wrong" : "Base DN 出現問題",
     "Configuration incorrect" : "設定不正確",
     "Configuration incomplete" : "設定未完成",
@@ -75,6 +80,12 @@ OC.L10N.register(
     "Saving" : "儲存",
     "Back" : "返回",
     "Continue" : "繼續",
+    "An internal error occurred." : "發生內部錯誤",
+    "Please try again or contact your administrator." : "請重試或聯絡系統管理員",
+    "Current password" : "目前密碼",
+    "New password" : "新密碼",
+    "Wrong password." : "密碼錯誤",
+    "Cancel" : "取消",
     "Server" : "伺服器",
     "Users" : "使用者",
     "Login Attributes" : "登入的設定",
