@@ -35,6 +35,8 @@ OC.L10N.register(
     "Entity %s has no event %s" : "Entita %s nemá událost %s",
     "Operation %s does not exist" : "Operace %s neexistuje",
     "Operation %s is invalid" : "Operace %s není platná",
+    "At least one check needs to be provided" : "Je třeba poskytnou alespoň jednu kontrolu",
+    "Invalid check provided" : "Zadána neplatná kontrola",
     "Check %s does not exist" : "Kontrola %s neexistuje",
     "Check %s is invalid" : "Kontrola %s je neplatná",
     "Check %s is not allowed with this entity" : "Zaškrtnutí %s není u této entity povoleno",
@@ -66,6 +68,7 @@ OC.L10N.register(
     "Desktop client" : "Desktopový klient",
     "Thunderbird & Outlook addons" : "Doplňky pro Thunderbird a Outlook",
     "Custom user agent" : "Uživatelem určený user agent",
+    "At least one event must be selected" : "Je třeba vybrat alespoň jednu událost",
     "Add new flow" : "Přidat nový tok",
     "When" : "Kdy",
     "and" : "a",
@@ -82,11 +85,11 @@ OC.L10N.register(
     "Show more" : "Zobrazit více",
     "Configured flows" : "Nastavené toky",
     "Your flows" : "Vaše toky",
-    "File name" : "Název souboru",
-    "is" : "je",
-    "is not" : "není",
     "matches" : "odpovídá",
     "does not match" : "neodpovídá",
+    "is" : "je",
+    "is not" : "není",
+    "File name" : "Název souboru",
     "File MIME type" : "MIME typ souboru",
     "File size (upload)" : "Velikost souboru (nahráno)",
     "less" : "menší",
