@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "Den givne starttid er invalid",
     "The given end time is invalid" : "Den givne sluttid er invalid",
     "The given group does not exist" : "Den givne gruppe eksisterer ikke",
+    "File" : "Fil",
     "Operation #%s does not exist" : "Operation #%s eksisterer ikke",
     "Operation %s does not exist" : "Operation %s eksisterer ikke",
     "Operation %s is invalid" : "Operation %s er invalid",
@@ -19,18 +20,24 @@ OC.L10N.register(
     "Check %s is invalid" : "Tjek %s er invalid",
     "Check #%s does not exist" : "Tjek #%s eksisterer",
     "Check %s is invalid or does not exist" : "Tjek %s er invalid eller eksisterer ikke",
+    "Images" : "Billeder",
+    "No results" : "Ingen resultater",
+    "%s (invisible)" : "%s (usynlig)",
+    "%s (restricted)" : "%s (begrænset)",
     "Predefined URLs" : "Foruddefineret URLer",
     "Files WebDAV" : "Fil WebDAV",
     "Android client" : "Android klient",
     "iOS client" : "iOS klient",
     "Desktop client" : "Dekstop klient",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook tilføjelser",
+    "Cancel" : "Annullér",
+    "Delete" : "Slet",
     "Save" : "Gem",
-    "File name" : "Filnavn",
-    "is" : "er",
-    "is not" : "er ikke",
     "matches" : "er lig med",
     "does not match" : "er ikke lig med",
+    "is" : "er",
+    "is not" : "er ikke",
+    "File name" : "Filnavn",
     "File MIME type" : "Fil MIME type",
     "File size (upload)" : "Filstørrelse (upload)",
     "less" : "mindre",
