@@ -20,6 +20,14 @@ OC.L10N.register(
     "File accessed" : "Auf Datei zugegriffen",
     "File copied" : "Datei kopiert",
     "Tag assigned" : "Schlagwort zugewiesen",
+    "Someone" : "Irgendjemand",
+    "%s created %s" : "%s hat %s erstellt",
+    "%s modified %s" : "%shat %s geändert",
+    "%s deleted %s" : "%s hat  %s gelöscht",
+    "%s accessed %s" : "%s hat auf %s zugegriffen",
+    "%s renamed %s" : "%shat %s umbenannt",
+    "%s copied %s" : "%s hat %s kopiert",
+    "%s assigned %s to %s" : "%s hat %s zugewiesen an %s",
     "Operation #%s does not exist" : "Operation #%s existiert nicht",
     "Entity %s does not exist" : "Entität %s existiert nicht",
     "Entity %s is invalid" : "Entität %s ist ungültig",
@@ -27,13 +35,15 @@ OC.L10N.register(
     "Entity %s has no event %s" : "Die Entität %s hat kein Ereignis %s",
     "Operation %s does not exist" : "Operation %s existiert nicht",
     "Operation %s is invalid" : "Operation %s ist ungültig",
+    "At least one check needs to be provided" : "Mindestens ein Test muss bereitgestellt werden",
+    "Invalid check provided" : "Ungültiger Test bereitgestellt",
     "Check %s does not exist" : "Die Prüfung %s existiert nicht",
     "Check %s is invalid" : "Die Prüfung %s ist ungültig",
     "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
     "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
     "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
-    "Workflows" : "Arbeitsabläufe",
-    "Nextcloud workflow engine" : "Nxtcloud Arbeitsablauf-Engine",
+    "Flow" : "Ablauf",
+    "Nextcloud workflow engine" : "Nextcloud Arbeitsablauf-Engine",
     "Select a filter" : "Filter wählen",
     "Select a comparator" : "Wählen Sie einen Komparator",
     "Select a file type" : "Dateityp auswählen",
@@ -58,18 +68,28 @@ OC.L10N.register(
     "Desktop client" : "Desktop-Client",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
     "Custom user agent" : "Benutzerdefinierter User-Agent",
+    "At least one event must be selected" : "Mindestens ein Ereignis muss ausgewählt werden",
+    "Add new flow" : "Neuen Ablauf hinzufügen",
     "When" : "Wenn",
     "and" : "und",
     "Cancel" : "Abbrechen",
     "Delete" : "Löschen",
     "The configuration is invalid" : "Die Konfiguration ist ungültig",
+    "Active" : "Aktiv",
+    "Save" : "Speichern",
+    "Available flows" : "Verfügbare Abläufe",
+    "For details on how to write your own flow, check out the development documentation." : "Informationen wie eigene Abläufe erstellt werden, finden Sie in der Entwickler-Dokumentation.",
+    "More flows" : "Weitere Abläufe",
+    "Browse the app store" : "Appstore durchsuchen",
     "Show less" : "Weniger anzeigen",
     "Show more" : "Mehr anzeigen",
-    "File name" : "Dateiname",
-    "is" : "ist",
-    "is not" : "ist nicht",
+    "Configured flows" : "Konfigurierte Abläufe",
+    "Your flows" : "Ihre Abläufe",
     "matches" : "entspricht",
     "does not match" : "entspricht nicht",
+    "is" : "ist",
+    "is not" : "ist nicht",
+    "File name" : "Dateiname",
     "File MIME type" : "Datei MIME-Typ",
     "File size (upload)" : "Dateigröße (beim Hochladen)",
     "less" : "weniger",
@@ -95,7 +115,6 @@ OC.L10N.register(
     "Short rule description" : "Kurze Regelbeschreibung",
     "Add rule" : "Regel hinzufügen",
     "Reset" : "Zurücksetzen",
-    "Save" : "Speichern",
     "Saving…" : "Speichern…",
     "Group list is empty" : "Gruppenliste ist leer",
     "Unable to retrieve the group list" : "Gruppenliste konnte nicht abgerufen werden",
