@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "The given start time is invalid",
     "The given end time is invalid" : "The given end time is invalid",
     "The given group does not exist" : "The given group does not exist",
+    "File" : "File",
     "Operation #%s does not exist" : "Operation #%s does not exist",
     "Operation %s does not exist" : "Operation %s does not exist",
     "Operation %s is invalid" : "Operation %s is invalid",
@@ -19,17 +20,25 @@ OC.L10N.register(
     "Check %s is invalid" : "Check %s is invalid",
     "Check #%s does not exist" : "Check #%s does not exist",
     "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
+    "Images" : "Images",
+    "No results" : "No results",
+    "%s (invisible)" : "%s (invisible)",
+    "%s (restricted)" : "%s (restricted)",
     "Predefined URLs" : "Predefined URLs",
     "Files WebDAV" : "Files WebDAV",
     "Android client" : "Android client",
     "iOS client" : "iOS client",
     "Desktop client" : "Desktop client",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
-    "File name" : "File name",
-    "is" : "is",
-    "is not" : "is not",
+    "Cancel" : "Cancel",
+    "Delete" : "Delete",
+    "Save" : "Save",
+    "Browse the app store" : "Browse the app store",
     "matches" : "matches",
     "does not match" : "does not match",
+    "is" : "is",
+    "is not" : "is not",
+    "File name" : "File name",
     "File MIME type" : "File MIME type",
     "File size (upload)" : "File size (upload)",
     "less" : "less",
@@ -55,7 +64,6 @@ OC.L10N.register(
     "Short rule description" : "Short rule description",
     "Add rule" : "Add rule",
     "Reset" : "Reset",
-    "Save" : "Save",
     "Saving…" : "Saving…",
     "Group list is empty" : "Group list is empty",
     "Unable to retrieve the group list" : "Unable to retrieve the group list",
