@@ -20,6 +20,14 @@ OC.L10N.register(
     "File accessed" : "Archivo accedido",
     "File copied" : "Archivo copiado",
     "Tag assigned" : "Etiqueta asignada",
+    "Someone" : "Alguien",
+    "%s created %s" : "%s ha creado %s",
+    "%s modified %s" : "%s ha modificado %s",
+    "%s deleted %s" : "%s ha eliminado %s",
+    "%s accessed %s" : "%s ha accedido a %s",
+    "%s renamed %s" : "%s ha renombrado %s",
+    "%s copied %s" : "%s ha copiado %s",
+    "%s assigned %s to %s" : "%s ha asignado %s a %s",
     "Operation #%s does not exist" : "Operación #%s no existe",
     "Entity %s does not exist" : "Entidad %s no existe",
     "Entity %s is invalid" : "La entidad %s no es valida",
@@ -27,12 +35,14 @@ OC.L10N.register(
     "Entity %s has no event %s" : "La entidad %s no tiene eventos %s",
     "Operation %s does not exist" : "Operación %s no existe",
     "Operation %s is invalid" : "Operación %s no es valida",
-    "Check %s does not exist" : "Chequeo %s no existe",
-    "Check %s is invalid" : "Chequeo %s no es valido",
+    "At least one check needs to be provided" : "Has de seleccionar al menos una comprobación",
+    "Invalid check provided" : "La comprobación proporcionada no es válida",
+    "Check %s does not exist" : "La comprobación %s no existe",
+    "Check %s is invalid" : "La comprobación %s no es válida",
     "Check %s is not allowed with this entity" : "La comprobación %s no se permite con esta entidad",
     "Check #%s does not exist" : "El chequeo #%s no existe",
     "Check %s is invalid or does not exist" : "Comprueba %s no es valido o no existe",
-    "Workflows" : "Flujos de trabajo",
+    "Flow" : "Flujo",
     "Nextcloud workflow engine" : "Motor de flujo de trabajo de Nextcloud",
     "Select a filter" : "Seleccione un filtro",
     "Select a comparator" : "Seleccione un comparador",
@@ -58,18 +68,28 @@ OC.L10N.register(
     "Desktop client" : "Cliente de escritorio",
     "Thunderbird & Outlook addons" : "Complementos de Thunderbird y Outlook",
     "Custom user agent" : "Agente de usuario personalizado",
+    "At least one event must be selected" : "Has de seleccionar al menos un evento",
+    "Add new flow" : "Añadir nuevo flujo",
     "When" : "Cuando",
     "and" : "y",
     "Cancel" : "Cancelar",
     "Delete" : "Eliminar",
     "The configuration is invalid" : "La configuración es incorrecta",
+    "Active" : "Activo",
+    "Save" : "Guardar",
+    "Available flows" : "Flujos disponibles",
+    "For details on how to write your own flow, check out the development documentation." : "Para detalles acerca de cómo escribir su propio flujo, mire la documentación dedesarrollo.",
+    "More flows" : "Más flujos",
+    "Browse the app store" : "Explora la tienda de aplicaciones",
     "Show less" : "Ver menos",
     "Show more" : "Ver más",
-    "File name" : "Nombre del archivo",
-    "is" : "es/esta",
-    "is not" : "no es/esta",
+    "Configured flows" : "Configurar flujos",
+    "Your flows" : "Sus flujos",
     "matches" : "coincidencias",
     "does not match" : "no coincide",
+    "is" : "es/esta",
+    "is not" : "no es/esta",
+    "File name" : "Nombre del archivo",
     "File MIME type" : "Tipo MIME del archivo",
     "File size (upload)" : "Tamaño del archivo (para subir)",
     "less" : "menos",
@@ -95,7 +115,6 @@ OC.L10N.register(
     "Short rule description" : "Descripción de la regla corta",
     "Add rule" : "Añadir regla",
     "Reset" : "Restablecer",
-    "Save" : "Guardar",
     "Saving…" : "Guardando...",
     "Group list is empty" : "La lista de grupos está vacía",
     "Unable to retrieve the group list" : "No es posible recibir la lista de grupos",
