@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "El tiempo inicial dado no es válido",
     "The given end time is invalid" : "El tiempo final dado no es válido",
     "The given group does not exist" : "El grupo dado no existe",
+    "File" : "Archivo",
     "Operation #%s does not exist" : "La operación #%s  no existe",
     "Operation %s does not exist" : "La operación %s no existe",
     "Operation %s is invalid" : "La operación %s es inválida",
@@ -19,15 +20,23 @@ OC.L10N.register(
     "Check %s is invalid" : "La validación %s no es inválida",
     "Check #%s does not exist" : "La validación #%s no existe",
     "Check %s is invalid or does not exist" : "La validación %s es inválida o no existe",
+    "Images" : "Imágenes",
+    "No results" : "Sin resultados",
+    "%s (invisible)" : "%s (invisible) ",
+    "%s (restricted)" : "%s (restringido)",
     "Predefined URLs" : "URLs predefinidos",
     "Files WebDAV" : "Archivos en WebDAV",
     "Android client" : "Cliente Android",
     "iOS client" : "Cliente iOS",
     "Desktop client" : "Cliente de escritorio",
-    "is" : "es",
-    "is not" : "no es",
+    "Cancel" : "Cancelar",
+    "Delete" : "Eliminar",
+    "Save" : "Guardar",
     "matches" : "coincide",
     "does not match" : "No coincide",
+    "is" : "es",
+    "is not" : "no es",
+    "File name" : "Nombre",
     "File MIME type" : "Tipo MIME del archivo",
     "File size (upload)" : "Tamaño del archivo (carga)",
     "less" : "menor",
@@ -53,7 +62,6 @@ OC.L10N.register(
     "Short rule description" : "Descripción corta de regla",
     "Add rule" : "Agregar regla",
     "Reset" : "Restablecer",
-    "Save" : "Guardar",
     "Saving…" : "Guardando...",
     "Saved" : "Guardado",
     "Saving failed:" : "Falla al guardar:",
@@ -65,6 +73,7 @@ OC.L10N.register(
     "Select timezone…" : "Seleccionar zona horaria...",
     "Sync clients" : "Sincronizar clientes",
     "Workflow" : "Flujo de trabajo",
+    "Files workflow engine" : "Motor de flujo de trabajo de archivos",
     "Open documentation" : "Abrir documentación",
     "Loading…" : "Cargando..."
 },
