@@ -1,46 +1,6 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
-    "Saved" : "Guardado",
-    "Saving failed:" : "Falla al guardar:",
-    "File MIME type" : "Tipo MIME del archivo",
-    "is" : "es",
-    "is not" : "no es",
-    "matches" : "coincide",
-    "does not match" : "No coincide",
-    "Example: {placeholder}" : "Ejemplo: {placeholder}",
-    "File size (upload)" : "Tamaño del archivo (carga)",
-    "less" : "menos",
-    "less or equals" : "menos o igual",
-    "greater or equals" : "mayor o igual",
-    "greater" : "mayor",
-    "File system tag" : "Etiqueta del sistema de archivos",
-    "is tagged with" : "está etiquetado con",
-    "is not tagged with" : "no está etiquetado con",
-    "Select tag…" : "Seleccionar etiqueta...",
-    "Request remote address" : "Solicitar dirección remota",
-    "matches IPv4" : "coincide con IPv4",
-    "does not match IPv4" : "no coincide con IPv4",
-    "matches IPv6" : "coincide con IPv6",
-    "does not match IPv6" : "no coincide con IPv6",
-    "Request time" : "Tiempo de la solicitud",
-    "between" : "entre",
-    "not between" : "no entre",
-    "Start" : "Inicio",
-    "End" : "Fin",
-    "Select timezone…" : "Selecciona la zona horaria...",
-    "Request URL" : "Solicitar URL",
-    "Predefined URLs" : "URLs predefinidos",
-    "Files WebDAV" : "Archivos WebDAV",
-    "Request user agent" : "Solicitar agente de usuario",
-    "Sync clients" : "Sincronizar clientes",
-    "Android client" : "Cliente Android",
-    "iOS client" : "Cliente iOS",
-    "Desktop client" : "Cliente de escritorio",
-    "User group membership" : "Membresia al grupo de usuarios",
-    "is member of" : "es miembro de",
-    "is not member of" : "no es miembro de",
     "The given operator is invalid" : "El operador indicado es inválido",
     "The given regular expression is invalid" : "La expresión regular indicada es inválida",
     "The given file size is invalid" : "El tamaño de archivo indicado es inválido",
@@ -52,22 +12,72 @@ OC.L10N.register(
     "The given start time is invalid" : "El tiempo inicial dado no es válido",
     "The given end time is invalid" : "El tiempo final dado no es válido",
     "The given group does not exist" : "El grupo dado no existe",
-    "Check %s is invalid or does not exist" : "La validación %s es inválida o no existe",
+    "File" : "Archivo",
     "Operation #%s does not exist" : "La operación #%s  no existe",
     "Operation %s does not exist" : "La operación %s no existe",
     "Operation %s is invalid" : "La operación %s es inválida",
     "Check %s does not exist" : "La validación %s no existe",
     "Check %s is invalid" : "La validación %s no es inválida",
     "Check #%s does not exist" : "La validación #%s no existe",
-    "Workflow" : "Flujo de trabajo",
-    "Files workflow engine" : "Motor de flujo de trabajo de archivos",
-    "Open documentation" : "Abrir la documentación",
-    "Add rule group" : "Agregar regla de grupo",
+    "Check %s is invalid or does not exist" : "La validación %s es inválida o no existe",
+    "Images" : "Imágenes",
+    "No results" : "Sin resultados",
+    "%s (invisible)" : "%s (invisible) ",
+    "%s (restricted)" : "%s (restringido)",
+    "Predefined URLs" : "URLs predefinidos",
+    "Files WebDAV" : "Archivos WebDAV",
+    "Android client" : "Cliente Android",
+    "iOS client" : "Cliente iOS",
+    "Desktop client" : "Cliente de escritorio",
+    "Cancel" : "Cancelar",
+    "Delete" : "Borrar",
+    "Save" : "Guardar",
+    "Browse the app store" : "Navega la tienda de aplicaciones",
+    "matches" : "coincide",
+    "does not match" : "No coincide",
+    "is" : "es",
+    "is not" : "no es",
+    "File name" : "Nombre",
+    "File MIME type" : "Tipo MIME del archivo",
+    "File size (upload)" : "Tamaño del archivo (carga)",
+    "less" : "menos",
+    "less or equals" : "menos o igual",
+    "greater or equals" : "mayor o igual",
+    "greater" : "mayor",
+    "Request remote address" : "Solicitar dirección remota",
+    "matches IPv4" : "coincide con IPv4",
+    "does not match IPv4" : "no coincide con IPv4",
+    "matches IPv6" : "coincide con IPv6",
+    "does not match IPv6" : "no coincide con IPv6",
+    "File system tag" : "Etiqueta del sistema de archivos",
+    "is tagged with" : "está etiquetado con",
+    "is not tagged with" : "no está etiquetado con",
+    "Request URL" : "Solicitar URL",
+    "Request time" : "Tiempo de la solicitud",
+    "between" : "entre",
+    "not between" : "no entre",
+    "Request user agent" : "Solicitar agente de usuario",
+    "User group membership" : "Membresia al grupo de usuarios",
+    "is member of" : "es miembro de",
+    "is not member of" : "no es miembro de",
     "Short rule description" : "Descripción corta de la regla",
     "Add rule" : "Agregar regla",
     "Reset" : "Restablecer",
-    "Save" : "Guardar",
     "Saving…" : "Guardando...",
+    "Group list is empty" : "La lista de grupos esta vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
+    "Saved" : "Guardado",
+    "Saving failed:" : "Falla al guardar:",
+    "Add rule group" : "Agregar regla de grupo",
+    "Example: {placeholder}" : "Ejemplo: {placeholder}",
+    "Select tag…" : "Seleccionar etiqueta...",
+    "Start" : "Inicio",
+    "End" : "Fin",
+    "Select timezone…" : "Selecciona la zona horaria...",
+    "Sync clients" : "Sincronizar clientes",
+    "Workflow" : "Flujo de trabajo",
+    "Files workflow engine" : "Motor de flujo de trabajo de archivos",
+    "Open documentation" : "Abrir la documentación",
     "Loading…" : "Cargando..."
 },
 "nplurals=2; plural=(n != 1);");
