@@ -11,18 +11,26 @@ OC.L10N.register(
     "The given start time is invalid" : "Antud algusaeg on vigane",
     "The given end time is invalid" : "Antud lõppaeg on vigane",
     "The given group does not exist" : "Antud gruppi ei leitud",
+    "File" : "Fail",
     "Operation #%s does not exist" : "Tegevus # %s ei leitud",
     "Operation %s does not exist" : "Tegevust %s ei leitud",
     "Operation %s is invalid" : "Tegevus %s on vigane",
+    "Images" : "Pildid",
+    "No results" : "Vasteid ei leitud",
+    "%s (invisible)" : "%s (nähtamatu)",
+    "%s (restricted)" : "%s (piiratud)",
     "Predefined URLs" : "Eelmääratletud URL-id",
     "Files WebDAV" : "WebDAV failid",
     "Android client" : "Android klient",
     "iOS client" : "iOS klient",
     "Desktop client" : "Töölaua klient",
-    "is" : "on",
-    "is not" : "ei ole",
+    "Cancel" : "Loobu",
+    "Delete" : "Kustuta",
+    "Save" : "Salvesta",
     "matches" : "kattub",
     "does not match" : "ei kattu",
+    "is" : "on",
+    "is not" : "ei ole",
     "File MIME type" : "Faili MIME tüüp",
     "File size (upload)" : "Faili suurus (üleslaadimine)",
     "less" : "väiksem",
@@ -48,7 +56,6 @@ OC.L10N.register(
     "Short rule description" : "Reegli lühikirjeldus",
     "Add rule" : "Lisa reegel",
     "Reset" : "Lähtesta",
-    "Save" : "Salvesta",
     "Saving…" : "Salvestamine...",
     "Saved" : "Salvestatud",
     "Saving failed:" : "Salvestamine ebaõnnestus:",
