@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "تاریخ شروع معتبر نیست",
     "The given end time is invalid" : "تاریخ پایان معتبر نیست ",
     "The given group does not exist" : "گروه گرفته شده معتبر نیست",
+    "File" : "File",
     "Operation #%s does not exist" : "عمل %s وجود ندارد",
     "Operation %s does not exist" : "عمل %s وجود ندارد ",
     "Operation %s is invalid" : "عمل %s معتبر نیست",
@@ -19,16 +20,19 @@ OC.L10N.register(
     "Check %s is invalid" : "%s را چک کنید معتبر نیست",
     "Check #%s does not exist" : "%s را چک کنید وجود ندارد ",
     "Check %s is invalid or does not exist" : "%s یا وجود ندارد یا معتبر نیست",
+    "No results" : "نتیجه ای یافت نشد",
     "Predefined URLs" : "URL از پیش تعریف شده ",
     "Files WebDAV" : "فایل های WebDAV",
     "Android client" : "دستگاه های اندروید ",
     "iOS client" : "دستگاه های IOS",
     "Desktop client" : "دستگاه دسکتاپ",
+    "Cancel" : "لغو",
+    "Delete" : "حذف",
     "Save" : "ذخیره",
-    "is" : "هست ",
-    "is not" : "نیست",
     "matches" : "مطابق است",
     "does not match" : "مطابق نیست",
+    "is" : "هست ",
+    "is not" : "نیست",
     "File MIME type" : "فایل از نوع MIME",
     "File size (upload)" : "حجم فایل (بارگزاری شده )",
     "less" : "کمتر",
@@ -55,6 +59,8 @@ OC.L10N.register(
     "Add rule" : "اضافه کردن قوانین ",
     "Reset" : "ریست",
     "Saving…" : "در حال ذخیره",
+    "Group list is empty" : "لیست گروه ها خالی است.",
+    "Unable to retrieve the group list" : "بازیابی لیست گروه امکان پذیر نیست",
     "Saved" : "ذخیره شده ",
     "Saving failed:" : "ذخیره فایل با خطا مواجه شد.",
     "Add rule group" : "اضافه کردن قوانین گروه",
