@@ -34,20 +34,26 @@ OC.L10N.register(
     "PDF documents" : "PDF-asiakirjat",
     "Custom mimetype" : "Mukautettu MIME-tyyppi",
     "No results" : "Ei tuloksia",
+    "%s (invisible)" : "%s (näkymätön)",
+    "%s (restricted)" : "%s (rajoitettu)",
     "Predefined URLs" : "Ennalta määritellyt URL-osoitteet",
     "Files WebDAV" : "Tiedostot WebDAV",
     "Android client" : "Android-sovellus",
     "iOS client" : "iOS-sovellus",
     "Desktop client" : "Työpöytäsovellus",
     "Thunderbird & Outlook addons" : "Thunderbird- & Outlook-lisäosat",
+    "Cancel" : "Peruuta",
+    "Delete" : "Poista",
+    "Active" : "Aktiivinen",
     "Save" : "Tallenna",
+    "Browse the app store" : "Selaa sovelluskauppaa",
     "Show less" : "Näytä vähemmän",
     "Show more" : "Näytä enemmän",
-    "File name" : "Tiedostonimi",
-    "is" : "on",
-    "is not" : "ei ole",
     "matches" : "täsmää",
     "does not match" : "ei täsmää",
+    "is" : "on",
+    "is not" : "ei ole",
+    "File name" : "Tiedostonimi",
     "File MIME type" : "Tiedoston MIME-tyyppi",
     "File size (upload)" : "Tiedostokoko (lähetys)",
     "less" : "pienempi",
