@@ -17,19 +17,32 @@ OC.L10N.register(
     "File updated" : "Fichier mis à jour",
     "File renamed" : "Fichier renommé",
     "File deleted" : "Fichier supprimé",
+    "File accessed" : "Fichier accédé",
     "File copied" : "Fichier copié",
     "Tag assigned" : "Étiquette assignée",
+    "Someone" : "Quelqu'un",
+    "%s created %s" : "%s créé %s",
+    "%s modified %s" : "%s modifié %s",
+    "%s deleted %s" : "%s supprimé %s",
+    "%s accessed %s" : "%sa accédé à %s",
+    "%s renamed %s" : "%s renommé %s",
+    "%s copied %s" : "%s copié %s",
+    "%s assigned %s to %s" : "%s a assigné %sà %s",
     "Operation #%s does not exist" : "L'opération #%s n'existe pas",
+    "Entity %s does not exist" : "L'entité %sn'existe pas",
+    "Entity %s is invalid" : "L'entité %s est non valide",
     "No events are chosen." : "Aucun évènement a été choisi.",
+    "Entity %s has no event %s" : "L'entité %sn'a aucun évènement %s",
     "Operation %s does not exist" : "L'opération %s n'existe pas",
     "Operation %s is invalid" : "L'opération %s est invalide",
     "Check %s does not exist" : "Vérifiez si %s n'existe pas",
     "Check %s is invalid" : "Vérifiez si %s est invalide",
     "Check #%s does not exist" : "Vérifiez si #%s n'existe pas",
     "Check %s is invalid or does not exist" : "Vérifiez si %s est invalide ou n'existe pas",
-    "Workflows" : "Workflows",
+    "Flow" : "Flux",
     "Nextcloud workflow engine" : "Moteur de workflow Nextcloud",
     "Select a filter" : "Sélectionner un filtre",
+    "Select a comparator" : "Sélectionnez un comparateur",
     "Select a file type" : "Sélectionnez un type de fichier",
     "Images" : "Images",
     "Office documents" : "Documents Office",
@@ -50,13 +63,16 @@ OC.L10N.register(
     "Cancel" : "Annuler",
     "Delete" : "Supprimer",
     "The configuration is invalid" : "Configuration non valide",
+    "Active" : "Actif",
+    "Save" : "Enregistrer",
+    "Browse the app store" : "Parcourir l'App Store",
     "Show less" : "Afficher moins",
     "Show more" : "Afficher plus",
-    "File name" : "Nom du fichier",
-    "is" : "est",
-    "is not" : "n'est pas",
     "matches" : "correspond",
     "does not match" : "ne correspond pas",
+    "is" : "est",
+    "is not" : "n'est pas",
+    "File name" : "Nom du fichier",
     "File MIME type" : "Type MIME du fichier",
     "File size (upload)" : "Taille du fichier ( à télécharger )",
     "less" : "moins",
@@ -82,7 +98,6 @@ OC.L10N.register(
     "Short rule description" : "Trier par description de règle",
     "Add rule" : "Ajouter règle",
     "Reset" : "Réinitialiser",
-    "Save" : "Enregistrer",
     "Saving…" : "Enregistrement...",
     "Group list is empty" : "La liste du groupe est vide",
     "Unable to retrieve the group list" : "Impossible de récupérer la liste du groupe",
