@@ -35,6 +35,8 @@ OC.L10N.register(
     "Entity %s has no event %s" : "A entidade %s non ten ningún evento %s",
     "Operation %s does not exist" : "Non existe a operación %s",
     "Operation %s is invalid" : "A operación %s é incorrecta",
+    "At least one check needs to be provided" : "É necesario fornecer polo menos unha comprobación",
+    "Invalid check provided" : "Forneceuse unha confirmación incorrecta",
     "Check %s does not exist" : "Non existe a proba %s",
     "Check %s is invalid" : "A proba %s é incorrecta",
     "Check %s is not allowed with this entity" : "A proba %s non está permitida con esta entidade",
@@ -66,6 +68,7 @@ OC.L10N.register(
     "Desktop client" : "Cliente de escritorio",
     "Thunderbird & Outlook addons" : "Complementos do Thunderbird e do Outlook",
     "Custom user agent" : "Axente de usuario personalizado",
+    "At least one event must be selected" : "Ten que seleccionar polo menos un evento",
     "Add new flow" : "Engadir un novo fluxo",
     "When" : "Cando",
     "and" : "e",
@@ -82,11 +85,11 @@ OC.L10N.register(
     "Show more" : "Amosar máis",
     "Configured flows" : "Fluxos configurados",
     "Your flows" : "Os seus fluxos",
-    "File name" : "Nome de ficheiro",
-    "is" : "é",
-    "is not" : "non é",
     "matches" : "coincidencias",
     "does not match" : "non coinciden",
+    "is" : "é",
+    "is not" : "non é",
+    "File name" : "Nome de ficheiro",
     "File MIME type" : "Tipo MIME do ficheiro",
     "File size (upload)" : "Tamaño do ficheiro (envío)",
     "less" : "menor",
