@@ -62,14 +62,16 @@ OC.L10N.register(
     "Cancel" : "Odustani",
     "Delete" : "Izbriši",
     "The configuration is invalid" : "Konfiguracija nije valjana",
+    "Active" : "Aktivan",
     "Save" : "Spremi",
+    "Browse the app store" : "Pretraži trgovinu aplikacijama",
     "Show less" : "Prikaži manje",
     "Show more" : "Prikaži više",
-    "File name" : "Naziv datoteke",
-    "is" : "je",
-    "is not" : "nije",
     "matches" : "podudara se",
     "does not match" : "ne podudara se",
+    "is" : "je",
+    "is not" : "nije",
+    "File name" : "Naziv datoteke",
     "File MIME type" : "Vrsta MIME datoteke",
     "File size (upload)" : "Veličina datoteke (otprema)",
     "less" : "manje",
