@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "A megadott kezdő idő nem érvényes",
     "The given end time is invalid" : "A megadott vég idő nem érvényes",
     "The given group does not exist" : "A megadott csoport nem létezik",
+    "File" : "Fájl",
     "Operation #%s does not exist" : "#%s művelet nem létezik",
     "Operation %s does not exist" : "%s művelet nem létezik",
     "Operation %s is invalid" : "#%s művelet érvénytelen",
@@ -19,18 +20,26 @@ OC.L10N.register(
     "Check %s is invalid" : "%s érvénytelen, ellenőrizd",
     "Check #%s does not exist" : "#%s nem létezik, ellenőrizd",
     "Check %s is invalid or does not exist" : "%s érvénytelen vagy nem létezik, ellenőrizd",
+    "Images" : "Képek",
+    "No results" : "Nincs találat",
+    "%s (invisible)" : "%s (láthatatlan)",
+    "%s (restricted)" : "%s (korlátozott)",
     "Predefined URLs" : "Elődefiniált URL-ek",
     "Files WebDAV" : "WebDAV fálok",
     "Android client" : "Android kliens",
     "iOS client" : "iOS klens",
     "Desktop client" : "Asztali kliens",
     "Thunderbird & Outlook addons" : "Thunderbird és Outlook bővítmények",
+    "Cancel" : "Mégse",
+    "Delete" : "Törlés",
+    "Active" : "Aktív",
     "Save" : "Mentés",
-    "File name" : "Fájlnév",
-    "is" : "ez",
-    "is not" : "nem ez",
+    "Browse the app store" : "Alkalmazás bolt böngészése",
     "matches" : "egyezik",
     "does not match" : "nem egyezik",
+    "is" : "ez",
+    "is not" : "nem ez",
+    "File name" : "Fájlnév",
     "File MIME type" : "Fájl MIME típus",
     "File size (upload)" : "Fájl méret (feltöltés)",
     "less" : "kisebb",
