@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "Waktu mulai yang diberikan tidak sah",
     "The given end time is invalid" : "Waktu selesai yang diberikan tidak sah",
     "The given group does not exist" : "Grup yang diberikan tidak ada",
+    "File" : "Berkas",
     "Operation #%s does not exist" : "Operasi #%s tidak ada",
     "Operation %s does not exist" : "Operasi %s tidak ada",
     "Operation %s is invalid" : "Operasi %s tidak valid",
@@ -19,15 +20,21 @@ OC.L10N.register(
     "Check %s is invalid" : "Cek %s tidak valid",
     "Check #%s does not exist" : "Cek #%s tidak ada",
     "Check %s is invalid or does not exist" : "Cek %s tidak valid atau tidak ada",
+    "No results" : "Tidak ada hasil",
+    "%s (invisible)" : "%s (tersembunyi)",
+    "%s (restricted)" : "%s (terbatas)",
     "Predefined URLs" : "URL terdefinisi",
     "Files WebDAV" : "Berkas WebDAV",
     "Android client" : "Klien Android",
     "iOS client" : "Klien iOS",
     "Desktop client" : "Klien desktop",
-    "is" : "adalah",
-    "is not" : "bukan",
+    "Cancel" : "Membatalkan",
+    "Delete" : "Hapus",
+    "Save" : "Simpan",
     "matches" : "cocok dengan",
     "does not match" : "tidak cocok dengan",
+    "is" : "adalah",
+    "is not" : "bukan",
     "File MIME type" : "Berkas tipe MIME",
     "File size (upload)" : "Ukuran berkas (unggah)",
     "less" : "kurang dari",
@@ -53,8 +60,9 @@ OC.L10N.register(
     "Short rule description" : "Deskripsi aturan singkat",
     "Add rule" : "Tambahkan aturan",
     "Reset" : "Setel ulang",
-    "Save" : "Simpan",
     "Saving…" : "Menyimpan...",
+    "Group list is empty" : "Daftar grup kosong",
+    "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
     "Saved" : "Disimpan",
     "Saving failed:" : "Penyimpanan gagal:",
     "Add rule group" : "Tambahkan aturan grup ",
