@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "Uppgefinn upphafstími er ógildur",
     "The given end time is invalid" : "Uppgefinn lokatími er ógildur",
     "The given group does not exist" : "Uppgefinn hópur er ekki til",
+    "File" : "Skrá",
     "Operation #%s does not exist" : "Aðgerðin #%s er ekki til",
     "Operation %s does not exist" : "Aðgerðin %s er ekki til",
     "Operation %s is invalid" : "Aðgerðin %s er ógild",
@@ -19,18 +20,26 @@ OC.L10N.register(
     "Check %s is invalid" : "Athugunin %s er ógild",
     "Check #%s does not exist" : "Athugunin #%s er ekki til",
     "Check %s is invalid or does not exist" : "Athugunin %s er ógild eða er ekki til",
+    "Images" : "Myndir",
+    "No results" : "Engar niðurstöður",
+    "%s (invisible)" : "%s (ósýnilegt)",
+    "%s (restricted)" : "%s (takmarkaður aðgangur)",
     "Predefined URLs" : "Forákvarðaðar slóðir",
     "Files WebDAV" : "WebDAV skráa",
     "Android client" : "Android-biðlari",
     "iOS client" : "iOS-biðlari",
     "Desktop client" : "Skjáborðsforrit",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook viðbætur",
+    "Cancel" : "Hætta við",
+    "Delete" : "Eyða",
+    "Active" : "Virkt",
     "Save" : "Vista",
-    "File name" : "Skráarheiti",
-    "is" : "er",
-    "is not" : "er ekki",
+    "Browse the app store" : "Flakka um forritasafnið",
     "matches" : "samsvarar",
     "does not match" : "samsvarar ekki",
+    "is" : "er",
+    "is not" : "er ekki",
+    "File name" : "Skráarheiti",
     "File MIME type" : "MIME-skráartegund",
     "File size (upload)" : "Skráarstærð (innsending)",
     "less" : "minna en",
