@@ -35,6 +35,8 @@ OC.L10N.register(
     "Entity %s has no event %s" : "L'entità %s non ha eventi %s",
     "Operation %s does not exist" : "L'operazione %s non esiste",
     "Operation %s is invalid" : "L'operazione %s non è valida",
+    "At least one check needs to be provided" : "Deve essere fornito almeno un controllo",
+    "Invalid check provided" : "Controllo fornito non valido ",
     "Check %s does not exist" : "Il controllo %s non esiste",
     "Check %s is invalid" : "Il controllo %s non è valido",
     "Check %s is not allowed with this entity" : "Il controllo di %s non è consentito con questa entità",
@@ -66,6 +68,7 @@ OC.L10N.register(
     "Desktop client" : "Client desktop",
     "Thunderbird & Outlook addons" : "Componenti aggiuntivi di Outlook e Thunderbird",
     "Custom user agent" : "User agent personalizzato",
+    "At least one event must be selected" : "Deve essere selezionato almeno un evento",
     "Add new flow" : "Aggiungi nuovo flusso",
     "When" : "Quando",
     "and" : "e",
@@ -82,11 +85,11 @@ OC.L10N.register(
     "Show more" : "Mostra più",
     "Configured flows" : "Flussi configurati",
     "Your flows" : "I tuoi flussi",
-    "File name" : "Nome file",
-    "is" : "è",
-    "is not" : "non è",
     "matches" : "corrisponde",
     "does not match" : "non corrisponde",
+    "is" : "è",
+    "is not" : "non è",
+    "File name" : "Nome file",
     "File MIME type" : "Tipo MIME del file",
     "File size (upload)" : "Dimensione file (caricamento)",
     "less" : "minore",
