@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "指定された開始時刻は無効です",
     "The given end time is invalid" : "指定された終了時刻は無効です",
     "The given group does not exist" : "指定されたグループは存在しません",
+    "File" : "ファイル",
     "Operation #%s does not exist" : "#%s 操作は存在しません",
     "Operation %s does not exist" : "%s 操作は存在しません",
     "Operation %s is invalid" : "%s 操作は無効です",
@@ -19,17 +20,27 @@ OC.L10N.register(
     "Check %s is invalid" : "チェック %s は無効です",
     "Check #%s does not exist" : "チェック #%s は存在しません",
     "Check %s is invalid or does not exist" : "%sのチェックは無効か存在しません",
+    "Flow" : "Flow",
+    "Images" : "画像",
+    "No results" : "該当なし",
+    "%s (invisible)" : "%s (不可視)",
+    "%s (restricted)" : "%s (制限)",
     "Predefined URLs" : "定義済みのURL",
     "Files WebDAV" : "ファイルWebDAV",
     "Android client" : "アンドロイドクライアント",
     "iOS client" : "iOSクライアント",
     "Desktop client" : "デスクトップクライアント",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook アドオン",
-    "File name" : "ファイル名",
-    "is" : "は",
-    "is not" : "は異なる",
+    "Cancel" : "キャンセル",
+    "Delete" : "削除",
+    "Active" : "アクティブ化",
+    "Save" : "保存",
+    "Browse the app store" : "アプリストアをブラウザでみる",
     "matches" : "合致",
     "does not match" : "一致しない",
+    "is" : "は",
+    "is not" : "は異なる",
+    "File name" : "ファイル名",
     "File MIME type" : "ファイルMIMEタイプ",
     "File size (upload)" : "ファイルサイズ（アップロード）",
     "less" : "より小さい",
@@ -55,7 +66,6 @@ OC.L10N.register(
     "Short rule description" : "ルールの簡潔な説明",
     "Add rule" : "ルールを追加",
     "Reset" : "リセット",
-    "Save" : "保存",
     "Saving…" : "保存中...",
     "Group list is empty" : "グループリストが空です",
     "Unable to retrieve the group list" : "グループリストを取得できません",
