@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "მოცემული საწყისი დრო არაა სწორი",
     "The given end time is invalid" : "მოცემული დროის დასასრული არაა სწორი",
     "The given group does not exist" : "მოცემული ჯგუფი არ არსებობს",
+    "File" : "ფაილი",
     "Operation #%s does not exist" : "ოპერაცია #%s არ არსებობს",
     "Operation %s does not exist" : "ოპერაცია %s არ არსებობს",
     "Operation %s is invalid" : "ოპერაცია %s არაა სწორი",
@@ -19,15 +20,22 @@ OC.L10N.register(
     "Check %s is invalid" : "შეამოწმეთ %s არასწორია",
     "Check #%s does not exist" : "შეამოწმეთ #%s არ არსებობს",
     "Check %s is invalid or does not exist" : "შეამოწმეთ %s არასწორია ან არ არსებობს",
+    "Images" : "სურათები",
+    "No results" : "შედეგები არაა",
+    "%s (invisible)" : "%s (უჩინარი)",
+    "%s (restricted)" : "%s (აკრძალული)",
     "Predefined URLs" : "წინასწარ განსაზღვრული URL-ები",
     "Files WebDAV" : "ფაილები WebDAV",
     "Android client" : "Android კლიენტი",
     "iOS client" : "iOS კლიენტი",
     "Desktop client" : "დესკტოპ კლიენტი",
-    "is" : "არის",
-    "is not" : "არ არის",
+    "Cancel" : "უარყოფა",
+    "Delete" : "წაშლა",
+    "Save" : "შენახვა",
     "matches" : "ემთხვევა",
     "does not match" : "არ ემთხვევა",
+    "is" : "არის",
+    "is not" : "არ არის",
     "File MIME type" : "ფაილის MIME სახეობა",
     "File size (upload)" : "ფაილის ზომა (ატვირთვა)",
     "less" : "უფრო ნაკლები",
@@ -53,7 +61,6 @@ OC.L10N.register(
     "Short rule description" : "წესის მოკლე აღწერა",
     "Add rule" : "წესის დამატება",
     "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
-    "Save" : "შენახვა",
     "Saving…" : "მიმდინარეობს დამახსოვრება...",
     "Saved" : "შენახულია",
     "Saving failed:" : "შენახვა ვერ მოხერხდა:",
