@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "지정한 시작 시간이 올바르지 않음",
     "The given end time is invalid" : "지정한 끝 시간이 올바르지 않음",
     "The given group does not exist" : "지정한 그룹이 존재히지 않음",
+    "File" : "파일",
     "Operation #%s does not exist" : "작업 #%s이(가) 존재하지 않음",
     "Operation %s does not exist" : "작업 %s이(가) 존재하지 않음",
     "Operation %s is invalid" : "작업 %s이(가) 잘못됨",
@@ -19,18 +20,24 @@ OC.L10N.register(
     "Check %s is invalid" : "검사 %s이(가) 잘못됨",
     "Check #%s does not exist" : "검사 #%s이(가) 존재하지 않음",
     "Check %s is invalid or does not exist" : "검사 %s이(가) 올바르지 않거나 존재하지 않음",
+    "Images" : "파일",
+    "No results" : "결과 없음",
+    "%s (invisible)" : "%s(숨겨짐)",
+    "%s (restricted)" : "%s(제한됨)",
     "Predefined URLs" : "사전 정의된 URL",
     "Files WebDAV" : "파일 WebDAV",
     "Android client" : "Android 클라이언트",
     "iOS client" : "iOS 클라이언트",
     "Desktop client" : "데스크톱 클라이언트",
     "Thunderbird & Outlook addons" : "Thunderbird와 Outlook 확장 기능",
+    "Cancel" : "취소",
+    "Delete" : "삭제",
     "Save" : "저장",
-    "File name" : "파일 이름",
-    "is" : "맞음",
-    "is not" : "아님",
     "matches" : "일치함",
     "does not match" : "일치하지 않음",
+    "is" : "맞음",
+    "is not" : "아님",
+    "File name" : "파일 이름",
     "File MIME type" : "파일 MIME 형식",
     "File size (upload)" : "파일 크기(업로드)",
     "less" : "작음",
