@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "Neteisingai nurodyta laiko pradžia",
     "The given end time is invalid" : "Neteisingai nurodyta laiko pabaiga",
     "The given group does not exist" : "Pateikta grupė neegzistuoja",
+    "File" : "Failas",
     "File renamed" : "Failas pervadintas",
     "File deleted" : "Failas ištrintas",
     "File copied" : "Failas nukopijuotas",
@@ -26,6 +27,7 @@ OC.L10N.register(
     "Images" : "Paveikslai",
     "Office documents" : "Raštinės dokumentai",
     "PDF documents" : "PDF dokumentai",
+    "No results" : "Rezultatų nėra",
     "Predefined URLs" : "Iš anksto apibrėžti URL adresai",
     "Files WebDAV" : "WebDAV failai",
     "Android client" : "Android klientas",
@@ -37,11 +39,11 @@ OC.L10N.register(
     "Save" : "Įrašyti",
     "Show less" : "Rodyti mažiau",
     "Show more" : "Rodyti daugiau",
-    "File name" : "Failo pavadinimas",
-    "is" : "yra",
-    "is not" : "nėra",
     "matches" : "atitinka",
     "does not match" : "neatitinka",
+    "is" : "yra",
+    "is not" : "nėra",
+    "File name" : "Failo pavadinimas",
     "File MIME type" : "Failo MIME tipas",
     "File size (upload)" : "Failo dydis (įkėlimas)",
     "less" : "mažiau",
