@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "Dotais sākuma laiks ir nederīgs",
     "The given end time is invalid" : "Norādītais beigu laiks nav derīgs.",
     "The given group does not exist" : "Norādītā grupa nepastāv.",
+    "File" : "Datne",
     "Operation #%s does not exist" : "Operation #%s does not exist",
     "Operation %s does not exist" : "Darbība %s neeksistē",
     "Operation %s is invalid" : "Darbība %s ir nederīga",
@@ -19,15 +20,23 @@ OC.L10N.register(
     "Check %s is invalid" : "Pārbaude %s ir nederīga",
     "Check #%s does not exist" : "Pārbaude #%s nepastāv",
     "Check %s is invalid or does not exist" : "Pārbaude %s ir nederīga vai nepastāv",
+    "Images" : "Attēli",
+    "No results" : "Nav rezultātu",
+    "%s (invisible)" : "%s (neredzams)",
+    "%s (restricted)" : "%s (ierobežots)",
     "Predefined URLs" : "Standarta URLs",
     "Files WebDAV" : "WebDAV datnes",
     "Android client" : "Android klients",
     "iOS client" : "iOS klients",
     "Desktop client" : "Darbvirsmas klients",
-    "is" : "ir",
-    "is not" : "nav",
+    "Cancel" : "Atcelt",
+    "Delete" : "Dzēst",
+    "Save" : "Saglabāt",
     "matches" : "atbilst",
     "does not match" : "neatbilst",
+    "is" : "ir",
+    "is not" : "nav",
+    "File name" : "Faila nosaukums",
     "File MIME type" : "Datnes MIME tips",
     "File size (upload)" : "Datnes lielums (augšupielādēt)",
     "less" : "mazāk",
@@ -53,7 +62,6 @@ OC.L10N.register(
     "Short rule description" : "Īss kārtulas apraksts",
     "Add rule" : "Pievienot kārtulu",
     "Reset" : "Atiestatīt",
-    "Save" : "Saglabāt",
     "Saving…" : "Saglabā...",
     "Group list is empty" : "Grupu saraksts ir tukšš",
     "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
@@ -67,6 +75,7 @@ OC.L10N.register(
     "Select timezone…" : "Izvēlieties laika joslu...",
     "Sync clients" : "Sync klients",
     "Workflow" : "Darbplūsma",
+    "Files workflow engine" : "Faila darblūsmas programma",
     "Open documentation" : "Atvērt dokumentāciju",
     "Loading…" : "Ielādē …"
 },
