@@ -20,6 +20,14 @@ OC.L10N.register(
     "File accessed" : "Bestand benaderd",
     "File copied" : "Bestand gekopieerd",
     "Tag assigned" : "Tag toegewezen",
+    "Someone" : "Iemand",
+    "%s created %s" : "%s creëerde %s",
+    "%s modified %s" : "%s wijzigde %s",
+    "%s deleted %s" : "%s verwijderde %s",
+    "%s accessed %s" : "%s opende %s",
+    "%s renamed %s" : "%s hernoemde %s",
+    "%s copied %s" : "%s kopieerde %s",
+    "%s assigned %s to %s" : "%s wees %s toe aan %s",
     "Operation #%s does not exist" : "Bewerking #%s bestaat niet",
     "Entity %s does not exist" : "Entiteit %s bestaat niet",
     "Entity %s is invalid" : "Entiteit %s is ongeldig",
@@ -32,10 +40,12 @@ OC.L10N.register(
     "Check %s is not allowed with this entity" : "Check %s is niet toegestaan met deze entiteit",
     "Check #%s does not exist" : "Controleer: #%s bestaat niet",
     "Check %s is invalid or does not exist" : "Controleer: %s is ongeldig of bestaat niet",
+    "Flow" : "Flow",
     "Nextcloud workflow engine" : "Nextcloud workflow engine",
     "Select a filter" : "Selecteer een filter",
     "Select a comparator" : "Selecteer een comparator",
     "Select a file type" : "Selecteer een bestandstype",
+    "e.g. httpd/unix-directory" : "bijv. httpd/unix-directory",
     "Images" : "Afbeeldingen",
     "Office documents" : "Office documenten",
     "PDF documents" : "PDF documenten",
@@ -44,6 +54,7 @@ OC.L10N.register(
     "No results" : "Geen resultaten",
     "%s (invisible)" : "%s (onzichtbaar)",
     "%s (restricted)" : "%s (beperkt)",
+    "Please enter a valid time span" : "Geef een geldige tijdsinterval op",
     "Select a request URL" : "Selecteer een aanvraag URL",
     "Predefined URLs" : "Voorgedefinieerde URL's",
     "Files WebDAV" : "Bestanden WebDAV",
@@ -55,19 +66,26 @@ OC.L10N.register(
     "Desktop client" : "Desktop client",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
     "Custom user agent" : "Aangepaste 'user agent'",
+    "Add new flow" : "Toevoegen nieuwe flow",
     "When" : "Wanneer",
     "and" : "en",
     "Cancel" : "Annuleren",
     "Delete" : "Verwijderen",
     "The configuration is invalid" : "De configuratie is ongeldig",
+    "Active" : "Actief",
     "Save" : "Opslaan",
+    "Available flows" : "Beschikbare flows",
+    "More flows" : "Meer flows",
+    "Browse the app store" : "Blader door de app store",
     "Show less" : "Toon minder",
     "Show more" : "Toon meer",
-    "File name" : "Bestandsnaam",
-    "is" : "is",
-    "is not" : "is niet",
+    "Configured flows" : "Geconfigureerde flows",
+    "Your flows" : "Jouw flows",
     "matches" : "komt overeen",
     "does not match" : "komt niet overeen",
+    "is" : "is",
+    "is not" : "is niet",
+    "File name" : "Bestandsnaam",
     "File MIME type" : "Mimetype bestand",
     "File size (upload)" : "Bestandsgrootte (upload)",
     "less" : "minder",
