@@ -35,6 +35,8 @@ OC.L10N.register(
     "Entity %s has no event %s" : "Obiekt %s nie ma zdarzenia %s",
     "Operation %s does not exist" : "Operacja do wykonania %s nie istnieje",
     "Operation %s is invalid" : "Operacja %s jest nieprawidłowa",
+    "At least one check needs to be provided" : "Co najmniej jedno sprawdzenie musi być dostarczone",
+    "Invalid check provided" : "Sprawdzenie niepoprawnie dostarczone",
     "Check %s does not exist" : "Sprawdź, czy %s nie istnieje",
     "Check %s is invalid" : "Sprawdź, czy %s jest nieprawidłowy",
     "Check %s is not allowed with this entity" : "Sprawdzenie %s jest niedozwolone w tym obiekcie",
@@ -66,6 +68,7 @@ OC.L10N.register(
     "Desktop client" : "Klient na komputer",
     "Thunderbird & Outlook addons" : "Dodatki Thunderbird i Outlook",
     "Custom user agent" : "Niestandardowy klient użytkownika",
+    "At least one event must be selected" : "Należy wybrać co najmniej jedno wydarzenie",
     "Add new flow" : "Dodaj nowy przepływ",
     "When" : "Kiedy",
     "and" : "i",
@@ -82,11 +85,11 @@ OC.L10N.register(
     "Show more" : "Pokaż więcej",
     "Configured flows" : "Skonfigurowane przepływy",
     "Your flows" : "Twoje przepływy",
-    "File name" : "Nazwa pliku",
-    "is" : "jest",
-    "is not" : "nie jest",
     "matches" : "pasuje",
     "does not match" : "nie pasuje",
+    "is" : "jest",
+    "is not" : "nie jest",
+    "File name" : "Nazwa pliku",
     "File MIME type" : "Typy plików MIME",
     "File size (upload)" : "Rozmiar pliku (wczytywanego)",
     "less" : "mniejszy",
