@@ -20,6 +20,14 @@ OC.L10N.register(
     "File accessed" : "Arquivo acessado",
     "File copied" : "Arquivo copiado",
     "Tag assigned" : "Rótulo atribuído",
+    "Someone" : "Alguém",
+    "%s created %s" : "%s criou %s",
+    "%s modified %s" : "%s modificou %s",
+    "%s deleted %s" : "%s excluiu %s",
+    "%s accessed %s" : "%s acessou %s",
+    "%s renamed %s" : "%s renomeado %s",
+    "%s copied %s" : "%s copiou %s",
+    "%s assigned %s to %s" : "%s atribuiu %s para %s",
     "Operation #%s does not exist" : "Operação #%s não existe",
     "Entity %s does not exist" : "Entidade %s não existe",
     "Entity %s is invalid" : "Entidade %s é inválida",
@@ -27,12 +35,14 @@ OC.L10N.register(
     "Entity %s has no event %s" : "Entidade %s não tem evento %s",
     "Operation %s does not exist" : "Operação %s não existe",
     "Operation %s is invalid" : "Operação %s é inválida",
+    "At least one check needs to be provided" : "É necessário fornecer ao menos uma verificação",
+    "Invalid check provided" : "Verificação fornecida inválida",
     "Check %s does not exist" : "Verifique se %s não existe",
     "Check %s is invalid" : "Verifique se %s é inválido",
     "Check %s is not allowed with this entity" : "Verificação de %s não é permitida nesta entidade",
     "Check #%s does not exist" : "Verifique se %s não existe",
     "Check %s is invalid or does not exist" : "Verifique se %s é valido ou existe",
-    "Workflows" : "Fluxo de Trabalho",
+    "Flow" : "Fluxo",
     "Nextcloud workflow engine" : "Mecanismo de fluxo de trabalho Nextcloud",
     "Select a filter" : "Selecionar um filtro",
     "Select a comparator" : "Selecionar um comparador",
@@ -58,18 +68,28 @@ OC.L10N.register(
     "Desktop client" : "Cliente de Desktop",
     "Thunderbird & Outlook addons" : "Extensões para Thunderbird & Outlook",
     "Custom user agent" : "Agente do usuário personalizado",
+    "At least one event must be selected" : "É necessário selecionar ao menos um evento",
+    "Add new flow" : "Adicionar novo fluxo",
     "When" : "Quando",
     "and" : "e",
     "Cancel" : "Cancelar",
     "Delete" : "Excluir",
     "The configuration is invalid" : "A configuração é inválida",
+    "Active" : "Ativar",
+    "Save" : "Salvar",
+    "Available flows" : "Fluxos disponíveis",
+    "For details on how to write your own flow, check out the development documentation." : "Para detalhes sobre como escrever seu próprio fluxo, consulte a documentação de desenvolvimento.",
+    "More flows" : "Mais fluxos",
+    "Browse the app store" : "Navegar pela loja de aplicativos",
     "Show less" : "Mostrar menos",
     "Show more" : "Mostrar mais",
-    "File name" : "Nome do arquivo",
-    "is" : "é",
-    "is not" : "não é",
+    "Configured flows" : "Fluxos configurados",
+    "Your flows" : "Seus fluxos",
     "matches" : "coincide",
     "does not match" : "não coincide",
+    "is" : "é",
+    "is not" : "não é",
+    "File name" : "Nome do arquivo",
     "File MIME type" : "Tipo de arquivo MIME",
     "File size (upload)" : "Tamanho do arquivo (envio)",
     "less" : "menos",
@@ -95,7 +115,6 @@ OC.L10N.register(
     "Short rule description" : "Descrição curta da regra",
     "Add rule" : "Adicionar regra",
     "Reset" : "Redefinir",
-    "Save" : "Salvar",
     "Saving…" : "Salvando...",
     "Group list is empty" : "Lista de grupos vazia",
     "Unable to retrieve the group list" : "Impossível recuperar a lista do grupo",
