@@ -56,15 +56,19 @@ OC.L10N.register(
     "Custom user agent" : "Пользовательский user agent",
     "When" : "Когда",
     "and" : "и",
+    "Cancel" : "Отменить",
+    "Delete" : "Удалить",
     "The configuration is invalid" : "Конфигурация неверна",
+    "Active" : "Активный",
     "Save" : "Сохранить",
+    "Browse the app store" : "Перейти в магазин приложений",
     "Show less" : "Показывать меньше",
     "Show more" : "Показывать больше",
-    "File name" : "Имя файла",
-    "is" : "равняется",
-    "is not" : "не равняется",
     "matches" : "соответствует",
     "does not match" : "не соответствует",
+    "is" : "равняется",
+    "is not" : "не равняется",
+    "File name" : "Имя файла",
     "File MIME type" : "MIME-тип файла",
     "File size (upload)" : "Размер передаваемого на сервер файла",
     "less" : "меньше",
