@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "Koha e fillimit është e pavlefshme",
     "The given end time is invalid" : "Koha e mbarimit është e pavlefshme",
     "The given group does not exist" : "Grupi i dhënë nuk ekziston",
+    "File" : "Skedar ",
     "Operation #%s does not exist" : "Operacioni #%s nuk ekziston",
     "Operation %s does not exist" : "Operacioni %s nuk ekziston",
     "Operation %s is invalid" : "Operacioni %s është i pavlefshëm",
@@ -19,18 +20,24 @@ OC.L10N.register(
     "Check %s is invalid" : "Kontrolli %s është i pavlefshëm",
     "Check #%s does not exist" : "Kontrolli #%s nuk ekziston",
     "Check %s is invalid or does not exist" : "Kontrolli %s është i pavlefshëm ose nuk ekziston",
+    "Images" : "Imazhe ",
+    "No results" : "Asnjë rezultat",
+    "%s (invisible)" : "%s (e padukshme)",
+    "%s (restricted)" : "%s (e kufizuar)",
     "Predefined URLs" : "URL të paracaktuara",
     "Files WebDAV" : "Skedarët WebDAV ",
     "Android client" : "Klient Android",
     "iOS client" : "Klient IOS",
     "Desktop client" : "Klient Desktop",
     "Thunderbird & Outlook addons" : "Shtojcat e Thunderbird & Outlook",
+    "Cancel" : "Anullo",
+    "Delete" : "Delete",
     "Save" : "Ruaj",
-    "File name" : "Emri i skedarit",
-    "is" : "është",
-    "is not" : "nuk është",
     "matches" : "përputhje",
     "does not match" : "nuk përputhet",
+    "is" : "është",
+    "is not" : "nuk është",
+    "File name" : "Emri i skedarit",
     "File MIME type" : "Skedari i tipit MIME",
     "File size (upload)" : "Madhësia e skedarit (ngarko)",
     "less" : "më pak",
@@ -67,6 +74,7 @@ OC.L10N.register(
     "Select timezone…" : "Zgjidh brezin kohorë",
     "Sync clients" : "Klient të sinkronizuar",
     "Workflow" : "Rrjedha e punëve",
+    "Files workflow engine" : "Motori i rrjedhës së punës së skedarëve",
     "Open documentation" : "Dokumentacion i hapur",
     "Loading…" : "Po ngarkohet..."
 },
