@@ -20,6 +20,14 @@ OC.L10N.register(
     "File accessed" : "Фајлу приступљено",
     "File copied" : "Фајл копиран",
     "Tag assigned" : "Додељена ознака",
+    "Someone" : "Неко",
+    "%s created %s" : "%s је направио %s",
+    "%s modified %s" : "%s је изменио %s",
+    "%s deleted %s" : "%s је обрисао %s",
+    "%s accessed %s" : "%s је приступио %s",
+    "%s renamed %s" : "%s је преименовао %s",
+    "%s copied %s" : "%s је копирао %s",
+    "%s assigned %s to %s" : "%s је доделио %s на %s",
     "Operation #%s does not exist" : "Операција #%s не постоји",
     "Entity %s does not exist" : "Ентитет %s не постоји",
     "Entity %s is invalid" : "Ентитет %s није исправан",
@@ -32,7 +40,8 @@ OC.L10N.register(
     "Check %s is not allowed with this entity" : "Провера %s није дозвољена са овим ентитетом",
     "Check #%s does not exist" : "Проверите да ли #%s постоји",
     "Check %s is invalid or does not exist" : "Проверите да ли је %s неисправно или не постоји",
-    "Nextcloud workflow engine" : "Некстклауд мотор процеса рада",
+    "Flow" : "Ток",
+    "Nextcloud workflow engine" : "Некстклауд мотор тока рада",
     "Select a filter" : "Одаберите филтер",
     "Select a comparator" : "Одаберите компаратор",
     "Select a file type" : "Одаберите тип фајла",
@@ -57,19 +66,27 @@ OC.L10N.register(
     "Desktop client" : "Десктоп клијент",
     "Thunderbird & Outlook addons" : "Додаци за Thunderbird & Outlook",
     "Custom user agent" : "Произвољни агент захтева",
+    "Add new flow" : "Додај нови ток",
     "When" : "Када",
     "and" : "и",
     "Cancel" : "Откажи",
     "Delete" : "Обриши",
     "The configuration is invalid" : "Конфигурација је неисправна",
+    "Active" : "Активан",
     "Save" : "Сачувај",
+    "Available flows" : "Доступни токови",
+    "For details on how to write your own flow, check out the development documentation." : "За детаље како писати Ваш ток, погледај програмерску документацију.",
+    "More flows" : "Још токова",
+    "Browse the app store" : "Прегледајте продавницу апликација",
     "Show less" : "Прикажи мање",
     "Show more" : "Прикажи више",
-    "File name" : "Име фајла",
-    "is" : "је",
-    "is not" : "није",
+    "Configured flows" : "Подешени токови",
+    "Your flows" : "Ваши токови",
     "matches" : "се поклапа са",
     "does not match" : "се не поклапа са",
+    "is" : "је",
+    "is not" : "није",
+    "File name" : "Име фајла",
     "File MIME type" : "MIME тип фајла",
     "File size (upload)" : "Величина фајла (отпремање)",
     "less" : "је мања од",
@@ -107,7 +124,7 @@ OC.L10N.register(
     "End" : "Крај",
     "Select timezone…" : "Одаберите временску зону…",
     "Sync clients" : "Синхронизовани клијенти",
-    "Workflow" : "Процес рада",
+    "Workflow" : "Ток рада",
     "Files workflow engine" : "Датотеке за мотор процеса рада",
     "Open documentation" : "Отвори документацију",
     "Loading…" : "Учитавање…",
