@@ -20,25 +20,40 @@ OC.L10N.register(
     "File accessed" : "Fil öppnad",
     "File copied" : "Fil kopierad",
     "Tag assigned" : "Tagg tilldelad",
+    "Someone" : "Någon",
+    "%s created %s" : "%s skapad %s",
+    "%s modified %s" : "%s ändrad %s",
+    "%s deleted %s" : "%s raderad %s",
+    "%s renamed %s" : "%s omdöpt %s",
+    "%s copied %s" : "%s kopierad %s",
+    "%s assigned %s to %s" : "%s tilldelad %s till %s",
     "Operation #%s does not exist" : "Operationen #%s existerar inte",
+    "Entity %s does not exist" : "Objekt 1%s finns inte",
+    "Entity %s is invalid" : "Entitet %s är ogiltig",
     "No events are chosen." : "Inga händelser valda",
+    "Entity %s has no event %s" : "Objekt 1%s har ingen händelse 1%s",
     "Operation %s does not exist" : "Operationen %s existerar inte",
     "Operation %s is invalid" : "Operationen %s är ogiltig",
     "Check %s does not exist" : "Kontroll av %s existerar inte",
     "Check %s is invalid" : "Kontroll av %s är ogiltig",
+    "Check %s is not allowed with this entity" : "Kontroll %s tillåts inte med denna enhet",
     "Check #%s does not exist" : "Kontroll av #%s existerar inte",
     "Check %s is invalid or does not exist" : "Kontroll av %s är ogiltig eller existerar inte",
-    "Workflows" : "Arbetsflöden",
+    "Flow" : "Flöde",
+    "Nextcloud workflow engine" : "Nextcloud arbetsflödesmotor",
     "Select a filter" : "Välj ett filter",
     "Select a comparator" : "Välj en jämförelse",
     "Select a file type" : "Välj en filtyp",
+    "e.g. httpd/unix-directory" : "t.ex. httpd/unix-directory",
     "Images" : "Bilder",
     "Office documents" : "Officedokument",
     "PDF documents" : "PDF-dokument",
     "Custom mimetype" : "Anpassad mimetyp",
+    "Select a tag" : "Välj en tagg",
     "No results" : "Inga resultat",
     "%s (invisible)" : "%s (osynlig)",
     "%s (restricted)" : "%s (begränsad)",
+    "Please enter a valid time span" : "Ange ett giltigt tidsintervall",
     "Select a request URL" : "Välj en webbadress för begäran",
     "Predefined URLs" : "Förinställda webbadresser",
     "Files WebDAV" : "Filer WebDAV",
@@ -50,16 +65,27 @@ OC.L10N.register(
     "Desktop client" : "Skrivbordsklient",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook - tillägg",
     "Custom user agent" : "Anpassad användaragent",
+    "Add new flow" : "Lägg till nytt flöde",
     "When" : "När",
     "and" : "och",
+    "Cancel" : "Avbryt",
+    "Delete" : "Radera",
     "The configuration is invalid" : "Konfigurationen är felaktig",
+    "Active" : "Aktiv",
+    "Save" : "Spara",
+    "Available flows" : "Tillgängliga flöden",
+    "For details on how to write your own flow, check out the development documentation." : "För information om hur du skriver ditt eget flöde, se utvecklingsdokumentationen.",
+    "More flows" : "Fler flöden",
+    "Browse the app store" : "Bläddra i appbutiken",
     "Show less" : "Visa mindre",
     "Show more" : "Visa mer",
-    "File name" : "Filnamn",
-    "is" : "är",
-    "is not" : "är inte",
+    "Configured flows" : "Konfigurerade flöden",
+    "Your flows" : "Dina flöden",
     "matches" : "träffar",
     "does not match" : "matchar inte",
+    "is" : "är",
+    "is not" : "är inte",
+    "File name" : "Filnamn",
     "File MIME type" : "Filens MIME-typ",
     "File size (upload)" : "Filstorlek (uppladdning)",
     "less" : "mindre",
@@ -85,12 +111,11 @@ OC.L10N.register(
     "Short rule description" : "Kort regelbeskrivning",
     "Add rule" : "Lägg till regel",
     "Reset" : "Återställ",
-    "Save" : "Spara",
     "Saving…" : "Sparar...",
     "Group list is empty" : "Grupplistan är tom",
     "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
     "Saved" : "Sparad",
-    "Saving failed:" : "Gick ej att spara: ",
+    "Saving failed:" : "Det gick inte att spara: ",
     "Add rule group" : "Lägg till regelgrupp",
     "Example: {placeholder}" : "Exempel: {placeholder}",
     "Select tag…" : "Välj tagg...",
@@ -99,6 +124,7 @@ OC.L10N.register(
     "Select timezone…" : "Välj tidszon...",
     "Sync clients" : "Synkroniseringsklienter",
     "Workflow" : "Arbetsflöde",
+    "Files workflow engine" : "Arbetsflödesmotor för Filer",
     "Open documentation" : "Öppna dokumentation",
     "Loading…" : "Laddar...",
     "Tag management" : "Tagghantering"
