@@ -35,6 +35,8 @@ OC.L10N.register(
     "Entity %s has no event %s" : "%s varlığının herhangi bir etkinliği yok %s",
     "Operation %s does not exist" : "%s işlemi bulunamadı",
     "Operation %s is invalid" : "%s işlemi geçersiz",
+    "At least one check needs to be provided" : "En az bir denetim belirtilmelidir",
+    "Invalid check provided" : "Geçersiz denetim belirtildi",
     "Check %s does not exist" : "%s denetimi bulunamadı",
     "Check %s is invalid" : "%s denetimi geçersiz",
     "Check %s is not allowed with this entity" : "Bu varlık için %s denetimi yapılamaz",
@@ -66,6 +68,7 @@ OC.L10N.register(
     "Desktop client" : "Masaüstü istemcisi",
     "Thunderbird & Outlook addons" : "Thunderbird ve Outlook eklentileri",
     "Custom user agent" : "Özel kullanıcı uygulaması",
+    "At least one event must be selected" : "En az bir etkinlik seçilmelidir",
     "Add new flow" : "Akış ekle",
     "When" : "Şu zamanda",
     "and" : "ve",
@@ -82,11 +85,11 @@ OC.L10N.register(
     "Show more" : "Daha çok ayrıntı",
     "Configured flows" : "Yapılandırılmış akışlar",
     "Your flows" : "Akışlarınız",
-    "File name" : "Dosya adı",
-    "is" : "şu olan",
-    "is not" : "şu olmayan",
     "matches" : "şuna uyan",
     "does not match" : "şuna uymayan",
+    "is" : "şu olan",
+    "is not" : "şu olmayan",
+    "File name" : "Dosya adı",
     "File MIME type" : "Dosya MIME türü",
     "File size (upload)" : "Dosya boyutu (yükleme)",
     "less" : "şundan küçük",
