@@ -20,6 +20,14 @@ OC.L10N.register(
     "File accessed" : "已访问的文件",
     "File copied" : "已复制的文件",
     "Tag assigned" : "已指派的标签",
+    "Someone" : "某人",
+    "%s created %s" : "%s 创建了 %s",
+    "%s modified %s" : "%s 修改了 %s",
+    "%s deleted %s" : "%s 删除了 %s",
+    "%s accessed %s" : "%s 访问了 %s",
+    "%s renamed %s" : "%s 重命名了 %s",
+    "%s copied %s" : "%s 复制了 %s",
+    "%s assigned %s to %s" : "%s 分配了 %s 给 %s",
     "Operation #%s does not exist" : "操作 %s 不存在",
     "Entity %s does not exist" : "实体%s不存在",
     "Entity %s is invalid" : "实体%s是无效的",
@@ -27,23 +35,28 @@ OC.L10N.register(
     "Entity %s has no event %s" : "实体%s没有事件%s",
     "Operation %s does not exist" : "操作 %s 不存在",
     "Operation %s is invalid" : "操作 %s 无效",
+    "At least one check needs to be provided" : "至少需要提供一次检查",
+    "Invalid check provided" : "提供的检查无效",
     "Check %s does not exist" : "检查 %s 不存在",
     "Check %s is invalid" : "检查%s是不可用",
     "Check %s is not allowed with this entity" : "对于此实体，检查%s是不被允许的",
     "Check #%s does not exist" : "检查 #%s 不存在",
     "Check %s is invalid or does not exist" : "检查%s是不可用或者不存在",
-    "Workflows" : "工作流",
-    "Nextcloud workflow engine" : "Nextcloud工作流引擎",
+    "Flow" : "流程",
+    "Nextcloud workflow engine" : "Nextcloud 工作流引擎",
     "Select a filter" : "选择一个过滤器",
     "Select a comparator" : "选择一个比较器",
     "Select a file type" : "选择一个文件类型",
+    "e.g. httpd/unix-directory" : "例如： httpd/unix-directory",
     "Images" : "图片",
     "Office documents" : "Office 文档",
     "PDF documents" : "PDF文档",
     "Custom mimetype" : "自定义MIME类型",
-    "No results" : "无结果",
+    "Select a tag" : "选择标签",
+    "No results" : "没有结果",
     "%s (invisible)" : "%s（不可见）",
     "%s (restricted)" : "%s（受限）",
+    "Please enter a valid time span" : "请输入有效的时间范围",
     "Select a request URL" : "选择一个请求URL",
     "Predefined URLs" : "预定义 URL",
     "Files WebDAV" : "文件 WebDAV",
@@ -55,16 +68,28 @@ OC.L10N.register(
     "Desktop client" : "桌面客户端",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook 插件",
     "Custom user agent" : "自定义用户代理",
+    "At least one event must be selected" : "必须至少选择一个事件",
+    "Add new flow" : "添加新的流程",
     "When" : "时间",
     "and" : "与",
+    "Cancel" : "取消",
+    "Delete" : "删除",
     "The configuration is invalid" : "此配置是无效的",
+    "Active" : "活动",
+    "Save" : "保存",
+    "Available flows" : "可用的流程",
+    "For details on how to write your own flow, check out the development documentation." : "有关如何编写自己的流程的详细信息，请查看开发文档。",
+    "More flows" : "更多流程",
+    "Browse the app store" : "浏览应用商店",
     "Show less" : "显示更少",
     "Show more" : "显示更多",
-    "File name" : "文件名",
-    "is" : "是",
-    "is not" : "不是",
+    "Configured flows" : "已配置的流程",
+    "Your flows" : "你的流程",
     "matches" : "匹配",
     "does not match" : "不匹配",
+    "is" : "是",
+    "is not" : "不是",
+    "File name" : "文件名",
     "File MIME type" : "文件 MIME 类型",
     "File size (upload)" : "文件大小 (上传)",
     "less" : "小于",
@@ -90,7 +115,6 @@ OC.L10N.register(
     "Short rule description" : "短规则说明",
     "Add rule" : "添加规则",
     "Reset" : "重置",
-    "Save" : "保存",
     "Saving…" : "保存中...",
     "Group list is empty" : "用户群组列表空",
     "Unable to retrieve the group list" : "无法获取用户群组列表",
