@@ -12,6 +12,7 @@ OC.L10N.register(
     "The given start time is invalid" : "指定的開始時間無效",
     "The given end time is invalid" : "指定的結束時間無效",
     "The given group does not exist" : "指定的群組不存在",
+    "File" : "檔案",
     "Operation #%s does not exist" : "操作 #%s 不存在",
     "Operation %s does not exist" : "操作 %s 不存在",
     "Operation %s is invalid" : "操作 #%s 無效",
@@ -19,16 +20,24 @@ OC.L10N.register(
     "Check %s is invalid" : "檢查 %s 無效",
     "Check #%s does not exist" : "檢查 #%s 不存在",
     "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
+    "Images" : "圖片",
+    "No results" : "沒有符合搜尋的項目",
+    "%s (invisible)" : "%s （隱藏）",
+    "%s (restricted)" : "%s （受限）",
     "Predefined URLs" : "預定義網址",
     "Files WebDAV" : "檔案 WebDAV",
     "Android client" : "Android 客戶端",
     "iOS client" : "iOS 客戶端",
     "Desktop client" : "桌面客戶端",
+    "Cancel" : "取消",
+    "Delete" : "刪除",
+    "Active" : "啟動",
     "Save" : "儲存",
-    "is" : "是",
-    "is not" : "不是",
+    "Browse the app store" : "瀏覽應用程式商店",
     "matches" : "匹配",
     "does not match" : "不能匹配",
+    "is" : "是",
+    "is not" : "不是",
     "File MIME type" : "檔案MIME類型",
     "File size (upload)" : "檔案大小(上傳)",
     "less" : "更少",
