@@ -76,6 +76,7 @@ OC.L10N.register(
     "Password" : "Wagwoord",
     "Log in" : "Meld aan",
     "Logging in …" : "Meld tans aan …",
+    "Wrong username or password." : "Verkeerde gebruikersnaam of wagwoord.",
     "Reset password" : "Herstel wagwoord",
     "Couldn't send reset email. Please contact your administrator." : "Kon nie die herstel-e-pos stuur nie. Kontak asseblief jou administrateur.",
     "Password can not be changed. Please contact your administrator." : "Wagwoord kan nie verander word nie. Kontak asseblief u administrateur.",
@@ -94,6 +95,11 @@ OC.L10N.register(
     "No" : "Nee",
     "Yes" : "Ja",
     "No files in here" : "Geen lêers hier nie",
+    "New folder" : "Nuwe vouer",
+    "Name" : "Naam",
+    "Size" : "Grootte",
+    "Modified" : "Gewysig",
+    "{newName} already exists" : "{newName} bestaan reeds",
     "Choose" : "Kies",
     "Copy" : "Kopieer",
     "Move" : "Skuif",
@@ -168,7 +174,6 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
     "Two-factor authentication" : "Twee-faktor-verifikasie",
     "Use backup code" : "Gebruik rugsteunkode",
-    "Cancel log in" : "Kanselleer aanmelding",
     "Error while validating your second factor" : "Fout terwyl u tweede faktor gevalideer word",
     "App update required" : "Toepbywerking benodig",
     "These apps will be updated:" : "Die volgende toeps sal bygewerk word:",
@@ -187,6 +192,7 @@ OC.L10N.register(
     "Choose a password for the public link" : "Kies 'n wagwoord vir die publieke skakel",
     "Choose a password for the public link or press the \"Enter\" key" : "Kies 'n wagwoord vir die publieke skakel, of druk die \"Enter\" sleutel",
     "Copied!" : "Gekopieer!",
+    "Copy link" : "Kopieer skakel",
     "Not supported!" : "Word nie ondersteun nie!",
     "Press ⌘-C to copy." : "Druk ⌘-C om te kopieer.",
     "Press Ctrl-C to copy." : "Druk Ctrl-C om te kopieer.",
@@ -238,6 +244,7 @@ OC.L10N.register(
     "Error removing share" : "Fout terwyl deel verwyder word",
     "SQLite will be used as database." : "SQLite sal as databasis gebruik word.",
     "Wrong password." : "Verkeerde wagwoord.",
-    "New Password" : "Nuwe wagwoord"
+    "New Password" : "Nuwe wagwoord",
+    "Cancel log in" : "Kanselleer aanmelding"
 },
 "nplurals=2; plural=(n != 1);");
