@@ -42,6 +42,8 @@ OC.L10N.register(
     "So-so password" : "Contraseña pasable",
     "Good password" : "Contraseña bona",
     "Strong password" : "Contraseña mui bona",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nun paez tar configuráu de mou afayadizu pa solicitar les variables del sistema. La prueba con getenv(\"PATH\") namái devuelve una rempuesta balera.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto aconséyase particularmente al usar el veceru d'escritoriu pa la sincronización de ficheros.",
     "Error occurred while checking server setup" : "Fallu entrín se comprobaba la configruación del sirvidor",
     "Non-existing tag #{tag}" : "Etiqueta inesistente #{tag}",
     "invisible" : "invisible",
@@ -72,6 +74,8 @@ OC.L10N.register(
     "Password" : "Contraseña",
     "Log in" : "Aniciar sesión",
     "Logging in …" : "Aniciando sesión...",
+    "Wrong username or password." : "Nome d'usuariu y contraseña incorreutos",
+    "User disabled" : "Usuariu desactiváu",
     "Reset password" : "Restablecer contraseña",
     "Couldn't send reset email. Please contact your administrator." : "Nun pudo unviase'l corréu de reaniciu. Contauta col to alministrador, por favor.",
     "Password can not be changed. Please contact your administrator." : "Nun pue camudase la contraseña. Contauta col alministrador, por favor.",
@@ -87,8 +91,14 @@ OC.L10N.register(
     "No" : "Non",
     "Yes" : "Sí",
     "No files in here" : "Equí nun hai ficheros",
+    "New folder" : "Carpeta nueva",
+    "Name" : "Nome",
+    "Size" : "Tamañu",
+    "Modified" : "Modificóse'l",
+    "{newName} already exists" : "{newName} yá esiste",
     "Choose" : "Escoyer",
     "Copy" : "Copiar",
+    "Move" : "Mover",
     "Error loading file picker template: {error}" : "Fallu cargando'l ficheru de plantía d'escoyeta: {error}",
     "OK" : "Aceutar",
     "Error loading message template: {error}" : "Fallu cargando'l mensaxe de la plantía: {error}",
@@ -112,6 +122,7 @@ OC.L10N.register(
     "seconds ago" : "hai segundos",
     "Connection to server lost" : "Perdióse la conexón del sirvidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Fallu cargando la páxina, recargando en %n segundu","Fallu cargando la páxina, recargando en %n segundos"],
+    "Hide details" : "Anubrir detalles",
     "No action available" : "Nun hai aiciones disponibles",
     "Error fetching contact actions" : "Fallu diendo en cata de les aiciones de contautos",
     "Personal" : "Personal",
@@ -152,9 +163,14 @@ OC.L10N.register(
     "Need help?" : "¿Precises ayuda?",
     "See the documentation" : "Mira la documentación",
     "More apps" : "Más aplicaciones",
+    "More" : "Más",
     "Search" : "Guetar",
+    "Contacts" : "Contautos",
     "Confirm your password" : "Confirma la to contraseña",
     "App token" : "Pase d'aplicación",
+    "Grant access" : "Conceder accesu",
+    "This share is password-protected" : "Esta compartición tien contraseña protexida",
+    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
     "Two-factor authentication" : "Autenticación en dos pasos",
     "Use backup code" : "Usar códigu de respaldu",
     "Error while validating your second factor" : "Fallu al validar el to pasu segundu",
@@ -173,8 +189,10 @@ OC.L10N.register(
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Unviósete al corréu l'enllaz pa reaniciar la to contraseña. Si nun lu recibes nuna cantidá razonable de tiempu, comprueba les tos carpetes de corréu puxarra. <br>Si nun ta ehí, entruga al to alministrador llocal",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Los tos ficheros tán cifraos. Nun habrá mou de recuperar los datos dempués de reaniciar la to contraseña.<br />Si nun tas seguru de lo que facer, contautua col to alministrador enantes de siguir. <br />¿De xuru que quies siguir?",
     "Shared" : "Compartíu",
+    "Shared by" : "Compartíos por",
     "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
     "Copied!" : "¡Copióse!",
+    "Copy link" : "Copiar enllaz",
     "Not supported!" : "¡Nun se sofita!",
     "Press ⌘-C to copy." : "Primi ⌘-C pa copiar.",
     "Press Ctrl-C to copy." : "Primi Ctrl-C pa copiar.",
@@ -208,6 +226,9 @@ OC.L10N.register(
     "No users or groups found for {search}" : "Nun s'alcontraron usuarios o grupos pa {search}",
     "No users found for {search}" : "Nun s'alcontraron usuarios pa {search}",
     "An error occurred. Please try again" : "Asocedió un fallu. Volvi tentalo, por favor",
+    "Home" : "Aniciu",
+    "Work" : "Trabayu",
+    "Other" : "Otru",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Compartir",
     "Name or email address..." : "Nome o direición de corréu...",
