@@ -21,6 +21,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следния бутон, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете върху следната връзка, за да възстановите паролата си. Ако не сте поискали възстановяване на паролата, игнорирайте този имейл.",
     "Reset your password" : "Възстановяване на вашата парола",
+    "Nextcloud Server" : "Nextcloud сървър",
     "Preparing update" : "Подготовка за актуализиране",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Моля използвайте съветникът за актуализиране в командния ред, защото автоматичният е забранен в config.php.",
@@ -54,6 +55,7 @@ OC.L10N.register(
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "Модула PHP OPcache не е настроен правилно. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">За по-добра производителност е препоръчително</a> да ползвате следните настройки във файла <code>php.ini</code>:",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Някои индекси липсват в базата данни. Не са добавени защото процеса може да отнеме доста време. Можете да стартирате процеса ръчно като изпълните командата \"occ db:add-missing-indices\". След добавянето на индексите заявките към изброените таблици ще минават много по-бързо.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Някои колони от базата данни не са конвертирани към \"big int\". Конвертирането не е осъществено защото може да отнеме доста време. Можете да стартирате процеса ръчно като изпълните командата \"occ db:convert-filecache-bigint\". Но преди това инсталацията трябва да бъде в \"maintenance\" режим. За допълнителна информация <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">прочетете документацията</a>.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Препоръчително, особено ако ползвате клиента за настолен компютър.",
     "Error occurred while checking server setup" : "Възникна грешка при проверката на настройките на сървъра",
     "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
     "restricted" : "ограничен",
@@ -93,8 +95,10 @@ OC.L10N.register(
     "Reset password" : "Възстановяване на паролата",
     "Couldn't send reset email. Please contact your administrator." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, свържете се с вашия администратор.",
     "Password can not be changed. Please contact your administrator." : "Паролата не може да бъде промена. Моля, свържете се с администратора.",
+    "Back to login" : "Обратно към вписване",
     "New password" : "Нова парола",
     "I know what I'm doing" : "Знам какво правя",
+    "Resetting password" : "Възстановяване на паролата",
     "Cancel" : "Отказ",
     "Forgot password?" : "Забравена парола?",
     "Settings" : "Настройки",
@@ -108,6 +112,9 @@ OC.L10N.register(
     "No files in here" : "Няма файлове",
     "New folder" : "Нова папка",
     "No more subfolders in here" : "Няма подпапки",
+    "Name" : "Име",
+    "Size" : "Размер",
+    "Modified" : "Промяна",
     "{newName} already exists" : "{newName} вече съществува",
     "Choose" : "Избор",
     "Copy" : "Копирай",
@@ -137,6 +144,8 @@ OC.L10N.register(
     "seconds ago" : "преди секунди",
     "Connection to server lost" : "Няма връзка със сървъра",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при зареждането на страницата, презареждане след %n секунда","Проблем при зареждането на страницата, презареждане след %n секунди"],
+    "Hide details" : "Скриване на подробностите",
+    "New in" : "Ново в",
     "View changelog" : "Преглед на списъка с промени",
     "No action available" : "Няма налични действия",
     "Personal" : "Лични",
@@ -165,6 +174,7 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Информация, как да настроите сървъра коректно, ще намерите в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацията</a>.",
     "Create an <strong>admin account</strong>" : "Създаване на <strong>администраторски профил</strong>.",
     "Username" : "Потребител",
+    "Show password" : "Покажи парола",
     "Storage & database" : "Хранилища и бази данни",
     "Data folder" : "Директория за данни",
     "Configure the database" : "Конфигуриране на базата данни",
@@ -183,8 +193,11 @@ OC.L10N.register(
     "See the documentation" : "Прегледайте документацията",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Приложението изисква JavaScript. Моля, {linkstart}включете JavaScript{linkend} и презаредете страницата.",
     "More apps" : "Още приложения",
+    "More" : "Още",
     "Search" : "Търсене",
     "Contacts" : "Контакти",
+    "Contacts menu" : "Контакти",
+    "Settings menu" : "Настройки",
     "Confirm your password" : "Потвърдете паролата си",
     "Connect to your account" : "Свързване към вашия профил",
     "Please log in before granting %1$s access to your %2$s account." : "Необходимо е да се впишете, преди да дадете достъп на %1$s до вашия %2$s профил.",
@@ -193,10 +206,12 @@ OC.L10N.register(
     "Alternative log in using app token" : "Алтернативен метод за вписване с парола за приложение",
     "Account access" : "Достъп до профил",
     "You are about to grant %1$s access to your %2$s account." : "Ще разрешите на %1$s да ползва вашия %2$s профил.",
+    "This share is password-protected" : "Тази зона е защитена с парола.",
     "The password is wrong. Try again." : "Паролата е грешна. Опитайте отново.",
     "Two-factor authentication" : "Двустепенно удостоверяване",
+    "Set up two-factor authentication" : "Двустепенно удостоверяване",
     "Use backup code" : "Използвай код за възстановяване",
-    "Cancel log in" : "Откажи вписването",
+    "Cancel login" : "Откажи вписване",
     "Error while validating your second factor" : "Грешка при валидиране на втория ви фактор",
     "Access through untrusted domain" : "Достъп през недоверен домейн",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Моля, свържете се с администратора. Ако сте администратор на текущата инстанция, конфигурирайте \"trusted_domains\" настройките в config/config.php. Примерна конфигурация е предоставена в config/config.sample.php.",
@@ -231,6 +246,7 @@ OC.L10N.register(
     "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C.",
     "Resharing is not allowed" : "Повторното споделяне е забранено",
     "Link" : "Връзка",
+    "Hide download" : "Скрий свалянето",
     "Password protect" : "Защита с парола",
     "Allow editing" : "Възможност за редактиране",
     "Email link to person" : "Изпрати чрез имейл връзката",
@@ -265,9 +281,14 @@ OC.L10N.register(
     "Access control" : "Контрол на достъпа",
     "Error while sharing" : "Грешка при споделяне",
     "Share details could not be loaded for this item." : "Данните за споделяне не могат да бъдат заредени",
+    "This list is maybe truncated - please refine your search term to see more results." : "Този списък може да е съкратен, моля рафинирайте параметрите на търсене за повече резултати.",
     "No users or groups found for {search}" : "Няма потребители или групи за {search}",
     "No users found for {search}" : "Няма потребители за {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Възникна грешка (\"{message}\"). Моля, опитайте отново",
     "An error occurred. Please try again" : "Възникна грешка. Моля, опитайте отново",
+    "Home" : "Начало",
+    "Work" : "Служебен",
+    "Other" : "Друг",
     "{sharee} (remote group)" : "{sharee} (отдалечена група)",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Споделяне",
@@ -281,6 +302,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Използването на SQLite не се препоръчва, особено ако ползвате клиента за настолни компютри.",
     "Wrong password." : "Грешна парола",
     "New Password" : "Нова парола",
+    "Cancel log in" : "Откажи вписването",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "До имейла на профила е изпратена връзка за възстановяване на паролата. Не забравяйте да проверете и спам/junk папката.<br> Свържете с администратора ако не получите имейла."
 },
 "nplurals=2; plural=(n != 1);");
