@@ -54,6 +54,10 @@ OC.L10N.register(
     "Strong password" : "Strong password",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Your web server is not yet properly set up to allow file synchronisation, because the WebDAV interface seems to be broken.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "It was not possible to execute the cron job via CLI. The following technical errors have appeared:",
+    "Check the background job settings" : "Check the background job settings",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it.",
@@ -66,6 +70,8 @@ OC.L10N.register(
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Missing index \"{indexName}\" in table \"{tableName}\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "This is particularly recommended when using the desktop client for file synchronisation.",
     "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
@@ -105,6 +111,8 @@ OC.L10N.register(
     "Password" : "Password",
     "Log in" : "Log in",
     "Logging in …" : "Logging in …",
+    "Wrong username or password." : "Wrong username or password.",
+    "User disabled" : "User disabled",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
     "Reset password" : "Reset password",
     "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
@@ -124,6 +132,11 @@ OC.L10N.register(
     "No" : "No",
     "Yes" : "Yes",
     "No files in here" : "No files in here",
+    "New folder" : "New folder",
+    "Name" : "Name",
+    "Size" : "Size",
+    "Modified" : "Modified",
+    "{newName} already exists" : "{newName} already exists",
     "Choose" : "Choose",
     "Copy" : "Copy",
     "Move" : "Move",
@@ -152,6 +165,8 @@ OC.L10N.register(
     "seconds ago" : "seconds ago",
     "Connection to server lost" : "Connection to server lost",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
+    "Hide details" : "Hide details",
+    "View changelog" : "View changelog",
     "No action available" : "No action available",
     "Error fetching contact actions" : "Error fetching contact actions",
     "Personal" : "Personal",
@@ -161,6 +176,7 @@ OC.L10N.register(
     "Help" : "Help",
     "Access forbidden" : "Access denied",
     "File not found" : "File not found",
+    "Back to %s" : "Back to %s",
     "Error" : "Error",
     "Internal Server Error" : "Internal Server Error",
     "The server was unable to complete your request." : "The server was unable to complete your request.",
@@ -199,6 +215,7 @@ OC.L10N.register(
     "See the documentation" : "See the documentation",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
     "More apps" : "More apps",
+    "More" : "More",
     "More apps menu" : "More apps menu",
     "Search" : "Search",
     "Reset search" : "Reset search",
@@ -211,9 +228,11 @@ OC.L10N.register(
     "Grant access" : "Grant access",
     "Alternative log in using app token" : "Alternative log in using app token",
     "Account access" : "Account access",
+    "This share is password-protected" : "This share is password-protected",
+    "The password is wrong. Try again." : "The password is wrong. Try again.",
     "Two-factor authentication" : "Two-factor authentication",
     "Use backup code" : "Use backup code",
-    "Cancel log in" : "Cancel log in",
+    "Cancel login" : "Cancel login",
     "Error while validating your second factor" : "Error while validating your second factor",
     "Access through untrusted domain" : "Access through untrusted domain",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
@@ -244,11 +263,13 @@ OC.L10N.register(
     "Choose a password for the public link" : "Choose a password for the public link",
     "Choose a password for the public link or press the \"Enter\" key" : "Choose a password for the public link or press the \"Enter\" key",
     "Copied!" : "Copied!",
+    "Copy link" : "Copy link",
     "Not supported!" : "Not supported!",
     "Press ⌘-C to copy." : "Press ⌘-C to copy.",
     "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
     "Resharing is not allowed" : "Resharing is not allowed",
     "Link" : "Link",
+    "Hide download" : "Hide download",
     "Password protect" : "Password protect",
     "Allow editing" : "Allow editing",
     "Email link to person" : "Email link to person",
@@ -259,6 +280,7 @@ OC.L10N.register(
     "Set expiration date" : "Set expiration date",
     "Expiration" : "Expiration",
     "Expiration date" : "Expiration date",
+    "Note to recipient" : "Note to recipient",
     "Unshare" : "Unshare",
     "Share to {name}" : "Share to {name}",
     "Share link" : "Share link",
@@ -284,6 +306,9 @@ OC.L10N.register(
     "No users found for {search}" : "No users found for {search}",
     "An error occurred (\"{message}\"). Please try again" : "An error occurred (\"{message}\"). Please try again",
     "An error occurred. Please try again" : "An error occurred. Please try again",
+    "Home" : "Home",
+    "Work" : "Work",
+    "Other" : "Other",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Share",
     "Name or email address..." : "Name or email address...",
@@ -295,6 +320,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "For larger installations we recommend to choose a different database backend.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
     "Wrong password." : "Wrong password.",
-    "New Password" : "New Password"
+    "New Password" : "New Password",
+    "Cancel log in" : "Cancel log in"
 },
 "nplurals=2; plural=(n != 1);");
