@@ -52,6 +52,9 @@ OC.L10N.register(
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Su base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente está usando SQLite como el backend de base de datos. Para instalaciones más grandes le recomendamos cambiar a un backend de base de datos diferente.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto es particularmente recomendado cuando se usa el cliente de escritorio para sincronización de archivos. ",
     "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
     "restricted" : "restringido",
@@ -88,11 +91,14 @@ OC.L10N.register(
     "Password" : "Contraseña",
     "Log in" : "Ingresar",
     "Logging in …" : "Ingresando ...",
+    "Wrong username or password." : "Nombre de usuario o contraseña equivocado. ",
+    "User disabled" : "Usuario deshabilitado",
     "Reset password" : "Restablecer contraseña",
     "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Favor de contactar a su adminsitrador. ",
     "Password can not be changed. Please contact your administrator." : "Las contraseñas no se pueden cambiar. Favor de contactar a su adminstrador",
     "New password" : "Nueva contraseña",
     "I know what I'm doing" : "Sé lo que estoy haciendo",
+    "Cancel" : "Cancelar",
     "Settings" : "Configuraciones ",
     "Search contacts …" : "Buscar contactos ...",
     "No contacts found" : "No se encontraron contactos",
@@ -102,8 +108,14 @@ OC.L10N.register(
     "No" : "No",
     "Yes" : "Sí",
     "No files in here" : "No hay archivos aquí",
+    "New folder" : "Carpeta nueva",
+    "Name" : "Nombre",
+    "Size" : "Tamaño",
+    "Modified" : "Modificado",
+    "{newName} already exists" : "{newName} ya existe",
     "Choose" : "Seleccionar",
     "Copy" : "Copiar",
+    "Move" : "Mover",
     "Error loading file picker template: {error}" : "Se presentó un error al cargar la plantilla del seleccionador de archivos: {error}",
     "OK" : "OK",
     "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
@@ -114,7 +126,6 @@ OC.L10N.register(
     "Already existing files" : "Archivos ya existentes",
     "Which files do you want to keep?" : "¿Cuales archivos desea mantener?",
     "If you select both versions, the copied file will have a number added to its name." : "Si selecciona ambas versiones, se le agregará un número al nombre del archivo copiado.",
-    "Cancel" : "Cancelar",
     "Continue" : "Continuar",
     "(all selected)" : "(todos seleccionados)",
     "({count} selected)" : "({count} seleccionados)",
@@ -128,6 +139,7 @@ OC.L10N.register(
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión con el servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un erorr al cargar la página, recargando en %n segundo","Se presentó un erorr al cargar la página, recargando en %n segundo"],
+    "Hide details" : "Ocultar detalles",
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Personal" : "Personal",
@@ -172,13 +184,17 @@ OC.L10N.register(
     "See the documentation" : "Ver la documentación",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Favor de {linkstart}habilitar JavaScript{linkend} y vuelva a cargar la página. ",
     "More apps" : "Más aplicaciones",
+    "More" : "Más",
     "Search" : "Buscar",
+    "Contacts" : "Contactos",
     "Confirm your password" : "Confirme su contraseña",
     "App token" : "Ficha de la aplicación",
+    "Grant access" : "Conceder acceso",
     "Account access" : "Acceso a la cuenta",
+    "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
+    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
     "Two-factor authentication" : "Autenticación de dos-factores",
     "Use backup code" : "Usar código de respaldo",
-    "Cancel log in" : "Cancelar inicio de sesión",
     "Error while validating your second factor" : "Se presentó un error al validar su segundo factor",
     "App update required" : "Se requiere una actualización de la aplicación",
     "These apps will be updated:" : "Las siguientes apllicaciones se actualizarán:",
@@ -200,14 +216,17 @@ OC.L10N.register(
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "El link para restablecer su contraseña ha sido enviada a su correo electrónico. Si no lo recibe dentro de un tiempo razonable, verifique las carpetas de spam/basura.<br>Si no la encuentra consulte a su adminstrador local.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sus archivos están encriptados. No habrá manera de recuperar sus datos una vez que restablezca su contraseña. <br />Si no está seguro de qué hacer, favor de contactar a su administrador antes de continuar. <br />¿Realmente desea continuar?",
     "Shared" : "Compartido",
+    "Shared by" : "Compartido por",
     "Choose a password for the public link" : "Seleccione una contraseña para el link público",
     "Choose a password for the public link or press the \"Enter\" key" : "Favor de elegir una contraseña para el link público o presione  \"Intro\"",
     "Copied!" : "¡Copiado!",
+    "Copy link" : "Copiar enlace",
     "Not supported!" : "¡No está soportado!",
     "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
     "Resharing is not allowed" : "No se permite volver a compartir",
     "Link" : "Link",
+    "Hide download" : "Ocultar descarga",
     "Password protect" : "Proteger con contraseña",
     "Allow editing" : "Permitir editar",
     "Email link to person" : "Enviar el link por correo electrónico a una persona",
@@ -218,6 +237,7 @@ OC.L10N.register(
     "Set expiration date" : "Establecer la fecha de expiración",
     "Expiration" : "Expiración",
     "Expiration date" : "Fecha de expiración",
+    "Note to recipient" : "Nota al destinatario",
     "Unshare" : "Dejar de compartir",
     "Share to {name}" : "Compartir con {name}",
     "Share link" : "Compartir link",
@@ -242,6 +262,9 @@ OC.L10N.register(
     "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
     "No users found for {search}" : "No se encontraron usuarios para {search}",
     "An error occurred. Please try again" : "Se presentó un error. Favor de volver a intentar",
+    "Home" : "Casa",
+    "Work" : "Trabajo",
+    "Other" : "Otro",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Compartir",
     "Name or email address..." : "Nombre o dirección de correo electrónico",
@@ -253,6 +276,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "Para instalaciones más grandes le recomendamos elegir un backend de base de datos diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLiite es especialmente desalentado al usar el cliente de escritorio para sincrionizar. ",
     "Wrong password." : "Contraseña inválida. ",
-    "New Password" : "Nueva Contraseña"
+    "New Password" : "Nueva Contraseña",
+    "Cancel log in" : "Cancelar inicio de sesión"
 },
 "nplurals=2; plural=(n != 1);");
