@@ -54,6 +54,10 @@ OC.L10N.register(
     "Strong password" : "Contraseña fuerte",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Tu servidor web aún no esta correctamente configurado para permitir la sincronización de archivos porque la interfaz WebDAV parece estar rota. ",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Tu servidor web no está correctamente configurado para resolver \"{url}\". Puedes encontrar más información al respecto en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "No fue posible ejecutar el trabajo de cron via CLI. Se presentaron los siguientes errores técnicos:",
+    "Check the background job settings" : "Verifica la configuración de los trabajos de fondo",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "El servidor no cuenta con una conexión a Internet: No se pudieron alcanzar múltiples endpoints. Esto significa que algunas características como montar almacenamiento externo, notificaciones de actualizaciones o instalación de aplicaciones de 3ros no funcionarán correctamente. Acceder archivos de forma remota y el envío de de notificaciones por correo electrónico puede que no funcionen tampoco. Establece una conexión desde este servidor a Internet para aprovechar todas las funcionalidades.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "No se ha configurado el caché de memoria. Para mejorar el desempeño, por favor configura un memcahce, si está disponible. Puedes encontrar más información en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Estás ejecutando PHP {version}. Actualiza tu versión de PHP para aprovechar las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">actualizaciones de desempeño y seguridad proporcionadas por el Grupo PHP</a> tan pronto como tu distribución lo soporte. ",
@@ -64,6 +68,8 @@ OC.L10N.register(
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "El OPcache de PHP no está configurado correctamente. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Para un mejor desempeño se recomienda</a> usar las sigueintes configuraciones en el archivo <code>php.ini</code>:",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente estás usando SQLite como el backend de base de datos. Para instalaciones más grandes te recomendamos cambiar a un backend de base de datos diferente.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto es particularmente recomendado cuando se usa el cliente de escritorio para sincronización de archivos. ",
     "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Probablemente tu directorio de datos y archivos sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda ampliamente que configures tu servidor web para que el directorio de datos no sea accesible, o bien, que muevas el directorio de datos fuera del directorio raíz del servidor web.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" está establecido a \"{expected}\". Esto representa un riesgo potencial de seguridad o privacidad, y que se recomienda ajustar esta configuración. ",
@@ -103,6 +109,8 @@ OC.L10N.register(
     "Password" : "Contraseña",
     "Log in" : "Ingresar",
     "Logging in …" : "Iniciando sesión ...",
+    "Wrong username or password." : "Usuario o contraseña equivocado. ",
+    "User disabled" : "Usuario deshabilitado",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
     "Reset password" : "Restablecer contraseña",
     "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
@@ -122,6 +130,11 @@ OC.L10N.register(
     "No" : "No",
     "Yes" : "Sí",
     "No files in here" : "No hay archivos aquí",
+    "New folder" : "Carpeta nueva ",
+    "Name" : "Nombre",
+    "Size" : "Tamaño",
+    "Modified" : "Modificado",
+    "{newName} already exists" : "{newName} ya existe",
     "Choose" : "Seleccionar",
     "Copy" : "Copiar",
     "Move" : "Mover",
@@ -150,6 +163,7 @@ OC.L10N.register(
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión con el servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos"],
+    "Hide details" : "Ocultar detalles",
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Personal" : "Personal",
@@ -197,6 +211,7 @@ OC.L10N.register(
     "See the documentation" : "Ver la documentación",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
     "More apps" : "Más aplicaciones",
+    "More" : "Más",
     "More apps menu" : "Menú de más aplicaciones",
     "Search" : "Buscar",
     "Reset search" : "Reestablecer búsqueda",
@@ -209,9 +224,10 @@ OC.L10N.register(
     "Grant access" : "Conceder acceso",
     "Alternative log in using app token" : "Inicio de sesión alternativo usando una ficha de aplicación",
     "Account access" : "Acceo de cuenta",
+    "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
+    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
     "Two-factor authentication" : "Autenticación de dos-factores",
     "Use backup code" : "Usar código de respaldo",
-    "Cancel log in" : "Cancelar inicio de sesión",
     "Error while validating your second factor" : "Se presentó un error al validar tu segundo factor",
     "Access through untrusted domain" : "Accesa a través de un dominio no de confianza",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacta a tu adminsitrador. Si tu eres un administrador, edita la propiedad \"trusted_domains\" en el archivo config/config.php como en el ejemplo config.sample.php.",
@@ -242,11 +258,13 @@ OC.L10N.register(
     "Choose a password for the public link" : "Seleccione una contraseña para la liga pública",
     "Choose a password for the public link or press the \"Enter\" key" : "Elige una contraseña para la liga pública o presiona la tecla \"Intro\"",
     "Copied!" : "¡Copiado!",
+    "Copy link" : "Copiar liga",
     "Not supported!" : "¡No está soportado!",
     "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
     "Resharing is not allowed" : "No se permite volver a compartir",
     "Link" : "Liga",
+    "Hide download" : "Ocultar descarga",
     "Password protect" : "Proteger con contraseña",
     "Allow editing" : "Permitir editar",
     "Email link to person" : "Enviar la liga por correo electrónico a una persona",
@@ -282,6 +300,9 @@ OC.L10N.register(
     "No users found for {search}" : "No se encontraron usuarios para {search}",
     "An error occurred (\"{message}\"). Please try again" : "Se presentó un error (\"{message}\"). Por favor vuelve a intentarlo",
     "An error occurred. Please try again" : "Se presentó un error. Por favor vuelve a intentarlo",
+    "Home" : "Inicio",
+    "Work" : "Trabajo",
+    "Other" : "Otro",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Compartir",
     "Name or email address..." : "Nombre o dirección de correo electrónico",
@@ -293,6 +314,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "Para instalaciones más grandes te recomendamos elegir un backend de base de datos diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLiite es especialmente desalentado al usar el cliente de escritorio para sincrionizar. ",
     "Wrong password." : "Contraseña inválida. ",
-    "New Password" : "Nueva Contraseña"
+    "New Password" : "Nueva Contraseña",
+    "Cancel log in" : "Cancelar inicio de sesión"
 },
 "nplurals=2; plural=(n != 1);");
