@@ -18,18 +18,13 @@ OC.L10N.register(
     "Password reset is disabled" : "Restablecer contraseña se encuentra deshabilitado",
     "Couldn't reset password because the token is invalid" : "No ha sido posible restablecer la contraseña porque la ficha es inválida",
     "Couldn't reset password because the token is expired" : "No ha sido posible restablecer la contraseña porque la ficha ha expirado",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "No fue posible enviar el correo electrónico para restablecer porque no hay una dirección de correo electrónico para este usuario. Por favor contacta a tu adminsitrador. ",
     "%s password reset" : "%s restablecer la contraseña",
     "Password reset" : "Restablecer contraseña",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Haz click en el siguiente botón para restablecer tu contraseña. Si no has solicitado restablecer su contraseña, por favor ignora este correo. ",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Haz click en la siguiente liga para restablecer su contraseña. Si no has solicitado restablecer la contraseña, por favor ignora este mensaje. ",
     "Reset your password" : "Restablecer tu contraseña",
-    "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
-    "Couldn't send reset email. Please make sure your username is correct." : "No fue posible restablecer el correo electrónico. Por favor asegurarte de que tu nombre de usuario sea correcto. ",
     "Preparing update" : "Preparando actualización",
     "[%d / %d]: %s" : "[%d / %d]: %s ",
-    "Repair warning: " : "Advertencia de reparación:",
-    "Repair error: " : "Error de reparación: ",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor usa el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
     "Turned on maintenance mode" : "Modo mantenimiento activado",
@@ -45,7 +40,6 @@ OC.L10N.register(
     "Checked for update of app \"%s\" in appstore" : "Se verificaron actualizaciones para la aplicación \"%s\" en la appstore",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando si el esquema de la base de datos para %s puede ser actualizado (esto puede tomar mucho tiempo dependiendo del tamaño de la base de datos)",
     "Checked database schema update for apps" : "Se verificó la actualización del esquema de la base de datos para las aplicaciones",
-    "Updated \"%s\" to %s" : "Actualizando \"%s\" a %s",
     "Set log level to debug" : "Establecer nivel de bitacora a depurar",
     "Reset log level" : "Restablecer nivel de bitácora",
     "Starting code integrity check" : "Comenzando verificación de integridad del código",
@@ -53,56 +47,6 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "Following apps have been disabled: %s" : "Las siguientes aplicaciones han sido deshabilitadas: %s",
     "Already up to date" : "Ya está actualizado",
-    "Search contacts …" : "Buscar contactos ...",
-    "No contacts found" : "No se encontraron contactos",
-    "Show all contacts …" : "Mostrar todos los contactos ...",
-    "Loading your contacts …" : "Cargando sus contactos ... ",
-    "Looking for {term} …" : "Buscando {term} ...",
-    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Se presentaron problemas con la verificación de integridad del código. Más información ...</a>",
-    "No action available" : "No hay acciones disponibles",
-    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
-    "Settings" : "Configuraciones ",
-    "Connection to server lost" : "Se ha perdido la conexión con el servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos"],
-    "Saving..." : "Guardando...",
-    "Dismiss" : "Descartar",
-    "Authentication required" : "Se requiere autenticación",
-    "This action requires you to confirm your password" : "Esta acción requiere que confirmes tu contraseña",
-    "Confirm" : "Confirmar",
-    "Password" : "Contraseña",
-    "Failed to authenticate, try again" : "Falla en la autenticación, por favor reintentalo",
-    "seconds ago" : "hace segundos",
-    "Logging in …" : "Iniciando sesión ...",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "La liga para restablecer tu contraseña ha sido enviada a tu correo electrónico. Si no lo recibes dentro de un tiempo razonable, verifica las carpetas de spam/basura.<br>Si no la encuentras consulta a tu adminstrador local.",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tus archivos están encriptados. No habrá manera de recuperar tus datos una vez que restablezca tu contraseña. <br />Si no estás seguro de qué hacer, por favor contacta a tu administrador antes de continuar. <br />¿Realmente deseas continuar?",
-    "I know what I'm doing" : "Sé lo que estoy haciendo",
-    "Password can not be changed. Please contact your administrator." : "Las contraseñas no se pueden cambiar. Por favor contacta a tu adminstrador",
-    "Reset password" : "Restablecer contraseña",
-    "Sending email …" : "Enviando correo electrónico ...",
-    "No" : "No",
-    "Yes" : "Sí",
-    "No files in here" : "No hay archivos aquí",
-    "Choose" : "Seleccionar",
-    "Copy" : "Copiar",
-    "Move" : "Mover",
-    "Error loading file picker template: {error}" : "Se presentó un error al cargar la plantilla del seleccionador de archivos: {error}",
-    "OK" : "OK",
-    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
-    "read-only" : "sólo-lectura",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo"],
-    "One file conflict" : "Un conflicto en el archivo",
-    "New Files" : "Archivos Nuevos",
-    "Already existing files" : "Archivos ya existentes",
-    "Which files do you want to keep?" : "¿Cuales archivos deseas mantener?",
-    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, se le agregará un número al nombre del archivo copiado.",
-    "Cancel" : "Cancelar",
-    "Continue" : "Continuar",
-    "(all selected)" : "(todos seleccionados)",
-    "({count} selected)" : "({count} seleccionados)",
-    "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
-    "Pending" : "Pendiente",
-    "Copy to {folder}" : "Copiar a {folder}",
-    "Move to {folder}" : "Mover a {folder}",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
@@ -110,9 +54,11 @@ OC.L10N.register(
     "Strong password" : "Contraseña fuerte",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Tu servidor web aún no esta correctamente configurado para permitir la sincronización de archivos porque la interfaz WebDAV parece estar rota. ",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Tu servidor web no está correctamente configurado para resolver \"{url}\". Puedes encontrar más información al respecto en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "No fue posible ejecutar el trabajo de cron via CLI. Se presentaron los siguientes errores técnicos:",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "El servidor no cuenta con una conexión a Internet: No se pudieron alcanzar múltiples endpoints. Esto significa que algunas características como montar almacenamiento externo, notificaciones de actualizaciones o instalación de aplicaciones de 3ros no funcionarán correctamente. Acceder archivos de forma remota y el envío de de notificaciones por correo electrónico puede que no funcionen tampoco. Establece una conexión desde este servidor a Internet para aprovechar todas las funcionalidades.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "No se ha configurado el caché de memoria. Para mejorar el desempeño, por favor configura un memcahce, si está disponible. Puedes encontrar más información en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP no puede leer /dev/urandom y no se recomienda por razones de seguridad. Puedes encontrar más información en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Estás ejecutando PHP {version}. Actualiza tu versión de PHP para aprovechar las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">actualizaciones de desempeño y seguridad proporcionadas por el Grupo PHP</a> tan pronto como tu distribución lo soporte. ",
     "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Actualmente estás corriendo PHP 5.6. La versión principal actual de Nextcloud es la última que será soportada en PHPH 5.6. Te recomendamos actualizar la versión de PHP a la 7.0+ para que puedas actualizar a Nextcloud 14.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "La configuración de los encabezados del proxy inverso es incorrecta, o estás accediendo a Nextcloud desde un proxy de confianza. Si no es el caso, se trata de un tema de seguridad y le puede permitir a un atacante hacer su dirección IP apócrifa visible para Nextcloud. Puedes encontar más infomración en nuestra <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>.",
@@ -120,69 +66,12 @@ OC.L10N.register(
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Algunos archivos no pasaron la verificación de integridad. Puedes encontrar más información de cómo resolver este problema en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentación</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista de archivos inválidos...</a>/<a href=\"{rescanEndpoint}\">Volver a verificar...</a>)",
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "El OPcache de PHP no está configurado correctamente. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Para un mejor desempeño se recomienda</a> usar las sigueintes configuraciones en el archivo <code>php.ini</code>:",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente estás usando SQLite como el backend de base de datos. Para instalaciones más grandes te recomendamos cambiar a un backend de base de datos diferente.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto es particularmente recomendado cuando se usa el cliente de escritorio para sincronización de archivos. ",
     "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Probablemente tu directorio de datos y archivos sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda ampliamente que configures tu servidor web para que el directorio de datos no sea accesible, o bien, que muevas el directorio de datos fuera del directorio raíz del servidor web.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" está establecido a \"{expected}\". Esto representa un riesgo potencial de seguridad o privacidad, y que se recomienda ajustar esta configuración. ",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" no está establecido a \"{expected}\". Puede que lgunas características no funcionen correctamente, y se recomienda ajustar esta confirguración. ",
-    "Shared" : "Compartido",
-    "Shared with" : "Compartido con",
-    "Shared by" : "Compartido por",
-    "Error setting expiration date" : "Se presentó un error al establecer la fecha de expiración",
-    "The public link will expire no later than {days} days after it is created" : "La liga pública expirará a los {days} días de haber sido creada",
-    "Set expiration date" : "Selecciona la vigencia de tu archivo",
-    "Expiration" : "Expiración",
-    "Expiration date" : "Fecha de expiración",
-    "Choose a password for the public link" : "Seleccione una contraseña para la liga pública",
-    "Choose a password for the public link or press the \"Enter\" key" : "Elige una contraseña para la liga pública o presiona la tecla \"Intro\"",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No está soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
-    "Resharing is not allowed" : "No se permite volver a compartir",
-    "Share to {name}" : "Compartir con {name}",
-    "Share link" : "Compartir liga",
-    "Link" : "Liga",
-    "Password protect" : "Proteger con contraseña",
-    "Allow editing" : "Permitir editar",
-    "Email link to person" : "Enviar la liga por correo electrónico a una persona",
-    "Send" : "Enviar",
-    "Allow upload and editing" : "Permitir carga y edición",
-    "Read only" : "Sólo lectura",
-    "File drop (upload only)" : "Permitir carga",
-    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
-    "Shared with you by {owner}" : "Compartido contigo por {owner}",
-    "Choose a password for the mail share" : "Elige una contraseña para el elemento compartido por correo",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} ha compartido mediante una liga",
-    "group" : "grupo",
-    "remote" : "remoto",
-    "email" : "correo electrónico",
-    "shared by {sharer}" : "compartido por {sharer}",
-    "Unshare" : "Dejar de compartir",
-    "Can reshare" : "Puede volver a compartir",
-    "Can edit" : "Puede editar",
-    "Can create" : "Puede crear",
-    "Can change" : "Puede cambiar",
-    "Can delete" : "Puede borrar",
-    "Access control" : "Control de acceso",
-    "Could not unshare" : "No fue posible dejar de compartir",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "Share details could not be loaded for this item." : "Los detalles del recurso compartido no se pudieron cargar para este elemento. ",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Se requiere de la menos {count} caracter para el auto completar","Se requieren de la menos {count} caracteres para el auto completar"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar truncada - por favor refina tus términos de búsqueda para poder ver más resultados. ",
-    "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
-    "No users found for {search}" : "No se encontraron usuarios para {search}",
-    "An error occurred. Please try again" : "Se presentó un error. Por favor vuelve a intentarlo",
-    "{sharee} (group)" : "{sharee} (grupo)",
-    "{sharee} (remote)" : "{sharee} (remoto)",
-    "{sharee} (email)" : "{sharee} (correo electrónico)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Compartir",
-    "Name or email address..." : "Nombre o dirección de correo electrónico",
-    "Name or federated cloud ID..." : "Nombre...",
-    "Name, federated cloud ID or email address..." : "Nombre o dirección de correo electrónico...",
-    "Name..." : "Nombre...",
-    "Error" : "Error",
-    "Error removing share" : "Se presentó un error al dejar de compartir",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
     "restricted" : "restringido",
     "invisible" : "invisible",
@@ -210,6 +99,68 @@ OC.L10N.register(
     "Searching other places" : "Buscando en otras ubicaciones",
     "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados para la búsqueda {tag}{filter}{endtag} en otras carpetas",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de la búsqueda en otra carpeta","{count} resultados de la búsqueda en otras carpetas"],
+    "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
+    "Please contact your administrator." : "Por favor contacta al administrador.",
+    "An internal error occurred." : "Se presentó un error interno.",
+    "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
+    "Username or email" : "Usuario o correo electrónico",
+    "Password" : "Contraseña",
+    "Log in" : "Ingresar",
+    "Logging in …" : "Iniciando sesión ...",
+    "Wrong username or password." : "Usuario o contraseña equivocado. ",
+    "User disabled" : "Usuario deshabilitado",
+    "Reset password" : "Restablecer contraseña",
+    "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
+    "Password can not be changed. Please contact your administrator." : "Las contraseñas no se pueden cambiar. Por favor contacta a tu adminstrador",
+    "New password" : "Nueva contraseña",
+    "I know what I'm doing" : "Sé lo que estoy haciendo",
+    "Cancel" : "Cancelar",
+    "Forgot password?" : "¿Olvidaste tu contraseña?",
+    "Settings" : "Configuraciones ",
+    "Search contacts …" : "Buscar contactos ...",
+    "No contacts found" : "No se encontraron contactos",
+    "Show all contacts …" : "Mostrar todos los contactos ...",
+    "Loading your contacts …" : "Cargando sus contactos ... ",
+    "Looking for {term} …" : "Buscando {term} ...",
+    "No" : "No",
+    "Yes" : "Sí",
+    "No files in here" : "No hay archivos aquí",
+    "New folder" : "Carpeta nueva",
+    "Name" : "Nombre",
+    "Size" : "Tamaño",
+    "Modified" : "Modificado",
+    "{newName} already exists" : "{newName} ya existe",
+    "Choose" : "Seleccionar",
+    "Copy" : "Copiar",
+    "Move" : "Mover",
+    "Error loading file picker template: {error}" : "Se presentó un error al cargar la plantilla del seleccionador de archivos: {error}",
+    "OK" : "OK",
+    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
+    "read-only" : "sólo-lectura",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo"],
+    "One file conflict" : "Un conflicto en el archivo",
+    "New Files" : "Archivos Nuevos",
+    "Already existing files" : "Archivos ya existentes",
+    "Which files do you want to keep?" : "¿Cuales archivos deseas mantener?",
+    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, se le agregará un número al nombre del archivo copiado.",
+    "Continue" : "Continuar",
+    "(all selected)" : "(todos seleccionados)",
+    "({count} selected)" : "({count} seleccionados)",
+    "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
+    "Pending" : "Pendiente",
+    "Copy to {folder}" : "Copiar a {folder}",
+    "Move to {folder}" : "Mover a {folder}",
+    "Saving..." : "Guardando...",
+    "Authentication required" : "Se requiere autenticación",
+    "This action requires you to confirm your password" : "Esta acción requiere que confirmes tu contraseña",
+    "Confirm" : "Confirmar",
+    "Failed to authenticate, try again" : "Falla en la autenticación, por favor reintentalo",
+    "seconds ago" : "hace segundos",
+    "Connection to server lost" : "Se ha perdido la conexión con el servidor",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos"],
+    "Hide details" : "Ocultar detalles",
+    "No action available" : "No hay acciones disponibles",
+    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Personal" : "Personal",
     "Users" : "Usuarios",
     "Apps" : "Aplicaciones",
@@ -217,8 +168,7 @@ OC.L10N.register(
     "Help" : "Ayuda",
     "Access forbidden" : "Acceso prohibido",
     "File not found" : "Archivo no encontrado",
-    "The specified document has not been found on the server." : "El documento especificado no ha sido encontrado en el servidor. ",
-    "You can click here to return to %s." : "Puedes hacer click aquí para regresar a %s.",
+    "Error" : "Error",
     "Internal Server Error" : "Error interno del servidor",
     "The server was unable to complete your request." : "El servidor no pudo completar tu solicitud.",
     "If this happens again, please send the technical details below to the server administrator." : "Si esto vuelve a suceder, por favor envia los detalles tecnicos siguientes al adminsitrador del sistema.",
@@ -250,42 +200,28 @@ OC.L10N.register(
     "Database host" : "Servidor de base de datos",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
     "Performance warning" : "Advertencia de desempeño",
-    "SQLite will be used as database." : "SQLite será usado como la base de datos.",
-    "For larger installations we recommend to choose a different database backend." : "Para instalaciones más grandes te recomendamos elegir un backend de base de datos diferente.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLiite es especialmente desalentado al usar el cliente de escritorio para sincrionizar. ",
     "Finish setup" : "Terminar configuración",
     "Finishing …" : "Terminando …",
     "Need help?" : "¿Necesitas ayuda?",
     "See the documentation" : "Ver la documentación",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
     "More apps" : "Más aplicaciones",
+    "More" : "Más",
     "Search" : "Buscar",
     "Reset search" : "Reestablecer búsqueda",
+    "Contacts" : "Contactos",
     "Confirm your password" : "Confirma tu contraseña",
-    "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
-    "Please contact your administrator." : "Por favor contacta al administrador.",
-    "An internal error occurred." : "Se presentó un error interno.",
-    "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
-    "Username or email" : "Usuario o correo electrónico",
-    "Log in" : "Ingresar",
-    "Wrong password." : "Contraseña inválida. ",
-    "Forgot password?" : "¿Olvidaste tu contraseña?",
     "App token" : "Ficha de la aplicación",
     "Grant access" : "Conceder acceso",
     "Account access" : "Acceo de cuenta",
-    "You are about to grant %s access to your %s account." : "Estas a punto de otorgar acceso de %s a tu cuenta %s.",
-    "Redirecting …" : "Redireccionando ... ",
-    "New password" : "Nueva contraseña",
-    "New Password" : "Nueva Contraseña",
+    "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
+    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
     "Two-factor authentication" : "Autenticación de dos-factores",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "La seguridad mejorada está habilitada para tu cuenta. Favor de autenticarte usando un segundo factor. ",
-    "Cancel log in" : "Cancelar inicio de sesión",
     "Use backup code" : "Usar código de respaldo",
     "Error while validating your second factor" : "Se presentó un error al validar tu segundo factor",
     "Access through untrusted domain" : "Accesa a través de un dominio no de confianza",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacta a tu adminsitrador. Si tu eres un administrador, edita la propiedad \"trusted_domains\" en el archivo config/config.php como en el ejemplo config.sample.php.",
     "App update required" : "Se requiere una actualización de la aplicación",
-    "%s will be updated to version %s" : "%s será actualizado a la versión %s",
     "These apps will be updated:" : "Las siguientes apllicaciones se actualizarán:",
     "These incompatible apps will be disabled:" : "Las siguientes aplicaciones incompatibles serán deshabilitadas:",
     "The theme %s has been disabled." : "El tema %s ha sido deshabilitado. ",
@@ -299,19 +235,74 @@ OC.L10N.register(
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continúo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
     "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
-    "This page will refresh itself when the %s instance is available again." : "Esta página se actualizará sola cuando la instancia %s esté disponible de nuevo. ",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Thank you for your patience." : "Gracias por tu paciencia.",
-    "Share with other people by entering a user or group, a federated cloud ID or an email address." : "Comparte con otras personas ingresando una dirección de correo electrónico.",
-    "Share with other people by entering a user or group or a federated cloud ID." : "Comparte con otras personas ingresando un usuario o un grupo.",
-    "Share with other people by entering a user or group or an email address." : "Comparte con otras personas ingresando un usuario, un grupo o una dirección de correo electrónico.",
-    "Stay logged in" : "Mantener la sesión abierta",
-    "Alternative Logins" : "Accesos Alternativos",
-    "Alternative login using app token" : "Inicio de sesión alternativo usando la ficha de la aplicación",
-    "Add \"%s\" as trusted domain" : "Agregar \"%s\" como un dominio de confianza",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips</a>." : "El encabezado HTTP \"Strict-Transport-Security\" no está configurado a al menos \"{seconds}\" segundos. Para una seguridad mejorada, se recomienda configurar el HSTS como se describe en los <a href=\"{docUrl}\" rel=\"noreferrer noopener\">consejos de seguridad</a>.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips</a>." : "Accediendo al sitio de forma insegura vía HTTP. Se recomienda configurar el servidor para, en su lugar, requerir HTTPS, como se describe en los <a href=\"{docUrl}\">consejos de seguridad</a>.",
-    "Back to log in" : "Regresar al inicio de sesión",
-    "Depending on your configuration, this button could also work to trust the domain:" : "Dependiendo de tu configuración, este botón podría funcionar también para confiar en el dominio:"
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "No fue posible enviar el correo electrónico para restablecer porque no hay una dirección de correo electrónico para este usuario. Por favor contacta a tu adminsitrador. ",
+    "Couldn't send reset email. Please make sure your username is correct." : "No fue posible restablecer el correo electrónico. Por favor asegurarte de que tu nombre de usuario sea correcto. ",
+    "Dismiss" : "Descartar",
+    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "La liga para restablecer tu contraseña ha sido enviada a tu correo electrónico. Si no lo recibes dentro de un tiempo razonable, verifica las carpetas de spam/basura.<br>Si no la encuentras consulta a tu adminstrador local.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tus archivos están encriptados. No habrá manera de recuperar tus datos una vez que restablezca tu contraseña. <br />Si no estás seguro de qué hacer, por favor contacta a tu administrador antes de continuar. <br />¿Realmente deseas continuar?",
+    "Sending email …" : "Enviando correo electrónico ...",
+    "Shared" : "Compartido",
+    "Shared with" : "Compartido con",
+    "Shared by" : "Compartido por",
+    "Choose a password for the public link" : "Seleccione una contraseña para la liga pública",
+    "Choose a password for the public link or press the \"Enter\" key" : "Elige una contraseña para la liga pública o presiona la tecla \"Intro\"",
+    "Copied!" : "¡Copiado!",
+    "Copy link" : "Copiar liga",
+    "Not supported!" : "¡No está soportado!",
+    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
+    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
+    "Resharing is not allowed" : "No se permite volver a compartir",
+    "Link" : "Liga",
+    "Password protect" : "Proteger con contraseña",
+    "Allow editing" : "Permitir editar",
+    "Email link to person" : "Enviar la liga por correo electrónico a una persona",
+    "Send" : "Enviar",
+    "Allow upload and editing" : "Permitir carga y edición",
+    "Read only" : "Sólo lectura",
+    "File drop (upload only)" : "Permitir carga",
+    "Set expiration date" : "Selecciona la vigencia de tu archivo",
+    "Expiration" : "Expiración",
+    "Expiration date" : "Fecha de expiración",
+    "Unshare" : "Dejar de compartir",
+    "Share to {name}" : "Compartir con {name}",
+    "Share link" : "Compartir liga",
+    "Could not unshare" : "No fue posible dejar de compartir",
+    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
+    "Shared with you by {owner}" : "Compartido contigo por {owner}",
+    "Choose a password for the mail share" : "Elige una contraseña para el elemento compartido por correo",
+    "group" : "grupo",
+    "remote" : "remoto",
+    "email" : "correo electrónico",
+    "shared by {sharer}" : "compartido por {sharer}",
+    "Can reshare" : "Puede volver a compartir",
+    "Can edit" : "Puede editar",
+    "Can create" : "Puede crear",
+    "Can change" : "Puede cambiar",
+    "Can delete" : "Puede borrar",
+    "Access control" : "Control de acceso",
+    "Error while sharing" : "Se presentó un error al compartir",
+    "Share details could not be loaded for this item." : "Los detalles del recurso compartido no se pudieron cargar para este elemento. ",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Se requiere de la menos {count} caracter para el auto completar","Se requieren de la menos {count} caracteres para el auto completar"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar truncada - por favor refina tus términos de búsqueda para poder ver más resultados. ",
+    "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
+    "No users found for {search}" : "No se encontraron usuarios para {search}",
+    "An error occurred. Please try again" : "Se presentó un error. Por favor vuelve a intentarlo",
+    "Home" : "Inicio",
+    "Work" : "Trabajo",
+    "Other" : "Otro",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Compartir",
+    "Name or email address..." : "Nombre o dirección de correo electrónico",
+    "Name or federated cloud ID..." : "Nombre...",
+    "Name, federated cloud ID or email address..." : "Nombre o dirección de correo electrónico...",
+    "Name..." : "Nombre...",
+    "Error removing share" : "Se presentó un error al dejar de compartir",
+    "SQLite will be used as database." : "SQLite será usado como la base de datos.",
+    "For larger installations we recommend to choose a different database backend." : "Para instalaciones más grandes te recomendamos elegir un backend de base de datos diferente.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLiite es especialmente desalentado al usar el cliente de escritorio para sincrionizar. ",
+    "Wrong password." : "Contraseña inválida. ",
+    "New Password" : "Nueva Contraseña",
+    "Cancel log in" : "Cancelar inicio de sesión"
 },
 "nplurals=2; plural=(n != 1);");
