@@ -85,6 +85,8 @@ OC.L10N.register(
     "Password" : "Parool",
     "Log in" : "Logi sisse",
     "Logging in …" : "Sisselogimine ...",
+    "Wrong username or password." : "Vale kasutajanimi või parool.",
+    "User disabled" : "Kasutaja deaktiveeritud",
     "Reset password" : "Lähtesta parool",
     "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
     "Password can not be changed. Please contact your administrator." : "Parooli ei saa muuta. Palun kontakteeru oma süsteemihalduriga.",
@@ -102,6 +104,11 @@ OC.L10N.register(
     "No" : "Ei",
     "Yes" : "Jah",
     "No files in here" : "Siin ei ole faile",
+    "New folder" : "Uus kaust",
+    "Name" : "Nimi",
+    "Size" : "Suurus",
+    "Modified" : "Muudetud",
+    "{newName} already exists" : "{newName} on juba olemas",
     "Choose" : "Vali",
     "Copy" : "Kopeeri",
     "Move" : "Liiguta",
@@ -177,14 +184,17 @@ OC.L10N.register(
     "See the documentation" : "Vaata dokumentatsiooni",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "See rakendus vajab toimimiseks JavaScripti. Palun {linkstart}luba JavaScript{linkend} ning laadi see leht uuesti.",
     "More apps" : "Veel rakendusi",
+    "More" : "Rohkem",
     "Search" : "Otsi",
     "Reset search" : "Lähtesta otsing",
+    "Contacts" : "Kontaktid",
     "Confirm your password" : "Kinnita oma parool",
     "Grant access" : "Anna ligipääs",
     "Account access" : "Konto ligipääs",
+    "This share is password-protected" : "See jagamine on parooliga kaitstud",
+    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
     "Two-factor authentication" : "Kaheastmeline autentimine",
     "Use backup code" : "Kasuta varu koodi",
-    "Cancel log in" : "Katkesta sisselogimine",
     "Error while validating your second factor" : "Teise faktori valideerimise viga",
     "Access through untrusted domain" : "Ligipääs läbi ebausaldusväärse domeeni",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Palun võtke ühendust oma administraatoriga. Kui olete administraator, muutke konfiguratsioonis config/config.php sätet \"trusted_domains\", nagu näidis config.sample.php failis.",
@@ -214,6 +224,7 @@ OC.L10N.register(
     "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
     "Choose a password for the public link or press the \"Enter\" key" : "Vali avaliku lingi jaoks parool või vajuta klahvi \"Enter\"",
     "Copied!" : "Kopeeritud!",
+    "Copy link" : "Kopeeri link",
     "Not supported!" : "Pole toetatud!",
     "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
     "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
@@ -251,7 +262,11 @@ OC.L10N.register(
     "This list is maybe truncated - please refine your search term to see more results." : "See nimekiri võib olla kärbitud - palun täpsusta oma otsingut, et näha rohkem tulemusi.",
     "No users or groups found for {search}" : "Otsingu {search} põhjal kasutajaid ega gruppe ei leitud",
     "No users found for {search}" : "Otsingu {search} põhjal kasutajaid ei leitud",
+    "An error occurred (\"{message}\"). Please try again" : "Tekkis tõrge (\"{message}\"). Palun proovi uuesti.",
     "An error occurred. Please try again" : "Tekkis tõrge. Palun proovi uuesti",
+    "Home" : "Avaleht",
+    "Work" : "Töö",
+    "Other" : "Muu",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Jaga",
     "Name or email address..." : "Nimi või e-posti aadress",
@@ -263,6 +278,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "Suuremate paigalduste jaoks soovitame valida teise andmebaasi.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Eriti kui tasutad töölaua rakendust failide sünkroonimiseks on SQLite andmebaas ebasoovitav.",
     "Wrong password." : "Vale parool.",
-    "New Password" : "Uus parool"
+    "New Password" : "Uus parool",
+    "Cancel log in" : "Katkesta sisselogimine"
 },
 "nplurals=2; plural=(n != 1);");
