@@ -88,6 +88,7 @@ OC.L10N.register(
     "Password" : "گذرواژه",
     "Log in" : "ورود",
     "Logging in …" : "ورود به سیستم ...",
+    "User disabled" : "کاربر غیرفعال",
     "Reset password" : "تنظیم مجدد رمز عبور",
     "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
     "Password can not be changed. Please contact your administrator." : "رمز عبور نمی تواند تغییر بکند . لطفا با مدیر سیستم تماس بگیرید .",
@@ -103,6 +104,11 @@ OC.L10N.register(
     "No" : "نه",
     "Yes" : "بله",
     "No files in here" : "هیچ فایلی اینجا وجود ندارد",
+    "New folder" : "پوشه جدید",
+    "Name" : "نام",
+    "Size" : "اندازه",
+    "Modified" : "تغییر یافته",
+    "{newName} already exists" : "{newName} قبلاً موجود است",
     "Choose" : "انتخاب کردن",
     "Copy" : "کپی",
     "Move" : "انتقال",
@@ -176,12 +182,16 @@ OC.L10N.register(
     "Need help?" : "کمک لازم دارید ؟",
     "See the documentation" : "مشاهده‌ی مستندات",
     "More apps" : "برنامه های بیشتر",
+    "More" : "بیش‌تر",
     "Search" : "جست‌و‌جو",
+    "Contacts" : "مخاطبین",
     "Confirm your password" : "گذرواژه خود را تأیید کنید",
     "App token" : "App token",
+    "Grant access" : " مجوز اعطا دسترسی",
     "Account access" : "دسترسی به حساب",
+    "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
+    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
     "Use backup code" : "از کد پشتیبان استفاده شود",
-    "Cancel log in" : "لغو ورود",
     "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
     "These apps will be updated:" : "این برنامه‌ها بروزرسانی شده‌اند:",
     "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
@@ -194,9 +204,11 @@ OC.L10N.register(
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "لینک تنظیم مجدد رمز عبور به ایمیل شما ارسال شده است.<br>اگر آن رادر یک زمان مشخصی دریافت نکرده اید، لطفا هرزنامه/ پوشه های ناخواسته را بررسی کنید.<br>در صورت نبودن از مدیر خود بپرسید.",
     "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "فایل های شما رمزگذاری می شوند پس از بازنشانی گذرواژه شما هیچ راهی برای بازگرداندن اطلاعات نخواهید داشت. <br /> اگر مطمئن نیستید که چه کاری باید انجام دهید، قبل از ادامه دادن، با ادمین خود تماس بگیرید. <br />واقعا می خواهید ادامه دهید؟ ",
     "Shared" : "اشتراک گذاشته شده",
+    "Shared by" : "اشتراک گذاشته شده به وسیله",
     "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
     "Choose a password for the public link or press the \"Enter\" key" : "یک رمز عبور برای لینک عمومی انتخاب کنید یا کلید \"Enter\" را فشار دهید",
     "Copied!" : "کپی انجام شد!",
+    "Copy link" : "کپی کردن لینک",
     "Not supported!" : "پشتیبانی وجود ندارد!",
     "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
     "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
@@ -236,6 +248,9 @@ OC.L10N.register(
     "No users or groups found for {search}" : "هیچ کاربری یا گروهی یافت نشد {search}",
     "No users found for {search}" : "هیچ کاربری با جستجوی {search} یافت نشد",
     "An error occurred. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
+    "Home" : "خانه ",
+    "Work" : "کار",
+    "Other" : "دیگر",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "اشتراک‌گذاری",
     "Name or email address..." : "نام یا آدرس ایمیل ...",
@@ -246,6 +261,7 @@ OC.L10N.register(
     "SQLite will be used as database." : "SQLite به عنوان پایگاه‎داده استفاده خواهد شد.",
     "For larger installations we recommend to choose a different database backend." : "برای نصب و راه اندازی بزرگتر توصیه می کنیم یک پایگاه داده متفاوتی را انتخاب کنید.",
     "Wrong password." : "گذرواژه اشتباه.",
-    "New Password" : "رمزعبور جدید"
+    "New Password" : "رمزعبور جدید",
+    "Cancel log in" : "لغو ورود"
 },
 "nplurals=2; plural=(n > 1);");
