@@ -64,6 +64,7 @@ OC.L10N.register(
     "Strong password" : "Vahva salasana",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Palvelintasi ei ole määritetty oikein tiedostojen synkronointia varten, koska WebDAV-liitäntä vaikuttaa olevan rikki.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Palvelinta ei ole määritelty oikein tunnistamaan osoitetta \"{url}\". Katso lisätiedot <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ohjeista</a>.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tietokantaasi ei suoriteta \"READ COMMITTED\"-transaktioeristystasolla. Tämä saattaa aiheuttaa ongelmia, kun useita toimintoja suoritetaan rinnakkaisesti.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Cron-työtä ei voitu suorittaa komentorivin kautta. Seuraavat tekniset virheet havaittiin:",
     "Check the background job settings" : "Tarkista taustatyön asetukset",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Välimuistia ei ole asennettu oikein. Suorituskykyä parantaaksesi, asenna memcache, jos käytettävissä. Katso lisätiedot <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ohjeista</a>.",
@@ -76,6 +77,7 @@ OC.L10N.register(
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-asennuksessasi ei ole FreeType-tukea, ja siitä aiheutuu profiilikuvien sekä asetuskäyttöliittymän rikkoutuminen.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Puuttuva indeksi \"{indexName}\" taulussa \"{tableName}\".",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite on parhaillaan käytössä tietokantaratkaisuna. Suuria asennuksia varten suosittelemme vaihtamaan toiseen tietokantaratkaisuun.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Tämä on suositeltavaa erityisesti silloin, kun työpöytäsovellusta käytetään tiedostojen synkronointiin.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Tee migraatio toiseen tietokantaan komentorivityökalulla: 'occ db:convert-type', tai lue <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaatio ↗</a>.",
     "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Sisäänrakennetun php mailerin käyttö ei ole enää tuettua. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Päivitä sähköpostipalvelimesi asetukset ↗<a/>.",
     "The PHP memory limit is below the recommended value of 512MB." : "PHP:n muistiraja on asetettu alle suositellun 512 megatavun arvon.",
@@ -256,7 +258,7 @@ OC.L10N.register(
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
     "Set up two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
     "Use backup code" : "Käytä varakoodia",
-    "Cancel log in" : "Peru kirjautuminen",
+    "Cancel login" : "Peru kirjautuminen",
     "Setup two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
     "Error while validating your second factor" : "Tunnistuksen toisen vaiheen tarkistus epäonnistui",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ota yhteys ylläpitoon, tai jos olet tämän palvelun ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tiedostossa config/config.sample.php.",
@@ -311,6 +313,7 @@ OC.L10N.register(
     "Set expiration date" : "Aseta vanhenemispäivä",
     "Expiration" : "Vanheneminen",
     "Expiration date" : "Vanhenemispäivä",
+    "Note to recipient" : "Huomio vastaanottajalle",
     "Unshare" : "Lopeta jakaminen",
     "Delete share link" : "Poista jakolinkki",
     "Add another link" : "Lisää toinen linkki",
@@ -357,6 +360,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "Suuria asennuksia varten suositellaan muun tietokannan käyttöä.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Varsinkin työpöytäsovelluksen tiedostosynkronointia käyttäessä SQLiten käyttö ei ole suositeltavaa.",
     "Wrong password." : "Väärä salasana.",
-    "New Password" : "Uusi salasana"
+    "New Password" : "Uusi salasana",
+    "Cancel log in" : "Peru kirjautuminen"
 },
 "nplurals=2; plural=(n != 1);");
