@@ -139,6 +139,7 @@ OC.L10N.register(
     "Back to login" : "חזרה לכניסה",
     "New password" : "ססמה חדשה",
     "I know what I'm doing" : "אני יודע/ת מה אני עושה",
+    "Cancel" : "ביטול",
     "Forgot password?" : "שכחת ססמה?",
     "Settings" : "הגדרות",
     "Could not load your contacts" : "לא ניתן לטעון את אנשי הקשר שלך",
@@ -169,7 +170,6 @@ OC.L10N.register(
     "Already existing files" : "קבצים קיימים כבר",
     "Which files do you want to keep?" : "אילו קבצים ברצונך לשמור?",
     "If you select both versions, the copied file will have a number added to its name." : "אם תבחר האפשרות לשמור את שתי הגרסאות, לשם קובץ המועתק יתווסף מספר.",
-    "Cancel" : "ביטול",
     "Continue" : "המשך",
     "(all selected)" : "(הכול נבחר)",
     "({count} selected)" : "({count} נבחרו)",
@@ -185,6 +185,7 @@ OC.L10N.register(
     "seconds ago" : "שניות",
     "Connection to server lost" : "החיבור לשרת אבד",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["תקלה בטעינת העמוד, יתבצע רענון בעוד שנייה","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות"],
+    "Hide details" : "הסתרת פרטים",
     "New in" : "חדש ב־",
     "View changelog" : "הצגת יומן שינויים",
     "No action available" : "אין פעולה זמינה",
@@ -266,7 +267,7 @@ OC.L10N.register(
     "Set up two-factor authentication" : "הגדרת אימות דו־שלבי",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא להשתמש באחד מהקודים לצורכי גיבוי כדי להיכנס או ליצור קשר עם המנהל שלך לקבלת עזרה.",
     "Use backup code" : "שימוש בקוד גיבוי",
-    "Cancel log in" : "ביטול כניסה",
+    "Cancel login" : "ביטול התחברות",
     "Setup two-factor authentication" : "הגדרת אימות דו־שלבי",
     "Error while validating your second factor" : "שגיאה בעת אימות הגורם השני",
     "Access through untrusted domain" : "גישה דרך שם מתחם בלתי מהימן",
@@ -377,6 +378,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "במיוחד כאשר משתמשים במחשב שולחני לסנכרון קבצים השימוש ב SQLite אינו מומלץ.",
     "Wrong password." : "ססמה שגויה.",
     "New Password" : "ססמה חדשה",
+    "Cancel log in" : "ביטול כניסה",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "שלחנו הודעת דוא״ל לאיפוס ססמה לכתובת הדוא״ל שאנו מכירים לחשבון זה. אם לא קיבלת את ההודעה תוך זמן סביר, מומלץ לחפש בתיקיות הספאם/זבל שלך.<br>אם היא לא שם כדאי לשאול את מנהל הרשת המקומית.",
     "Search globally" : "חיפוש גלובלי",
     "Your client should now be connected! You can close this window." : "הלקוח שלך אמור להיות מחובר עכשיו! ניתן לסגור את החלון הזה."
