@@ -25,6 +25,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi hnapp til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi tengil til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
     "Reset your password" : "Endurstilltu lykilorðið þitt",
+    "Nextcloud Server" : "Nextcloud þjónn",
     "Some of your link shares have been removed" : "Sumir tenglar þnir  sameignir hafa verið fjarlægðir",
     "Preparing update" : "Undirbý uppfærslu",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -100,6 +101,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn inniheldur ekki \"{expected}\". Þetta er möguleg áhætta varðandi öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP-hausinn \"{header}\" er ekki stilltur á \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" eða \"{val5}\". Þetta getur lekið upplýsingum um kerfið. Skoðaðu hvað <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C mælir með ↗</a>.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP-hausinn er ekki stilltur á að minnsa kosti \"{seconds}\" sekúndur. Fyrir aukið öryggi mælum við með því að virkja HSTS eins og lýst er í <a href=\"{docUrl}\" rel=\"noreferrer noopener\">öryggisleiðbeiningum ↗ </a>.",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : " Þú ert að tengjast þessu vefsvæði með HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í <a href=\"{docUrl}\">öryggisleiðbeiningunum ↗</a> okkar.",
     "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
     "restricted" : "takmarkaður aðgangur",
     "invisible" : "ósýnilegt",
@@ -145,7 +147,11 @@ OC.L10N.register(
     "Password can not be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
     "Back to login" : "Til baka í innskráningu",
     "New password" : "Nýtt lykilorð",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt. Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. Viltu halda áfram?",
     "I know what I'm doing" : "Ég veit hvað ég er að gera",
+    "Resetting password" : "Endurstilli lykilorð",
+    "Recommended apps" : "Ráðlögð forrit",
+    "Cancel" : "Hætta við",
     "Forgot password?" : "Gleymdirðu lykilorði?",
     "Settings" : "Stillingar",
     "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
@@ -177,7 +183,6 @@ OC.L10N.register(
     "Already existing files" : "Skrá er nú þegar til",
     "Which files do you want to keep?" : "Hvaða skrám vilt þú vilt halda eftir?",
     "If you select both versions, the copied file will have a number added to its name." : "Ef þú velur báðar útgáfur, þá mun verða bætt tölustaf aftan við heiti afrituðu skrárinnar.",
-    "Cancel" : "Hætta við",
     "Continue" : "Halda áfram",
     "(all selected)" : "(allt valið)",
     "({count} selected)" : "({count} valið)",
@@ -248,6 +253,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Þú valdir SQLite sem gagnagrunn.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ætti aðeins að nota fyrir lágmarksuppsetningar og til prófana. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ef verið er að nota biðlaraforrit til að samstilla skrár, þá er ekki mælt með notkun SQLite.",
+    "Install recommended apps" : "Setja upp ráðlögð forrit",
     "Finish setup" : "Ljúka uppsetningu",
     "Finishing …" : "Að klára ...",
     "Need help?" : "Þarftu hjálp?",
@@ -273,6 +279,8 @@ OC.L10N.register(
     "Account access" : "Aðgangur að notandaaðgangi",
     "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
     "Account connected" : "Aðgangur er tengdur",
+    "Your client should now be connected!" : "Biðlaraforritið þitt ætti núna að vera tengt!",
+    "You can close this window." : "Þú mátt loka þessum glugga.",
     "This share is password-protected" : "Þessi sameign er varin með lykilorði",
     "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
     "Two-factor authentication" : "Tveggja-þrepa auðkenning",
@@ -283,8 +291,9 @@ OC.L10N.register(
     "Set up two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Notaðu einn af öryggisafritunarkóðunum þínum til að skrá þig inn, eða hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
     "Use backup code" : "Nota öryggisafritskóða",
-    "Cancel log in" : "Hætta við innskráningu",
+    "Cancel login" : "Hætta við innskráningu",
     "Setup two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu hvaða auðkenningarveitu eigi að nota til auðkenningar:",
     "Error while validating your second factor" : "Villa við að sannreyna seinna þrepið",
     "Access through untrusted domain" : "Tenging frá ótreystu léni",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
@@ -396,6 +405,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Sérstaklega þegar verið er að nota skjáborðsforritið til að samræma skrár, þá er ekki mælt með notkun SQLite.",
     "Wrong password." : "Rangt lykilorð.",
     "New Password" : "Nýtt lykilorð",
+    "Cancel log in" : "Hætta við innskráningu",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
     "Search globally" : "Leita allstaðar",
     "Your client should now be connected! You can close this window." : "Biðlaraforritið þitt ætti núna að vera tengt! Þú mátt loka þessum glugga."
