@@ -7,12 +7,12 @@ OC.L10N.register(
     "The selected file cannot be read." : "選択されたファイルを読み込めませんでした",
     "Invalid file provided" : "無効なファイルが提供されました",
     "No image or file provided" : "画像またはファイルが提供されていません",
-    "Unknown filetype" : "不明なファイルタイプ",
+    "Unknown filetype" : "不明なファイル形式",
     "Invalid image" : "無効な画像",
     "An error occurred. Please contact your admin." : "エラーが発生しました。管理者に連絡してください。",
     "No temporary profile picture available, try again" : "一時的なプロファイル用画像が利用できません。もう一度試してください",
-    "No crop data provided" : "クロップデータは提供されません",
-    "No valid crop data provided" : "有効なクロップデータは提供されません",
+    "No crop data provided" : "クロップデータが提供されていません",
+    "No valid crop data provided" : "有効なクロップデータが提供されていません",
     "Crop is not square" : "クロップが正方形ではありません",
     "State token does not match" : "状態トークンが一致しません",
     "Could not complete login" : "ログインが完了できませんでした",
@@ -107,6 +107,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーに \"{expected}\"が含まれていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします。",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "\"{header}\" HTTPヘッダーが \"{val1}\"、 \"{val2}\"、 \"{val3}\"、 \"{val4}\"、または \"{val5}\"に設定されていません。 これにより、参照元情報が漏れる可能性があります。 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C勧告↗</a>を参照してください。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTPヘッダが最低でも \"{seconds}\" 秒に設定されていません。セキュリティを強化するには、<a href=\"{docUrl}\" rel=\"noreferrer noopener\">セキュリティTips ↗</a>で解説しているHSTSを有効にすることを推奨します。",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "セキュアではないHTTP経由でアクセスしています。<a href=\"{docUrl}\">セキュリティTips ↗</a>で述べているように、代わりにHTTPSを必要とするようサーバーを設定することを強くおすすめします。",
     "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
     "restricted" : "制限済",
     "invisible" : "不可視",
@@ -156,6 +157,19 @@ OC.L10N.register(
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ファイルが暗号化されます。パスワードがリセットされた後は、データを元に戻すことはできません。対処方法がわからない場合は、続行する前に管理者に問い合わせてください。本当に続行しますか?",
     "I know what I'm doing" : "どういう操作をしているか理解しています",
     "Resetting password" : "パスワードのリセット",
+    "Recommended apps" : "推奨アプリ",
+    "Loading apps …" : "アプリを読み込み中…",
+    "Could not fetch list of apps from the app store." : "App Storeからアプリのリストを取得できませんでした。",
+    "Installing apps …" : "アプリをインストールしています…",
+    "Nextcloud {app}" : "Nextcloud {app}",
+    "App download or installation failed" : "アプリのダウンロードまたはインストールに失敗しました",
+    "Can't install this app because it is not compatible" : "アプリの互換性がないため、インストールできません",
+    "Can't install this app" : "このアプリはインストールできません",
+    "Cancel" : "キャンセル",
+    "Schedule work & meetings, synced with all your devices." : "すべての端末と同期して、仕事と会議をスケジュールに組み込みます",
+    "Keep your colleagues and friends in one place without leaking their private info." : "個人情報を漏らさずに、同僚や友人をまとめて保管します。",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "ファイル、連絡先、カレンダーとうまく合わさったシンプルなメールアプリ。",
+    "Screensharing, online meetings and web conferencing – on desktop and with mobile apps." : "スクリーン共有、オンライン会議、およびWeb会議 - デスクトップ上およびモバイルのアプリ",
     "Forgot password?" : "パスワードをお忘れですか?",
     "Settings" : "設定",
     "Could not load your contacts" : "連絡先を読み込めませんでした",
@@ -187,7 +201,6 @@ OC.L10N.register(
     "Already existing files" : "既存のファイル",
     "Which files do you want to keep?" : "どちらのファイルを保持しますか？",
     "If you select both versions, the copied file will have a number added to its name." : "両方のバージョンを選択した場合は、ファイル名の後ろに数字を追加したファイルのコピーを作成します。",
-    "Cancel" : "キャンセル",
     "Continue" : "続ける",
     "(all selected)" : "(すべて選択)",
     "({count} selected)" : "({count} 選択)",
@@ -244,6 +257,7 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
     "Create an <strong>admin account</strong>" : "<strong>管理者アカウント</strong>を作成してください",
     "Username" : "ユーザー名",
+    "Show password" : "パスワードを表示",
     "Storage & database" : "ストレージとデータベース",
     "Data folder" : "データフォルダー",
     "Configure the database" : "データベースを設定してください",
@@ -260,6 +274,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
+    "Install recommended apps" : "推奨アプリをインストール",
     "Finish setup" : "セットアップを完了します",
     "Finishing …" : "作業を完了しています ...",
     "Need help?" : "ヘルプが必要ですか？",
@@ -287,6 +302,8 @@ OC.L10N.register(
     "Account access" : "アカウントによるアクセス許可",
     "You are about to grant %1$s access to your %2$s account." : "%2$s アカウントに あなたのアカウント %1$s へのアクセスを許可",
     "Account connected" : "アカウント接続済",
+    "Your client should now be connected!" : "クライアントはもう接続されているはずです！",
+    "You can close this window." : "このウィンドウは閉じてしまって構いません。",
     "This share is password-protected" : "この共有はパスワードで保護されています",
     "The password is wrong. Try again." : "パスワードが違います。再入力してください",
     "Two-factor authentication" : "二要素認証",
@@ -297,8 +314,9 @@ OC.L10N.register(
     "Set up two-factor authentication" : "二要素認証を設定",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "二要素認証が強制されていますが、アカウントに設定されていません。 バックアップコードを使用してログインするか、不明点は管理者に連絡してください。",
     "Use backup code" : "バックアップコードを使用する",
-    "Cancel log in" : "ログインをキャンセルする",
+    "Cancel login" : "ログインをキャンセル",
     "Setup two-factor authentication" : "二要素認証を設定",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "アカウントのセキュリティ強化が必要です。使用する認証手段を選択してください。",
     "Error while validating your second factor" : "第二要素の検証でエラーが発生しました",
     "Access through untrusted domain" : "信頼できないドメインを介したアクセス",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "管理者に連絡してください。 管理者の場合は、config.sample.phpを参照して config/config.phpの \"trusted_domains\" を設定してください。",
@@ -410,6 +428,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特にデスクトップクライアントをファイル同期に使用する場合，SQLiteは非推奨です.",
     "Wrong password." : "パスワードが間違っています。",
     "New Password" : "新しいパスワード",
+    "Cancel log in" : "ログインをキャンセルする",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "このアカウントのパスワードをリセットするためのメールを、登録されているアドレスに送信しました。 あなたが妥当な時間内にメールを受け取れない場合は、スパム/ジャンクフォルダーをチェックしてください。<br>そこにもない場合は、サーバー管理者に確認してください。",
     "Search globally" : "グローバルに検索",
     "Your client should now be connected! You can close this window." : "あなたのクライアントは接続されているはずです。 このウィンドウは閉じても構いません。"
