@@ -54,6 +54,9 @@ OC.L10N.register(
     "Strong password" : "ძლიერი პაროლი",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "ფაილის სინქრონიზაციის დასაშვებად თქვენი ვებ-სერვერი ჯერ არაა სწორად კოფინგირურებული, როგორც ჩანს WebDAV ინტერფეისი გაფუჭებულია.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "\"{url}\"-ის გასახსნელად თქვენი ვებ-სერვერი არაა სწორად კონფიგურირებული. შეგიძლიათ იხილოთ მეტი ინფორმაცია <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">დოკუმენტაციაში</a>.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "როგორც ჩანს PHP სისტემის გარემოს ცვლადების მიღებისთვის არაა სწორად მოწყობილი. ეს ტესტი getenv(\"PATH\")-ით აბრუნებს მხოლოდ ცარიელ პასუხს.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "თქვენი მონაცემთა ბაზა არ მოქმედებს \"READ COMMITTED\" ტრანზაქციის იზოლაციის დონით. ამან შეიძლება გამოიწვიოს პრობლემა, როდესაც მრავალი ქმედება შესრულდება პარალელურად.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "CLI-ით კრონ საქმის ეგზეკუცია ვერ მოხერხდა. წარმოიშვა შემდეგი ტექნიკური შეცდომები:",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "ამ სერვერს არ გააჩნია მოქმედი ინტერნეტ კავშირი: მიუწვდომელია მრავალი წერტილი. ეს ნიშნავს, რომ ფუნქციები როგორებიცაა ექსტერნალური საცავის დაყენება, შეტყობინებები განახლებებზე ან მესამე მხარის აპლიკაციების ინსტალაცია არ იმუშავებს. შესაძლოა ფაილებთან დისტანციური წვდომა და საფოსტო შეტყობინებების გაგზავნაც არ მუშაობდეს. ყველა ფუნქციის მუშაობისთვის, ამ სერვერზე ჩართეთ ინტერნეტ კავშირი.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "მეხსიერების კეში არაა კონფიგურირებული. მოქმედების მახასიათებლების გაუმჯობესებისთვის გთოხვთ გაუწიოთ კონფიგურაცია memcache-ს. შეგიძლიათ იხილოთ მეტი ინფორმაცია <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">დოკუმენტაციაში</a>.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "ამჟამად თქვენთან მოქმედია PHP {version}. განაახლეთ თქვენი PHP ვერსია, რათა ისარგებლოთ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">PHP Group-ის მიერ უზრუნველყოფილი გაუმჯობესებული ქმედებითა და უსაფრთხოებებისის განახლებებით</a>.",
@@ -64,6 +67,8 @@ OC.L10N.register(
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP OPcache არაა სწორად კონფიგურირებული. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">უკეთესი მოქმედებისთვის რეკომენდირებულია</a> <code>php.ini</code>-ში გამოიყენოთ შემდეგი პარამეტრები:",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-ს ფუნქცია \"set_time_limit\" არაა ხელმისაწვდომი. ამან შეიძლება ქმედებისას გამოიწვიოს სკრიპტების შეჩერება, ინსტალაციის შეწყვეტა. რეკომენდირებულია ამ ფუნქციის ჩართვა.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "თქვენს PHP-ს არ აქვს FreeType-ის მხარდაჭერა, რაც გამოწვევს დარღვეულ პროფილის სურათებს და პარამეტრების ინტერფეისს.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "ამჟამად ბექენდზე მონაცემთა ბაზად მოიხმარება SQLite. უფრო დიდი ინსტალაციებისთვის რეკომენდაციას გიწევთ აირჩიოთ სხვა მონაცემთა ბაზა.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "ეს კერძოდ რეკომედირებულია განსაკუთრებით მაშინ, როდესაც ფაილების სინქრონიზაციისთვის იყენებთ დესკტოპ-კლიენტს.",
     "Error occurred while checking server setup" : "შეცდომა სერვერის მოწყობის შემოწმებისას",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "თქვენი data დირექტორია და ფაილები ალბათ წვდომადია ინტერნეტიდან. .htaccess ფაილი არ მუშაობს. მკაცრად რეკომენდირებულია ისე გაუწიოთ თქვენს ვებ-სერვერს კონფიგურაცია, რომ data დირექტორია აღარ იყოს წვდომადი, ან გაიტანოთ ის ვებ-სერვერის root დირექტორიიდან.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP დასათაურება \"{header}\" არაა კონფიგურირებული უტოლდებოდეს \"{expected}\"-ს. ეს პოტენციური უსაფრთხოების და კონფიდენციალურობის რისკია, რეკომენდირებულია ამ პარამეტრის გამოსწორება.",
@@ -103,6 +108,8 @@ OC.L10N.register(
     "Password" : "პაროლი",
     "Log in" : "შესვლა",
     "Logging in …" : "შესვლა ...",
+    "Wrong username or password." : "არასწორი მომხმარებლის სახელი ან პაროლი.",
+    "User disabled" : "მომხმარებელი გათიშულია",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "თქვენი IP მისამართით შევნიშნეთ არაერთი წარუმატებელი ავტორიზაციის მცდელობა. აქედან გამომდინარე თქვენი შემდეგი ავტორიზაციის მცდელობა შეიზღუდება დაახლოებით 30 წამით.",
     "Reset password" : "პაროლის შეცვლა",
     "Couldn't send reset email. Please contact your administrator." : "აღდგენის ელ-წერილი ვერ გაიგზავნა. გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
@@ -121,6 +128,11 @@ OC.L10N.register(
     "No" : "არა",
     "Yes" : "კი",
     "No files in here" : "აქ ფაილები არაა",
+    "New folder" : "ახალი დირექტორია",
+    "Name" : "სახელი",
+    "Size" : "ზომა",
+    "Modified" : "შეიცვალა",
+    "{newName} already exists" : "{newName} უკვე არსებობს",
     "Choose" : "არჩევა",
     "Copy" : "კოპირება",
     "Move" : "გადატანა",
@@ -149,6 +161,7 @@ OC.L10N.register(
     "seconds ago" : "წამის წინ",
     "Connection to server lost" : "სერვერთან კავშირი დაიკარგა",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["გვერდის ჩატვირთვის პროლბემა, ხელახალი ჩატვირთვა მოხდება %n წამში","გვერდის ჩატვირთვის პროლბემა, ხელახალი ჩატვირთვა მოხდება %n წამში"],
+    "Hide details" : "დეტალების დამალვა",
     "No action available" : "ქმედება არაა ხელმისაწვდომი",
     "Error fetching contact actions" : "კონტაქტის ქმედებების მოხვეწისას წარმოიქმნა შეცდომა",
     "Personal" : "პირადი",
@@ -196,15 +209,18 @@ OC.L10N.register(
     "See the documentation" : "იხილეთ დოკუმენტაცია",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "ეს აპლიკაცია სწორი ოპერაციისთვის საჭიროებს JavaScript-ს. გთხოვთ {linkstart}ჩართოთ JavaScript-ი{linkend} და გადატვირთოთ გვერდი.",
     "More apps" : "მეტი აპლიკაცია",
+    "More" : "მეტი",
     "Search" : "ძებნა",
     "Reset search" : "ძიების შედეგები",
+    "Contacts" : "კონტაქტები",
     "Confirm your password" : "დაადასტურეთ თქვენი პაროლი",
     "App token" : "აპლიკაციის ტოკენი",
     "Grant access" : "უფლებების მინიჭება",
     "Account access" : "წვდომა ანგარიშზე",
+    "This share is password-protected" : "ეს გაზიარება დაცულია პაროლით",
+    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
     "Two-factor authentication" : "ორ-ფაქტრიანი აუტენტიფიკაცია",
     "Use backup code" : "ბექაფის კოდის გამოყენება",
-    "Cancel log in" : "ავტორიზაციის შეჩერება",
     "Error while validating your second factor" : "მეორე ფაქტორის ვალიდაციისას წარმოიშვა შეცდომა",
     "Access through untrusted domain" : "წვდომა არა-სანდო დომენიდან",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს. იმ შემთხვევაში თუ ბრძანდებით ადმინისტრატორი, config/config.php-ში შეცვალეთ \"trusted_domains\" პარამეტრი, ისე როგორც ნაჩვენებია მაგალითში config.sample.php.",
@@ -235,6 +251,7 @@ OC.L10N.register(
     "Choose a password for the public link" : "საზოგადო ბმულისთვის აირჩიეთ პაროლი",
     "Choose a password for the public link or press the \"Enter\" key" : "აირჩიეთ პაროლი საზოგადო ბმულისთვის ან დააჭირეთ \"Enter\"-ს",
     "Copied!" : "კოპირებულია!",
+    "Copy link" : "ბმულის კოპირება",
     "Not supported!" : "არაა მხარდაჭერილი!",
     "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
     "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
@@ -274,6 +291,9 @@ OC.L10N.register(
     "No users or groups found for {search}" : "მომხმარებლები და ჯგუფები {search}-ისთვის არ იქნა ნაპოვნი",
     "No users found for {search}" : "მომხმარებლები {search}-ისთვის არ იქნა ნაპოვნი",
     "An error occurred. Please try again" : "წარმოიშვა შეცდომა. გთხოვთ სცადოთ ახლიდან.",
+    "Home" : "სახლი",
+    "Work" : "სამსახური",
+    "Other" : "სხვა",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "გაზიარება",
     "Name or email address..." : "სახელი ან ელ-ფოსტის მისამართი...",
@@ -285,6 +305,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "უფრო დიდი ინსტალაციებისთვის რეკომენდაციას გიწევთ აირჩიოთ სხვა მონაცემთა ბაზა.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite-ის გამოყენება არაა რეკომედირებული განსაკუთრებით მაშინ, როდესაც ფაილების სინქრონიზაციისთვის იყენებთ დესკტოპ-კლიენტს.",
     "Wrong password." : "არასწორი პაროლი.",
-    "New Password" : "ახლი პაროლი"
+    "New Password" : "ახლი პაროლი",
+    "Cancel log in" : "ავტორიზაციის შეჩერება"
 },
 "nplurals=2; plural=(n!=1);");
