@@ -151,6 +151,7 @@ OC.L10N.register(
     "Back to login" : "로그인으로 돌아가기",
     "New password" : "새 암호",
     "I know what I'm doing" : "지금 하려는 것을 알고 있습니다",
+    "Cancel" : "취소",
     "Forgot password?" : "암호를 잊으셨습니까?",
     "Settings" : "설정",
     "Could not load your contacts" : "연락처를 불러올 수 없음",
@@ -181,7 +182,6 @@ OC.L10N.register(
     "Already existing files" : "파일이 이미 존재합니다",
     "Which files do you want to keep?" : "어느 파일을 유지하시겠습니까?",
     "If you select both versions, the copied file will have a number added to its name." : "두 버전을 모두 선택하면 복사된 파일 이름에 번호가 추가됩니다.",
-    "Cancel" : "취소",
     "Continue" : "계속",
     "(all selected)" : "(모두 선택됨)",
     "({count} selected)" : "({count}개 선택됨)",
@@ -197,6 +197,10 @@ OC.L10N.register(
     "seconds ago" : "초 전",
     "Connection to server lost" : "서버 연결이 끊어짐",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["페이지 불러오기 오류, %n초 후 새로 고침"],
+    "Add to a project" : "프로젝트에 추가",
+    "Hide details" : "자세한 정보 숨기기",
+    "Connect items to a project to make them easier to find" : "폴더 또는 파일을 찾기 쉽게 프로젝트에 연결하세요.",
+    "Type to search for existing projects" : "이미 존재하는 프로젝트를 찾기 위해 입력하세요.",
     "New in" : "새로운 것",
     "View changelog" : "변경 기록 확인",
     "No action available" : "사용할 수 있는 동작 없음",
@@ -282,7 +286,7 @@ OC.L10N.register(
     "Set up two-factor authentication" : "2단계 인증 설정",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "2단계 인증이 필수로 설정되어 있지만 현재 계정에 설정되어 있지 않습니다. 백업 코드를 사용하여 로그인하거나 관리자에게 도움을 요청하십시오.",
     "Use backup code" : "백업 코드 사용",
-    "Cancel log in" : "로그인 취소",
+    "Cancel login" : "로그인 취소",
     "Setup two-factor authentication" : "2단계 인증 설정",
     "Error while validating your second factor" : "2단계 인증을 검증하는 중 오류 발생",
     "Access through untrusted domain" : "신뢰하지 않는 도메인으로 접근",
@@ -395,6 +399,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정이면 SQLite를 사용하지 않는 것이 좋습니다.",
     "Wrong password." : "암호가 잘못되었습니다.",
     "New Password" : "새 암호",
+    "Cancel log in" : "로그인 취소",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 이 계정에 연결된 이메일 주소로 보냈습니다. 일정 시간이 지난 후에도 이메일을 받지 못했다면 스팸 메일함을 확인해 보십시오.<br>스팸 메일함에도 링크가 없다면 시스템 관리자에게 문의하십시오.",
     "Search globally" : "전역 검색",
     "Your client should now be connected! You can close this window." : "클라이언트가 연동되었습니다! 이제 창을 닫으셔도 됩니다."
