@@ -94,6 +94,7 @@ OC.L10N.register(
     "Continue to Nextcloud" : "Eiti į NextCloud",
     "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Atnaujinimas buvo sėkmingas. Po %n sekundės būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundžių būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundžių būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundės būsite nukreipti į Nextcloud."],
     "Searching other places" : "Ieškoma kitose vietose",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Kituose aplankuose nėra paieškos rezultatų, skirtų {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} paieškos rezultatas kitame aplanke","{count} paieškos rezultatai kitame aplanke","{count} paieškos rezultatų kitame aplanke","{count} paieškos rezultatas kitame aplanke"],
     "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
     "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
@@ -167,8 +168,9 @@ OC.L10N.register(
     "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
     "seconds ago" : "prieš keletą sekundžių",
     "Connection to server lost" : "Ryšys su serveriu nutrūko",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių"],
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
     "Add to a project" : "Pridėti į projektą",
+    "Hide details" : "Slėpti išsamesnę informaciją",
     "Rename project" : "Pervadinti projektą",
     "Failed to rename the project" : "Nepavyko pervadinti projekto",
     "Failed to create a project" : "Nepavyko sukurti projekto",
@@ -252,7 +254,6 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
     "Two-factor authentication" : "Dviejų žingsnių prisijungimas",
     "Use backup code" : "Naudoti atsarginį kodą",
-    "Cancel log in" : "Atšaukti prisijungimą",
     "Error while validating your second factor" : "Klaida antrame prisijungimo žingsnyje",
     "Access through untrusted domain" : "Prieiga iš nepatikimo domeno",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Susisiekite su savo administratoriumi. Jeigu jūs esate administratorius, pataisykite \"trusted_domains\" nustatymą config/config.php faile, kaip tai parodyta pavyzdyje config.sample.php faile.",
@@ -291,6 +292,7 @@ OC.L10N.register(
     "Unable to toggle this option" : "Nepavyko perjungti pasirinkimo",
     "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
     "Link" : "Nuoroda",
+    "Hide download" : "Slėpti atsisiuntimą",
     "Password protection enforced" : "Aktyvuota apsauga slaptažodžiu",
     "Password protect" : "Apsaugoti slaptažodžiu",
     "Allow editing" : "Leisti redaguoti",
@@ -314,7 +316,7 @@ OC.L10N.register(
     "Created on {time}" : "Sukurta {time}",
     "Password protect by Talk" : "„Talk“ apsauga slaptažodžiu",
     "Could not unshare" : "Nepavyko nustoti bendrinti",
-    "Shared with you and the group {group} by {owner}" : "{owner} pasidalino su jumis ir grupe {group}",
+    "Shared with you and the group {group} by {owner}" : "{owner} pradėjo bendrinti su jumis ir su grupe {group}",
     "Shared with you and {circle} by {owner}" : "{owner} pasidalino su jumis ir {circle}",
     "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokabliu {conversation}",
     "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
@@ -335,9 +337,8 @@ OC.L10N.register(
     "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} pradėjo bendrinti per nuorodą",
     "Error while sharing" : "Klaida bendrinant",
     "Share details could not be loaded for this item." : "Dalinimosi detalės negali būti atskleistos šiai bylai",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius"],
     "This list is maybe truncated - please refine your search term to see more results." : "Sąrašas galimai sutrumpintas - prašome patikslinti paiešką, norint matyti daugiau rezultatų.",
-    "No users or groups found for {search}" : "Nerasta vartotojų ar grupių pagal paieškos kriterijų: {search}",
+    "No users or groups found for {search}" : "Pagal užklausą {search}, nerasta jokių naudotojų ar grupių",
     "No users found for {search}" : "Nerasta vartotojų pagal paieškos kriterijų: {search}",
     "An error occurred (\"{message}\"). Please try again" : "Įvyko klaida (\"{message}\"). Bandykite dar kartą",
     "An error occurred. Please try again" : "Įvyko klaida. Bandykite dar kartą",
@@ -357,6 +358,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite naudojimas yra nerekomenduotinas, kai duomenų sinchronizacijai naudojamas darbalaukio klientas.",
     "Wrong password." : "Neteisingas slaptažodis.",
     "New Password" : "Naujas slaptažodis",
+    "Cancel log in" : "Atšaukti prisijungimą",
     "Search globally" : "Ieškoti visur",
     "Your client should now be connected! You can close this window." : "Klientas jau turi būti prijungtas! Langą galite užverti."
 },
