@@ -23,6 +23,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Nospiediet sekojošo pogu, lai atiestatītu paroli. Ja jūs nepieprasijāt paroles atiestatīšanu, ignorējiet šo e-pastu.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Nospiediet sekojošo saiti, lai atiestatītu paroli. Ja jūs nepieprasijāt paroles atiestatīšanu, ignorējiet šo e-pastu.",
     "Reset your password" : "Atiestatīt paroli",
+    "Nextcloud Server" : "Nextcloud Serveris",
     "Preparing update" : "Sagatavo atjauninājumu",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Lūdzu izmanto komandrindas atjaunināšanu, jo automātiskā atjaunināšana ir atspējota konfigurācijas datnē config.php.",
@@ -63,6 +64,7 @@ OC.L10N.register(
     "Last background job execution ran {relativeTime}. Something seems wrong." : "Pēdējā fona darba palaišana aizņēma {relativeTime}. Kaut kas škiet nepareizi.",
     "Check the background job settings" : "Pārmainīt fona darbu iestatījumus",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Šim serverim nav interneta savienojuma. Tas nozīmē, ka daži līdzekļi, piemēram, ārējās atmiņas montēšana vai trešās puses lietotņu paziņojumi par atjauninājumiem nedarbosies. Iespējams nedarbosies attālināti piekļūt datnēm un nosūtīt paziņojumus uz e-pastu. Izveido interneta savienojumu ar serveri, lai visas funkcijas darbotos.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Tas ir īpaši ieteicams, ja, izmantojot darbvirsmas klientu, lai veiktu failu sinhronizāciju.",
     "Error occurred while checking server setup" : "Radās kļūda, pārbaudot servera ",
     "Non-existing tag #{tag}" : "Neeksistējošs tags #{tag}",
     "restricted" : "ierobežots",
@@ -118,8 +120,12 @@ OC.L10N.register(
     "No" : "Nē",
     "Yes" : "Jā",
     "No files in here" : "Šeit nav datņu",
+    "New folder" : "Jauna mape",
     "No more subfolders in here" : "Šeit nav vairāk apakšmapju",
+    "Name" : "Vārds",
     "Size" : "Izmērs",
+    "Modified" : "Mainīts",
+    "{newName} already exists" : "{newName} jau eksistē",
     "Choose" : "Izvēlieties",
     "Copy" : "Kopēt",
     "Move" : "Pārvietot",
@@ -205,7 +211,7 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
     "Two-factor authentication" : "Divpakāpju autentifikācija",
     "Use backup code" : "Izmantojiet dublēšanas kodu",
-    "Cancel log in" : "Atcelt pieteikšanos",
+    "Cancel login" : "Atcelt pieteikšanos",
     "Error while validating your second factor" : "Kļūda validējot jūsu otru faktoru.",
     "Access through untrusted domain" : "Piekļūt caur neuzticamu domēnu",
     "App update required" : "Lietotnei nepieciešama atjaunināšana",
@@ -277,6 +283,8 @@ OC.L10N.register(
     "No users or groups found for {search}" : "Pēc  {search} netika atrasts neviens lietotājs vai grupa",
     "No users found for {search}" : "Pēc  {search} netika atrasts neviens lietotājs",
     "An error occurred. Please try again" : "Notika kļūda. Mēģini vēlreiz.",
+    "Home" : "Sākums",
+    "Work" : "Darbs",
     "Other" : "Cits",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Koplietot",
@@ -289,6 +297,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "Priekš lielākām instalācijām mēs iesakām izvēlēties citu datubāzes serveri.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Sevišķi, ja izmantojat darbvirsmas klientu datņu sinhronizācijai, SQLite izmantošana nav ieteicama.",
     "Wrong password." : "Nepareiza parole.",
-    "New Password" : "Jauna parole"
+    "New Password" : "Jauna parole",
+    "Cancel log in" : "Atcelt pieteikšanos"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
