@@ -157,7 +157,19 @@ OC.L10N.register(
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše súbory sú šifrované. Po obnovení hesla nebude možné dostať sa k vašim údajom. Ak neviete, čo robíte, kontaktujte vášho administrátora a až potom pokračujte. Naozaj chcete pokračovať?",
     "I know what I'm doing" : "Viem, čo robím",
     "Resetting password" : "Obnovuje sa heslo",
+    "Recommended apps" : "Odporúčané apky",
+    "Loading apps …" : "Načítavanie apiek...",
+    "Could not fetch list of apps from the app store." : "Nepodarilo sa načítať zoznam apiek z katalógu.",
+    "Installing apps …" : "Inštalácia apiek...",
+    "Nextcloud {app}" : "Nextcloud {app}",
+    "App download or installation failed" : "Nepodarilo sa prevziať alebo nainštalovať apku",
+    "Can't install this app because it is not compatible" : "Táto apka sa nedá nainštalovať, nie je kompatibilná",
+    "Can't install this app" : "Táto apka sa nedá nainštalovať",
     "Cancel" : "Zrušiť",
+    "Schedule work & meetings, synced with all your devices." : "Naplánujte si prácu a stretnutia, synchronizované so všetkými vašimi zariadeniami.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Udržujte si údaje o svojich kolegoch a priateľoch na jednom mieste bez hrozby úniku ich súkromných informácií tretím stranám.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednoduchá apka pre čítanie e-mailov, prepojená so Súbormi, Kontaktami a Kalendárom.",
+    "Screensharing, online meetings and web conferencing – on desktop and with mobile apps." : "Zdieľanie obrazovky, online schôdzky a webové konferencie - v PC a mobilných apkách.",
     "Forgot password?" : "Zabudli ste heslo?",
     "Settings" : "Nastavenia",
     "Could not load your contacts" : "Nie je možné načítať Vaše kontakty",
@@ -245,6 +257,7 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pre podrobnosti ako správne nakonfigurovať server si pozrite prosím <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentáciu</a>.",
     "Create an <strong>admin account</strong>" : "Vytvoriť <strong>administrátorský účet</strong>",
     "Username" : "Meno používateľa",
+    "Show password" : "Zobraziť heslo",
     "Storage & database" : "Úložisko & databáza",
     "Data folder" : "Priečinok dát",
     "Configure the database" : "Nastaviť databázu",
@@ -261,6 +274,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Ako databázu ste vybrali SQLite.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by sa malo používať len pre naozaj maličké alebo vývojové inštancie. Pre produkčné použitie výrazne odporúčame použiť robustnejšiu databázu.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ak používate klientské aplikácie pre synchronizáciu súborov, tak výrazne odporúčame nepoužívať SQLite.",
+    "Install recommended apps" : "Nainštalovať odporúčané apky",
     "Finish setup" : "Dokončiť inštaláciu",
     "Finishing …" : "Dokončujem...",
     "Need help?" : "Potrebujete pomoc?",
@@ -300,7 +314,7 @@ OC.L10N.register(
     "Set up two-factor authentication" : "Nastaviť dvojzložkové overovanie",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dvojfaktorová autentifikácia je vyžadovaná ale nebola nakonfigurovaná pre Váš účet.  Použite jeden zo záložných kódov na prihlásenie alebo kontaktujte administrátora pre ďalšiu asistenciu.",
     "Use backup code" : "Použiť záložný kód",
-    "Cancel log in" : "Zrušiť prihlásenie",
+    "Cancel login" : "Zruš prihlasovanie",
     "Setup two-factor authentication" : "Nastaviť dvojzložkové overovanie",
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "Pre váš účet je vynútená zvýšená bezpečnosť. Vyberte si poskytovateľa, ktorého chcete nastaviť:",
     "Error while validating your second factor" : "Chyba počas overovania druhého faktora",
@@ -414,6 +428,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Najmä pri používaní klientských aplikácií na synchronizáciu s desktopom neodporúčame používať SQLite.",
     "Wrong password." : "Nesprávne heslo.",
     "New Password" : "Nové heslo",
+    "Cancel log in" : "Zrušiť prihlásenie",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovenie hesla bol odoslaný na e-mailovú adresu uvedenú pre tento účet. Ak ho v krátkej dobe neobdržíte, skontrolujte si priečinok nevyžiadanej pošty a kôš.<br>Ak ho nenájdete, kontaktujte svojho správcu systému.",
     "Search globally" : "Hľadať globálne",
     "Your client should now be connected! You can close this window." : "Váš klient by mal byť pripojený. Toto okno už môžete zatvoriť."
