@@ -16,11 +16,14 @@ OC.L10N.register(
     "Crop is not square" : "Obrez ni pravokoten",
     "State token does not match" : "Žeton stanja ni skladen",
     "Could not complete login" : "Prijave ni mogoče dokončati",
+    "Your login token is invalid or has expired" : "Prijavni žeton je neveljaven, ali pa je že potekel.",
     "Password reset is disabled" : "Ponastavitev gesla je onemogočena",
     "Couldn't reset password because the token is invalid" : "Zaradi neustreznega žetona ni mogoče ponastaviti gesla.",
     "Couldn't reset password because the token is expired" : "Ni mogoče ponastaviti gesla, ker je žeton potekel.",
     "%s password reset" : "Ponastavitev gesla %s",
     "Password reset" : "Ponastavitev gesla",
+    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Za ponastavitev gesla kliknite na gumb. Če ponastavitve gesla niste zahtevali, prezrite to sporočilo.",
+    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Za ponastavitev gesla kliknite na povezavo. Če ponastavitve gesla niste zahtevali, prezrite to sporočilo.",
     "Reset your password" : "Ponastavi geslo",
     "Nextcloud Server" : "Strežnik Nextcloud",
     "Some of your link shares have been removed" : "Nekatere povezave za souporabo so bile odstranjene.",
@@ -43,7 +46,7 @@ OC.L10N.register(
     "Checking updates of apps" : "Poteka preverjanje za posodobitve programov",
     "Checking for update of app \"%s\" in appstore" : "Poteka preverjanje posodobitev za program »%s« v trgovini",
     "Update app \"%s\" from appstore" : "Posodobi program »%s« iz trgovine",
-    "Checked for update of app \"%s\" in appstore" : "Preverjena posodobitev za \"%s\" v trgovini",
+    "Checked for update of app \"%s\" in appstore" : "Preverjanje posodobitev za »%s« v trgovini",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke za %s mogoče posodobiti (trajanje posodobitve je odvisno od velikosti zbirke).",
     "Checked database schema update for apps" : "Izbrana posodobitev sheme podatkovne zbirke za programe",
     "Updated \"%1$s\" to %2$s" : "Posodabljanje »%1$s« na različico %2$s",
@@ -61,7 +64,20 @@ OC.L10N.register(
     "Strong password" : "Odlično geslo",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Spletni stražnik še ni ustrezno nastavljen in ne omogoča usklajevanja, saj je vmesnik WebDAV videti okvarjen.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Spletni strežnik ni ustrezno nastavljen za razreševanje naslova »{url}«. Več podrobnosti je zapisanih v <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaciji</a>.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Kaže, da okolje PHP ni ustrezno nastavljeno za poizvedovanje sistemskih spremenljivk. Preizkus z ukazom getegetenv(\"PATH\") vrne le prazen odziv.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Preverite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">namestitveno dokumentacijo ↗</a> za nastavitve PHP strežnika, še posebej, če uporabljate php-fpm.",
+    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Manjka modul PHP »fileinfo«. Priporočljivo je omogočiti ta modul za popolno zaznavanje vrst MIME.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ni mogoče izvesti opravila cron prek vmesnika ukazne vrstice. Pojavile so se tehnične napake:",
+    "Last background job execution ran {relativeTime}. Something seems wrong." : " Zadnje ozadnje izvajanje opravila je potekalo{ relativeTime}. Kaže, da je nekaj narobe.",
     "Check the background job settings" : "Preverite nastavitve ozadnjih opravil",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Strežnik je brez vzpostavljene internetne povezave. Več končnih točk ni mogoče doseči. To pomeni, da priklapljanje zunanjih diskov,  opozorila za posodobitve in namestitve programske opreme iz drugih virov, niso mogoče. Oddaljen dostop do datotek in pošiljanje obvesti najverjetneje prav tako ne deluje. Vzpostavite povezavo, da omogočite vso funkcionalnost.",
+    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Ni nastavljenega predpomnilnika. Za izboljšanje hitrosti delovanja je treba predpomnilnik memcache, če je na voljo, ustrezno nastaviti. Več podrobnosti je na voljo v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaciji</a>.",
+    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Iz varnostnih razlogov je priporočljivo nastaviti ustrezen vir za naključno ustvarjanje podatkov, ki ga uporablja PHP. Več podrobnosti je zavedenih v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaciji</a>.",
+    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Trenutno je zagnana različica PHP {version}. Priporočljivo je posodobiti sistem na najnovejšo različico in s tem namestiti <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">funkcijske in varnostne posodobitve delovanja, ki jih zagotavlja skupnost PHP</a>. Pakete je priporočljivo posodobiti takoj, ko so na voljo za nameščeno distribucijo.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Predpomnilnik memcached je nastavljen kot porazdeljen predpomnilnik, vendar pa je nameščen napačen modul PHP »memcache«. Modul \\OC\\Memcache\\Memcached podpirao le »memcached«, ne pa tudi »memcache«. Več podrobnosti za oba modula je zapisanih <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">na wiki straneh</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Nekatere datoteke ne opravijo preizkusa celovitosti. Več podrobnosti o težavi je opisanih v <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaciji</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Seznam neveljavnih datotek … </a>/ <a href=\"{rescanEndpoint}\">Ponovni preizkus …</a>)",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Manjka kazalo » {indexName} « v razpredelnici »{tableName}«.",
+    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Uporaba vgrajenega pošiljalnika pošte ni več podprta. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Posodobite nastavitve poštnega strežnika ↗<a/>.",
     "The PHP memory limit is below the recommended value of 512MB." : "Omejitev pomnilnika PHP je pod priporočljivo vrednostjo 512 MB.",
     "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
     "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
@@ -79,13 +95,13 @@ OC.L10N.register(
     "Hello {name}" : "Pozdravljeni, {name}",
     "new" : "novo",
     "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Posodobitev je v teku. Če zapustiš to stran, lahko, v določenih okoljih, prekineš proces",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "V teku je posodobitev. Odhod s te strani lahko v določenih okoljih prekine opravilo.",
     "Update to {version}" : "Posodobi na {version}",
     "An error occurred." : "Prišlo je do napake.",
     "Please reload the page." : "Stran je treba osvežiti.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
-    "Continue to Nextcloud" : "Nadaljuj na Nextcloud",
+    "Continue to Nextcloud" : "Nadaljuj v oblak Nextcloud",
     "Searching other places" : "Poteka iskanje na drugih mestih",
     "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} rezultat v drugih mapah","{count} rezultata v drugih mapah","{count} rezultatov v drugih mapah","{count} rezultatov v drugih mapah"],
@@ -110,6 +126,8 @@ OC.L10N.register(
     "New password" : "Novo geslo",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Datoteke so šifrirane. Če niste omogočili obnovitvenega ključa, po ponastavitvi gesla dostop do datotek ne bo več mogoč.<br />Če niste prepričani, kaj storiti, stopite v stik s skrbnikom sistema.<br />Ali res želite nadaljevati?",
     "I know what I'm doing" : "Vem, kaj delam!",
+    "Resetting password" : "Ponastavljanje gesla",
+    "Cancel" : "Prekliči",
     "Forgot password?" : "Ali ste pozabili geslo?",
     "Settings" : "Nastavitve",
     "Could not load your contacts" : "Stikov ni mogoče naložiti",
@@ -141,7 +159,6 @@ OC.L10N.register(
     "Already existing files" : "Obstoječe datoteke",
     "Which files do you want to keep?" : "Katere datoteke želite ohraniti?",
     "If you select both versions, the copied file will have a number added to its name." : "Če izberete obe različici, bo k imenu kopirane datoteke dodana številka.",
-    "Cancel" : "Prekliči",
     "Continue" : "Nadaljuj",
     "(all selected)" : "(vse izbrano)",
     "({count} selected)" : "({count} izbranih)",
@@ -165,6 +182,8 @@ OC.L10N.register(
     "Failed to create a project" : "Ustvarjanje projekta je spodletelo",
     "Failed to add the item to the project" : "Dodajanje predmeta k projektu je spodletelo.",
     "Connect items to a project to make them easier to find" : "Povežite predmete s projektom, da jih bo lažje najti.",
+    "Type to search for existing projects" : "Vpišite niz za iskanje obstoječih projektov",
+    "New in" : "Novo v",
     "View changelog" : "Poglej dnevnik sprememb",
     "No action available" : "Ni razpoložljivih dejanj",
     "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
@@ -175,8 +194,10 @@ OC.L10N.register(
     "Help" : "Pomoč",
     "Access forbidden" : "Dostop je prepovedan",
     "File not found" : "Datoteke ni mogoče najti",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Na strežniku ni mogoče najti dokumentacije. Morda je mesto souprabe izbrisano ali pa so potekla dovoljenja.",
     "Error" : "Napaka",
     "Internal Server Error" : "Notranja napaka strežnika",
+    "The server was unable to complete your request." : "Odziv strežnika kaže, da ni mogoče končati zahteve.",
     "More details can be found in the server log." : "Več podrobnosti je zabeleženih v dnevniški datoteki strežnika.",
     "Technical details" : "Tehnične podrobnosti",
     "Remote Address: %s" : "Oddaljen naslov: %s",
@@ -194,7 +215,7 @@ OC.L10N.register(
     "Storage & database" : "Shramba in podatkovna zbirka",
     "Data folder" : "Podatkovna mapa",
     "Configure the database" : "Nastavi podatkovno zbirko",
-    "Only %s is available." : "Le %s je na voljo.",
+    "Only %s is available." : "Na voljo je le %s.",
     "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
     "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
     "Database user" : "Uporabnik podatkovne zbirke",
@@ -202,34 +223,41 @@ OC.L10N.register(
     "Database name" : "Ime podatkovne zbirke",
     "Database tablespace" : "Razpredelnica podatkovne zbirke",
     "Database host" : "Gostitelj podatkovne zbirke",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Skupaj z imenom gostitelja je treba določiti tudi številko vrat (na primer localhost:5432).",
     "Performance warning" : "Opozorilo učinkovitosti delovanja",
+    "You chose SQLite as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite.",
     "Finish setup" : "Končaj nastavitev",
     "Finishing …" : "Poteka zaključevanje opravila ...",
     "Need help?" : "Ali potrebujete pomoč?",
     "See the documentation" : "Preverite dokumentacijo",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
+    "Get your own free account" : "Pridobite brezplačni račun",
+    "Skip to main content" : "Preskoči na glavno vsebino",
+    "Skip to navigation of app" : "Preskoči na program za krmarjenje",
     "More apps" : "Več programov",
     "More" : "Več",
     "More apps menu" : "Meni več programov",
     "Search" : "Poišči",
     "Reset search" : "Ponastavi iskanje",
     "Contacts" : "Stiki",
-    "Contacts menu" : "Meni Stiki",
+    "Contacts menu" : "Meni Stikov",
     "Settings menu" : "Meni nastavitev",
-    "Confirm your password" : "Potrdi svoje geslo",
+    "Confirm your password" : "Potrdite geslo",
     "Connect to your account" : "Povežite z računom",
-    "App token" : "Ključ aplikacije",
+    "App token" : "Žeton programa",
     "Grant access" : "Odobri dostop",
     "Account access" : "Dostop do računa",
     "Account connected" : "Račun je povezan",
+    "You can close this window." : "To okno lahko zaprete.",
     "This share is password-protected" : "To mesto je zaščiteno z geslom",
     "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
     "Two-factor authentication" : "Dvo-stopenjska overitev",
     "Set up two-factor authentication" : "Nastavitev dvostopenjske overitve",
     "Use backup code" : "Uporabi varnostno kopijo šifre",
-    "Cancel log in" : "Prekini prijavo",
+    "Cancel login" : "Prekliči prijavo",
     "Setup two-factor authentication" : "Nastavite dvostopenjsko overitev",
     "Error while validating your second factor" : "Napaka med preverjanjem drugega koraka",
+    "Access through untrusted domain" : "Dostop prek domene, ki ni zaupanja vredna",
     "App update required" : "Zahtevana je posodobitev programa",
     "%1$s will be updated to version %2$s" : "Okolje %1$s bo posodobljeno na različico %2$s",
     "These apps will be updated:" : "Posodobljeni bodo programi:",
@@ -240,7 +268,8 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
     "Detailed logs" : "Podrobni dnevniški zapisi",
     "Update needed" : "Zahtevana je posodobitev",
-    "Upgrade via web on my own risk" : "Posodobi preko spleta na moje tveganje",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Za pomoč si oglejte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacijo</a>.",
+    "Upgrade via web on my own risk" : "Posodobi prek spleta kljub večjemu tveganju",
     "Maintenance mode" : "Vzdrževalni način",
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v načinu vzdrževanja, kar lahko zadrži izvajanje postopka.",
     "This page will refresh itself when the instance is available again." : "Stran bo osvežena, ko bo vsebina spet na voljo.",
@@ -253,7 +282,7 @@ OC.L10N.register(
     "Sending email …" : "Poteka pošiljanje elektronske pošte ...",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Do spletišča je omogočen dostop prek protokola HTTP. Priporočljivo je omogočiti podporo za varni protokol HTTPS, kot je to opisano med <a href=\"{docUrl}\">varnostnimi namigi</a>.",
     "Shared" : "V souporabi",
-    "Shared with" : "V skupni rabi z",
+    "Shared with" : "V skupni rabi z uporabnikom",
     "Shared by" : "V souporabi od",
     "Choose a password for the public link" : "Izberite geslo za javno povezavo",
     "Choose a password for the public link or press the \"Enter\" key" : "Izberite geslo za javno povezavo ali pritisnite tipko »Enter«.",
@@ -284,6 +313,7 @@ OC.L10N.register(
     "Share to {name}" : "Omogoči souporabo z uporabnikom {name}",
     "Share link" : "Povezava do mape souporabe",
     "New share link" : "Nova povezava za souporabo",
+    "Created on {time}" : "Ustvarjeno {time}",
     "Could not unshare" : "Ni mogoče preklicati souporabe",
     "Shared with you and the group {group} by {owner}" : "{owner} omogoči souporabo z vami in s skupino {group}.",
     "Shared with you by {owner}" : "{owner} vam omogoči souporabo",
@@ -300,22 +330,27 @@ OC.L10N.register(
     "Can delete" : "Lahko izbriše",
     "Access control" : "Nadzor dostopa",
     "Error while sharing" : "Napaka med omogočanjem souporabe",
-    "Share details could not be loaded for this item." : "Podrobnosti souporabe za te predmet ni mogoče naložiti.",
-    "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin za {search}",
-    "No users found for {search}" : "Ni uporabnikov, skladnih z iskalnim nizom {search}",
+    "Share details could not be loaded for this item." : "Podrobnosti souporabe za ta predmet ni mogoče naložiti.",
+    "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin, skladnih z iskalnim nizom {search}",
+    "No users found for {search}" : "Ni najdenih uporabnikov, skladnih z iskalnim nizom {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Prišlo je do napake (»{message}«). Poskusite znova.",
     "An error occurred. Please try again" : "Prišlo je do napake. Poskusite znova.",
+    "Home" : "Začetni pogled",
+    "Work" : "Službeni naslov",
+    "Other" : "Drugo",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Souporaba",
     "Name or email address..." : "Ime ali elektronski naslov ...",
-    "Name or federated cloud ID..." : "Ime ali ID oblaka...",
-    "Name, federated cloud ID or email address..." : "Ime, ID oblaka ali e-poštni naslov...",
+    "Name or federated cloud ID..." : "Ime ali ID zveznega oblaka ...",
+    "Name, federated cloud ID or email address..." : "Ime, ID zveznega oblaka ali elektronski naslov ...",
     "Name..." : "Ime ...",
     "Error removing share" : "Napaka odstranjevanja souporabe",
     "SQLite will be used as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite.",
     "For larger installations we recommend to choose a different database backend." : "Za večje namestitve je priporočljivo uporabiti drug ozadnji program zbirke podatkov.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, še posebej če se sistem krajevno usklajuje z namizjem prek odjemalca.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, še posebej, če se sistem krajevno usklajuje z namizjem prek odjemalca.",
     "Wrong password." : "Napačno geslo!",
     "New Password" : "Novo geslo",
+    "Cancel log in" : "Prekini prijavo",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Povezava za ponastavitev gesla je bila poslana na nam poznan elektronski naslov za ta račun. V kolikor sporočila ne prejmete v kratkem, preverite tudi mapo neželene pošte.<br> Če sporočila ni niti v tej mapi, stopite v stik s skrbnikom."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
