@@ -23,6 +23,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klikoni butonin më poshtë për të rivendosur fjalëkalimin tuaj. Nëse nuk keni kërkuar rivendosjen e fjalëkalimit, atëherë injorojeni këtë email.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klikoni ne 'link-un' e rradhes per te rivendosur fjalekalimin tuaj.Nese nuk e keni vendosur akoma fjalekalimin atehere mos e merrni parasysh kete email.",
     "Reset your password" : "Rivendosni nje fjalekalim te ri",
+    "Nextcloud Server" : "Server Nextcloud",
     "Preparing update" : "Duke përgatitur përditësimin",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Ju lutemi, përdorni përditësuesin e rreshtit të urdhrave, sepse përditësimi i vetvetishëm është i çaktivizuar te config.php.",
@@ -52,6 +53,11 @@ OC.L10N.register(
     "So-so password" : "Fjalëkalim çka",
     "Good password" : "Fjalëkalim i mirë",
     "Strong password" : "Fjalëkalim i fortë",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP-ja nuk duket të jetë ngritur si duhet për të kërkuar ndryshore mjedisi sistemi. Testi me getenv(\"PATH\") kthen vetëm një përgjigje të zbrazët.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza juaj e të dhënave nuk ekzekutohet me nivelin \"READ COMMITED\" e izolimit për ndërveprimet. Kjo mund të shkaktojë probleme, kur kryhen paralelisht disa veprime njëherësh.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nuk ishte e mundur që të ekzekutohej puna cron nëpërmjet CLI. Gabimet teknike në vijim janë shfaqur :",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite po përdoret si bazë të dhënash e programit klient. Për instalime më të ngarkuara, këshillojmë të kalohet në një program tjetër klient baze të dhënash.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Kjo është veçanërisht e rekomanduar gjatë  përdorimit  të desktopit të klientit për sinkronizimin skedari. ",
     "Error occurred while checking server setup" : "Ndodhi një gabim gjatë kontrollit të rregullimit të shërbyesit",
     "Non-existing tag #{tag}" : "Etiketë #{tag} që s’ekziston",
     "restricted" : "e kufizuar",
@@ -88,12 +94,14 @@ OC.L10N.register(
     "Password" : "Fjalëkalim",
     "Log in" : "Hyni",
     "Logging in …" : "Duke u loguar ...",
+    "Wrong username or password." : "Emër përdoruesi ose fjalëkalim i gabuar.",
     "User disabled" : "Përdorues i çaktivizuar",
     "Reset password" : "Ricaktoni fjalëkalimin",
     "Couldn't send reset email. Please contact your administrator." : "S’u dërgua dot email-i i ricaktimit. Ju lutemi, lidhuni me përgjegjësin tuaj.",
     "Password can not be changed. Please contact your administrator." : "Fjalëkalimi nuk mund të ndryshohet. Ju lutemi, lidhuni me përgjegjësin tuaj.",
     "New password" : "Fjalëkalim i ri",
     "I know what I'm doing" : "E di se ç’bëj",
+    "Cancel" : "Anuloje",
     "Forgot password?" : "Keni harruar fjalëkalimin?",
     "Settings" : "Rregullime",
     "Search contacts …" : "Kërko kontakte ...",
@@ -104,6 +112,11 @@ OC.L10N.register(
     "No" : "Jo",
     "Yes" : "Po",
     "No files in here" : "Jo skedar këtu",
+    "New folder" : "Dosje e re",
+    "Name" : "Emri",
+    "Size" : "Madhësi",
+    "Modified" : "Modifikuar ",
+    "{newName} already exists" : "{newName} ekziston tashmë",
     "Choose" : "Zgjidhni",
     "Copy" : "Kopjo",
     "Move" : "Lëvize",
@@ -117,7 +130,6 @@ OC.L10N.register(
     "Already existing files" : "Kartela ekzistuese",
     "Which files do you want to keep?" : "Cilat kartela doni të mbani?",
     "If you select both versions, the copied file will have a number added to its name." : "Nëse përzgjidhni të dy versionet, kartelës së kopjuar do t’i shtohet një numër në emrin e saj.",
-    "Cancel" : "Anuloje",
     "Continue" : "Vazhdo",
     "(all selected)" : "(krejt të përzgjedhurat)",
     "({count} selected)" : "({count} të përzgjedhura)",
@@ -131,6 +143,7 @@ OC.L10N.register(
     "seconds ago" : "sekonda më parë",
     "Connection to server lost" : "Lidhja me serverin u shkëput",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem gjatë ngarkimit të faqes, rifreskimi në %n sekonda","Problem gjatë ngarkimit të faqes, rifreskimi në %n sekonda"],
+    "Hide details" : "Fsheh detajet",
     "New in" : "I ri në ",
     "No action available" : "Jo veprim i mundur",
     "Error fetching contact actions" : "Gabim gjatë marrjes së veprimeve të kontaktit",
@@ -176,6 +189,7 @@ OC.L10N.register(
     "See the documentation" : "Shihni dokumentimin",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ky aplikacion lyp JavaScript për punim të saktë. Ju lutemi, {linkstart}aktivizoni JavaScript-in{linkend} dhe ringarkoni faqen.",
     "More apps" : "Më shumë aplikacione",
+    "More" : "More",
     "Search" : "Kërko",
     "Contacts" : "Kontaktet",
     "Contacts menu" : "Menuja e kontakteve",
@@ -183,10 +197,12 @@ OC.L10N.register(
     "Confirm your password" : "Konfrimoni fjalëkalimin tuaj",
     "Connect to your account" : "Lidhuni me llogarinë tuaj",
     "App token" : "Çelës identifikues i API-t",
+    "Grant access" : "Akordoji hyrje",
+    "This share is password-protected" : "Kjo pjesë është e mbrojtur me fjalëkalim",
     "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
     "Two-factor authentication" : "Verifikim dy-element",
     "Use backup code" : "Përdorni kodin e kopjes rezervë",
-    "Cancel log in" : "Anuloni identifikimin",
+    "Cancel login" : "Anuloje hyrjen",
     "Error while validating your second factor" : "Gabim gjatë verifikimit të elementit të dytë",
     "App update required" : "Lypset përditësim aplikacioni",
     "These apps will be updated:" : "Do të përditësohen këto aplikacione:",
@@ -213,11 +229,13 @@ OC.L10N.register(
     "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
     "Choose a password for the public link or press the \"Enter\" key" : "Zgjidhni një fjalëkalim për lidhjen publike ose shtypni butonin \"Enter\"",
     "Copied!" : "U kopjua!",
+    "Copy link" : "Kopjo linkun",
     "Not supported!" : "Jo i përshtatshëm!",
     "Press ⌘-C to copy." : "Shtyp ⌘-C për të kopjuar.",
     "Press Ctrl-C to copy." : "Shtypni Ctrl-C për të kopjuar.",
     "Resharing is not allowed" : "Nuk lejohen rindarjet",
     "Link" : "Lidhje",
+    "Hide download" : "Fshih shkarkimin",
     "Password protect" : "Mbroje me fjalëkalim",
     "Allow editing" : "Lejo përpunim",
     "Email link to person" : "Dërgoja personit lidhjen me email",
@@ -228,6 +246,7 @@ OC.L10N.register(
     "Set expiration date" : "Caktoni datë skadimi",
     "Expiration" : "Skadim",
     "Expiration date" : "Datë skadimi",
+    "Note to recipient" : "Shënim për marrësin",
     "Unshare" : "Hiqe ndarjen",
     "Share to {name}" : "Ndaj tek {name}",
     "Share link" : "Lidhje ndarjeje",
@@ -253,6 +272,9 @@ OC.L10N.register(
     "No users or groups found for {search}" : "S’u gjetën përdorues ose grupe për {search}",
     "No users found for {search}" : "S’u gjet përdorues për {search}",
     "An error occurred. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
+    "Home" : "Kryefaqja",
+    "Work" : "Punë",
+    "Other" : "Tjetër",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Ndaje",
     "Name or email address..." : "Emri ose adresa e email-it",
@@ -264,6 +286,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "Për instalime më të mëdha këshillojmë të zgjidhni një tjetër program shërbyesi baze të dhënash.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Përdorimi i SQLite-it shkëshillohet veçanërisht, kur për njëkohësim kartelash përdoret klienti desktop.",
     "Wrong password." : "Fjalëkalim i gabuar.",
-    "New Password" : "Fjalëkalim i Ri"
+    "New Password" : "Fjalëkalim i Ri",
+    "Cancel log in" : "Anuloni identifikimin"
 },
 "nplurals=2; plural=(n != 1);");
