@@ -86,6 +86,7 @@ OC.L10N.register(
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Saknar index \"{indexName}\" i tabellen \"{tableName}\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen saknar några index. På grund av det faktum att lägga index på stora tabeller kan ta lite tid de inte sattes automatiskt. Genom att köra \"occ db: add-missing-index\" kan de saknade index läggas till manuellt medan instansen fortsätter att springa. När index läggs frågor till dessa tabeller är oftast mycket snabbare.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instansen saknar några rekommenderade PHP-moduler. För förbättrad prestanda och kompatibilitet är det starkt rekommenderat att installera dem.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite används som databas. För större installationer så rekommenderar vi ett byte till en annan databasbackend.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "Detta rekommenderas särskilt när du använder skrivbordsklienten för filsynkronisering.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "För att migrera till en annan databas använd kommandoradsverktyget: \"occ db:convert-type\", eller se <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentationen ↗</a>.",
     "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Användning av den inbyggda php mailer stöds inte längre. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Vänligen uppdatera inställningarna för din e-postserver ↗<a/>.",
@@ -143,15 +144,19 @@ OC.L10N.register(
     "Password can not be changed. Please contact your administrator." : "Lösenordet kan inte ändras. Vänligen kontakta din administratör.",
     "Back to login" : "Tillbaka till inloggning",
     "New password" : "Nytt lösenord",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka din data efter att ditt lösenord har återställs. Om du är osäker på hur du ska göra, kontakta din administratör innan du fortsätter. Är du verkligen säker på att du vill fortsätta?",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka dina data efter att ditt lösenord har återställs. Om du är osäker på hur du ska göra, kontakta din administratör innan du fortsätter. Är du verkligen säker på att du vill fortsätta?",
     "I know what I'm doing" : "Jag vet vad jag gör",
     "Resetting password" : "Återställer lösenord",
     "Recommended apps" : "Rekommenderade appar",
     "Loading apps …" : "Laddar appar …",
     "Cancel" : "Avbryt",
+    "Schedule work & meetings, synced with all your devices." : "Planera arbete och möten, synkronisera med alla dina enheter.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Håll dina kollegor och vänner på ett ställe utan att läcka deras privata info.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app integrerad med filer, kontakter och kalender.",
+    "Screensharing, online meetings and web conferencing – on desktop and with mobile apps." : "Skärmdelning, onlinemöten och webbkonferenser – på dator och med mobilappar.",
     "Forgot password?" : "Glömt lösenordet?",
     "Settings" : "Inställningar",
-    "Could not load your contacts" : "Kunde inte ladda dina kontakter",
+    "Could not load your contacts" : "Det gick inte att läsa in dina kontakter",
     "Search contacts …" : "Sök kontakter ...",
     "No contacts found" : "Inga kontakter hittades",
     "Show all contacts …" : "Visa alla kontakter ...",
@@ -283,13 +288,13 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Felaktigt lösenord. Försök igen.",
     "Two-factor authentication" : "Tvåfaktorsautentisering",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj en andra faktor för autentisering:",
-    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kunde inte ladda minst en av dina aktiverade inloggningsmetoder. Vänligen kontakta din systemadministratören.",
+    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Det gick inte att läsa in minst en av dina aktiverade tvåfaktorsautentiseringsmetoder. Vänligen kontakta din systemadministratören.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Kontakta din administratör för hjälp.",
     "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Fortsätt och konfigurera tvåfaktorsautentisering.",
     "Set up two-factor authentication" : "Ställ in tvåfaktorsautentisering",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Använd en av dina säkerhetskoder för att logga in eller kontakta din administratör för hjälp.",
     "Use backup code" : "Använd reservkod",
-    "Cancel log in" : "Avbryt inloggning",
+    "Cancel login" : "Avbryt inloggning",
     "Setup two-factor authentication" : "Ställ in tvåfaktorsautentisering",
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj vilken leverantör du vill konfigurera:",
     "Error while validating your second factor" : "Fel vid verifiering av tvåfaktorsautentisering.",
@@ -318,9 +323,10 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "Kunde inte skicka återställningsmejl. Vänligen kontrollera att ditt användarnamn är korrekt.",
     "Dismiss" : "Avfärda",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Länken för att återställa ditt lösenord har skickats till din e-post. Om du inte mottar något inom kort, kontrollera spam/skräpkorgen.<br>Om det inte finns något där, vänligen kontakta din lokala administratör.",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka din data efter att ditt lösenord om ditt lösenord återställs..<br />Om du är osäker på hur du ska göra, vänligen kontakta din administratör innan du fortsätter..<br />Är du verkligen säker på att du vill fortsätta?",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka dina data efter att ditt lösenord om ditt lösenord återställs..<br />Om du är osäker på hur du ska göra, vänligen kontakta din administratör innan du fortsätter..<br />Är du verkligen säker på att du vill fortsätta?",
     "Sending email …" : "Skickar epost ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} under version {version} är installerad, för stabilitet och prestanda rekommenderar vi uppdatering till en nyare {name} version.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Åtkomst till webbplatsen osäkert via HTTP. Du rekommenderas starkt att ställa in din server att kräva HTTPS istället, som beskrivs i <a href=\"{docUrl}\">säkerhetstips ↗</a>.",
     "Shared" : "Delad",
     "Shared with" : "Delad med",
     "Shared by" : "Delad av",
@@ -328,7 +334,7 @@ OC.L10N.register(
     "Choose a password for the public link or press the \"Enter\" key" : "Välj ett lösenord för den publika länken eller tryck Enter",
     "Copied!" : "Kopierad!",
     "Copy link" : "Kopiera länk",
-    "Not supported!" : "Stöds ej!",
+    "Not supported!" : "Stöds inte!",
     "Press ⌘-C to copy." : "Tryck ned ⌘-C för att kopiera.",
     "Press Ctrl-C to copy." : "Tryck ned Ctrl-C för att kopiera.",
     "Unable to create a link share" : "Kan inte skapa länkdelning",
@@ -402,6 +408,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Speciellt när skrivbordsklienten för filsynkronisering används så avråds användande av SQLite.",
     "Wrong password." : "Fel lösenord.",
     "New Password" : "Nytt lösenord",
+    "Cancel log in" : "Avbryt inloggning",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Vi har skickat ett mejl för lösenordsåterställning till den e-postadress som är känd för detta konto. Om du inte får det inom rimlig tid, kontrollera dina skräppost-mappar.<br>Om det inte är där, fråga din lokala administratör.",
     "Search globally" : "Sök globalt",
     "Your client should now be connected! You can close this window." : "Din klient ska nu vara ansluten! Du kan stänga det här fönstret."
