@@ -67,6 +67,8 @@ OC.L10N.register(
     "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "Модуль PHP OPCache не завантажений. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Для кращої продуктивності рекомендується</a> завантажити його у свою установку PHP.",
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "Модуль PHP OPcache налаштовано неправильно. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Для підвищення продуктивності рекомендується</a> використовувати наступні параметри у <code>php.ini</code>:",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Відсутній індекс \"{indexName}\" у таблиці \"{tableName}\".",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite в даний час використовується як база даних бекенда.  Для великих установок ми рекомендуємо перейти на інший тип серверу баз даних.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Це особливо рекомендується при використанні клієнтського ПК для синхронізації файлів.",
     "The PHP memory limit is below the recommended value of 512MB." : "Обсяг пам'яті PHP нижчий від рекомендованого значення 512 МБ.",
     "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
     "Non-existing tag #{tag}" : "Ця позначка відсутня #{tag}",
@@ -94,6 +96,7 @@ OC.L10N.register(
     "Continue to Nextcloud" : "Продовжити у Nextcloud",
     "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Оновлення успішне. Перенаправлення до Nextcloud через %n секунду.","Оновлення успішне. Перенаправлення до Nextcloud через %n секунди.","Оновлення успішне. Перенаправлення до Nextcloud через %n секунд.","Оновлення успішне. Перенаправлення до Nextcloud через %n секунд."],
     "Searching other places" : "Йде пошук в інших місцях",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Нічого не знайдено в інших каталогах за запитом {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} результат пошуку в інших теках","{count} результатів пошуку в інших теках","{count} результатів пошуку в інших теках","{count} результатів пошуку в інших теках"],
     "Server side authentication failed!" : "Невдала аутентифікація на стороні сервера!",
     "Please contact your administrator." : "Будь ласка, зверніться до вашого Адміністратора.",
@@ -232,7 +235,6 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
     "Two-factor authentication" : "Двофакторна аутентифікація",
     "Use backup code" : "Використати резервний код",
-    "Cancel log in" : "Скасувати вхід",
     "Setup two-factor authentication" : "Налаштувати двофакторну автентифікацію",
     "Access through untrusted domain" : "Доступ з не довіреного домену",
     "App update required" : "Додаток потребує оновлення",
@@ -338,6 +340,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Використання SQLite особливо не рекомендується при синхронізації файлів з використанням клієнта для ПК.",
     "Wrong password." : "Невірний пароль.",
     "New Password" : "Новий пароль",
+    "Cancel log in" : "Скасувати вхід",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Посилання для скидання вашого паролю було надіслано на ваш email. Якщо ви не отримали його найближчим часом, перевірте теку зі спамом.<br>Якщо і там немає, спитайте вашого місцевого адміністратора.",
     "Search globally" : "Шукати всюди",
     "Your client should now be connected! You can close this window." : "Тепер ваш клієнт під’єднано. Ви можете закрити це вікно."
