@@ -95,6 +95,7 @@ OC.L10N.register(
     "Back to login" : "Quay lại trang đăng nhập",
     "New password" : "Mật khẩu mới",
     "I know what I'm doing" : "Tôi biết tôi đang làm gì",
+    "Cancel" : "Hủy",
     "Forgot password?" : "Quên mật khẩu sao?",
     "Settings" : "Cài đặt",
     "Could not load your contacts" : "Không thể tải liên hệ của bạn",
@@ -106,6 +107,11 @@ OC.L10N.register(
     "No" : "Không",
     "Yes" : "Có",
     "No files in here" : "Không có file nào ở đây",
+    "New folder" : "Tạo thư mục",
+    "Name" : "Tên",
+    "Size" : "Kích cỡ",
+    "Modified" : "Thay đổi",
+    "{newName} already exists" : "{newName} đã có",
     "Choose" : "Chọn",
     "Copy" : "Sao chép",
     "Move" : "Chuyển",
@@ -119,7 +125,6 @@ OC.L10N.register(
     "Already existing files" : "Các file đang tồn tại",
     "Which files do you want to keep?" : "Bạn muốn tiếp tục với những tập tin nào?",
     "If you select both versions, the copied file will have a number added to its name." : "Nếu bạn chọn cả hai phiên bản, tập tin được sao chép sẽ được đánh thêm số vào tên của nó.",
-    "Cancel" : "Hủy",
     "Continue" : "Tiếp tục",
     "(all selected)" : "(Tất cả các lựa chọn)",
     "({count} selected)" : "({count} được chọn)",
@@ -181,6 +186,7 @@ OC.L10N.register(
     "See the documentation" : "Xem tài liệu",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ứng dụng này yêu cầu JavaScript để hoạt động chính xác. Vui lòng {linkstart} bật JavaScript {linkend} và tải lại trang.",
     "More apps" : "Thêm ứng dụng",
+    "More" : "hơn",
     "More apps menu" : "Nhiều trình đơn ứng dụng hơn",
     "Search" : "Tìm kiếm",
     "Reset search" : "Đặt lại tìm kiếm",
@@ -190,11 +196,11 @@ OC.L10N.register(
     "Confirm your password" : "Xác nhận mật khẩu của bạn",
     "Connect to your account" : "Kết nối tài khoản của bạn",
     "App token" : "Dấu hiệu ứng dụng",
+    "Grant access" : "Cấp quyền truy cập",
     "Account access" : "Truy cập tài khoản",
     "The password is wrong. Try again." : "Sai mật khẩu. Hãy thử lại.",
     "Two-factor authentication" : "Xác thực 2 bước",
     "Use backup code" : "Sử dụng mã dự phòng",
-    "Cancel log in" : "Hủy đăng nhập",
     "Error while validating your second factor" : "Lỗi khi xác thực 2 bước",
     "Access through untrusted domain" : "Truy nhập thông qua tên miền không đáng tin",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Xin vui lòng liên hệ với quản trị hệ thống của bạn. Nếu ban là người quản trị hệ thống, sửa phần thiết lập \"trusted_domains\" trong file config/config.php giống như trong ví dụ tại file config.sample.php.",
@@ -225,6 +231,7 @@ OC.L10N.register(
     "Choose a password for the public link" : "Chọn mật khẩu cho liên kết công khai",
     "Choose a password for the public link or press the \"Enter\" key" : "Chọn một mật khẩu cho liên kết công cộng hoặc nhấn phím \"Enter\"",
     "Copied!" : "Được sao chép",
+    "Copy link" : "Sao chép liên kết",
     "Not supported!" : "Không được hỗ trợ",
     "Press ⌘-C to copy." : "Nhất  ⌘-C để sao chép",
     "Press Ctrl-C to copy." : "Nhấn Ctrl-C để sao chép.",
@@ -267,6 +274,9 @@ OC.L10N.register(
     "No users found for {search}" : "Không tìm thấy người dùng cho {search}",
     "An error occurred (\"{message}\"). Please try again" : "Đã xảy ra lỗi (\"{message}\"). Hãy thử lại",
     "An error occurred. Please try again" : "Có lỗi vừa xảy ra. Xin vui lòng thử lại",
+    "Home" : "Trang nhất",
+    "Work" : "Công việc",
+    "Other" : "Khác",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
     "Share" : "Chia sẻ",
     "Name or email address..." : "Tên hoặc địa chỉ email.",
@@ -278,6 +288,7 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "Đối với các cài đặt hệ thống lớn, chúng tôi khuyên bạn nên chọn một hệ cơ sở dữ liệu khác.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Đặc biệt khi đang sử dụng phần mềm đồng bộ dữ liệu desktop client  để đồng bộ file thì việc sử dụng CSDL SQLite là không nên.",
     "Wrong password." : "Sai mật khẩu.",
-    "New Password" : "Mật khẩu mới"
+    "New Password" : "Mật khẩu mới",
+    "Cancel log in" : "Hủy đăng nhập"
 },
 "nplurals=1; plural=0;");
