@@ -148,7 +148,7 @@ OC.L10N.register(
     "User disabled" : "用户不可用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到您的 IP 进行了多次无效登录尝试。因此，请 30 秒之后再尝试。",
     "Reset password" : "重置密码",
-    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "密码重置的电子邮件发送到此帐户的电子邮件地址。 如果您未在合理的时间内收到，请优先检查您的垃圾邮件/垃圾邮件文件夹。如果不存在此电子邮件，请咨询系统管理员。",
+    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "密码重置的电子邮件发送到此账号的电子邮件地址。 如果您未在合理的时间内收到，请优先检查您的垃圾邮件/垃圾邮件文件夹。如果不存在此电子邮件，请咨询系统管理员。",
     "If it is not there ask your local administrator." : "如果它不在此处，请询问您的本地管理员。",
     "Couldn't send reset email. Please contact your administrator." : "未能成功发送重置邮件，请联系管理员。",
     "Password can not be changed. Please contact your administrator." : "无法修改密码，请联系管理员。",
@@ -169,7 +169,7 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "安排工作和会议，并与您的所有设备同步。",
     "Keep your colleagues and friends in one place without leaking their private info." : "将您的同事和朋友放在一个地方，而不会泄漏他们的私人信息。",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "简单的电子邮件应用程序与文件，联系人和日历完美集成。",
-    "Screensharing, online meetings and web conferencing – on desktop and with mobile apps." : "屏幕共享，在线会议和网络会议 – 在桌面和移动应用程序上。",
+    "Screensharing, online meetings and web conferencing – on desktop and with mobile apps." : "屏幕共享，线上见面和网络会议 – 在桌面和移动应用程序上。",
     "Forgot password?" : "忘记密码？",
     "Settings" : "设置",
     "Could not load your contacts" : "无法加载您的联系人",
@@ -282,7 +282,7 @@ OC.L10N.register(
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "看起来您正在尝试重新安装您的Nextcloud。但您的config文件夹中没有CAN_INSTALL文件。请在您的config文件夹中创建CAN_INSTALL文件以继续。",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "无法从config文件夹中移除CAN_INSTALL文件。请手动移除此文件。",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "对于正确的操作，该应用需要使用 JavaScript。请 {linkstart}启用 JavaScript{linkend}，并重新加载页面。",
-    "Get your own free account" : "获取自己的免费账户",
+    "Get your own free account" : "获取自己的免费账号",
     "Skip to main content" : "跳过主内容",
     "Skip to navigation of app" : "跳过应用向导",
     "More apps" : "更多的应用程序",
@@ -294,29 +294,29 @@ OC.L10N.register(
     "Contacts menu" : "联系人菜单",
     "Settings menu" : "设置菜单",
     "Confirm your password" : "确认您的密码",
-    "Connect to your account" : "连接您的账户",
-    "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的 %2$s 账户之前，请先登录。",
+    "Connect to your account" : "连接到您的账号",
+    "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的账号 %2$s 之前，请先登录。",
     "App token" : "App 令牌",
     "Grant access" : "授权访问",
     "Alternative log in using app token" : "使用应用程序令牌替代登录",
-    "Account access" : "账户访问",
-    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的 %2$s 账户。",
+    "Account access" : "账号访问",
+    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的账号 %2$s 。",
     "Account connected" : "账号已连接",
     "Your client should now be connected!" : "您的客户端现在应该可以连接了！",
     "You can close this window." : "您可以关闭此窗口。",
     "This share is password-protected" : "这个共享是被密码保护的",
     "The password is wrong. Try again." : "密码错误。请重试。",
     "Two-factor authentication" : "两步验证",
-    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的账户已启用安全增强。请选择第二种验证方式。",
+    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的账号已启用安全增强。请选择第二种验证方式。",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "无法载入您启用的任何两步验证方法。请联系管理员。",
-    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "两步验证是强制性的，但您的账户似乎未做配置。请联系管理员获得支持。",
-    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "两步验证是强制性的，但您的账户未做配置。请联系管理员配置两步验证。",
+    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "已强制执行两步验证，但尚未在您的账号上对其进行配置。 请与您的管理员联系以获取帮助。",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "已强制执行两步验证，但尚未在您的账号上对其进行配置。 请继续设置两步验证。",
     "Set up two-factor authentication" : "配置两步验证",
-    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "两步验证是强制性的，但您的账户似乎未做配置。使用您的备份代码登录或联系管理员。",
+    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "已强制执行两步验证，但尚未在您的账号上对其进行配置。 使用您的备用验证码之一登录或与管理员联系以获取帮助。",
     "Use backup code" : "使用备用口令",
-    "Cancel log in" : "取消登录",
+    "Cancel login" : "取消登录",
     "Setup two-factor authentication" : "配置两步验证",
-    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的账户已启用安全增强。请选择提供者进行配置：",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的账号将获得增强的安全性。 选择要设置的提供者：",
     "Error while validating your second factor" : "验证您的第二项时出错",
     "Access through untrusted domain" : "通过不被信任的域名访问",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "请联系您的管理员。如果您就是管理员，请参照 config.sample.php 中的示例编辑 config/config.php 中的  \"trusted_domains\" 设置。",
@@ -397,7 +397,7 @@ OC.L10N.register(
     "email" : "邮件",
     "conversation" : "对话",
     "shared by {sharer}" : "由 {sharer} 共享",
-    "Can reshare" : "允许重新分享",
+    "Can reshare" : "允许重新共享",
     "Can edit" : "可以编辑",
     "Can create" : "可以创建",
     "Can change" : "可以修改",
@@ -428,7 +428,8 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特别当使用桌面客户端来同步文件时，不鼓励使用 SQLite。",
     "Wrong password." : "密码错误。",
     "New Password" : "新密码",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "我们已将密码重置电子邮件发送到我们已知道的此帐户的电子邮件地址。 如果您未在合理的时间内收到，请检查您的垃圾邮件/垃圾邮件文件夹。<br> 如果不存在，请咨询管理员。",
+    "Cancel log in" : "取消登录",
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "我们已将密码重置电子邮件发送到我们已知道的此账号的电子邮件地址。 如果您未在合理的时间内收到，请检查您的垃圾邮件/垃圾邮件文件夹。<br> 如果不存在，请咨询管理员。",
     "Search globally" : "全局搜索",
     "Your client should now be connected! You can close this window." : "您的客户端现在应该可以连接了！您可以关闭这个窗口。"
 },
