@@ -157,6 +157,19 @@ OC.L10N.register(
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "由於您已啟用檔案加密，重設密碼後，您的資料將無法解密。若您不確定繼續與否，請與管理員聯繫。確定要繼續嗎？",
     "I know what I'm doing" : "我知道我在幹嘛",
     "Resetting password" : "重設密碼",
+    "Recommended apps" : "推薦的應用程式",
+    "Loading apps …" : "正在載入應用程式…",
+    "Could not fetch list of apps from the app store." : "無法從應用程式商店抓取應用程式清單",
+    "Installing apps …" : "正在安裝應用程式…",
+    "Nextcloud {app}" : "Nextcloud {app}",
+    "App download or installation failed" : "應用程式下載或是安裝失敗",
+    "Can't install this app because it is not compatible" : "應用程式無法安裝，因為不相容",
+    "Can't install this app" : "無法安裝這個應用程式",
+    "Cancel" : "取消",
+    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
+    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
+    "Screensharing, online meetings and web conferencing – on desktop and with mobile apps." : "螢幕分享和線上會議—支援電腦和手機",
     "Forgot password?" : "忘記密碼？",
     "Settings" : "設定",
     "Could not load your contacts" : "無法載入您的聯絡人",
@@ -188,7 +201,6 @@ OC.L10N.register(
     "Already existing files" : "已經存在的檔案",
     "Which files do you want to keep?" : "您要保留哪一個檔案？",
     "If you select both versions, the copied file will have a number added to its name." : "如果您同時選擇兩個版本，被複製的那個檔案名稱後面會加上編號",
-    "Cancel" : "取消",
     "Continue" : "繼續",
     "(all selected)" : "（已全選）",
     "({count} selected)" : "（已選取 {count} 項）",
@@ -245,6 +257,7 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "閱讀<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明文件</a>來瞭解如何正確設定您的伺服器",
     "Create an <strong>admin account</strong>" : "新增<strong>管理者帳號</strong>",
     "Username" : "使用者名稱",
+    "Show password" : "顯示密碼",
     "Storage & database" : "儲存空間和資料庫",
     "Data folder" : "資料儲存位置",
     "Configure the database" : "設定資料庫",
@@ -261,6 +274,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "您選擇了 SQLite 作為資料庫",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或是開發用站台，針對上線服務我們建議使用其他資料庫後端。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若使用桌面版或是手機版客戶端同步檔案，不建議使用 SQLite",
+    "Install recommended apps" : "安裝推薦的應用程式",
     "Finish setup" : "完成設定",
     "Finishing …" : "即將完成…",
     "Need help?" : "需要協助嗎？",
@@ -300,7 +314,7 @@ OC.L10N.register(
     "Set up two-factor authentication" : "設定雙因素驗證",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "雙重認證已被強制要求啟用，您的帳號目前還沒設定。請使用一個備用碼來登入或聯絡管理員。",
     "Use backup code" : "使用備用認證碼",
-    "Cancel log in" : "取消登入",
+    "Cancel login" : "取消登入",
     "Setup two-factor authentication" : "設定雙因素驗證",
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的帳號已啟用進階安全機制，請選擇一個供應者：",
     "Error while validating your second factor" : "驗證二階段因子發生錯誤",
@@ -414,6 +428,7 @@ OC.L10N.register(
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "若使用桌面版程式同步檔案，不建議使用 SQLite",
     "Wrong password." : "密碼錯誤",
     "New Password" : "新密碼",
+    "Cancel log in" : "取消登入",
     "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "我們已將重設密碼的信件寄到這個帳號所對應的信箱。如果你在合理的時間內沒有收到，請至垃圾郵件中檢查，如果還是沒有，請聯絡管理員。",
     "Search globally" : "全域搜尋",
     "Your client should now be connected! You can close this window." : "您的客戶端應該已經完成連結，您可以關閉這個視窗"
