@@ -19,6 +19,7 @@ OC.L10N.register(
     "The command line tool %s could not be found" : "La ferramienta línea de comandu %s nun pudo alcontrase",
     "The library %s is not available." : "La librería %s nun ta disponible",
     "Following platforms are supported: %s" : "Les siguientes plataformes tan sofitaes: %s",
+    "Authentication" : "Autenticación",
     "Unknown filetype" : "Triba de ficheru desconocida",
     "Invalid image" : "Imaxe inválida",
     "Avatar image is not square" : "La imaxe del avatar nun ye cuadrada",
@@ -41,12 +42,15 @@ OC.L10N.register(
     "__language_name__" : "Asturianu",
     "Help" : "Ayuda",
     "Apps" : "Aplicaciones",
+    "Settings" : "Settings",
     "Log out" : "Zarrar sesión",
     "Users" : "Usuarios",
     "Unknown user" : "Usuariu desconocíu",
     "Basic settings" : "Axustes básicos",
+    "Sharing" : "Compartiendo",
     "Security" : "Seguranza",
     "Additional settings" : "Axustes adicionales",
+    "Personal info" : "Información personal",
     "%s enter the database username and name." : "%s introducir el nome d'usuariu y el nome de la base de datos .",
     "%s enter the database username." : "%s introducir l'usuariu de la base de datos.",
     "%s enter the database name." : "%s introducir nome de la base de datos.",
@@ -66,19 +70,36 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartíu %s tien d'implementar la interfaz OCP\\Share_Backend",
     "Sharing backend %s not found" : "Nun s'alcontró'l botón de compartición %s",
     "Sharing backend for %s not found" : "Nun s'alcontró'l botón de partición pa %s",
+    "Open »%s«" : "Abrir «%s»",
     "You are not allowed to share %s" : "Nun tienes permisu pa compartir %s",
     "Can’t increase permissions of %s" : "Nun pue aumentase los permisos de %s",
     "Files can’t be shared with delete permissions" : "Los ficheros nun puen compartise colos permisos de desaniciu",
     "Files can’t be shared with create permissions" : "Los ficheros nun puen compartise colos permisos de creación",
     "Expiration date is in the past" : "La data de caducidá ta nel pasáu.",
     "Can’t set expiration date more than %s days in the future" : "Nun pue afitase la data de caducidá más de %s díes nel futuru",
+    "Click the button below to open it." : "Primi'l botón d'embaxo p'abrilu.",
     "Could not find category \"%s\"" : "Nun pudo alcontrase la estaya \"%s.\"",
     "Sunday" : "Domingu",
     "Monday" : "Llunes",
+    "Tuesday" : "Martes",
+    "Wednesday" : "Miércoles",
+    "Thursday" : "Xueves",
     "Friday" : "Vienres",
     "Saturday" : "Sábadu",
+    "Sun." : "Dom.",
     "Mon." : "Llu.",
+    "Tue." : "Mar.",
+    "Wed." : "Mié.",
+    "Thu." : "Xue.",
+    "Fri." : "Vie.",
     "Sat." : "Sáb.",
+    "Su" : "Do",
+    "Mo" : "Ll",
+    "Tu" : "Ma",
+    "We" : "Mi",
+    "Th" : "Xu",
+    "Fr" : "Vi",
+    "Sa" : "Sá",
     "January" : "Xineru",
     "February" : "Febreru",
     "March" : "Marzu",
@@ -98,6 +119,7 @@ OC.L10N.register(
     "May." : "May.",
     "Jun." : "Xun.",
     "Jul." : "Xnt.",
+    "Aug." : "Ago.",
     "Sep." : "Set.",
     "Oct." : "Och.",
     "Nov." : "Pay.",
@@ -133,6 +155,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dablemente esto seya culpa d'un caché o acelerador, como por exemplu Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse los módulos PHP, ¿pero tán entá llistaos como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor, entruga al to alministrador pa reaniciar el sirvidor web.",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requeríu",
     "Please upgrade your database version" : "Por favor, anueva la versión de la to base de datos",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, camuda los permisos a 0770 pa que'l direutoriu nun pueda llistase por otros usuarios.",
     "Check the value of \"datadirectory\" in your configuration" : "Comprobar el valor del \"datadirectory\" na so configuración",
@@ -143,32 +166,24 @@ OC.L10N.register(
     "Storage connection error. %s" : "Fallu de conexón al almacenamientu. %s",
     "Storage is temporarily not available" : "L'almacenamientu ta temporalmente non disponible",
     "Storage connection timeout. %s" : "Tiempu escosao de conexón al almacenamientu. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Necesítase una librería %s con ua versión superior a %s - versión disponible %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Necesítase una librería %s con una versión anterior a %s - versión disponible %s.",
+    "Create" : "Crear",
+    "Change" : "Camudar",
+    "Delete" : "Desaniciar",
+    "Share" : "Share",
+    "Unlimited" : "Non llendáu",
+    "Verifying" : "Verificando",
+    "Verifying …" : "Verificando...",
+    "Verify" : "Verificar",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Compartir %s falló, por cuenta qu'el backend nun dexa acciones de tipu %i",
     "Sharing %s failed, because the file does not exist" : "Compartir %s falló, porque'l ficheru nun esiste",
     "Sharing %s failed, because you can not share with yourself" : "Compartir %s falló, porque nun puede compartise contigo mesmu",
-    "Sharing %s failed, because the user %s does not exist" : "Compartir %s falló, yá que l'usuariu %s nun esiste",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Compartir %s falló, yá que l'usuariu %s nun ye miembru de nengún de los grupos de los que ye miembru %s",
-    "Sharing %s failed, because this item is already shared with %s" : "Compartir %s falló, porque esti elementu yá ta compartiéndose con %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Compartir %s falló, porque esti elementu yá ta compartiéndose col usuariu %s",
-    "Sharing %s failed, because the group %s does not exist" : "Compartir %s falló, porque'l grupu %s nun esiste",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Compartir %s falló, porque %s nun ye miembru del grupu %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Necesites apurrir una contraseña pa crear un enllaz públicu, namái tan permitíos los enllaces protexíos",
     "Sharing %s failed, because sharing with links is not allowed" : "Compartir %s falló, porque nun se permite compartir con enllaces",
     "Not allowed to create a federated share with the same user" : "Nun s'almite crear un recursu compartíu federáu col mesmu usuariu",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Compartir %s falló, nun pudo atopase %s, pue qu'el servidor nun seya anguaño algamable.",
-    "Share type %s is not valid for %s" : "La triba de compartición %s nun ye válida pa %s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nun pue afitase la data de caducidá. Ficheros compartíos nun puen caducar dempués de %s de compartise",
     "Cannot set expiration date. Expiration date is in the past" : "Nun pue afitase la data d'espiración. La data d'espiración ta nel pasáu",
     "Sharing failed, because the user %s is the original sharer" : "Compartir falló, porque l'usuariu %s ye'l compartidor orixinal",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Compartir %s falló, porque los permisos perpasen los otorgaos a %s",
     "Sharing %s failed, because resharing is not allowed" : "Compartir %s falló, porque nun se permite la re-compartición",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Compartir %s falló porque'l motor compartíu pa %s podría nun atopar el so orixe",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Compartir %s falló, yá que'l ficheru nun pudo atopase na caché de ficheru",
-    "%s shared »%s« with you" : "%s compartió »%s« contigo",
-    "%s via %s" : "%s via %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'aplicación \"%s\" nun puede instalase porque les siguientes dependencies nun se cumplen: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requeríu"
+    "Sharing %s failed, because the file could not be found in the file cache" : "Compartir %s falló, yá que'l ficheru nun pudo atopase na caché de ficheru"
 },
 "nplurals=2; plural=(n != 1);");
