@@ -10,8 +10,12 @@ OC.L10N.register(
     "today" : "Bu gün",
     "seconds ago" : "saniyələr öncə",
     "__language_name__" : "Azərbaycan dili",
+    "Help" : "Kömək",
+    "Settings" : "Quraşdırmalar",
     "Users" : "İstifadəçilər",
     "Unknown user" : "Istifadəçi tanınmır ",
+    "Sharing" : "Paylaşılır",
+    "Personal info" : "Şəxsi məlumat",
     "%s enter the database username." : "Verilənlər bazası istifadəçi adını %s daxil et.",
     "%s enter the database name." : "Verilənlər bazası adını %s daxil et.",
     "Oracle connection could not be established" : "Oracle qoşulması alınmır",
@@ -19,12 +23,54 @@ OC.L10N.register(
     "Set an admin username." : "İnzibatçı istifadəçi adını təyin et.",
     "Set an admin password." : "İnzibatçı şifrəsini təyin et.",
     "You are not allowed to share %s" : "%s-in yayimlanmasına sizə izin verilmir",
+    "Sunday" : "Bazar",
+    "Monday" : "Bazar ertəsi",
+    "Tuesday" : "Çərşənbə axşamı",
+    "Wednesday" : "Çərşənbə",
+    "Thursday" : "Cümə axşamı",
+    "Friday" : "Cümə",
+    "Saturday" : "Şənbə",
+    "Sun." : "Baz.",
+    "Mon." : "Ber.",
+    "Tue." : "Çax.",
+    "Wed." : "Çər.",
+    "Thu." : "Cax.",
+    "Fri." : "Cüm.",
+    "Sat." : "Şnb.",
+    "January" : "Yanvar",
+    "February" : "Fevral",
+    "March" : "Mart",
+    "April" : "Aprel",
+    "May" : "May",
+    "June" : "İyun",
+    "July" : "İyul",
+    "August" : "Avqust",
+    "September" : "Sentyabr",
+    "October" : "Oktyabr",
+    "November" : "Noyabr.",
+    "December" : "Dekabr",
+    "Jan." : "Yan.",
+    "Feb." : "Fev.",
+    "Mar." : "Mar.",
+    "Apr." : "Apr.",
+    "May." : "May.",
+    "Jun." : "İyn.",
+    "Jul." : "İyl.",
+    "Aug." : "Avq.",
+    "Sep." : "Sen.",
+    "Oct." : "Okt.",
+    "Nov." : "Noy.",
+    "Dec." : "Dek.",
     "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir",
     "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
     "Application is not enabled" : "Proqram təminatı aktiv edilməyib",
     "Authentication error" : "Təyinat metodikası",
     "Token expired. Please reload page." : "Token vaxtı bitib. Xahiş olunur səhifəni yenidən yükləyəsiniz.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu ola bilər ki, cache/accelerator such tərəfindən cağırılıb hansi ki, Zend OPcache və eAccelerator-da olduğu kimidir.",
+    "Create" : "Yarat",
+    "Delete" : "Sil",
+    "Share" : "Paylaş",
+    "Unlimited" : "Limitsiz",
     "Sharing %s failed, because the file does not exist" : "%s yayımlanmasında səhv baş verdi ona görə ki, fayl mövcud deyil."
 },
 "nplurals=2; plural=(n != 1);");
