@@ -113,7 +113,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you and wants to add" : "%1$s us ha compartit »%2$s« i vol afegir",
     "»%s« added a note to a file shared with you" : "»%s« ha afegit una anotació a un fitxer amb qui teniu compartit",
     "Open »%s«" : "Obre »%s«",
-    "%1$s via %2$s" : "%1$s via %2$s",
+    "%1$s via %2$s" : "%1$s mitjançant %2$s",
     "You are not allowed to share %s" : "No se us permet compartir %s",
     "Can’t increase permissions of %s" : "No es poden augmentar els permisos de %s",
     "Files can’t be shared with delete permissions" : "No es poden compartir els fitxers amb permisos de supressió",
