@@ -66,6 +66,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["Vor %n Minute","Vor %n Minuten"],
     "in a few seconds" : "in wenigen Sekunden",
     "seconds ago" : "Gerade eben",
+    "Empty file" : "Leere Datei",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Das Modul mit der ID:  %s existiert nicht. Bitte aktivieren Sie es in Ihren Einstellungen oder kontaktieren Sie Ihren Administrator.",
     "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
     "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
@@ -119,7 +120,7 @@ OC.L10N.register(
     "Files can’t be shared with delete permissions" : "Dateien mit Lösch-Berechtigungen können nicht geteilt werden",
     "Files can’t be shared with create permissions" : "Dateien mit Erstell-Berechtigungen können nicht geteilt werden",
     "Expiration date is in the past" : "Das Ablaufdatum liegt in der Vergangenheit.",
-    "Can’t set expiration date more than %s days in the future" : "Das Ablaufdatum kann nicht mehr als %s Tage in die Zukunft liegen",
+    "Can’t set expiration date more than %s days in the future" : "Das Ablaufdatum kann nicht mehr als %s Tage in der Zukunft liegen",
     "%1$s shared »%2$s« with you" : "%1$s hat »%2$s« mit Ihnen geteilt",
     "%1$s shared »%2$s« with you." : "%1$s hat »%2$s« mit Ihnen geteilt.",
     "Click the button below to open it." : "Klicken Sie zum Öffnen auf die untere Schaltfläche.",
@@ -174,6 +175,7 @@ OC.L10N.register(
     "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
     "Username contains whitespace at the beginning or at the end" : "Der Benutzername enthält Leerzeichen am Anfang oder am Ende",
     "Username must not consist of dots only" : "Der Benutzername darf nicht nur aus Punkten bestehen",
+    "Username is invalid because files already exist for this user" : "Der Benutzer ist ungültig, da bereits Dateien von diesem Benutzer existieren",
     "A valid password must be provided" : "Es muss ein gültiges Passwort eingegeben werden",
     "The username is already being used" : "Dieser Benutzername existiert bereits",
     "Could not create user" : "Benutzer konnte nicht erstellt werden",
@@ -207,7 +209,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
     "Please ask your server administrator to restart the web server." : "Bitte kontaktieren Sie Ihren Server-Administrator und bitten Sie um den Neustart des Webservers.",
-    "PostgreSQL >= 9.5 required" : "PostgreSQL >= 9.5 benötigt",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 benötigt",
     "Please upgrade your database version" : "Bitte aktualisieren Sie Ihre Datenbankversion",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bitte ändern Sie die Berechtigungen auf 0770, so dass das Verzeichnis nicht von anderen Benutzern angezeigt werden kann.",
     "Your data directory is readable by other users" : "Ihr Datenverzeichnis kann von anderen Benutzern gelesen werden",
@@ -226,8 +228,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Verbindungsfehler zum Speicherplatz. %s",
     "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Speicherplatz. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Die Bibliothek %s wird in einer neueren Version als %s benötigt - verfügbare Version ist %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Die Bibliothek %s wird in einer früheren Version als %s benötigt - verfügbare Version ist %s.",
     "Create" : "Erstellen",
     "Change" : "Ändern",
     "Delete" : "Löschen",
@@ -239,39 +239,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %i nicht erlaubt.",
     "Sharing %s failed, because the file does not exist" : "Freigabe von %s fehlgeschlagen, da die Datei nicht existiert",
     "Sharing %s failed, because you can not share with yourself" : "Freigabe von %s fehlgeschlagen, da das Teilen mit sich selbst nicht möglich ist",
-    "Sharing %s failed, because the user %s does not exist" : "Freigabe von %s fehlgeschlagen, da der Benutzer %s nicht existiert",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Freigabe von %s fehlgeschlagen, da der Benutzer %s kein Gruppenmitglied einer der Gruppen von %s ist",
-    "Sharing %s failed, because this item is already shared with %s" : "Freigabe von %s fehlgeschlagen, da dieses Element schon mit %s geteilt wird",
-    "Sharing %s failed, because this item is already shared with user %s" : "Freigabe von %s fehlgeschlagen, da dieses Element schon mit dem Benutzer %s geteilt wird",
-    "Sharing %s failed, because the group %s does not exist" : "Freigabe von %s fehlgeschlagen, da die Gruppe %s nicht existiert",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Freigabe von %s fehlgeschlagen, da %s kein Mitglied der Gruppe %s ist",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Es sind nur geschützte Links zulässig, daher müssen Sie ein Passwort angeben, um einen öffentlichen Link zu generieren",
-    "Sharing %s failed, because sharing with links is not allowed" : "Freigabe von %s fehlgeschlagen, da das Teilen von Verknüpfungen nicht erlaubt ist",
-    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated-Cloud-Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Freigabe von %s fehlgeschlagen, da %s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar.",
-    "Share type %s is not valid for %s" : "Freigabetyp %s ist nicht gültig für %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ablaufdatum kann nicht gesetzt werden. Freigaben können nach dem Teilen, nicht länger als %s gültig sein.",
-    "Cannot set expiration date. Expiration date is in the past" : "Ablaufdatum kann nicht gesetzt werden. Ablaufdatum liegt in der Vergangenheit.",
-    "Sharing failed, because the user %s is the original sharer" : "Freigabe fehlgeschlagen, da der Benutzer %s der ursprünglich Teilende ist",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Freigabe von %s fehlgeschlagen, da die Berechtigungen die erteilten Berechtigungen %s überschreiten",
-    "Sharing %s failed, because resharing is not allowed" : "Freigabe von %s fehlgeschlagen, da das nochmalige Freigeben einer Freigabe nicht erlaubt ist",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Freigabe von %s fehlgeschlagen, da das Freigabe-Backend für %s nicht in dieser Quelle gefunden werden konnte",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Freigabe von %s fehlgeschlagen, da die Datei im Datei-Cache nicht gefunden werden konnte",
-    "%s shared »%s« with you" : "%s hat „%s“ mit Ihnen geteilt",
-    "%s shared »%s« with you." : "%s hat mit Ihnen »%s« geteilt.",
-    "%s via %s" : "%s via %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Die App „%s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 benötigt",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "ID \"%s\" wird bereits von Cloud-Federation-Provider \"%s\" verwendet.",
     "Sharing %1$s failed, because the user %2$s does not exist" : "Freigabe von %1$s fehlgeschlagen, da der Benutzer %2$s nicht existiert",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Freigabe von %1$s fehlgeschlagen, da der Benutzer %2$s kein Mitglied einer der Gruppen von %3$s ist",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "Freigabe von %1$s fehlgeschlagen, da dieses Element schon mit %2$s geteilt wird",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "Freigabe von %1$s fehlgeschlagen, da dieses Element schon mit dem Benutzer %2$s geteilt wird",
     "Sharing %1$s failed, because the group %2$s does not exist" : "Freigabe von %1$s fehlgeschlagen, da die Gruppe %2$s nicht existiert",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Freigabe von %1$s fehlgeschlagen, da %2$s kein Mitglied der Gruppe %3$s ist",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Es sind nur geschützte Links zulässig, daher müssen Sie ein Passwort angeben, um einen öffentlichen Link zu generieren",
+    "Sharing %s failed, because sharing with links is not allowed" : "Freigabe von %s fehlgeschlagen, da das Teilen von Verknüpfungen nicht erlaubt ist",
+    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated-Cloud-Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Die Freigabe von %1$s ist fehlgeschlagen, da %2$s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar.",
     "Share type %1$s is not valid for %2$s" : "Freigabetyp %1$s ist nicht gültig für %2$s",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ablaufdatum kann nicht gesetzt werden. Freigaben können nach dem Teilen, nicht länger als %s gültig sein.",
+    "Cannot set expiration date. Expiration date is in the past" : "Ablaufdatum kann nicht gesetzt werden. Ablaufdatum liegt in der Vergangenheit.",
+    "Sharing failed, because the user %s is the original sharer" : "Freigabe fehlgeschlagen, da der Benutzer %s der ursprünglich Teilende ist",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Freigabe von %1$s fehlgeschlagen, da die Berechtigungen die erteilten Berechtigungen von %2$s überschreiten",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Freigabe von %1$s fehlgeschlagen, da das Freigabe-Backend für %2$s nicht in dieser Quelle gefunden werden konnte"
+    "Sharing %s failed, because resharing is not allowed" : "Freigabe von %s fehlgeschlagen, da das nochmalige Freigeben einer Freigabe nicht erlaubt ist",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Freigabe von %1$s fehlgeschlagen, da das Freigabe-Backend für %2$s nicht in dieser Quelle gefunden werden konnte",
+    "Sharing %s failed, because the file could not be found in the file cache" : "Freigabe von %s fehlgeschlagen, da die Datei im Datei-Cache nicht gefunden werden konnte"
 },
 "nplurals=2; plural=(n != 1);");
