@@ -25,6 +25,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Server version %s or higher is required.",
     "Server version %s or lower is required." : "Server version %s or lower is required.",
     "Logged in user must be an admin" : "Logged in user must be an admin",
+    "Authentication" : "Authentication",
     "Unknown filetype" : "Unknown filetype",
     "Invalid image" : "Invalid image",
     "Avatar image is not square" : "Avatar image is not square",
@@ -180,6 +181,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modules have been installed, but they are still listed as missing?",
     "Please ask your server administrator to restart the web server." : "Please ask your server administrator to restart the web server.",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 required",
     "Please upgrade your database version" : "Please upgrade your database version",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Please change the permissions to 0770 so that the directory cannot be listed by other users.",
     "Your data directory is readable by other users" : "Your data directory is readable by other users",
@@ -193,8 +195,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Storage connection error. %s",
     "Storage is temporarily not available" : "Storage is temporarily not available",
     "Storage connection timeout. %s" : "Storage connection timeout. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Library %s with a version higher than %s is required - available version %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Library %s with a version lower than %s is required - available version %s.",
     "Create" : "Create",
     "Change" : "Change",
     "Delete" : "Delete",
@@ -206,28 +206,13 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Sharing %s failed, because the backend does not allow shares from type %i",
     "Sharing %s failed, because the file does not exist" : "Sharing %s failed, because the file does not exist",
     "Sharing %s failed, because you can not share with yourself" : "Sharing %s failed, because you can not share with yourself",
-    "Sharing %s failed, because the user %s does not exist" : "Sharing %s failed, because the user %s does not exist",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of",
-    "Sharing %s failed, because this item is already shared with %s" : "Sharing %s failed, because this item is already shared with %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
-    "Sharing %s failed, because the group %s does not exist" : "Sharing %s failed, because the group %s does not exist",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Sharing %s failed, because %s is not a member of the group %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "You need to provide a password to create a public link, only protected links are allowed",
     "Sharing %s failed, because sharing with links is not allowed" : "Sharing %s failed, because sharing with links is not allowed",
     "Not allowed to create a federated share with the same user" : "Not allowed to create a federated share with the same user",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Sharing %s failed, could not find %s, maybe the server is currently unreachable.",
-    "Share type %s is not valid for %s" : "Share type %s is not valid for %s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Cannot set expiry date. Shares cannot expire later than %s after they have been shared",
     "Cannot set expiration date. Expiration date is in the past" : "Cannot set expiry date. Expiry date is in the past",
     "Sharing failed, because the user %s is the original sharer" : "Sharing failed, because the user %s is the original sharer",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Sharing %s failed, because the permissions exceed permissions granted to %s",
     "Sharing %s failed, because resharing is not allowed" : "Sharing %s failed, because resharing is not allowed",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Sharing %s failed, because the sharing backend for %s could not find its source",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Sharing %s failed, because the file could not be found in the file cache",
-    "%s shared »%s« with you" : "%s shared \"%s\" with you",
-    "%s shared »%s« with you." : "%s shared »%s« with you.",
-    "%s via %s" : "%s via %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 required"
+    "Sharing %s failed, because the file could not be found in the file cache" : "Sharing %s failed, because the file could not be found in the file cache"
 },
 "nplurals=2; plural=(n != 1);");
