@@ -23,6 +23,7 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
     "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
     "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
+    "Authentication" : "Autenticación",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
@@ -48,6 +49,7 @@ OC.L10N.register(
     "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, favor de no contestarlo. ",
     "Help" : "Ayuda",
     "Apps" : "Aplicaciones",
+    "Settings" : "Ajustes",
     "Log out" : "Cerrar sesión",
     "Users" : "Usuarios",
     "Unknown user" : "Ususario desconocido",
@@ -55,6 +57,7 @@ OC.L10N.register(
     "Sharing" : "Compartiendo",
     "Security" : "Seguridad",
     "Additional settings" : "Configuraciones adicionales",
+    "Personal info" : "Información Personal",
     "%s enter the database username and name." : "%s ingrese el nombre del usuario y nombre de la base de datos",
     "%s enter the database username." : "%s ingresar el nombre de usuario de la base de datos.",
     "%s enter the database name." : "%s ingresar el nombre de la base de datos",
@@ -74,8 +77,10 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
+    "Open »%s«" : "Abrir »%s«",
     "You are not allowed to share %s" : "No tiene permitido compartir %s",
     "Expiration date is in the past" : "La fecha de expiración ya ha pasado",
+    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
     "Sunday" : "Domingo",
     "Monday" : "Lunes",
@@ -157,6 +162,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
     "Please ask your server administrator to restart the web server." : "Favor de solicitar al administrador reiniciar el servidor web. ",
+    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
     "Please upgrade your database version" : "Favor de actualizar la versión de la base de datos",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Favor de cambiar los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
     "Your data directory is readable by other users" : "Su direcctorio data puede ser leído por otros usuarios",
@@ -169,32 +175,24 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "Se agotó el tiempo de conexión del almacenamiento. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "La biblitoteca %s con una versión superiror a la %s es requerida - versión disponible %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Se requiere de la biblioteca %s con una versión inferiror a la %s - la versión %s está disponible. ",
+    "Create" : "Crear",
+    "Change" : "Cambiar",
+    "Delete" : "Eliminar",
+    "Share" : "Compartir",
+    "Unlimited" : "Ilimitado",
+    "Verifying" : "Verificando",
+    "Verifying …" : "Verificando ...",
+    "Verify" : "Verificar",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Se presentó una falla al compartir %s, porque el backend no permite elementos compartidos de tipo %i",
     "Sharing %s failed, because the file does not exist" : "Se presentó una falla al compartir %s porque el archivo no existe",
     "Sharing %s failed, because you can not share with yourself" : "Se presento una falla al compartir %s, porque no puede compartir con usted mismo",
-    "Sharing %s failed, because the user %s does not exist" : "Se presentó una falla al compartir %s porque el usuario %s no existe",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Se presentó una falla al compartir %s proque el usuario %s no es un miembro de ninguno de los grupos de los cuales %s es miembro",
-    "Sharing %s failed, because this item is already shared with %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
-    "Sharing %s failed, because the group %s does not exist" : "Se presentó una falla al compartir %s, porque el grupo %s no existe",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Se presentó una falla al compartir %s debido a que %s no es un miembro del grupo %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Usted necesita proporcionar una contraseña para crear un link público, sólo los links protegidos están permitidos. ",
     "Sharing %s failed, because sharing with links is not allowed" : "Se presentó una falla al compartir %s porque no está permitido compartir con links",
     "Not allowed to create a federated share with the same user" : "No está permitido crear un elemento compartido federado con el mismo usuario",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Se presentó una falla al compartir %s, no fue posible encontrar %s, tal vez el servidor sea inalcanzable por el momento",
-    "Share type %s is not valid for %s" : "El tipo del elemento compartido %s no es válido para %s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No ha sido posible establecer la fecha de expiración. Los recursos compartidos no pueden expirar después de %s tras haber sido compartidos",
     "Cannot set expiration date. Expiration date is in the past" : "No ha sido posible establecer la fecha de expiración. La fecha de expiración ya ha pasado",
     "Sharing failed, because the user %s is the original sharer" : "Se presento una falla al compartir, porque el usuario %s es quien compartió originalmente",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Se presentó una falla al compartir %s, porque los permisos exceden los permisos otorgados a %s",
     "Sharing %s failed, because resharing is not allowed" : "Falla al compartir %s debído a que no se permite volver a compartir",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se presentó una falla al compartir  %s porque el backend que comparte %s no pudo encontrar su origen",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Se presentó una falla al compartir %s porque el archivo no se encontró en el caché de archivos",
-    "%s shared »%s« with you" : "%s ha compartido  »%s« con usted",
-    "%s via %s" : "%s por %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La aplicación \"%s\" no puede ser instalada porque las siguientes dependencias no están satisfechas: %s ",
-    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9"
+    "Sharing %s failed, because the file could not be found in the file cache" : "Se presentó una falla al compartir %s porque el archivo no se encontró en el caché de archivos"
 },
 "nplurals=2; plural=(n != 1);");
