@@ -25,6 +25,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
     "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
     "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
+    "Authentication" : "Autenticación",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
@@ -180,6 +181,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor solicita al administrador reiniciar el servidor web. ",
+    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
     "Please upgrade your database version" : "Por favor actualiza tu versión de la base de datos",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
     "Your data directory is readable by other users" : "Tu direcctorio data puede ser leído por otros usuarios",
@@ -193,8 +195,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "La biblitoteca %s con una versión superiror a la %s es requerida - versión disponible %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Se requiere de la biblioteca %s con una versión inferiror a la %s - la versión %s está disponible. ",
     "Create" : "Crear",
     "Change" : "Cambiar",
     "Delete" : "Borrar",
@@ -206,28 +206,13 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Se presentó una falla al compartir %s, porque el backend no permite elementos compartidos de tipo %i",
     "Sharing %s failed, because the file does not exist" : "Se presentó una falla al compartir %s porque el archivo no existe",
     "Sharing %s failed, because you can not share with yourself" : "Se presentó una falla al compartir %s, porque no puedes compartir contigo mismo",
-    "Sharing %s failed, because the user %s does not exist" : "Se presentó una falla al compartir %s porque el usuario %s no existe",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Se presentó una falla al compartir %s porque el usuario %s no es un miembro de ninguno de los grupos de los cuales %s es miembro",
-    "Sharing %s failed, because this item is already shared with %s" : "Se presentó una falla al compartir %s, porque este elemento ya había sido compartido con %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
-    "Sharing %s failed, because the group %s does not exist" : "Se presentó una falla al compartir %s, porque el grupo %s no existe",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Se presentó una falla al compartir %s debido a que %s no es un miembro del grupo %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Necesitas proporcionar una contraseña para crear una liga pública, sólo se permiten ligas protegidas. ",
     "Sharing %s failed, because sharing with links is not allowed" : "Se presentó una falla al compartir %s porque no está permitido compartir con ligas",
     "Not allowed to create a federated share with the same user" : "No está permitido crear un elemento compartido con el mismo usuario",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Se presentó una falla al compartir %s, no fue posible encontrar %s, tal vez el servidor sea inalcanzable por el momento",
-    "Share type %s is not valid for %s" : "El tipo del elemento compartido %s no es válido para %s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No ha sido posible establecer la fecha de expiración. Los recursos compartidos no pueden expirar después de %s tras haber sido compartidos",
     "Cannot set expiration date. Expiration date is in the past" : "No ha sido posible establecer la fecha de expiración. La fecha de expiración ya ha pasado",
     "Sharing failed, because the user %s is the original sharer" : "Se presentó una falla al compartir, porque el usuario %s es quien compartió originalmente",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Se presentó una falla al compartir %s, porque los permisos exceden los permisos otorgados a %s",
     "Sharing %s failed, because resharing is not allowed" : "Falla al compartir %s debído a que no se permite volver a compartir",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Se presentó una falla al compartir  %s porque el backend que comparte %s no pudo encontrar su origen",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Se presentó una falla al compartir %s porque el archivo no se encontró en el caché de archivos",
-    "%s shared »%s« with you" : "%s ha compartido  »%s« contigo",
-    "%s shared »%s« with you." : "%s compartió contigo »%s«.",
-    "%s via %s" : "%s por %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "La aplicación \"%s\" no puede ser instalada porque las siguientes dependencias no están satisfechas: %s ",
-    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9"
+    "Sharing %s failed, because the file could not be found in the file cache" : "Se presentó una falla al compartir %s porque el archivo no se encontró en el caché de archivos"
 },
 "nplurals=2; plural=(n != 1);");
