@@ -24,6 +24,7 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
     "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
     "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
+    "Authentication" : "Autenticación",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
@@ -191,6 +192,10 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
+    "Create" : "Crear",
+    "Change" : "Cambiar",
+    "Delete" : "Borrar",
+    "Share" : "Compartir",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verficando",
     "Verifying …" : "Verficando ...",
