@@ -18,6 +18,7 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Toetatud on järgnevad platformid: %s",
     "Server version %s or higher is required." : "Serveri versioon %s või kõrgem on nõutav.",
     "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
+    "Authentication" : "Autentimine",
     "Unknown filetype" : "Tundmatu failitüüp",
     "Invalid image" : "Vigane pilt",
     "Avatar image is not square" : "Avatari pilt pole ruut",
@@ -147,9 +148,14 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
     "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 on nõutav",
     "Please upgrade your database version" : "Palun uuenda oma andmebaasi versiooni",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
     "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
+    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
+    "Create" : "Loo",
+    "Delete" : "Kustuta",
+    "Share" : "Jaga",
     "Unlimited" : "Piiramatult",
     "Verifying" : "Kontrollin",
     "Verifying …" : "Kontrollin ...",
@@ -157,28 +163,13 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "%s jagamine ebaõnnestus sest server ei luba %i tüüpi jagamisi",
     "Sharing %s failed, because the file does not exist" : "%s jagamine ebaõnnestus, kuna faili pole olemas",
     "Sharing %s failed, because you can not share with yourself" : "%s jagamine ebaõnnestus, kuna sa ei saa jagada iseendaga",
-    "Sharing %s failed, because the user %s does not exist" : "%s jagamine ebaõnnestus, kuna kasutajat %s pole olemas",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s jagamine ebaõnnestus, kuna kasutaja %s pole ühegi grupi liige, millede liige on %s",
-    "Sharing %s failed, because this item is already shared with %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud kasutajaga %s",
-    "Sharing %s failed, because the group %s does not exist" : "%s jagamine ebaõnnestus, kuna gruppi %s pole olemas",
-    "Sharing %s failed, because %s is not a member of the group %s" : "%s jagamine ebaõnnestus, kuna %s pole grupi %s liige",
     "You need to provide a password to create a public link, only protected links are allowed" : "Avaliku viite tekitamiseks pead sisestama parooli, ainult kaitstud viited on lubatud",
     "Sharing %s failed, because sharing with links is not allowed" : "%s jagamine ebaõnnestus, kuna linkidega jagamine pole lubatud",
     "Not allowed to create a federated share with the same user" : "Liitjagamise loomine sama kasutajaga ei ole lubatud.",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s jagamine ebaõnnestus, ei suutnud %s leida, ehk ei ole server hetkel kättesaadav.",
-    "Share type %s is not valid for %s" : "Jagamise tüüp %s ei ole õige %s jaoks",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Aegumise kuupäeva ei saa määrata. Jagamised ei saa aeguda hiljem kui %s peale jagamist.",
     "Cannot set expiration date. Expiration date is in the past" : "Aegumiskuupäeva ei saa määrata. Aegumise kuupäev on minevikus",
     "Sharing failed, because the user %s is the original sharer" : "Jagamine ebaõnnestus kuna kasutaja %s on algne jagaja",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s jagamine ebaõnnestus, kuna antud õigused ületavad %s jaoks määratud õigusi",
     "Sharing %s failed, because resharing is not allowed" : "%s jagamine ebaõnnestus, kuna edasijagamine pole lubatud",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s jagamine ebaõnnestus, kuna jagamise tagarakend ei suutnud leida %s jaoks lähteallikat",
-    "Sharing %s failed, because the file could not be found in the file cache" : "%s jagamine ebaõnnestus, kuna faili ei suudetud leida failide puhvrist",
-    "%s shared »%s« with you" : "%s jagas sinuga »%s«",
-    "%s shared »%s« with you." : "%s jagas »%s« sinuga.",
-    "%s via %s" : "%s läbi %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Rakendust \"%s\" ei saa paigaldada sest järgmised sõltuvused ei ole täidetud: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 on nõutav"
+    "Sharing %s failed, because the file could not be found in the file cache" : "%s jagamine ebaõnnestus, kuna faili ei suudetud leida failide puhvrist"
 },
 "nplurals=2; plural=(n != 1);");
