@@ -66,6 +66,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["il y a %n minute","il y a %n minutes"],
     "in a few seconds" : "dans quelques secondes",
     "seconds ago" : "il y a quelques secondes",
+    "Empty file" : "Fichier vide",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Le module avec l'ID: %s n'existe pas. Merci de l'activer dans les paramètres d'applications ou de contacter votre administrateur.",
     "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
     "File name contains at least one invalid character" : "Le nom de fichier contient un (des) caractère(s) non valide(s)",
@@ -174,6 +175,7 @@ OC.L10N.register(
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
     "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
     "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
+    "Username is invalid because files already exist for this user" : "Ce nom d'utilisateur n'est pas valide car des fichiers existent déjà pour cet utilisateur",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
     "Could not create user" : "Impossible de créer l'utilisateur",
@@ -207,7 +209,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Les modules PHP ont été installés mais sont toujours indiqués comme manquants ?",
     "Please ask your server administrator to restart the web server." : "Veuillez demander à votre administrateur serveur de redémarrer le serveur web.",
-    "PostgreSQL >= 9.5 required" : "PostgreSQL version >= 9.5 requise",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
     "Please upgrade your database version" : "Veuillez mettre à jour votre gestionnaire de base de données",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
     "Your data directory is readable by other users" : "Votre répertoire est lisible par les autres utilisateurs",
@@ -226,8 +228,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "La librairie %s doit être au moins à la version %s. Version disponible : %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "La librairie %s doit avoir une version antérieure à %s. Version disponible : %s.",
     "Create" : "Créer",
     "Change" : "Modifier",
     "Delete" : "Supprimer",
@@ -239,39 +239,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Le partage de %s a échoué car l’infrastructure n'autorise pas les partages de type %i",
     "Sharing %s failed, because the file does not exist" : "Le partage de %s a échoué car le fichier n'existe pas",
     "Sharing %s failed, because you can not share with yourself" : "Le partage de %s a échoué car vous ne pouvez pas partager avec vous-même",
-    "Sharing %s failed, because the user %s does not exist" : "Le partage de %s a échoué car l'utilisateur %s n'existe pas",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Le partage de %s a échoué car l'utilisateur %s n'est membre d'aucun groupe auquel %s appartient",
-    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet objet est déjà partagé avec %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec l'utilisateur %s",
-    "Sharing %s failed, because the group %s does not exist" : "Le partage de %s a échoué car le groupe %s n'existe pas",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Le partage de %s a échoué car %s n'est pas membre du groupe %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Vous devez fournir un mot de passe pour créer un lien public, seuls les liens protégés sont autorisées.",
-    "Sharing %s failed, because sharing with links is not allowed" : "Le partage de %s a échoué car le partage par lien n'est pas permis",
-    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Le partage de %s a échoué : impossible de trouver %s. Peut-être le serveur est-il momentanément injoignable.",
-    "Share type %s is not valid for %s" : "Le type de partage %s n'est pas valide pour %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Impossible de configurer la date d'expiration. Un partage ne peut expirer plus de %s après sa création",
-    "Cannot set expiration date. Expiration date is in the past" : "Impossible de configurer la date d'expiration : elle est dans le passé.",
-    "Sharing failed, because the user %s is the original sharer" : "Le partage a échoué car l'utilisateur %s est le propriétaire original",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Le partage de %s a échoué car les permissions dépassent celles accordées à %s",
-    "Sharing %s failed, because resharing is not allowed" : "Le partage de %s a échoué car le repartage n'est pas autorisé",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Le partage de %s a échoué car le service %s n'a pas trouvé sa source..",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Le partage de %s a échoué car le fichier n'a pas été trouvé dans les fichiers mis en cache.",
-    "%s shared »%s« with you" : "%s a partagé «%s» avec vous",
-    "%s shared »%s« with you." : "%s a partagé «%s» avec vous.",
-    "%s via %s" : "%s via %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "L'identifiant \"%s\" est déjà utilisé par le fournisseur de cloud \"%s\"",
     "Sharing %1$s failed, because the user %2$s does not exist" : "Le partage de %1$s a échoué car l'utilisateur %2$s n'existe pas",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Le partage de %1$s a échoué car l'utilisateur %2$s n'est membre d'aucun groupe auquel %3$s appartient",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "Le partage de %1$s a échoué car cet élément est déjà partagé avec %2$s",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "Le partage de %1$s a échoué car cet élément est déjà partagé avec l'utilisateur %2$s",
     "Sharing %1$s failed, because the group %2$s does not exist" : "Le partage de %1$s a échoué car le groupe %2$s n'existe pas",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Le partage de %1$s a échoué car %2$s n'est pas membre du groupe %3$s",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Vous devez fournir un mot de passe pour créer un lien public, seuls les liens protégés sont autorisées.",
+    "Sharing %s failed, because sharing with links is not allowed" : "Le partage de %s a échoué car le partage par lien n'est pas permis",
+    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Le partage de %1$s a échoué : impossible de trouver %2$s. Le serveur est peut-être momentanément injoignable.",
     "Share type %1$s is not valid for %2$s" : "Le type de partage %1$s n'est pas valide pour %2$s",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Impossible de configurer la date d'expiration. Un partage ne peut expirer plus de %s après sa création",
+    "Cannot set expiration date. Expiration date is in the past" : "Impossible de configurer la date d'expiration : elle est dans le passé.",
+    "Sharing failed, because the user %s is the original sharer" : "Le partage a échoué car l'utilisateur %s est le propriétaire original",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Le partage de %1$s a échoué car les permissions dépassent celles accordées à %2$s",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Le partage de %1$s a échoué car le service %2$s n'a pas trouvé sa source.."
+    "Sharing %s failed, because resharing is not allowed" : "Le partage de %s a échoué car le repartage n'est pas autorisé",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Le partage de %1$s a échoué car le service %2$s n'a pas trouvé sa source..",
+    "Sharing %s failed, because the file could not be found in the file cache" : "Le partage de %s a échoué car le fichier n'a pas été trouvé dans les fichiers mis en cache."
 },
 "nplurals=2; plural=(n > 1);");
