@@ -66,6 +66,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["hai %n minuto","hai %n minutos"],
     "in a few seconds" : "en poucos segundos",
     "seconds ago" : "segundos atrás",
+    "Empty file" : "Ficheiro baleiro",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte co administrador.",
     "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
     "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
@@ -174,6 +175,7 @@ OC.L10N.register(
     "A valid username must be provided" : "Debe fornecer un nome de usuario correcto",
     "Username contains whitespace at the beginning or at the end" : "O nome de usuario contén un espazo en branco no inicio ou no final",
     "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
+    "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
     "A valid password must be provided" : "Debe fornecer un contrasinal",
     "The username is already being used" : "Este nome de usuario xa está a ser usado",
     "Could not create user" : "Non foi posíbel crear o usuario",
