@@ -25,6 +25,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "נדרשת גרסה שרת %s ומעלה.",
     "Server version %s or lower is required." : "נדרשת גרסה שרת %s ומטה.",
     "Logged in user must be an admin" : "על המשתמש שנכנס להיות מנהל",
+    "Authentication" : "אימות",
     "Unknown filetype" : "סוג קובץ לא מוכר",
     "Invalid image" : "תמונה לא חוקית",
     "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
@@ -181,6 +182,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
     "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
+    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
     "Please upgrade your database version" : "יש לשדרג את גרסת מסד הנתונים שלך",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
     "Your data directory is readable by other users" : "תיקיית הנתונים שלך ניתנת לקריאה על ידי משתמשים אחרים",
@@ -197,8 +199,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
     "Storage is temporarily not available" : "האחסון אינו זמין כרגע",
     "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "ספריה %s בגרסה גבוהה מ- %s נדרשת - גרסה זמינה %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "ספריה %s בגרסה נמוכה מ- %s נדרשת - גרסה זמינה %s.",
     "Create" : "יצירה",
     "Change" : "שינוי",
     "Delete" : "מחיקה",
@@ -210,29 +210,15 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "השיתוף %s נכשל, כיוון שהצד האחורי אינו מאפשר שיתופים מסוג %i",
     "Sharing %s failed, because the file does not exist" : "השיתוף %s נכשל, כיוון שהקובץ אינו קיים",
     "Sharing %s failed, because you can not share with yourself" : "השיתוף %s נכשל, כיוון שלא ניתן לשתף עם עצמך",
-    "Sharing %s failed, because the user %s does not exist" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו קיים",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו חבר בקבוצות ש- %s חבר ב-",
-    "Sharing %s failed, because this item is already shared with %s" : "שיתוף %s נכשל, כיוון שפריט זה כבר משותף עם %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
-    "Sharing %s failed, because the group %s does not exist" : "השיתוף %s נכשל, כיוון שהקבוצה %s אינה קיימת",
-    "Sharing %s failed, because %s is not a member of the group %s" : "השיתוף %s נכשל, כיוון ש- %s אינו חבר בקבוצה %s",
+    "Sharing %1$s failed, because the user %2$s does not exist" : "השיתוף של %1$s נכשל כיוון שהמשתמש %2$s אינו קיים",
+    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "השיתוף של %1$s נכשל, כיוון שהמשתמש %2$s אינו חבר בקבוצות באף קבוצה בה יש ל־%3$s חברות בה",
     "You need to provide a password to create a public link, only protected links are allowed" : "יש לספק סיסמא ליצירת קישור ציבורי, רק קישורים מוגנים מותרים",
     "Sharing %s failed, because sharing with links is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף עם קישור אינו מותר",
     "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "שיתוף %s נכשל, לא ניתן לאתר %s, ייתכן שהשרת לא ניתן להשגה כרגע.",
-    "Share type %s is not valid for %s" : "שיתוף מסוג %s אינו תקף ל- %s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "לא ניתן לקבוע תאריך תפוגה. שיתופים אינם יכולים לפוג תוקף מאוחר יותר מ- %s לאחר ששותפו",
     "Cannot set expiration date. Expiration date is in the past" : "לא ניתן לקבוע תאריך תפוגה. תאריך התפוגה הנו בעבר",
     "Sharing failed, because the user %s is the original sharer" : "שיתוף נכשל, כיוון שמשתמש %s הנו המשתף המקורי",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "השיתוף %s נכשל, כיוון שההרשאות עלו על ההרשאות שניתנו ל- %s",
     "Sharing %s failed, because resharing is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף מחודש אסור",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "השיתוף %s נכשל, כיוון שבצד אחורי לשיתוף עבור %s לא ניתן היה לאתר את מקורו",
-    "Sharing %s failed, because the file could not be found in the file cache" : "השיתוף %s נכשל, כייון שלא ניתן היה למצוא את הקובץ בזכרון המטמון",
-    "%s shared »%s« with you" : "%s שיתף/שיתפה איתך את »%s«",
-    "%s via %s" : "%s על בסיס %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "היישום \"%s\" לא ניתן להתקנה כיוון שיחסי התלות הבאים אינם מתקיימים: %s",
-    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
-    "Sharing %1$s failed, because the user %2$s does not exist" : "השיתוף של %1$s נכשל כיוון שהמשתמש %2$s אינו קיים",
-    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "השיתוף של %1$s נכשל, כיוון שהמשתמש %2$s אינו חבר בקבוצות באף קבוצה בה יש ל־%3$s חברות בה"
+    "Sharing %s failed, because the file could not be found in the file cache" : "השיתוף %s נכשל, כייון שלא ניתן היה למצוא את הקובץ בזכרון המטמון"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
