@@ -29,6 +29,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "%s vagy újabb szerver verzió szükséges.",
     "Server version %s or lower is required." : "%s vagy régebbi szerver verzió szükséges.",
     "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
+    "Authentication" : "Hitelesítés",
     "Unknown filetype" : "Ismeretlen fájl típus",
     "Invalid image" : "Hibás kép",
     "Avatar image is not square" : "Az avatár kép nem négyzetes.",
@@ -192,6 +193,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár ill. kódgyorsító, mint pl, a Zend, OPcache vagy eAccelererator okozza.",
     "PHP modules have been installed, but they are still listed as missing?" : "A PHP modulok telepítve vannak, de a listában mégsincsenek felsorolva?",
     "Please ask your server administrator to restart the web server." : "Kérje meg a rendszergazdát, hogy indítsa újra a webszervert!",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 szükséges",
     "Please upgrade your database version" : "Kérem frissítse az adatbázis-szoftvert!",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Kérjük módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználó ne listázhassa!",
     "Your data directory is readable by other users" : "Az adatkönyvtárad mások által olvasható",
@@ -210,8 +212,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tároló kapcsolódási hiba. %s",
     "Storage is temporarily not available" : "A tároló átmenetileg nem érthető el",
     "Storage connection timeout. %s" : "Tároló kapcsolat időtúllépés. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "%s könyvtár %s vagy újabb verziója szükséges - elérhető verzió: %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "%s könyvtár %s vagy régebbi verziója szükséges - elérhető verzió: %s.",
     "Create" : "Létrehozás",
     "Change" : "Változtatás",
     "Delete" : "Törlés",
@@ -223,39 +223,23 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "%s megosztása sikertelen, mert a megosztási alrendszer nem engedi a %l típus megosztását",
     "Sharing %s failed, because the file does not exist" : "%s megosztása sikertelen, mert a fájl nem létezik",
     "Sharing %s failed, because you can not share with yourself" : "%s megosztása sikertelen, mert magaddal nem oszthatod meg",
-    "Sharing %s failed, because the user %s does not exist" : "%s megosztása nem sikerült, mert %s felhasználó nem létezik",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja egyik olyan csoportnak sem, aminek %s tagja",
-    "Sharing %s failed, because this item is already shared with %s" : "%s megosztása nem sikerült, mert ez már meg van osztva %s-vel",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s megosztása sikertelen, mert már meg van osztva %s felhasználóval",
-    "Sharing %s failed, because the group %s does not exist" : "%s megosztása nem sikerült, mert %s csoport nem létezik",
-    "Sharing %s failed, because %s is not a member of the group %s" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja a %s csoportnak",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Meg kell adnia egy jelszót is, mert a nyilvános hivatkozások csak jelszóval védetten használhatók",
-    "Sharing %s failed, because sharing with links is not allowed" : "%s megosztása nem sikerült, mert a hivatkozással történő megosztás nincs engedélyezve",
-    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet létrehozni egyesített megosztást.",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s megosztása sikertelen, mert %s nem található, talán a szerver jelenleg nem elérhető.",
-    "Share type %s is not valid for %s" : "A %s megosztási típus nem érvényes %s-re",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nem lehet beállítani a lejárati időt. A megosztások legfeljebb ennyi idővel járhatnak le a létrehozásukat követően: %s",
-    "Cannot set expiration date. Expiration date is in the past" : "Nem lehet beállítani a lejárati időt, mivel a megadott lejárati időpont már elmúlt.",
-    "Sharing failed, because the user %s is the original sharer" : "Megosztás sikertelen, mert %s felhasználó az eredeti megosztó",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s megosztása nem sikerült, mert a jogosultságok túllépik azt, ami %s rendelkezésére áll",
-    "Sharing %s failed, because resharing is not allowed" : "%s megosztása nem sikerült, mert a megosztás továbbadása nincs engedélyezve",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s megosztása nem sikerült, mert %s megosztási alrendszere nem találja",
-    "Sharing %s failed, because the file could not be found in the file cache" : "%s megosztása nem sikerült, mert a fájl nem található a gyorsítótárban",
-    "%s shared »%s« with you" : "%s megosztotta veled ezt:  »%s«",
-    "%s shared »%s« with you." : "%s megosztotta »%s«-t veled.",
-    "%s via %s" : "%s - %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "\"%s\" alkalmazás nem lehet telepíteni, mert a következő függőségek nincsenek kielégítve: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 szükséges",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "ID \"%s\" már hasznalatban van a Felhő szolgáltatónál: \"%s\"",
     "Sharing %1$s failed, because the user %2$s does not exist" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem létezik",
     "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem tagja egyik olyan csoportnak sem, aminek %3$s tagja",
     "Sharing %1$s failed, because this item is already shared with %2$s" : "%1$s megosztása nem sikerült, mert ez már meg van osztva vele: %2$s",
     "Sharing %1$s failed, because this item is already shared with user %2$s" : "%1$s megosztása sikertelen, mert már meg van osztva %2$s felhasználóval",
     "Sharing %1$s failed, because the group %2$s does not exist" : "%1$s megosztása nem sikerült, mert %2$s csoport nem létezik",
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem tagja a %3$s csoportnak",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Meg kell adnia egy jelszót is, mert a nyilvános hivatkozások csak jelszóval védetten használhatók",
+    "Sharing %s failed, because sharing with links is not allowed" : "%s megosztása nem sikerült, mert a hivatkozással történő megosztás nincs engedélyezve",
+    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet létrehozni egyesített megosztást.",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "%1$s megosztása sikertelen, mert %2$s nem található; talán a szerver jelenleg nem elérhető.",
     "Share type %1$s is not valid for %2$s" : "A %1$s megosztási típus nem érvényes %2$s-re",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nem lehet beállítani a lejárati időt. A megosztások legfeljebb ennyi idővel járhatnak le a létrehozásukat követően: %s",
+    "Cannot set expiration date. Expiration date is in the past" : "Nem lehet beállítani a lejárati időt, mivel a megadott lejárati időpont már elmúlt.",
+    "Sharing failed, because the user %s is the original sharer" : "Megosztás sikertelen, mert %s felhasználó az eredeti megosztó",
     "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "%1$s megosztása nem sikerült, mert a jogosultságok túllépik azt, ami %2$s rendelkezésére áll",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "%1$s megosztása nem sikerült, mert %2$s megosztási alrendszere nem találja"
+    "Sharing %s failed, because resharing is not allowed" : "%s megosztása nem sikerült, mert a megosztás továbbadása nincs engedélyezve",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "%1$s megosztása nem sikerült, mert %2$s megosztási alrendszere nem találja",
+    "Sharing %s failed, because the file could not be found in the file cache" : "%s megosztása nem sikerült, mert a fájl nem található a gyorsítótárban"
 },
 "nplurals=2; plural=(n != 1);");
