@@ -15,6 +15,7 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Berikut adalah platform yang didukung: %s",
     "Server version %s or higher is required." : "Server versi %s atau yang lebih tinggi diperlukan.",
     "Server version %s or lower is required." : "Server versi %s atau yang lebih rendah diperlukan.",
+    "Authentication" : "Otentikasi",
     "Unknown filetype" : "Tipe berkas tak dikenal",
     "Invalid image" : "Gambar tidak sah",
     "today" : "hari ini",
@@ -37,9 +38,13 @@ OC.L10N.register(
     "__language_name__" : "Bahasa Indonesia",
     "Help" : "Bantuan",
     "Apps" : "aplikasi",
+    "Settings" : "Setelan",
     "Log out" : "Keluar",
     "Users" : "Pengguna",
     "Unknown user" : "Pengguna tidak dikenal",
+    "Sharing" : "Berbagi",
+    "Security" : "Keamanan",
+    "Personal info" : "Info pribadi",
     "%s enter the database username and name." : "%s masukkan nama pengguna database dan nama database.",
     "%s enter the database username." : "%s masukkan nama pengguna basis data.",
     "%s enter the database name." : "%s masukkan nama basis data.",
@@ -58,9 +63,55 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
     "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
+    "Open »%s«" : "Buka »%s«",
     "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
     "Expiration date is in the past" : "Tanggal kedaluwarsa sudah lewat",
     "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
+    "Sunday" : "Minggu",
+    "Monday" : "Senin",
+    "Tuesday" : "Selasa",
+    "Wednesday" : "Rabu",
+    "Thursday" : "Kamis",
+    "Friday" : "Jumat",
+    "Saturday" : "Sabtu",
+    "Sun." : "Min.",
+    "Mon." : "Sen.",
+    "Tue." : "Sel.",
+    "Wed." : "Rab.",
+    "Thu." : "Kam.",
+    "Fri." : "Jum.",
+    "Sat." : "Sab.",
+    "Su" : "Min",
+    "Mo" : "Sen",
+    "Tu" : "Sel",
+    "We" : "Rab",
+    "Th" : "Kam",
+    "Fr" : "Jum",
+    "Sa" : "Sab",
+    "January" : "Januari",
+    "February" : "Februari",
+    "March" : "Maret",
+    "April" : "April",
+    "May" : "Mei",
+    "June" : "Juni",
+    "July" : "Juli",
+    "August" : "Agustus",
+    "September" : "September",
+    "October" : "Oktober",
+    "November" : "November",
+    "December" : "Desember",
+    "Jan." : "Jan.",
+    "Feb." : "Feb.",
+    "Mar." : "Mar.",
+    "Apr." : "Apr.",
+    "May." : "Mei",
+    "Jun." : "Jun.",
+    "Jul." : "Jul.",
+    "Aug." : "Agu.",
+    "Sep." : "Sep.",
+    "Oct." : "Okt.",
+    "Nov." : "Nov.",
+    "Dec." : "Des.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Hanya karakter ini yang diizinkan dalam nama pengguna: \"a-z\", \"A-Z\", \"0-9\", dan \"_.@-'\"",
     "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
     "Username contains whitespace at the beginning or at the end" : "Nama pengguna mengandung spasi di depan atau di belakang.",
@@ -91,6 +142,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Modul PHP telah terinstal, tetapi mereka terlihat tidak ada?",
     "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
+    "PostgreSQL >= 9 required" : "Diperlukan PostgreSQL >= 9",
     "Please upgrade your database version" : "Mohon perbarui versi basis data Anda",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
     "Check the value of \"datadirectory\" in your configuration" : "Periksa nilai \"datadirectory\" di konfigurasi Anda",
@@ -99,32 +151,22 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Konfigurasi penyimpanan tidak terselesaikan. %s",
     "Storage connection error. %s" : "Koneksi penyimpanan bermasalah. %s",
     "Storage connection timeout. %s" : "Koneksi penyimpanan waktu-habis. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih tinggi dari %s - versi yang tersedia %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih rendah dari %s - versi yang tersedia %s.",
+    "Create" : "Buat",
+    "Delete" : "Hapus",
+    "Share" : "Bagikan",
+    "Unlimited" : "Tak terbatas",
+    "Verifying …" : "Sedang memferivikasi …",
+    "Verify" : "Verifikasi",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Gagal berbagi %s, karena backend tidak mengizinkan berbagi dengan tipe %i",
     "Sharing %s failed, because the file does not exist" : "Gagal membagikan %s, karena berkas tidak ada",
     "Sharing %s failed, because you can not share with yourself" : "Berbagi %s gagal, karena Anda tidak dapat berbagi dengan diri sendiri",
-    "Sharing %s failed, because the user %s does not exist" : "Gagal membagikan %s, karena pengguna %s tidak ada",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Gagal membagikan %s, karena pengguna %s bukan merupakan anggota dari grup yang %s ikuti",
-    "Sharing %s failed, because this item is already shared with %s" : "Gagal membagkan %s, karena item ini sudah dibagikan dengan %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
-    "Sharing %s failed, because the group %s does not exist" : "Gagal membagikan %s, karena grup %s tidak ada",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Gagal membagikan %s, karena %s bukan anggota dari grup %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Anda perlu memberikan kata sandi untuk membuat tautan publik, hanya tautan yang terlindungi yang diizinkan",
     "Sharing %s failed, because sharing with links is not allowed" : "Gagal membagikan %s, karena berbag dengan tautan tidak diizinkan",
     "Not allowed to create a federated share with the same user" : "Tidak diizinkan membuat pembagian terfederasi dengan pengguna yang sama",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Berbagi %s gagal, tidak menemukan %s, kemungkinan saat ini server tidak dapat dijangkau.",
-    "Share type %s is not valid for %s" : "Barbagi tipe %s tidak sah untuk %s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Tidak dapat menyetel tanggal kadaluarsa. Pembagian tidak dapat kadaluarsa lebih lambat dari %s setelah mereka dibagikan.",
     "Cannot set expiration date. Expiration date is in the past" : "Tidak dapat menyetel tanggal kadaluarsa. Tanggal kadaluarsa dimasa lalu",
     "Sharing failed, because the user %s is the original sharer" : "Berbagi gagal, karena pengguna %s adalah pembagi awal",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Gagal membagikan %s, karena izin melebihi izin yang diberikan untuk %s",
     "Sharing %s failed, because resharing is not allowed" : "Gagal berbagi %s, karena membagikan ulang tidak diizinkan",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Berbagi %s gagal, karena backend berbagi untuk %s tidak menemukan sumbernya",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Gagal berbagi %s, karena berkas tidak ditemukan di berkas cache",
-    "%s shared »%s« with you" : "%s membagikan »%s« dengan anda",
-    "%s via %s" : "%s melalui %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "aplikasi \"%s\" tidak dapat dipasang karena dependensi berikut belum terpenuhi: %s",
-    "PostgreSQL >= 9 required" : "Diperlukan PostgreSQL >= 9"
+    "Sharing %s failed, because the file could not be found in the file cache" : "Gagal berbagi %s, karena berkas tidak ditemukan di berkas cache"
 },
 "nplurals=1; plural=0;");
