@@ -66,6 +66,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n 分前"],
     "in a few seconds" : "数秒",
     "seconds ago" : "数秒前",
+    "Empty file" : "空白のファイル",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
     "File name is a reserved word" : "ファイル名が予約された単語です",
     "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
@@ -109,6 +110,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s のバックエンドの共有には、OCP\\Share_Backend インターフェースを実装しなければなりません。",
     "Sharing backend %s not found" : "共有バックエンド %s が見つかりません",
     "Sharing backend for %s not found" : "%s のための共有バックエンドが見つかりません",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s さんが »%2$s« にノートを追加しました。",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
     "»%s« added a note to a file shared with you" : "»%s« があなたと共有しているファイルにノートを追加しました。 ",
     "Open »%s«" : "»%s«を開く",
@@ -173,6 +175,7 @@ OC.L10N.register(
     "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
     "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
     "Username must not consist of dots only" : "ユーザー名は、ドットのみではつけられません",
+    "Username is invalid because files already exist for this user" : "このユーザーのファイルが既に存在するため、ユーザー名は無効です",
     "A valid password must be provided" : "有効なパスワードを指定する必要があります",
     "The username is already being used" : "ユーザー名はすでに使われています",
     "Could not create user" : "ユーザーを作成できませんでした",
