@@ -25,6 +25,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "საჭიროა სერვერი ვერსიით %s ან მეტი.",
     "Server version %s or lower is required." : "საჭიროა სერვერი ვერსიით %s ან ნაკლები.",
     "Logged in user must be an admin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ადმინისტრატორი",
+    "Authentication" : "აუტენტიფიკაცია",
     "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
     "Invalid image" : "არასწორი სურათი",
     "Avatar image is not square" : "ავატარის სურათი არაა კვადრატი",
@@ -178,6 +179,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "ეს შესაძლოა გამოწვეული იყოს ისეთი კეშით/აქსელერატორით როგორიცაა Zend OPcache ან eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP მოდულები დაყენდა, მაგრამ მაინც ჩამოწერილია როგორც არმყოფები?",
     "Please ask your server administrator to restart the web server." : "გთხოვთ სთხოვოთ თქვენს სერვერის ადმინისტრატორს გადატვირთოს ვებ-სერვერი.",
+    "PostgreSQL >= 9 required" : "საჭიროა PostgreSQL >= 9",
     "Please upgrade your database version" : "გთხოვთ განაახლოთ თქვენი მონაცემთა ბაზის ვერსია",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "გთხოვთ შეცვალოთ უფლებები 0770-ზე, რათა დირექტორია სხვა მომხმარებლების მიერ აღარ იყოს კითხვადი.",
     "Your data directory is readable by other users" : "თქვენი მონაცემების დირექტორია სხვა მომხარებლების მიერ კითხვადია",
@@ -191,8 +193,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "საცავის კავშირის შეცდომა. %s",
     "Storage is temporarily not available" : "საცავი დროებით ხელმიუწვდომელია",
     "Storage connection timeout. %s" : "საცავის კავშირის დროის ამოწურვა. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "საჭიროა ბიბლიოთკეა %s %s-ზე მაღალი ვერსიით - ნაპოვნია ვერსია %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "საჭიროა ბიბლიოთეკა %s %s-ზე მცირე ვერსიით - ნაპოვნია ვერსია %s.",
     "Create" : "შექმნა",
     "Change" : "შეცვლა",
     "Delete" : "გაუქმება",
@@ -204,28 +204,13 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "%s-ის გაზიარება არ მოხერხდა, რადგანაც ბექენდი არ იღებს გაზიარებებს სახეობით %s",
     "Sharing %s failed, because the file does not exist" : "%s-ის გაზიარება არ მოხერხდა, რადგან ფაილი არ არსებობს",
     "Sharing %s failed, because you can not share with yourself" : "%s-ის გაზიარება ვერ მოხერხდა, რადგან საკუთარ თავთან ვერ გააზიარებთ",
-    "Sharing %s failed, because the user %s does not exist" : "%s-ის გაზიარება ვერ მოხერხდა, რადგან მომხმარებელი %s არ არსებობს",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s-ის გაზიარება არ მოხერხდა, რადგან მომხმარებელი %s არ მიეკუთხვნება ჯგუფს რომელსაც მიეკუთვნება მომხმარებელი %s",
-    "Sharing %s failed, because this item is already shared with %s" : "%s-ის გაზიარება არ მოხერხდა, რადგან ობიექტი %s-თან უკვე გაზიარებულია",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s-ის გაზიარება არ მოხერხდა, რადგან ობიექტი მომხმარებელ %s-თან უკვე გაზიარებულია",
-    "Sharing %s failed, because the group %s does not exist" : "%s-ის გაზიარება არ მოხერხდა, რადგან ჯგუფი %s არ არსებობს",
-    "Sharing %s failed, because %s is not a member of the group %s" : "%s-ის გაზიარება არ მოხერხდა, რადგან %s არაა ჯგუფ %s-ის წევრი",
     "You need to provide a password to create a public link, only protected links are allowed" : "საზოგადო ბმულის შექმნისთვის აუცილებელია პაროლის მითთება, მხადაჭერილია მხოლოდ დაცული ბმულები",
     "Sharing %s failed, because sharing with links is not allowed" : "%s-ის გაზიარება არ მოხერხდა, ბმულებით გაზიარება არაა ნებადართული",
     "Not allowed to create a federated share with the same user" : "იმავე მომხმარებელთან ფედერალური გაზიარება ვერ შეიქმნება",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s-ის გაზიარება ვერ მოხერხდა, ვერ ვიპოვეთ %s, ალბათ სერვერი ახლა მიუწვდომელია.",
-    "Share type %s is not valid for %s" : "%s ტიპის გაზიარება მომხმარებლისთვის %s არაა მართებული",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "ვადის ამოწურვის დროის მითთება ვერ ხერხდება. გაზიარებები გაზიარების შემდეგ %s-ზე ადრე ვერ გაუქმდებიან",
     "Cannot set expiration date. Expiration date is in the past" : "ვადის ამოწურვის დროის მითითება ვერ ხერხდება. ვადის გასვლის დრო წარსულია",
     "Sharing failed, because the user %s is the original sharer" : "გაზიარება ვერ მოხერხდა, რადგან მომხმარებელი %s თავდაპირველი გამზიარებელია",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s-ის გაზიარება ვერ მოხერხდა, უფლებები აჭარბებს უფლებებს, რომლებიც მინიჭებული აქვს %s-ს",
     "Sharing %s failed, because resharing is not allowed" : "%s-გაზიარება ვერ მოხერხდა, რადგან ხელახალი გაზიარება ნებადართული არაა",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s-ის გაზიარება ვერ მოხერხდა, რადგანაც %s-ის გაზიარების ბექენდმა ვერ მიაგნო საკუთარ წყაროს",
-    "Sharing %s failed, because the file could not be found in the file cache" : "%s-ის გაზიარება ვერ მოხერხდა, რადგან ფაილი კეშში ვერ მოიძებნა",
-    "%s shared »%s« with you" : "%s მომხმარებელმა თქვენთან გააზიარა »%s«",
-    "%s shared »%s« with you." : "%s მომხმარებელმა თქვენთან გააზიარა »%s«.",
-    "%s via %s" : "%s %s-ით",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "აპლიკაცია \"%s\" ვერ ყენდება, რადგან შემდეგი დამოკიდებულებები არაა დაკმაყოფილებული: %s",
-    "PostgreSQL >= 9 required" : "საჭიროა PostgreSQL >= 9"
+    "Sharing %s failed, because the file could not be found in the file cache" : "%s-ის გაზიარება ვერ მოხერხდა, რადგან ფაილი კეშში ვერ მოიძებნა"
 },
 "nplurals=2; plural=(n!=1);");
