@@ -33,6 +33,7 @@ OC.L10N.register(
     "Logged in user must be an admin" : "로그인한 사용자는 관리자여야 합니다.",
     "Wiping of device %s has started" : "디바이스 %s의 완전 삭제가 시작되었습니다.",
     "Wiping of device »%s« has started" : "디바이스 »%s«의 완전 삭제가 시작되었습니다.",
+    "Authentication" : "인증",
     "Unknown filetype" : "알 수 없는 파일 형식",
     "Invalid image" : "잘못된 사진",
     "Avatar image is not square" : "아바타 사진이 정사각형이 아님",
@@ -99,6 +100,7 @@ OC.L10N.register(
     "Sharing backend %s not found" : "공유 백엔드 %s을(를) 찾을 수 없음",
     "Sharing backend for %s not found" : "%s의 공유 백엔드를 찾을 수 없음",
     "Open »%s«" : "%s 열기",
+    "%1$s via %2$s" : "%1$s(%2$s 경유)",
     "You are not allowed to share %s" : "%s을(를) 공유할 수 있는 권한이 없습니다",
     "Can’t increase permissions of %s" : "%s의 권한을 늘릴 수 없습니다",
     "Files can’t be shared with delete permissions" : "파일을 삭제 권한으로 공유할 수 없습니다",
@@ -189,6 +191,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Zend OPcache, eAccelerator 같은 캐시/가속기 문제일 수도 있습니다.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP 모듈이 설치되었지만 여전히 없는 것으로 나타납니까?",
     "Please ask your server administrator to restart the web server." : "서버 관리자에게 웹 서버 재시작을 요청하십시오.",
+    "PostgreSQL >= 9 required" : "PostgreSQL 버전 9 이상이 필요합니다",
     "Please upgrade your database version" : "데이터베이스 버전을 업그레이드 하십시오",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "권한을 0770으로 변경하여 다른 사용자가 읽을 수 없도록 하십시오.",
     "Your data directory is readable by other users" : "내 데이터 디렉터리를 다른 사용자가 읽을 수 있음",
@@ -203,8 +206,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "저장소 연결 오류입니다. %s",
     "Storage is temporarily not available" : "저장소를 임시로 사용할 수 없음",
     "Storage connection timeout. %s" : "저장소 연결 시간이 초과되었습니다. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "%s 라이브러리의 버전 %s 이상이 필요합니다. 사용 가능한 버전은 %s입니다.",
-    "Library %s with a version lower than %s is required - available version %s." : "%s 라이브러리의 버전 %s 미만이 필요합니다. 사용 가능한 버전은 %s입니다.",
     "Create" : "생성",
     "Change" : "변경",
     "Delete" : "삭제",
@@ -216,28 +217,14 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "%s을(를) 공유할 수 없습니다. 백엔드에서 %i 형식의 공유를 허용하지 않습니다",
     "Sharing %s failed, because the file does not exist" : "%s을(를) 공유할 수 없습니다. 파일이 존재하지 않습니다",
     "Sharing %s failed, because you can not share with yourself" : "%s을(를) 공유할 수 없습니다. 자기 자신과 공유할 수 없습니다",
-    "Sharing %s failed, because the user %s does not exist" : "%s을(를) 공유할 수 없습니다. 사용자 %s이(가) 존재하지 않습니다",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s을(를) 공유할 수 없습니다. 사용자 %s 님은 %s 님이 회원인 어떠한 그룹에도 속해 있지 않습니다",
-    "Sharing %s failed, because this item is already shared with %s" : "%s을(를) 공유할 수 없습니다. 이미 %s 님과 공유되어 있습니다",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s을(를) 공유할 수 없습니다. 이 항목을 이미 %s 님과 공유하고 있습니다",
-    "Sharing %s failed, because the group %s does not exist" : "%s을(를) 공유할 수 없습니다. 그룹 %s이(가) 존재하지 않습니다",
-    "Sharing %s failed, because %s is not a member of the group %s" : "%s을(를) 공유할 수 없습니다. %s 님이 그룹 %s의 구성원이 아닙니다",
+    "Sharing %1$s failed, because this item is already shared with %2$s" : "%1$s 공유 실패. %2$s와(과) 이미 공유되어 있습니다",
     "You need to provide a password to create a public link, only protected links are allowed" : "공개 링크를 만들려면 암호를 입력해야 합니다. 보호된 링크만 사용 가능합니다",
     "Sharing %s failed, because sharing with links is not allowed" : "%s을(를) 공유할 수 없습니다. 링크 공유가 허용되지 않았습니다",
     "Not allowed to create a federated share with the same user" : "같은 사용자와 연합 공유를 만들 수 없음",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s을(를) 공유할 수 없습니다. %s을(를) 찾을 수 없습니다. 서버에 접근하지 못할 수도 있습니다.",
-    "Share type %s is not valid for %s" : "공유 형식 %s을(를) %s에 대해서 사용할 수 없음",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "만료 날짜를 설정할 수 없습니다. 최대 공유 허용 기한이 %s입니다.",
     "Cannot set expiration date. Expiration date is in the past" : "만료 날짜를 설정할 수 없습니다. 만료 날짜가 과거입니다",
     "Sharing failed, because the user %s is the original sharer" : "공유할 수 없습니다. 사용자 %s이(가) 원 공유자입니다",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s을(를) 공유할 수 없습니다. %s 님에게 허용된 것 이상의 권한을 필요로 합니다",
     "Sharing %s failed, because resharing is not allowed" : "%s을(를) 공유할 수 없습니다. 다시 공유할 수 없습니다",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s을(를) 공유할 수 없습니다. %s의 공유 백엔드에서 원본 파일을 찾을 수 없습니다",
-    "Sharing %s failed, because the file could not be found in the file cache" : "%s을(를) 공유할 수 없습니다. 파일 캐시에서 찾을 수 없습니다",
-    "%s shared »%s« with you" : "%s 님이 %s을(를) 공유했습니다",
-    "%s shared »%s« with you." : "%s 님이 %s을(를) 공유했습니다.",
-    "%s via %s" : "%s(%s 경유)",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "앱 \"%s\"의 다음 의존성을 만족하지 못하므로 설치할 수 없습니다: %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL 버전 9 이상이 필요합니다"
+    "Sharing %s failed, because the file could not be found in the file cache" : "%s을(를) 공유할 수 없습니다. 파일 캐시에서 찾을 수 없습니다"
 },
 "nplurals=1; plural=0;");
