@@ -11,6 +11,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s ir %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ir %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ir %5$s",
+    "Groupware bundle" : "Grupinio darbo įrangos rinkinys",
     "PHP %s or higher is required." : "Reikalinga PHP %s arba aukštesnė.",
     "PHP with a version lower than %s is required." : "Reikalinga žemesnė nei %s PHP versija. ",
     "Following databases are supported: %s" : "Yra palaikomos šios duomenų bazės: %s",
@@ -20,20 +21,34 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Reikalinga %s arba aukštesnė serverio versija ",
     "Server version %s or lower is required." : "Reikalinga %s arba žemesnė serverio versija. ",
     "Logged in user must be an admin" : "Prisijungęs naudotojas privalo būti administratoriumi",
+    "Wiping of device %s has started" : "Įrenginio %s duomenų ištrynimas pradėtas",
+    "Wiping of device »%s« has started" : "Įrenginio »%s« duomenų ištrynimas pradėtas",
+    "»%s« started remote wipe" : "»%s« pradėjo nuotolinių duomenų ištrynimą",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Įrenginys ar programa »%s« pradėjo nuotolinių duomenų ištrynimo procesą. Procesui užsibaigus, gausite dar vieną el. laišką",
+    "Wiping of device %s has finished" : "Įrenginio %s duomenų ištrynimas užbaigtas",
+    "Wiping of device »%s« has finished" : "Įrenginio »%s« duomenų ištrynimas užbaigtas",
+    "»%s« finished remote wipe" : "»%s« užbaigė nuotolinių duomenų ištrynimą",
+    "Device or application »%s« has finished the remote wipe process." : "Įrenginys ar programa »%s« užbaigė nuotolinių duomenų ištrynimo procesą.",
+    "Remote wipe started" : "Nuotolinių duomenų ištrynimas pradėtas",
+    "A remote wipe was started on device %s" : "Nuotolinių duomenų ištrynimas buvo pradėtas įrenginyje %s",
+    "Remote wipe finished" : "Nuotolinių duomenų ištrynimas užbaigtas",
+    "The remote wipe on %s has finished" : "Nuotolinių duomenų ištrynimas ties %s yra užbaigtas",
+    "Authentication" : "Tapatybės nustatymas",
     "Unknown filetype" : "Nežinomas failo tipas",
     "Invalid image" : "Neteisingas paveikslas",
     "Avatar image is not square" : "Avataro paveikslas nėra kvadratinis",
     "today" : "šiandien",
     "tomorrow" : "rytoj",
     "yesterday" : "vakar",
-    "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dienų"],
+    "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dieną"],
     "last month" : "praeitą mėnesį",
-    "_%n month ago_::_%n months ago_" : ["prieš %n mėnesį","prieš %n mėnesius","prieš %n mėnesių","prieš %n mėnesių"],
+    "_%n month ago_::_%n months ago_" : ["prieš %n mėnesį","prieš %n mėnesius","prieš %n mėnesių","prieš %n mėnesį"],
     "last year" : "praeitais metais",
-    "_%n year ago_::_%n years ago_" : ["prieš %n metus","prieš %n metus","prieš %n metų","prieš %n metų"],
-    "_%n hour ago_::_%n hours ago_" : ["prieš %n valandą","prieš %n valandas","prieš %n valandų","prieš %n valandų"],
-    "_%n minute ago_::_%n minutes ago_" : ["prieš %n minutę","prieš % minutes","prieš %n minučių","prieš %n minučių"],
+    "_%n year ago_::_%n years ago_" : ["prieš %n metus","prieš %n metus","prieš %n metų","prieš %n metus"],
+    "_%n hour ago_::_%n hours ago_" : ["prieš %n valandą","prieš %n valandas","prieš %n valandų","prieš %n valandą"],
+    "_%n minute ago_::_%n minutes ago_" : ["prieš %n minutę","prieš %n minutes","prieš %n minučių","prieš %n minutę"],
     "seconds ago" : "prieš keletą sekundžių",
+    "Empty file" : "Tuščias failas",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulio, kurio ID: %s, nėra. Prašome jį įjungti savo programėlių nustatymuose arba susisiekti su savo administratoriumi.",
     "File name is a reserved word" : "Failo pavadinimas negalimas, žodis rezervuotas",
     "File name contains at least one invalid character" : "Failo vardas sudarytas iš neleistinų simbolių",
@@ -53,6 +68,7 @@ OC.L10N.register(
     "Basic settings" : "Pagrindiniai nustatymai",
     "Sharing" : "Bendrinimas",
     "Security" : "Saugumas",
+    "Groupware" : "Grupinio darbo įranga",
     "Additional settings" : "Papildomi nustatymai",
     "Personal info" : "Asmeninė informacija",
     "Mobile & desktop" : "Mobilieji ir darbalaukiai",
@@ -71,13 +87,19 @@ OC.L10N.register(
     "Set an admin password." : "Nustatyti administratoriaus slaptažodį.",
     "Can't create or write into the data directory %s" : "Negalima nuskaityti arba rašyti į duomenų katalogą. %s",
     "Invalid Federated Cloud ID" : "Neteisingas federacinės debesijos ID",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s pasidalino „%2$s“ su jumis ir parašė pastabą:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s pasidalino „%2$s“ su jumis ir parašė pastabą",
+    "»%s« added a note to a file shared with you" : "„%s“ parašė pastabą su jumis pasidalintam failui",
     "Open »%s«" : "Atverti \"%s\"",
+    "%1$s via %2$s" : "%1$s per %2$s",
     "You are not allowed to share %s" : "Jums neleidžiama bendrinti %s",
     "Can’t increase permissions of %s" : "Negalima pridėti papildomų %s leidimų",
     "Files can’t be shared with delete permissions" : "Failai negali būti bendrinami su trynimo leidimu.",
     "Files can’t be shared with create permissions" : "Failai negali būti bendrinami su sukūrimo leidimu.",
     "Expiration date is in the past" : "Bendrinimo pabaigos data yra praėjęs laikas",
     "Can’t set expiration date more than %s days in the future" : "Negalima nustatyti galiojimo laiko ilgesnio nei %s dienos.",
+    "%1$s shared »%2$s« with you" : "%1$s pasidalino „%2$s“ su jumis",
+    "%1$s shared »%2$s« with you." : "%1$s pasidalino „%2$s“ su jumis.",
     "Click the button below to open it." : "Norėdami atverti failą, spustelėkite mygtuką žemiau.",
     "The requested share does not exist anymore" : "Pageidaujamas bendrinimas daugiau neegzistuoja.",
     "Could not find category \"%s\"" : "Nepavyko rasti kategorijos „%s“",
@@ -135,6 +157,7 @@ OC.L10N.register(
     "Could not create user" : "Nepavyko sukurti naudotojo",
     "User disabled" : "Naudotojas išjungtas",
     "Login canceled by app" : "Programėlė nutraukė prisijungimo procesą",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Programėlė \"%1$s\" negali būti įdiegta, nes nėra patenkinamos šios priklausomybės: %2$s",
     "a safe home for all your data" : "saugūs namai visiems jūsų duomenims",
     "File is currently busy, please try again later" : "Failas šiuo metu yra užimtas, prašome vėliau pabandyti dar kartą",
     "Can't read file" : "Nepavyksta perskaityti failo",
@@ -160,6 +183,7 @@ OC.L10N.register(
     "To fix this issue update your libxml2 version and restart your web server." : "Atnaujinkite libxml2 versiją ir perkraukite žiniatinklio serverį, kad sutvarkytumėte šią problemą.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduliai yra įdiegti, bet jų vis tiek trūksta?",
     "Please ask your server administrator to restart the web server." : "Kreipkitės į savo sistemos administratorių, kad jis perkrautų žiniatinklio serverį.",
+    "PostgreSQL >= 9 required" : "Reikalinga PostgreSQL >= 9",
     "Please upgrade your database version" : "Atnaujinkite duomenų bazės versiją.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Pakeiskite leidimus į 0770, kad šis katalogas negalėtų būti išvardytas kitiems naudotojams.",
     "Your data directory is readable by other users" : "Duomenų katalogą gali skaityti kiti naudotojai",
@@ -168,15 +192,16 @@ OC.L10N.register(
     "Your data directory is invalid" : "Neteisingas duomenų katalogas",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Įsitikinkite, kad šakniniame duomenų kataloge yra  yra \".ocdata\" failas.",
     "Action \"%s\" not supported or implemented." : "Veiksmas \"%s\" nepalaikomas ar neįgyvendintas.",
+    "Could not obtain lock type %d on \"%s\"." : "Nepavyko gauti užrakto tipo %d ties \"%s\".",
     "Storage unauthorized. %s" : "Saugykla nesankcionuota. %s",
     "Storage incomplete configuration. %s" : "Nepilna saugyklos konfigūracija. %s",
     "Storage connection error. %s" : "Saugyklos sujungimo ryšio klaida. %s",
     "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
     "Storage connection timeout. %s" : "Sujungimo su saugykla laikas baigėsi. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Bibliotekos %s versija turi būti aukštesnė nei %s - turima versija %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Bibliotekos %s versija turi būti žemesnė nei %s - turima versija %s.",
     "Create" : "Sukurti",
+    "Change" : "Keisti",
     "Delete" : "Ištrinti",
+    "Share" : "Bendrinti",
     "Unlimited" : "Neribota",
     "Verifying" : "Tikrinimas",
     "Verifying …" : "Tikrinama...",
@@ -184,27 +209,19 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "%s dalinimasis nepavyko, nes sistema nepalaiko šio duomenų tipo %i",
     "Sharing %s failed, because the file does not exist" : "%s dalinimasis nepavyko, nes failas neegzistuoja.     ",
     "Sharing %s failed, because you can not share with yourself" : "%s bendrinimas nepavyko, jūs negalite bendrinti su savimi pačiu.",
-    "Sharing %s failed, because the user %s does not exist" : "%s bendrinimas nepavyko, nes naudotojas %s neegzistuoja",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s bendrinimas nepavyko, nes naudotojas %s nėra tos pačios grupės, kaip %s, narys.",
-    "Sharing %s failed, because this item is already shared with %s" : "%s bendrinimas nepavyko, kadangi šis elementas jau yra bendrinamas su %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s bendrinimas nepavyko, kadangi šis elementas jau yra bendrinamas su naudotoju %s",
-    "Sharing %s failed, because the group %s does not exist" : "%s bendrinimas nepavyko, nes grupė %s neegzistuoja",
-    "Sharing %s failed, because %s is not a member of the group %s" : " %s bendrinimas nepavyko, nes %s nėra %s grupės narys.",
+    "Sharing %1$s failed, because the user %2$s does not exist" : "Nepavyko bendrinti %1$s, nes naudotojo %2$s nėra",
+    "Sharing %1$s failed, because this item is already shared with %2$s" : "Nepavyko bendrinti %1$s, nes šis elementas jau yra bendrinamas su %2$s",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Nepavyko bendrinti %1$s, nes šis elementas jau yra bendrinamas su naudotoju %2$s",
+    "Sharing %1$s failed, because the group %2$s does not exist" : "Nepavyko bendrinti %1$s, nes grupės %2$s nėra",
+    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Nepavyko bendrinti %1$s, nes %2$s nėra grupės %3$s narys",
     "You need to provide a password to create a public link, only protected links are allowed" : "Viešoms nuorodoms būtinas slaptažodis, leidžiamos tik apsaugotos nuorodos.",
     "Sharing %s failed, because sharing with links is not allowed" : "Bendrinimas %s nepavyko, kadangi bendrinimas su nuorodomis yra neleidžiamas.",
     "Not allowed to create a federated share with the same user" : "Negalima sukurti federacinį viešinį su tuo pačiu naudotoju",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s pasidalinimas nepavyko, neįmanoma rasti %s, tikėtina, kad serveris šiuo metu nepasiekiamas",
-    "Share type %s is not valid for %s" : "Bendrinimo tipas %s netinka %s",
+    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Nepavyko bendrinti %1$s, nepavyko rasti %2$s, galbūt, šiuo metu serveris yra nepasiekiamas.",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Negalima nustatyti galiojimo pabaigos datos. Bendrinimas negali pasibaigti vėliau nei %s po jo pasidalinimo",
     "Cannot set expiration date. Expiration date is in the past" : "Nepavyko nustatyti galiojimo datos. Galiojimo data yra praėjęs laikas.",
     "Sharing failed, because the user %s is the original sharer" : "Bendrinimas nepavyko, nes naudotojas %s yra bendrintojas.",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s bendrinimas nepavyko, kadangi teisės  viršijo %s suteiktas teises.",
     "Sharing %s failed, because resharing is not allowed" : "%s bendrinimas nepavyko, nes perskirstymas yra neleidžiamas.",
-    "Sharing %s failed, because the file could not be found in the file cache" : "%s dalinimasis nepavyko, nes failo nepavyko rasti podelyje.   ",
-    "%s shared »%s« with you" : "%s pasidalino »%s« su jumis",
-    "%s shared »%s« with you." : "%s pasidalino »%s« su Jumis.",
-    "%s via %s" : "%s per %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Programa \"%s\" negali būti įdiegta, nes nėra įvykdytos: %s",
-    "PostgreSQL >= 9 required" : "Reikalinga PostgreSQL >= 9"
+    "Sharing %s failed, because the file could not be found in the file cache" : "%s dalinimasis nepavyko, nes failo nepavyko rasti podelyje.   "
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
