@@ -19,6 +19,7 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Tiek atbalstītas šādas platformas: %s",
     "Server version %s or higher is required." : "Ir vajadzīga servera versija %s vai jaunāka.",
     "Server version %s or lower is required." : "Ir vajadzīga servera versija %s vai vecāka.",
+    "Authentication" : "Autentifikācija",
     "Unknown filetype" : "Nezināms datnes tips",
     "Invalid image" : "Nederīgs attēls",
     "Avatar image is not square" : "Avatar attēls nav kvadrāts",
@@ -32,15 +33,18 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n stundas atpakaļ","%n stundas atpakaļ","%n stundām"],
     "_%n minute ago_::_%n minutes ago_" : ["%n minūtes atpakaļ","%n minūtes atpakaļ","%n minūtēm"],
     "seconds ago" : "sekundēm",
-    "File name is too long" : "Faila nosaukums ir pārāk garš",
-    "Empty filename is not allowed" : "Tukšs faila nosaukums nav atļauts",
+    "File name is too long" : "Datnes nosaukums ir pārāk garš",
+    "Empty filename is not allowed" : "Tukšs datnes nosaukums nav atļauts",
     "__language_name__" : "Latviešu",
     "Help" : "Palīdzība",
-    "Apps" : "Programmas",
+    "Apps" : "Lietotnes",
+    "Settings" : "Iestatījumi",
+    "Log out" : "Izrakstīties",
     "Users" : "Lietotāji",
     "Unknown user" : "Nezināms lietotājs",
     "Sharing" : "Koplietošana",
     "Additional settings" : "Papildu iestatījumi",
+    "Personal info" : "Personiskā informācija",
     "%s enter the database username." : "%s ievadiet datubāzes lietotājvārdu.",
     "%s enter the database name." : "%s ievadiet datubāzes nosaukumu.",
     "%s you may not use dots in the database name" : "%s datubāžu nosaukumos nedrīkst izmantot punktus",
@@ -50,6 +54,7 @@ OC.L10N.register(
     "Set an admin username." : "Iestatiet administratora lietotājvārdu.",
     "Set an admin password." : "Iestatiet administratora paroli.",
     "Invalid Federated Cloud ID" : "Nederīgs Federated Cloud ID",
+    "Open »%s«" : "Atvērt »%s«",
     "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
     "Sunday" : "Svētdiena",
     "Monday" : "Pirmdiena",
@@ -103,8 +108,8 @@ OC.L10N.register(
     "Login canceled by app" : "Pieteikšanos atcelā lietotne",
     "a safe home for all your data" : "droša vieta visiem jūsu datiem",
     "File is currently busy, please try again later" : "Datne pašlaik ir aizņemta. Lūdzu, vēlāk mēģiniet vēlreiz",
-    "Can't read file" : "Nevar nolasīt failu",
-    "Application is not enabled" : "Programma nav aktivēta",
+    "Can't read file" : "Nevar nolasīt datni",
+    "Application is not enabled" : "Lietotne nav iespējota",
     "Authentication error" : "Autentifikācijas kļūda",
     "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu.",
     "Please ask your server administrator to install the module." : "Lūdzu, palūdziet savam servera administratoram, lai instalē moduli.",
@@ -112,14 +117,18 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tas ir iespējams, kešatmiņa / paātrinātājs, piemēram, Zend OPcache vai eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modulis ir uzstādīts, taču tas joprojām ir uzskatāms kā trūkstošs, pazudis?",
     "Please ask your server administrator to restart the web server." : "Lūdzu, palūdziet savam servera administratoram, restartēt Web serveri.",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 nepieciešams",
     "Please upgrade your database version" : "Lūdzu, atjauniniet datu bāzes versiju",
     "Storage unauthorized. %s" : "Krātuve neautorizēta. %s",
     "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
     "Storage connection error. %s" : "Datu savienojuma kļūda. %s",
     "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
     "Storage connection timeout. %s" : "Datu savienojuma taimauts. %s",
-    "%s shared »%s« with you" : "%s kopīgots »%s« ar jums",
-    "%s via %s" : "%s ar %s",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 nepieciešams"
+    "Create" : "Izveidot",
+    "Change" : "Mainīt",
+    "Delete" : "Dzēst",
+    "Share" : "Koplietot",
+    "Unlimited" : "Neierobežota",
+    "Verify" : "Verificēt"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
