@@ -13,6 +13,12 @@ OC.L10N.register(
     "Groupware bundle" : "Пакет со групни производи",
     "Social sharing bundle" : "Пакет за споделување на социјални мрежи",
     "PHP %s or higher is required." : "Потребно е PHP верзија %s или повисока.",
+    "PHP with a version lower than %s is required." : "Потебна е PHP верзија пониска од %s.",
+    "Following databases are supported: %s" : "Следниве бази со податоци се поддржани: %s",
+    "The library %s is not available." : "Библиотеката %s не е достапна.",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Потребна е библиотека %1$s со повисока верзија од %2$s - достапна верзија %3$s.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Потебна е библиотека %1$s со пониска верзија од %2$s - достапна верзија %3$s.",
+    "Following platforms are supported: %s" : "Следниве платформи се поддржани: %s",
     "Server version %s or higher is required." : "Потребна е верзија %s или поголема на серверот.",
     "Server version %s or lower is required." : "Потербна е верзија %s или помала на серверот.",
     "Logged in user must be an admin or sub admin" : "Најавениот корисник мора да биде администратор или заменик администратор",
@@ -39,6 +45,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["пред 1 минута","пред %n минути"],
     "in a few seconds" : "за неколку секунди",
     "seconds ago" : "пред неколку секунди",
+    "Empty file" : "Празна датотека",
     "File name is too long" : "Името на датотеката е премногу долго",
     "Empty filename is not allowed" : "Датотеки без име не се дозболени",
     "__language_name__" : "Македонски",
@@ -66,7 +73,7 @@ OC.L10N.register(
     "Set an admin username." : "Постави администраторско корисничко име",
     "Set an admin password." : "Постави администраторска лозинка.",
     "Can't create or write into the data directory %s" : "Неможете да креирате или да запишувате во оваа папка %s",
-    "Invalid Federated Cloud ID" : "Невалиден федериран Cloud ID",
+    "Invalid Federated Cloud ID" : "Невалиден федерален ID",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s сподели »%2$s« со вас и сака да додаде:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s сподели »%2$s« со вас и сака да додаде",
     "»%s« added a note to a file shared with you" : "»%s« додаде белешка до датотеката што ја сподели со вас",
@@ -134,7 +141,11 @@ OC.L10N.register(
     "Application is not enabled" : "Апликацијата не е овозможена",
     "Authentication error" : "Грешка во автентикација",
     "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
+    "Setting locale to %s failed" : "Неуспешно поставување на локацијата %s ",
+    "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставката \"%s\" не е поставена до \"%s\".",
+    "Please ask your server administrator to restart the web server." : "Замолете го сервер администраторот да го рестартира веб серверот.",
     "PostgreSQL >= 9 required" : "Потребно е PostgreSQL >= 9 ",
+    "Storage is temporarily not available" : "Складиштето моментално не е достапно",
     "Create" : "Креирај",
     "Change" : "Измени",
     "Delete" : "Избриши",
@@ -143,6 +154,8 @@ OC.L10N.register(
     "Verifying" : "Потврдување",
     "Verifying …" : "Потврдување …",
     "Verify" : "Потврди",
+    "Sharing %1$s failed, because this item is already shared with %2$s" : "Споделувањето на %1$s е неуспешно, бидејќи истото веќе е споделено со %2$s",
+    "Not allowed to create a federated share with the same user" : "Не е овозможено да креирате федерално споделување со ист корисник",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Споделувањето на %1$s е неуспешно, неможе да се пронајде %2$s, можеби серверот моментално не е достапен.",
     "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Споделувањето на %1$s е неуспешно, бидејќи серверот на %2$s неможе да го пронајде споделувањето"
 },
