@@ -25,6 +25,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Serverversjon %s eller høyere kreves.",
     "Server version %s or lower is required." : "Serverversjon %s eller lavere kreves.",
     "Logged in user must be an admin" : "Innlogget bruker må være administrator",
+    "Authentication" : "Autentisering",
     "Unknown filetype" : "Ukjent filtype",
     "Invalid image" : "Ugyldig bilde",
     "Avatar image is not square" : "Avatarbilde er ikke firkantet",
@@ -89,6 +90,8 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delings-server %s må implementere grensesnittet OCP\\Share_Backend",
     "Sharing backend %s not found" : "Delings-server %s ikke funnet",
     "Sharing backend for %s not found" : "Delings-server for %s ikke funnet",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med deg og vil legge til:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med deg og vil legge til",
     "»%s« added a note to a file shared with you" : "»%s« la til en melding til en fil delt med deg",
     "Open »%s«" : "Åpne »%s«",
     "%1$s via %2$s" : "%1$s via %2$s",
