@@ -66,6 +66,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n minuta temu","%n minuty temu","%n minut temu","%n minut temu"],
     "in a few seconds" : "za kilka sekund",
     "seconds ago" : "przed chwilą",
+    "Empty file" : "Pusty plik",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Moduł o ID: %s nie istnieje. Włącz go w ustawieniach aplikacji lub skontaktuj się z administratorem.",
     "File name is a reserved word" : "Nazwa pliku jest zarezerwowana",
     "File name contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
@@ -174,6 +175,7 @@ OC.L10N.register(
     "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
     "Username contains whitespace at the beginning or at the end" : "Nazwa użytkownika zawiera spację na początku albo na końcu",
     "Username must not consist of dots only" : "Nazwa użytkownika nie może się składać tylko z kropek",
+    "Username is invalid because files already exist for this user" : "Nazwa użytkownika jest nieprawidłowa, ponieważ pliki już istnieją dla tego użytkownika",
     "A valid password must be provided" : "Należy podać prawidłowe hasło",
     "The username is already being used" : "Ta nazwa użytkownika jest już używana",
     "Could not create user" : "Nie można utworzyć użytkownika",
