@@ -24,6 +24,7 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "São suportadas as seguintes plataformas: %s",
     "Server version %s or higher is required." : "É necessária versão do servidor %s or superior. ",
     "Server version %s or lower is required." : "É necessária versão do servidor %s or inferior.",
+    "Authentication" : "Autenticação",
     "Unknown filetype" : "Tipo de ficheiro desconhecido",
     "Invalid image" : "Imagem inválida",
     "Avatar image is not square" : "A imagem do avatar não é quadrada.",
@@ -86,13 +87,19 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Ao partilhar a interface %s deve implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Não foi encontrada a partilha da interface %s",
     "Sharing backend for %s not found" : "Não foi encontrada a partilha da interface para %s",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
+    "»%s« added a note to a file shared with you" : "»%s« adicionou uma nota a um ficheiro partilhado consigo",
     "Open »%s«" : "Abrir »%s«",
+    "%1$s via %2$s" : "%1$s via %2$s",
     "You are not allowed to share %s" : "Não está autorizado a partilhar %s",
     "Can’t increase permissions of %s" : "Não é possível aumentar as permissões de %s",
     "Files can’t be shared with delete permissions" : "Ficheiros não podem ser partilhados com permissões de apagar",
     "Files can’t be shared with create permissions" : "Ficheiros não podem ser partilhados com permissões de criação",
     "Expiration date is in the past" : "A data de expiração está no passado",
     "Can’t set expiration date more than %s days in the future" : "Não é possível definir data de expiração a mais de %s dias no futuro",
+    "%1$s shared »%2$s« with you" : "%1$s partilhado »%2$s« contigo",
+    "%1$s shared »%2$s« with you." : "%1$s partilhado »%2$s« contigo.",
     "Click the button below to open it." : "Clicar no botão abaixo para abrir.",
     "The requested share does not exist anymore" : "A partilha requisitada já não existe",
     "Could not find category \"%s\"" : "Não foi encontrado a categoria \"%s\"",
@@ -191,6 +198,9 @@ OC.L10N.register(
     "Storage connection error. %s" : "Erro de ligação ao armazenamento. %s",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
     "Storage connection timeout. %s" : "Tempo de ligação ao armazenamento expirou. %s",
+    "Create" : "Criar",
+    "Delete" : "Apagar",
+    "Share" : "Partilhar",
     "Unlimited" : "Ilimitado",
     "Verifying" : "A verificar",
     "Verifying …" : "A verificar...",
