@@ -17,6 +17,7 @@ OC.L10N.register(
     "The command line tool %s could not be found" : "Unealta în linie de comandă %s nu a fost găsită",
     "The library %s is not available." : "Biblioteca %s nu este disponibilă.",
     "Following platforms are supported: %s" : "Sunt suportate următoarele platforme: %s",
+    "Authentication" : "Autentificare",
     "Unknown filetype" : "Tip fișier necunoscut",
     "Invalid image" : "Imagine invalidă",
     "today" : "astăzi",
@@ -32,7 +33,7 @@ OC.L10N.register(
     "in a few seconds" : "în câteva secunde",
     "seconds ago" : "secunde în urmă",
     "File name is a reserved word" : "Numele fișierului este un cuvânt rezervat",
-    "File name contains at least one invalid character" : "Numele fișierului conține măcar un caracter invalid",
+    "File name contains at least one invalid character" : "Numele fișierului conține cel puțin un caracter invalid",
     "File name is too long" : "Numele fișierului este prea lung",
     "Dot files are not allowed" : "Fișierele care încep cu caracterul punct nu sunt permise",
     "Empty filename is not allowed" : "Nu este permis fișier fără nume",
@@ -58,9 +59,14 @@ OC.L10N.register(
     "Set an admin username." : "Setează un nume de administrator.",
     "Set an admin password." : "Setează o parolă de administrator.",
     "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
+    "»%s« added a note to a file shared with you" : "%s« a adaugat un comentariu la un fișier partajat cu tine",
+    "Open »%s«" : "Deschide »%s«",
+    "%1$s via %2$s" : "%1$sprin %2$s",
     "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
     "Files can’t be shared with delete permissions" : "Fișierele nu pot fi partajate cu permisiuni de ștergere",
     "Expiration date is in the past" : "Data expirării este în trecut",
+    "%1$s shared »%2$s« with you." : "%1$sa partajat »%2$s« cu tine.",
+    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
     "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
     "Sunday" : "Duminică",
     "Monday" : "Luni",
@@ -125,6 +131,12 @@ OC.L10N.register(
     "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
     "PostgreSQL >= 9 required" : "Este necesară versiunea 9 sau mai mare a PostgreSQL",
     "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă",
+    "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
+    "Create" : "Creează",
+    "Delete" : "Șterge",
+    "Share" : "Partajează",
+    "Unlimited" : "Nelimitată",
+    "Verifying" : "Se verifică",
     "Verifying …" : "Se verifică ...",
     "Verify" : "Verifică",
     "Sharing %s failed, because the file does not exist" : "Partajarea %s a eșuat deoarece fișierul nu există",
