@@ -87,9 +87,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
     "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
     "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
+    "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
     "Open »%s«" : "Odpri »%s«",
+    "%1$s via %2$s" : "%1$s prek %2$s",
     "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
     "Expiration date is in the past" : "Datum preteka je že mimo!",
+    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
     "Could not find category \"%s\"" : "Kategorije »%s« ni mogoče najti.",
     "Sunday" : "nedelja",
     "Monday" : "ponedeljek",
@@ -180,6 +183,7 @@ OC.L10N.register(
     "Create" : "Ustvari",
     "Change" : "Spremeni",
     "Delete" : "Izbriši",
+    "Share" : "Souporaba",
     "Unlimited" : "Neomejeno",
     "Verifying" : "Overjanje",
     "Verifying …" : "Poteka overjanje ...",
