@@ -24,6 +24,7 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Mbulohen platformat vijuese: %s",
     "Server version %s or higher is required." : "Versioni i serverit kërkohet %s ose më lartë",
     "Server version %s or lower is required." : "Versioni i serverit kërkohet %s ose më poshtë",
+    "Authentication" : "Mirëfilltësim",
     "Unknown filetype" : "Lloj i panjohur skedari",
     "Invalid image" : "Figurë e pavlefshme",
     "Avatar image is not square" : "Imazhi avatar nuk është katror",
@@ -181,6 +182,10 @@ OC.L10N.register(
     "Storage connection error. %s" : "Gabim lidhje te depozita. %s",
     "Storage is temporarily not available" : "Hapsira ruajtëse nuk është në dispozicion përkohësisht",
     "Storage connection timeout. %s" : "Mbarim kohe lidhjeje për depozitën. %s",
+    "Create" : "Krijo",
+    "Change" : "Ndrysho",
+    "Delete" : "Delete",
+    "Share" : "Shpërndaje",
     "Unlimited" : "E palimituar",
     "Verifying" : "Duke e verifikuar",
     "Verifying …" : "Duke e verifikuar ...",
