@@ -66,6 +66,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["пре %n минут","пре %n минута","пре %n минута"],
     "in a few seconds" : "за пар секунди",
     "seconds ago" : "пре неколико секунди",
+    "Empty file" : "Празан фајл",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул са идентификацијом: %s не постоји. Омогућите га у подешавањима апликација или контактирајте администратора.",
     "File name is a reserved word" : "Назив фајла је резервисана реч",
     "File name contains at least one invalid character" : "Назив фајла садржи бар један недозвољен знак",
@@ -174,6 +175,7 @@ OC.L10N.register(
     "A valid username must be provided" : "Морате унети исправно корисничко име",
     "Username contains whitespace at the beginning or at the end" : "Корисничко име садржи белине на почетку или на крају",
     "Username must not consist of dots only" : "Корисничко име не могу бити само тачке",
+    "Username is invalid because files already exist for this user" : "Корисничко име није исправно пошто већ постоје фајлови за овог корисника",
     "A valid password must be provided" : "Морате унети исправну лозинку",
     "The username is already being used" : "Корисничко име се већ користи",
     "Could not create user" : "Не могу да направим корисника",
