@@ -14,10 +14,10 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s och %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s och %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s och %5$s",
-    "Education Edition" : "Utbildningspaketet",
+    "Education Edition" : "Utbildningspaket",
     "Enterprise bundle" : "Företagspaketet",
-    "Groupware bundle" : "Groupwarepaket",
-    "Social sharing bundle" : "Kommunikationspaketet ",
+    "Groupware bundle" : "Gruppvarupaket",
+    "Social sharing bundle" : "Kommunikationspaket",
     "PHP %s or higher is required." : "PHP %s eller högre krävs.",
     "PHP with a version lower than %s is required." : "PHP med version lägre än %s krävs.",
     "%sbit or higher PHP required." : "%sbit eller nyare PHP-version krävs.",
@@ -66,14 +66,15 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n minut sedan","%n minuter sedan"],
     "in a few seconds" : "om några sekunder",
     "seconds ago" : "sekunder sedan",
+    "Empty file" : "Tom fil",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med ID: %s finns inte längre. Vänligen aktivera det i dina appinställningar eller kontakta din administratör.",
     "File name is a reserved word" : "Filnamnet är ett reserverat ord",
     "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
     "File name is too long" : "Filnamnet är för långt",
     "Dot files are not allowed" : "Dot-filer är inte tillåtna",
     "Empty filename is not allowed" : "Tomma filnamn är inte tillåtna",
-    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Applikationen \"%s\" kan ej installeras eftersom informationen från appen ej kunde läsas.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Applikationen \"%s\" kan ej installeras eftersom den inte är kompatibel med denna serverversion.",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan inte installeras eftersom appinfo-filen inte kan läsas.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan inte installeras eftersom den inte är kompatibel med den här versionen av servern.",
     "__language_name__" : "Svenska",
     "This is an automatically sent email, please do not reply." : "Detta är ett automatiskt skickat e-postmeddelande, svara inte på detta meddelande.",
     "Help" : "Hjälp",
@@ -183,7 +184,7 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan inte installeras eftersom följande beroenden inte är uppfyllda: %2$s",
     "a safe home for all your data" : "ett säkert hem för alla dina data",
     "File is currently busy, please try again later" : "Filen är för tillfället upptagen, vänligen försök igen senare",
-    "Can't read file" : "Kan ej läsa filen",
+    "Can't read file" : "Kan inte läsa filen",
     "Application is not enabled" : "Applikationen är inte aktiverad",
     "Authentication error" : "Fel vid autentisering",
     "Token expired. Please reload page." : "Token har löpt ut. Vänligen uppdatera sidan.",
@@ -215,14 +216,14 @@ OC.L10N.register(
     "Your data directory must be an absolute path" : "Du måste specificera en korrekt sökväg till datamappen",
     "Check the value of \"datadirectory\" in your configuration" : "Kontrollera värdet av \"datakatalog\" i din konfiguration",
     "Your data directory is invalid" : "Din datamapp är ogiltig",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för din data.",
-    "Action \"%s\" not supported or implemented." : "Åtgärd \"%s\" stöds ej eller är inte implementerad.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för dina data.",
+    "Action \"%s\" not supported or implemented." : "Åtgärd \"%s\" stöds inte eller är inte implementerad.",
     "Authentication failed, wrong token or provider ID given" : "Autentisering misslyckades, felaktig token eller leverantörs-ID",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametrar saknas för att slutföra förfrågan. Saknade parametrar: \"%s\"",
     "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" används redan av moln - federationsleverantör \"%2$s\"",
     "Cloud Federation Provider with ID: \"%s\" does not exist." : "Moln - federationsleverantör med ID: \"%s\" finns inte.",
     "Could not obtain lock type %d on \"%s\"." : "Kunde inte hämta låstyp %d på \"%s\".",
-    "Storage unauthorized. %s" : "Lagringsutrymme ej tillåtet. %s",
+    "Storage unauthorized. %s" : "Lagring obehörig. %s",
     "Storage incomplete configuration. %s" : "Lagringsutrymme felaktigt inställt. %s",
     "Storage connection error. %s" : "Lagringsutrymme lyckas inte ansluta. %s",
     "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
@@ -246,7 +247,7 @@ OC.L10N.register(
     "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Delning %1$s misslyckades för att %2$s är inte medlem i gruppen %3$s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Du måste ange ett lösenord för att skapa en offentlig länk, endast skyddade länkar är tillåtna",
     "Sharing %s failed, because sharing with links is not allowed" : "Delning %s misslyckades därför att delning av länkar inte är tillåtet",
-    "Not allowed to create a federated share with the same user" : "Ej tillåtet att skapa en federerad delning med samma användare",
+    "Not allowed to create a federated share with the same user" : "Inte tillåtet att skapa en federerad delning med samma användare",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Delning %1$s misslyckades, kan inte hitta %2$s, servern är kanske inte åtkomlig för närvarande.",
     "Share type %1$s is not valid for %2$s" : "Delningstyp %1$s är inte giltig för %2$s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan inte sätta utgångsdatum. Utdelningar kan inte utgå senare än %s efter de har delats ut",
