@@ -13,6 +13,7 @@ OC.L10N.register(
     "The command line tool %s could not be found" : "ไม่พบเครื่องมือบรรทัดคำสั่ง %s ",
     "The library %s is not available." : "ไลบรารี %s ไม่สามารถใช้ได้",
     "Following platforms are supported: %s" : "แพลตฟอร์มต่อไปนี้ได้รับการสนับสนุน: %s",
+    "Authentication" : "รับรองความถูกต้อง",
     "Unknown filetype" : "ไม่รู้จักชนิดของไฟล์",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
     "today" : "วันนี้",
@@ -32,9 +33,14 @@ OC.L10N.register(
     "Empty filename is not allowed" : "ชื่อไฟล์ห้ามว่างเปล่า",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "แอพฯ \"%s\" ไม่สามารถติดตั้งได้เพราะไฟล์ appInfo ไม่สามารถอ่านได้",
     "__language_name__" : "ภาษาไทย - Thai languages",
+    "Help" : "ช่วยเหลือ",
     "Apps" : "แอปฯ",
+    "Settings" : "ตั้งค่า",
+    "Log out" : "ออกจากระบบ",
     "Users" : "ผู้ใช้งาน",
     "Unknown user" : "ไม่รู้จักผู้ใช้",
+    "Sharing" : "แชร์ข้อมูล",
+    "Personal info" : "ข้อมูลส่วนบุคคล",
     "%s enter the database username and name." : "%s ป้อนชื่อผู้ใช้ฐานข้อมูล และชื่อ",
     "%s enter the database username." : "%s ใส่ชื่อผู้ใช้ฐานข้อมูล",
     "%s enter the database name." : "%s ใส่ชื่อฐานข้อมูล",
@@ -56,6 +62,51 @@ OC.L10N.register(
     "You are not allowed to share %s" : "คุณยังไม่ได้รับอนุญาตให้แชร์ %s",
     "Expiration date is in the past" : "วันหมดอายุอยู่ในอดีตที่ผ่านมา",
     "Could not find category \"%s\"" : "ไม่พบหมวดหมู่ \"%s\"",
+    "Sunday" : "วันอาทิตย์",
+    "Monday" : "วันจันทร์",
+    "Tuesday" : "วันอังคาร",
+    "Wednesday" : "วันพุธ",
+    "Thursday" : "วันพฤหัสบดี",
+    "Friday" : "วันศุกร์",
+    "Saturday" : "วันเสาร์",
+    "Sun." : "อา.",
+    "Mon." : "จ.",
+    "Tue." : "อ.",
+    "Wed." : "พ.",
+    "Thu." : "พฤ.",
+    "Fri." : "ศ.",
+    "Sat." : "ส.",
+    "Su" : "อา",
+    "Mo" : "จัน",
+    "Tu" : "อัง",
+    "We" : "พุธ",
+    "Th" : "พฤ",
+    "Fr" : "ศุก",
+    "Sa" : "เสา",
+    "January" : "มกราคม",
+    "February" : "กุมภาพันธ์",
+    "March" : "มีนาคม",
+    "April" : "เมษายน",
+    "May" : "พฤษภาคม",
+    "June" : "มิถุนายน",
+    "July" : "กรกฏาคม",
+    "August" : "สิงหาคม",
+    "September" : "กันยายน",
+    "October" : "ตุลาคม",
+    "November" : "พฤศจิกายน",
+    "December" : "ธันวาคม",
+    "Jan." : "ม.ค.",
+    "Feb." : "ก.พ.",
+    "Mar." : "มี.ค.",
+    "Apr." : "เม.ย.",
+    "May." : "พ.ค.",
+    "Jun." : "มิ.ย.",
+    "Jul." : "ก.ค.",
+    "Aug." : "ส.ค.",
+    "Sep." : "ก.ย.",
+    "Oct." : "ต.ค.",
+    "Nov." : "พ.ย.",
+    "Dec." : "ธ.ค.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ชื่อผู้ใช้จะใช้ได้แค่อักษรดังต่อไปนี้: \"a-z\", \"A-Z\", \"0-9\" และ \"_.@-'\"",
     "A valid username must be provided" : "จะต้องระบุชื่อผู้ใช้ที่ถูกต้อง",
     "A valid password must be provided" : "รหัสผ่านที่ถูกต้องจะต้องให้",
@@ -89,6 +140,10 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "การตั้งค่าการจัดเก็บข้อมูลไม่สำเร็จ %s",
     "Storage connection error. %s" : "ข้อผิดพลาดการเชื่อมต่อพื้นที่จัดเก็บข้อมูล %s",
     "Storage connection timeout. %s" : "หมดเวลาการเชื่อมต่อพื้นที่จัดเก็บข้อมูล %s",
+    "Create" : "สร้าง",
+    "Delete" : "ลบ",
+    "Share" : "แชร์",
+    "Unlimited" : "ไม่จำกัด",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "การแชร์ %s ล้มเหลวเพราะแบ็กเอนด์ไม่อนุญาตให้แชร์จากไฟล์ประเภท %i",
     "Sharing %s failed, because the file does not exist" : "การแชร์ %s ล้มเหลวเพราะไม่มีไฟล์นี้อยู่",
     "Sharing %s failed, because you can not share with yourself" : "การแขร์ %s ล้มเหลวเพราะคุณไม่สามารถแชร์ให้กับตัวเอง",
