@@ -12,6 +12,7 @@ OC.L10N.register(
     "The command line tool %s could not be found" : "Утиліту командного рядка %s не знайдено",
     "The library %s is not available." : "Бібліотека %s недоступна.",
     "Following platforms are supported: %s" : "Підтримуються наступні платформи: %s",
+    "Authentication" : "Автентифікація",
     "Unknown filetype" : "Невідомий тип файлу",
     "Invalid image" : "Невірне зображення",
     "today" : "сьогодні",
@@ -28,9 +29,15 @@ OC.L10N.register(
     "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Додаток \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
     "__language_name__" : "Українська",
+    "Help" : "Допомога",
     "Apps" : "Додатки",
+    "Settings" : "Налаштування",
+    "Log out" : "Вихід",
     "Users" : "Користувачі",
     "Unknown user" : "Невідомий користувач",
+    "Sharing" : "Поділитись",
+    "Security" : "Безпека",
+    "Personal info" : "Особиста інформація",
     "%s enter the database username and name." : "%s введіть назву бази даних та ім'я користувача.",
     "%s enter the database username." : "%s введіть ім'я користувача бази даних.",
     "%s enter the database name." : "%s введіть назву бази даних.",
@@ -50,6 +57,7 @@ OC.L10N.register(
     "Sharing backend %s not found" : "Backend загального доступу %s не знайдено",
     "Sharing backend for %s not found" : "Бекенд загального доступу для %s не знайдено",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав Вам доступ »%2$s« та хоче додати:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав Вам доступ »%2$s« та хоче додати",
     "»%s« added a note to a file shared with you" : "»%s« додав нотатку до опублікованого файлу",
     "You are not allowed to share %s" : "Вам заборонено поширювати %s",
     "Expiration date is in the past" : "Дата закінчення в минулому",
@@ -57,6 +65,51 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s надав Вам доступ до »%2$s«.",
     "Click the button below to open it." : "Для відкриття натисніть кнопку нижче.",
     "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
+    "Sunday" : "Неділя",
+    "Monday" : "Понеділок",
+    "Tuesday" : "Вівторок",
+    "Wednesday" : "Середа",
+    "Thursday" : "Четвер",
+    "Friday" : "П'ятниця",
+    "Saturday" : "Субота",
+    "Sun." : "Нд.",
+    "Mon." : "Пн.",
+    "Tue." : "Вт.",
+    "Wed." : "Ср.",
+    "Thu." : "Чт.",
+    "Fri." : "Пт.",
+    "Sat." : "Сб.",
+    "Su" : "Нд.",
+    "Mo" : "Пн.",
+    "Tu" : "Вт.",
+    "We" : "Ср.",
+    "Th" : "Чт.",
+    "Fr" : "Пт.",
+    "Sa" : "Сб.",
+    "January" : "Січень",
+    "February" : "Лютий",
+    "March" : "Березень",
+    "April" : "Квітень",
+    "May" : "Травень",
+    "June" : "Червень",
+    "July" : "Липень",
+    "August" : "Серпень",
+    "September" : "Вересень",
+    "October" : "Жовтень",
+    "November" : "Листопад",
+    "December" : "Грудень",
+    "Jan." : "Січ.",
+    "Feb." : "Лют.",
+    "Mar." : "Бер.",
+    "Apr." : "Кві.",
+    "May." : "Тра.",
+    "Jun." : "Чер.",
+    "Jul." : "Лип.",
+    "Aug." : "Сер.",
+    "Sep." : "Вер.",
+    "Oct." : "Жов.",
+    "Nov." : "Лис.",
+    "Dec." : "Гру.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Тільки такі символи допускаються в імені користувача: \"a-z\", \"A-Z\", \"0-9\", і \"_.@-'\"",
     "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
     "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
@@ -64,6 +117,7 @@ OC.L10N.register(
     "The username is already being used" : "Ім'я користувача вже використовується",
     "User disabled" : "Користувач виключений",
     "Login canceled by app" : "Вхід скасовано додатком",
+    "a safe home for all your data" : "безпечний дім для ваших даних",
     "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
     "Can't read file" : "Не можливо прочитати файл",
     "Application is not enabled" : "Додаток не увімкнений",
@@ -85,6 +139,7 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
     "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
+    "PostgreSQL >= 9 required" : "Потрібно PostgreSQL> = 9",
     "Please upgrade your database version" : "Оновіть версію бази даних",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
     "Check the value of \"datadirectory\" in your configuration" : "Перевірте значення \"datadirectory\" у своїй конфігурації",
@@ -92,33 +147,23 @@ OC.L10N.register(
     "Storage unauthorized. %s" : "Сховище не авторизовано. %s",
     "Storage incomplete configuration. %s" : "Неповна конфігурація сховища. %s",
     "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
+    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
     "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "Потрібна бібліотека %s версії не більше %s, встановлена версія %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Потрібна бібліотека %s версії менш ніж %s, встановлена версія %s.",
+    "Create" : "Створити",
+    "Delete" : "Видалити",
+    "Share" : "Поділитися",
+    "Unlimited" : "Необмежено",
+    "Verifying …" : "Перевірка ...",
+    "Verify" : "Перевірити",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Не вдалося поділитися %s, загальний доступ не допускає публікації з елементів типу %i",
     "Sharing %s failed, because the file does not exist" : "Не вдалося поділитися %s, оскільки файл не існує",
     "Sharing %s failed, because you can not share with yourself" : "Не вдалося поділитися %s, оскільки ви не можете ділитись самі з собою",
-    "Sharing %s failed, because the user %s does not exist" : "Не вдалося поділитися з %s, оскільки користувач %s не існує",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Не вдалося поділитися %s, оскільки користувач %s не є членом будь-якої групи в яку входить %s",
-    "Sharing %s failed, because this item is already shared with %s" : "Не вдалося поділитися %s, оскільки файл вже в загальному доступі з %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Не вдалося поділитися %s, оскільки %s вже має до нього доступ",
-    "Sharing %s failed, because the group %s does not exist" : "Не вдалося поділитися %s, оскільки група %s не існує",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Не вдалося поділитися %s, оскільки %s не є членом групи %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Вам необхідно задати пароль для створення публічного посилання. Дозволені лише захищені посилання",
     "Sharing %s failed, because sharing with links is not allowed" : "Не вдалося поділитися %s, оскільки публічний доступ через посилання заборонений",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Не вдалося поділитися %s, не вдалося знайти %s, можливо, сервер не доступний.",
-    "Share type %s is not valid for %s" : "Тип загального доступу %s неприпустимий для %s",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Неможливо встановити дату закінчення. Загальні ресурси не можуть застаріти пізніше %s з моменту їх публікації.",
     "Cannot set expiration date. Expiration date is in the past" : "Неможливо встановити дату закінчення. Дата закінчення в минулому.",
     "Sharing failed, because the user %s is the original sharer" : "Не вдалося поділитися, оскільки %s є тим хто поділився з самого початку",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Не вдалося поділитися %s, права перевищують надані права доступу %s",
     "Sharing %s failed, because resharing is not allowed" : "Не вдалося поділитися %s, перевідкриття доступу заборонено",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Не вдалося поділитися %s, backend загального доступу не знайшов шлях до %s",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Не вдалося поділитися %s, елемент не знайдено у файловому кеші.",
-    "%s shared »%s« with you" : "%s поділився »%s« з вами",
-    "%s shared »%s« with you." : "%s надав Вам доступ до »%s«.",
-    "%s via %s" : "%s за допомогою %s",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Додаток \"%s\" не може бути встановлений, так як наступні залежності не виконано: %s",
-    "PostgreSQL >= 9 required" : "Потрібно PostgreSQL> = 9"
+    "Sharing %s failed, because the file could not be found in the file cache" : "Не вдалося поділитися %s, елемент не знайдено у файловому кеші."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
