@@ -66,6 +66,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n 分钟前"],
     "in a few seconds" : "几秒钟内",
     "seconds ago" : "几秒前",
+    "Empty file" : "空文件",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "模块：%s不存在。请在 App 设置中开启或联系管理员。",
     "File name is a reserved word" : "文件名包含敏感字符",
     "File name contains at least one invalid character" : "文件名中存在至少一个非法字符",
@@ -79,7 +80,7 @@ OC.L10N.register(
     "Help" : "帮助",
     "Apps" : "应用",
     "Settings" : "设置",
-    "Log out" : "注销",
+    "Log out" : "登出",
     "Users" : "用户",
     "Unknown user" : "未知用户",
     "Overview" : "概览",
@@ -97,7 +98,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "不能建立甲骨文连接",
     "Oracle username and/or password not valid" : "Oracle 数据库用户名和/或密码无效",
     "PostgreSQL username and/or password not valid" : "PostgreSQL 数据库用户名和/或密码无效",
-    "You need to enter details of an existing account." : "您需要输入现有帐户的详细信息。",
+    "You need to enter details of an existing account." : "您需要输入现有账号的详细信息。",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X 不被支持并且 %s 在这个平台上无法正常工作。请自行承担风险！",
     "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起来这个 %s 实例运行在32位PHP环境中并且已在php.ini中配置open_basedir。这将在文件超过4GB时出现问题，我们极力反对这样做。",
@@ -120,8 +121,8 @@ OC.L10N.register(
     "Files can’t be shared with create permissions" : "无法共享有创建权限的文件",
     "Expiration date is in the past" : "到期日期已过",
     "Can’t set expiration date more than %s days in the future" : "无法将过期日期设置为超过 %s 天。",
-    "%1$s shared »%2$s« with you" : "%1$s 与您分享了 »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s 与您分享了 »%2$s«。",
+    "%1$s shared »%2$s« with you" : "%1$s 对您共享了 »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s 对您共享了 »%2$s«。",
     "Click the button below to open it." : "点击下方按钮可打开它。",
     "The requested share does not exist anymore" : "当前请求的共享已经不存在",
     "Could not find category \"%s\"" : "无法找到分类 \"%s\"",
@@ -174,6 +175,7 @@ OC.L10N.register(
     "A valid username must be provided" : "必须提供合法的用户名",
     "Username contains whitespace at the beginning or at the end" : "用户名在开头或结尾处包含空格",
     "Username must not consist of dots only" : "用户名不能仅由点组成",
+    "Username is invalid because files already exist for this user" : "用户名无效，因为该用户已经存在文件",
     "A valid password must be provided" : "必须提供合法的密码",
     "The username is already being used" : "用户名已被使用",
     "Could not create user" : "无法创建用户",
