@@ -3,6 +3,9 @@
  * @copyright Copyright (c) 2017 Arthur Schiwon <blizzz@arthur-schiwon.de>
  *
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
+ * @author Joas Schilling <coding@schilljs.com>
+ * @author Julius Härtl <jus@bitgrid.net>
+ * @author Tobia De Koninck <tobia@ledfan.be>
  *
  * @license GNU AGPL version 3 or any later version
  *
@@ -17,7 +20,7 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -84,11 +87,17 @@ class MailPlugin implements ISearchPlugin {
 		foreach ($addressBookContacts as $contact) {
 			if (isset($contact['EMAIL'])) {
 				$emailAddresses = $contact['EMAIL'];
-				if (!is_array($emailAddresses)) {
+				if (\is_string($emailAddresses)) {
 					$emailAddresses = [$emailAddresses];
 				}
-				foreach ($emailAddresses as $emailAddress) {
+				foreach ($emailAddresses as $type => $emailAddress) {
 					$displayName = $emailAddress;
+					$emailAddressType = null;
+					if (\is_array($emailAddress)) {
+						$emailAddressData = $emailAddress;
+						$emailAddress = $emailAddressData['value'];
+						$emailAddressType = $emailAddressData['type'];
+					}
 					if (isset($contact['FN'])) 	{
 						$displayName = $contact['FN'] . ' (' . $emailAddress . ')';
 					}
@@ -121,6 +130,8 @@ class MailPlugin implements ISearchPlugin {
 							if (!$this->isCurrentUser($cloud) && !$searchResult->hasResult($userType, $cloud->getUser())) {
 								$singleResult = [[
 									'label' => $displayName,
+									'uuid' => $contact['UID'],
+									'name' => $contact['FN'],
 									'value' => [
 										'shareType' => Share::SHARE_TYPE_USER,
 										'shareWith' => $cloud->getUser(),
@@ -142,6 +153,8 @@ class MailPlugin implements ISearchPlugin {
 							if (!$this->isCurrentUser($cloud) && !$searchResult->hasResult($userType, $cloud->getUser())) {
 								$userResults['wide'][] = [
 									'label' => $displayName,
+									'uuid' => $contact['UID'],
+									'name' => $contact['FN'],
 									'value' => [
 										'shareType' => Share::SHARE_TYPE_USER,
 										'shareWith' => $cloud->getUser(),
@@ -160,6 +173,9 @@ class MailPlugin implements ISearchPlugin {
 						}
 						$result['exact'][] = [
 							'label' => $displayName,
+							'uuid' => $contact['UID'],
+							'name' => $contact['FN'],
+							'type' => $emailAddressType ?? '',
 							'value' => [
 								'shareType' => Share::SHARE_TYPE_EMAIL,
 								'shareWith' => $emailAddress,
@@ -168,6 +184,9 @@ class MailPlugin implements ISearchPlugin {
 					} else {
 						$result['wide'][] = [
 							'label' => $displayName,
+							'uuid' => $contact['UID'],
+							'name' => $contact['FN'],
+							'type' => $emailAddressType ?? '',
 							'value' => [
 								'shareType' => Share::SHARE_TYPE_EMAIL,
 								'shareWith' => $emailAddress,
@@ -194,6 +213,7 @@ class MailPlugin implements ISearchPlugin {
 		if (!$searchResult->hasExactIdMatch($emailType) && filter_var($search, FILTER_VALIDATE_EMAIL)) {
 			$result['exact'][] = [
 				'label' => $search,
+				'uuid' => $search,
 				'value' => [
 					'shareType' => Share::SHARE_TYPE_EMAIL,
 					'shareWith' => $search,
