@@ -22,7 +22,7 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
 
@@ -249,9 +249,7 @@ class CertificateManager implements ICertificateManager {
 		if ($uid === '') {
 			$uid = $this->uid;
 		}
-		$path = is_null($uid) ? '/files_external/' : '/' . $uid . '/files_external/';
-
-		return $path;
+		return is_null($uid) ? '/files_external/' : '/' . $uid . '/files_external/';
 	}
 
 	/**
