@@ -5,8 +5,12 @@
  * @author Andrius <andrius.kulbis@ktu.lt>
  * @author Bjoern Schiessle <bjoern@schiessle.org>
  * @author Björn Schießle <bjoern@schiessle.org>
+ * @author Daniel Calviño Sánchez <danxuliu@gmail.com>
  * @author Jan-Philipp Litza <jplitza@users.noreply.github.com>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Julius Härtl <jus@bitgrid.net>
+ * @author Lukas Reschke <lukas@statuscode.ch>
+ * @author Maxence Lange <maxence@artificial-owl.com>
  * @author phisch <git@philippschaffrath.de>
  * @author Robin Appelman <robin@icewind.nl>
  * @author Roeland Jago Douma <roeland@famdouma.nl>
@@ -24,32 +28,33 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
+
 namespace OC\Share20;
 
 use OC\Files\Cache\Cache;
+use OC\Share20\Exception\BackendError;
+use OC\Share20\Exception\InvalidShare;
+use OC\Share20\Exception\ProviderException;
+use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\Defaults;
 use OCP\Files\Folder;
+use OCP\Files\IRootFolder;
+use OCP\Files\Node;
+use OCP\IDBConnection;
+use OCP\IGroup;
+use OCP\IGroupManager;
 use OCP\IL10N;
 use OCP\IURLGenerator;
 use OCP\IUser;
+use OCP\IUserManager;
 use OCP\Mail\IMailer;
+use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IShare;
 use OCP\Share\IShareHelper;
 use OCP\Share\IShareProvider;
-use OC\Share20\Exception\InvalidShare;
-use OC\Share20\Exception\ProviderException;
-use OCP\Share\Exceptions\ShareNotFound;
-use OC\Share20\Exception\BackendError;
-use OCP\DB\QueryBuilder\IQueryBuilder;
-use OCP\IGroup;
-use OCP\IGroupManager;
-use OCP\IUserManager;
-use OCP\Files\IRootFolder;
-use OCP\IDBConnection;
-use OCP\Files\Node;
 
 /**
  * Class DefaultShareProvider
@@ -142,9 +147,20 @@ class DefaultShareProvider implements IShareProvider {
 		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_USER) {
 			//Set the UID of the user we share with
 			$qb->setValue('share_with', $qb->createNamedParameter($share->getSharedWith()));
+			$qb->setValue('accepted', $qb->createNamedParameter(IShare::STATUS_PENDING));
+
+			//If an expiration date is set store it
+			if ($share->getExpirationDate() !== null) {
+				$qb->setValue('expiration', $qb->createNamedParameter($share->getExpirationDate(), 'datetime'));
+			}
 		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
 			//Set the GID of the group we share with
 			$qb->setValue('share_with', $qb->createNamedParameter($share->getSharedWith()));
+
+			//If an expiration date is set store it
+			if ($share->getExpirationDate() !== null) {
+				$qb->setValue('expiration', $qb->createNamedParameter($share->getExpirationDate(), 'datetime'));
+			}
 		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
 			//set label for public link
 			$qb->setValue('label', $qb->createNamedParameter($share->getLabel()));
@@ -252,6 +268,7 @@ class DefaultShareProvider implements IShareProvider {
 				->set('file_source', $qb->createNamedParameter($share->getNode()->getId()))
 				->set('expiration', $qb->createNamedParameter($share->getExpirationDate(), IQueryBuilder::PARAM_DATE))
 				->set('note', $qb->createNamedParameter($share->getNote()))
+				->set('accepted', $qb->createNamedParameter($share->getStatus()))
 				->execute();
 		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
 			$qb = $this->dbConn->getQueryBuilder();
@@ -318,6 +335,72 @@ class DefaultShareProvider implements IShareProvider {
 		return $share;
 	}
 
+	/**
+	 * Accept a share.
+	 *
+	 * @param IShare $share
+	 * @param string $recipient
+	 * @return IShare The share object
+	 * @since 9.0.0
+	 */
+	public function acceptShare(IShare $share, string $recipient): IShare {
+		if ($share->getShareType() === IShare::TYPE_GROUP) {
+			$group = $this->groupManager->get($share->getSharedWith());
+			$user = $this->userManager->get($recipient);
+
+			if (is_null($group)) {
+				throw new ProviderException('Group "' . $share->getSharedWith() . '" does not exist');
+			}
+
+			if (!$group->inGroup($user)) {
+				throw new ProviderException('Recipient not in receiving group');
+			}
+
+			// Try to fetch user specific share
+			$qb = $this->dbConn->getQueryBuilder();
+			$stmt = $qb->select('*')
+				->from('share')
+				->where($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_USERGROUP)))
+				->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($recipient)))
+				->andWhere($qb->expr()->eq('parent', $qb->createNamedParameter($share->getId())))
+				->andWhere($qb->expr()->orX(
+					$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
+					$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
+				))
+				->execute();
+
+			$data = $stmt->fetch();
+			$stmt->closeCursor();
+
+			/*
+			 * Check if there already is a user specific group share.
+			 * If there is update it (if required).
+			 */
+			if ($data === false) {
+				$id = $this->createUserSpecificGroupShare($share, $recipient);
+			} else {
+				$id = $data['id'];
+			}
+
+		} else if ($share->getShareType() === IShare::TYPE_USER) {
+			if ($share->getSharedWith() !== $recipient) {
+				throw new ProviderException('Recipient does not match');
+			}
+
+			$id = $share->getId();
+		} else {
+			throw new ProviderException('Invalid shareType');
+		}
+
+		$qb = $this->dbConn->getQueryBuilder();
+		$qb->update('share')
+			->set('accepted', $qb->createNamedParameter(IShare::STATUS_ACCEPTED))
+			->where($qb->expr()->eq('id', $qb->createNamedParameter($id)))
+			->execute();
+
+		return $share;
+	}
+
 	/**
 	 * Get all children of this share
 	 * FIXME: remove once https://github.com/owncloud/core/pull/21660 is in
@@ -382,13 +465,13 @@ class DefaultShareProvider implements IShareProvider {
 	 * Unshare a share from the recipient. If this is a group share
 	 * this means we need a special entry in the share db.
 	 *
-	 * @param \OCP\Share\IShare $share
+	 * @param IShare $share
 	 * @param string $recipient UserId of recipient
 	 * @throws BackendError
 	 * @throws ProviderException
 	 */
-	public function deleteFromSelf(\OCP\Share\IShare $share, $recipient) {
-		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
+	public function deleteFromSelf(IShare $share, $recipient) {
+		if ($share->getShareType() === IShare::TYPE_GROUP) {
 
 			$group = $this->groupManager->get($share->getSharedWith());
 			$user = $this->userManager->get($recipient);
@@ -421,37 +504,23 @@ class DefaultShareProvider implements IShareProvider {
 			 * If there is update it (if required).
 			 */
 			if ($data === false) {
-				$qb = $this->dbConn->getQueryBuilder();
-
-				$type = $share->getNodeType();
-
-				//Insert new share
-				$qb->insert('share')
-					->values([
-						'share_type' => $qb->createNamedParameter(self::SHARE_TYPE_USERGROUP),
-						'share_with' => $qb->createNamedParameter($recipient),
-						'uid_owner' => $qb->createNamedParameter($share->getShareOwner()),
-						'uid_initiator' => $qb->createNamedParameter($share->getSharedBy()),
-						'parent' => $qb->createNamedParameter($share->getId()),
-						'item_type' => $qb->createNamedParameter($type),
-						'item_source' => $qb->createNamedParameter($share->getNodeId()),
-						'file_source' => $qb->createNamedParameter($share->getNodeId()),
-						'file_target' => $qb->createNamedParameter($share->getTarget()),
-						'permissions' => $qb->createNamedParameter(0),
-						'stime' => $qb->createNamedParameter($share->getShareTime()->getTimestamp()),
-					])->execute();
-
-			} else if ($data['permissions'] !== 0) {
+				$id = $this->createUserSpecificGroupShare($share, $recipient);
+				$permissions = $share->getPermissions();
+			} else {
+				$permissions = $data['permissions'];
+				$id = $data['id'];
+			}
 
+			if ($permissions !== 0) {
 				// Update existing usergroup share
 				$qb = $this->dbConn->getQueryBuilder();
 				$qb->update('share')
 					->set('permissions', $qb->createNamedParameter(0))
-					->where($qb->expr()->eq('id', $qb->createNamedParameter($data['id'])))
+					->where($qb->expr()->eq('id', $qb->createNamedParameter($id)))
 					->execute();
 			}
 
-		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_USER) {
+		} else if ($share->getShareType() === IShare::TYPE_USER) {
 
 			if ($share->getSharedWith() !== $recipient) {
 				throw new ProviderException('Recipient does not match');
@@ -464,6 +533,28 @@ class DefaultShareProvider implements IShareProvider {
 		}
 	}
 
+	protected function createUserSpecificGroupShare(IShare $share, string $recipient): int {
+		$type = $share->getNodeType();
+
+		$qb = $this->dbConn->getQueryBuilder();
+		$qb->insert('share')
+			->values([
+				'share_type' => $qb->createNamedParameter(self::SHARE_TYPE_USERGROUP),
+				'share_with' => $qb->createNamedParameter($recipient),
+				'uid_owner' => $qb->createNamedParameter($share->getShareOwner()),
+				'uid_initiator' => $qb->createNamedParameter($share->getSharedBy()),
+				'parent' => $qb->createNamedParameter($share->getId()),
+				'item_type' => $qb->createNamedParameter($type),
+				'item_source' => $qb->createNamedParameter($share->getNodeId()),
+				'file_source' => $qb->createNamedParameter($share->getNodeId()),
+				'file_target' => $qb->createNamedParameter($share->getTarget()),
+				'permissions' => $qb->createNamedParameter($share->getPermissions()),
+				'stime' => $qb->createNamedParameter($share->getShareTime()->getTimestamp()),
+			])->execute();
+
+		return $qb->getLastInsertId();
+	}
+
 	/**
 	 * @inheritdoc
 	 *
@@ -932,6 +1023,7 @@ class DefaultShareProvider implements IShareProvider {
 			->setTarget($data['file_target'])
 			->setNote($data['note'])
 			->setMailSend((bool)$data['mail_send'])
+			->setStatus((int)$data['accepted'])
 			->setLabel($data['label']);
 
 		$shareTime = new \DateTime();
@@ -940,6 +1032,10 @@ class DefaultShareProvider implements IShareProvider {
 
 		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_USER) {
 			$share->setSharedWith($data['share_with']);
+			$user = $this->userManager->get($data['share_with']);
+			if ($user !== null) {
+				$share->setSharedWithDisplayName($user->getDisplayName());
+			}
 		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
 			$share->setSharedWith($data['share_with']);
 		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
@@ -1016,6 +1112,7 @@ class DefaultShareProvider implements IShareProvider {
 
 			while($data = $stmt->fetch()) {
 				$shareMap[$data['parent']]->setPermissions((int)$data['permissions']);
+				$shareMap[$data['parent']]->setStatus((int)$data['accepted']);
 				$shareMap[$data['parent']]->setTarget($data['file_target']);
 				$shareMap[$data['parent']]->setParent($data['parent']);
 			}
@@ -1378,4 +1475,30 @@ class DefaultShareProvider implements IShareProvider {
 		}
 
 	}
+
+	public function getAllShares(): iterable {
+		$qb = $this->dbConn->getQueryBuilder();
+
+		$qb->select('*')
+			->from('share')
+			->where(
+				$qb->expr()->orX(
+					$qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share\IShare::TYPE_USER)),
+					$qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share\IShare::TYPE_GROUP)),
+					$qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share\IShare::TYPE_LINK))
+				)
+			);
+
+		$cursor = $qb->execute();
+		while($data = $cursor->fetch()) {
+			try {
+				$share = $this->createShare($data);
+			} catch (InvalidShare $e) {
+				continue;
+			}
+
+			yield $share;
+		}
+		$cursor->closeCursor();
+	}
 }
